@@ -352,7 +352,7 @@ angular.module('ambariAdminConsole')
             });
           }
         })
-        .catch(function (resp) {
+        .catch(function (data) {
           Alert.error($t('versions.alerts.readVersionInfoError'), data.message);
         });
       } else {
