@@ -60,31 +60,30 @@ angular.module('ambariAdminConsole')
       var url = Settings.baseUrl + '/stacks?fields=versions/*';
       var deferred = $q.defer();
       var sortFunction = this.sortByIdAsVersion;
-      $http.get(url, {mock: 'stack/allStackVersions.json'}).then(
-        function (resp) {
-          var data = resp.data;
-          var allStackVersions = [];
-          angular.forEach(data.items, function (stack) {
-            angular.forEach(stack.versions, function (version) {
-              var stack_name = version.Versions.stack_name;
-              var stack_version = version.Versions.stack_version;
-              var upgrade_packs = version.Versions.upgrade_packs;
-              var active = version.Versions.active;
-              allStackVersions.push({
-                id: stack_name + '-' + stack_version,
-                stack_name: stack_name,
-                stack_version: stack_version,
-                displayName: stack_name + '-' + stack_version,
-                upgrade_packs: upgrade_packs,
-                active: active
-              });
+      $http.get(url, {mock: 'stack/allStackVersions.json'})
+      .then(function (data) {
+        var allStackVersions = [];
+        angular.forEach(data.data.items, function (stack) {
+          angular.forEach(stack.versions, function (version) {
+            var stack_name = version.Versions.stack_name;
+            var stack_version = version.Versions.stack_version;
+            var upgrade_packs = version.Versions.upgrade_packs;
+            var active = version.Versions.active;
+            allStackVersions.push({
+              id: stack_name + '-' + stack_version,
+              stack_name: stack_name,
+              stack_version: stack_version,
+              displayName: stack_name + '-' + stack_version,
+              upgrade_packs: upgrade_packs,
+              active: active
             });
           });
-          deferred.resolve(allStackVersions.sort(sortFunction));
-        }, function (resp) {
-          deferred.reject(resp.data);
-        }
-      );
+        });
+        deferred.resolve(allStackVersions.sort(sortFunction));
+      })
+      .catch(function (data) {
+        deferred.reject(data);
+      });
       return deferred.promise;
     },
 
@@ -92,12 +91,12 @@ angular.module('ambariAdminConsole')
       var deferred = $q.defer();
 
       $http.get(Settings.baseUrl + '/services/AMBARI/components/AMBARI_SERVER?fields=RootServiceComponents/properties/gpl.license.accepted&minimal_response=true', {mock: 'true'})
-        .then(function(resp) {
-          deferred.resolve(resp.data.RootServiceComponents.properties && resp.data.RootServiceComponents.properties['gpl.license.accepted']);
-        }, function(resp) {
-          deferred.reject(resp.data);
-        }
-      );
+        .then(function(data) {
+          deferred.resolve(data.data.RootServiceComponents.properties && data.data.RootServiceComponents.properties['gpl.license.accepted']);
+        })
+        .catch(function(data) {
+          deferred.reject(data);
+        });
 
       return deferred.promise;
     },
@@ -108,11 +107,10 @@ angular.module('ambariAdminConsole')
         'VersionDefinition/stack_repo_update_link_exists,operating_systems/repositories/Repositories/*,' +
         'VersionDefinition/stack_services,VersionDefinition/repository_version&VersionDefinition/show_available=true';
       var deferred = $q.defer();
-      $http.get(Settings.baseUrl + url, {mock: 'version/versions.json'}).then(
-        function (resp) {
-          var data = resp.data;
+      $http.get(Settings.baseUrl + url, {mock: 'version/versions.json'})
+        .then(function (data) {
           var versions = [];
-          angular.forEach(data.items, function(version) {
+          angular.forEach(data.data.items, function(version) {
             var versionObj = {
               id: version.VersionDefinition.id,
               stackName: version.VersionDefinition.stack_name,
@@ -156,10 +154,10 @@ angular.module('ambariAdminConsole')
             versions.push(versionObj);
           });
           deferred.resolve(versions)
-        }, function (resp) {
-          deferred.reject(resp.data);
-        }
-      );
+        })
+        .catch(function (data) {
+          deferred.reject(data);
+        });
       return deferred.promise;
     },
 
@@ -195,32 +193,31 @@ angular.module('ambariAdminConsole')
     allRepos: function () {
       var url = '/stacks?fields=versions/repository_versions/RepositoryVersions';
       var deferred = $q.defer();
-      $http.get(Settings.baseUrl + url, {mock: 'version/versions.json'}).then(
-        function (resp) {
-          var data = resp.data;
-          var repos = [];
-          angular.forEach(data.items, function(stack) {
-            angular.forEach(stack.versions, function (version) {
-              var repoVersions = version.repository_versions;
-              if (repoVersions.length > 0) {
-                repos = repos.concat(repoVersions);
-              }
-            });
+      $http.get(Settings.baseUrl + url, {mock: 'version/versions.json'})
+      .then(function (data) {
+        var repos = [];
+        angular.forEach(data.data.items, function(stack) {
+          angular.forEach(stack.versions, function (version) {
+            var repoVersions = version.repository_versions;
+            if (repoVersions.length > 0) {
+              repos = repos.concat(repoVersions);
+            }
           });
-          repos = repos.map(function (stack) {
-            stack.RepositoryVersions.isPatch = stack.RepositoryVersions.type === 'PATCH';
-            stack.RepositoryVersions.isMaint = stack.RepositoryVersions.type === 'MAINT';
-            return stack.RepositoryVersions;
-          });
-          // prepare response data with client side pagination
-          var response = {};
-          response.items = repos;
-          response.itemTotal = repos.length;
-          deferred.resolve(response);
-        }, function (resp) {
-          deferred.reject(resp.data);
-        }
-      );
+        });
+        repos = repos.map(function (stack) {
+          stack.RepositoryVersions.isPatch = stack.RepositoryVersions.type === 'PATCH';
+          stack.RepositoryVersions.isMaint = stack.RepositoryVersions.type === 'MAINT';
+          return stack.RepositoryVersions;
+        });
+        // prepare response data with client side pagination
+        var response = {};
+        response.items = repos;
+        response.itemTotal = repos.length;
+        deferred.resolve(response);
+      })
+      .catch(function (data) {
+        deferred.reject(data);
+      });
       return deferred.promise;
     },
 
@@ -271,41 +268,41 @@ angular.module('ambariAdminConsole')
           '&repository_versions/RepositoryVersions/repository_version=' + repoVersion;
       }
       var deferred = $q.defer();
-      $http.get(url, {mock: 'version/version.json'}).then(
-        function (resp) {
-          var data = resp.data.items[0];
-          var response = {
-            id : data.repository_versions[0].RepositoryVersions.id,
-            stackVersion : data.Versions.stack_version,
-            stackName: data.Versions.stack_name,
-            type: data.repository_versions[0].RepositoryVersions.release? data.repository_versions[0].RepositoryVersions.release.type: null,
-            stackNameVersion: data.Versions.stack_name + '-' + data.Versions.stack_version, /// HDP-2.3
-            actualVersion: data.repository_versions[0].RepositoryVersions.repository_version, /// 2.3.4.0-3846
-            version: data.repository_versions[0].RepositoryVersions.release ? data.repository_versions[0].RepositoryVersions.release.version: null, /// 2.3.4.0
-            releaseNotes: data.repository_versions[0].RepositoryVersions.release ? data.repository_versions[0].RepositoryVersions.release.release_notes: null,
-            displayName: data.repository_versions[0].RepositoryVersions.display_name, //HDP-2.3.4.0
-            repoVersionFullName : data.Versions.stack_name + '-' + data.repository_versions[0].RepositoryVersions.repository_version,
-            ambari_managed_repositories: data.repository_versions[0].operating_systems[0].OperatingSystems.ambari_managed_repositories !== false,
-            osList: data.repository_versions[0].operating_systems,
-            updateObj: data.repository_versions[0]
-          };
-          var services = [];
-          angular.forEach(data.repository_versions[0].RepositoryVersions.stack_services, function (service) {
-            var servicesToExclude = ['GANGLIA', 'KERBEROS', 'MAPREDUCE2'];
-            if (servicesToExclude.indexOf(service.name) === -1) {
-              services.push({
-                name: service.name,
-                version: service.versions[0],
-                displayName: service.display_name
-              });
-            }
-          });
-          response.services = services.sort(function(a, b){return a.name.localeCompare(b.name)});
-          deferred.resolve(response);
-        }, function (resp) {
-          deferred.reject(resp.data);
-        }
-      );
+      $http.get(url, {mock: 'version/version.json'})
+      .then(function (data) {
+        data = data.data.items[0];
+        var response = {
+          id : data.repository_versions[0].RepositoryVersions.id,
+          stackVersion : data.Versions.stack_version,
+          stackName: data.Versions.stack_name,
+          type: data.repository_versions[0].RepositoryVersions.release? data.repository_versions[0].RepositoryVersions.release.type: null,
+          stackNameVersion: data.Versions.stack_name + '-' + data.Versions.stack_version, /// HDP-2.3
+          actualVersion: data.repository_versions[0].RepositoryVersions.repository_version, /// 2.3.4.0-3846
+          version: data.repository_versions[0].RepositoryVersions.release ? data.repository_versions[0].RepositoryVersions.release.version: null, /// 2.3.4.0
+          releaseNotes: data.repository_versions[0].RepositoryVersions.release ? data.repository_versions[0].RepositoryVersions.release.release_notes: null,
+          displayName: data.repository_versions[0].RepositoryVersions.display_name, //HDP-2.3.4.0
+          repoVersionFullName : data.Versions.stack_name + '-' + data.repository_versions[0].RepositoryVersions.repository_version,
+          ambari_managed_repositories: data.repository_versions[0].operating_systems[0].OperatingSystems.ambari_managed_repositories !== false,
+          osList: data.repository_versions[0].operating_systems,
+          updateObj: data.repository_versions[0]
+        };
+        var services = [];
+        angular.forEach(data.repository_versions[0].RepositoryVersions.stack_services, function (service) {
+          var servicesToExclude = ['GANGLIA', 'KERBEROS', 'MAPREDUCE2'];
+          if (servicesToExclude.indexOf(service.name) === -1) {
+            services.push({
+              name: service.name,
+              version: service.versions[0],
+              displayName: service.display_name
+            });
+          }
+        });
+        response.services = services.sort(function(a, b){return a.name.localeCompare(b.name)});
+        deferred.resolve(response);
+      })
+      .catch(function (data) {
+        deferred.reject(data);
+      });
       return deferred.promise;
     },
 
@@ -314,33 +311,55 @@ angular.module('ambariAdminConsole')
         url = Settings.baseUrl + '/version_definitions?skip_url_check=true' + (isDryRun ? '&dry_run=true' : ''),
         configs = isXMLdata? { headers: {'Content-Type': 'text/xml'}} : null;
 
-      $http.post(url, data, configs).then(
-        function (response) {
+      $http.post(url, data, configs)
+        .then(function (response) {
           if (response.data.resources.length && response.data.resources[0].VersionDefinition) {
             deferred.resolve(response.data);
           }
-        }, function (resp) {
-          deferred.reject(resp.data);
-        }
-      );
+        })
+        .catch(function (data) {
+          deferred.reject(data);
+        });
       return deferred.promise;
     },
 
     updateRepo: function (stackName, stackVersion, id, payload) {
       var url = Settings.baseUrl + '/stacks/' + stackName + '/versions/' + stackVersion + '/repository_versions/' + id;
-      return $http.put(url, payload);
+      var deferred = $q.defer();
+      $http.put(url, payload)
+      .then(function (data) {
+        deferred.resolve(data.data)
+      })
+      .catch(function (data) {
+        deferred.reject(data);
+      });
+      return deferred.promise;
     },
 
     deleteRepo: function (stackName, stackVersion, id) {
       var url = Settings.baseUrl + '/stacks/' + stackName + '/versions/' + stackVersion + '/repository_versions/' + id;
-      return $http.delete(url);
+      var deferred = $q.defer();
+      $http.delete(url)
+      .then(function (data) {
+        deferred.resolve(data.data)
+      })
+      .catch(function (data) {
+        deferred.reject(data);
+      });
+      return deferred.promise;
     },
 
     getSupportedOSList: function (stackName, stackVersion) {
       var url = Settings.baseUrl + '/stacks/' + stackName + '/versions/' + stackVersion + '?fields=operating_systems/repositories/Repositories';
-      return $http.get(url, {mock: 'stack/operatingSystems.json'}).then(function (resp) {
-        return resp.data;
+      var deferred = $q.defer();
+      $http.get(url, {mock: 'stack/operatingSystems.json'})
+      .then(function (data) {
+        deferred.resolve(data.data);
+      })
+      .catch(function (data) {
+        deferred.reject(data);
       });
+      return deferred.promise;
     },
 
     validateBaseUrls: function(skip, osList, stack) {
@@ -366,14 +385,16 @@ angular.module('ambariAdminConsole')
                 {
                   repo: repo
                 }
-              ).then(function () {
-                totalCalls--;
-                if (totalCalls === 0) deferred.resolve(invalidUrls);
-              }, function (response) {
-                invalidUrls.push(response.config.repo);
-                totalCalls--;
-                if (totalCalls === 0) deferred.resolve(invalidUrls);
-              });
+              )
+                .then(function () {
+                  totalCalls--;
+                  if (totalCalls === 0) deferred.resolve(invalidUrls);
+                })
+                .catch(function (response) {
+                  invalidUrls.push(response.config.repo);
+                  totalCalls--;
+                  if (totalCalls === 0) deferred.resolve(invalidUrls);
+                });
             });
           }
         });
