@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -15,6 +16,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+
 import logging
 
 logger = logging.getLogger()
@@ -22,20 +24,27 @@ installScriptHash = -1
 
 
 class BackgroundCommandExecutionHandle:
-  
-  SCHEDULED_STATUS = 'SCHEDULED'
-  RUNNING_STATUS = 'RUNNING'
-  STOP_REQUEST_STATUS = 'STOP_REQUEST'
-  STOPPED_STATUS = 'SCHEDULED'
-  
-  def __init__(self, command, commandId, on_background_command_started, on_background_command_complete_callback):
+  SCHEDULED_STATUS = "SCHEDULED"
+  RUNNING_STATUS = "RUNNING"
+  STOP_REQUEST_STATUS = "STOP_REQUEST"
+  STOPPED_STATUS = "SCHEDULED"
+
+  def __init__(
+    self,
+    command,
+    commandId,
+    on_background_command_started,
+    on_background_command_complete_callback,
+  ):
     self.command = command
     self.pid = 0
     self.status = None
     self.exitCode = None
     self.commandId = commandId
     self.on_background_command_started = on_background_command_started
-    self.on_background_command_complete_callback = on_background_command_complete_callback
+    self.on_background_command_complete_callback = (
+      on_background_command_complete_callback
+    )
 
   def __str__(self):
-    return "[BackgroundHandle: pid='{0}', status='{1}', exitCode='{2}', commandId='{3}']".format(self.pid, self.status, self.exitCode, self.commandId)
+    return f"[BackgroundHandle: pid='{self.pid}', status='{self.status}', exitCode='{self.exitCode}', commandId='{self.commandId}']"
