@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """
 Licensed to the Apache Software Foundation (ASF) under one
@@ -23,6 +23,7 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+
 class ClusterConfigurationCache(ClusterCache):
   """
   Maintains an in-memory cache and disk cache of the configurations for
@@ -30,20 +31,13 @@ class ClusterConfigurationCache(ClusterCache):
   configuration properties.
   """
 
-  def __init__(self, cluster_cache_dir, initializer_module):
+  def __init__(self, cluster_cache_dir):
     """
     Initializes the configuration cache.
     :param cluster_cache_dir: directory the changed json are saved
     :return:
     """
-    self.initializer_module = initializer_module
     super(ClusterConfigurationCache, self).__init__(cluster_cache_dir)
-  
-  def on_cache_update(self):
-    for cluster_id, configurations in self.iteritems():
-      # FIXME: Recovery manager does not support multiple cluster as of now.
-      self.initializer_module.recovery_manager.cluster_id = cluster_id
-      self.initializer_module.recovery_manager.on_config_update(configurations)
 
   def get_cache_name(self):
-    return 'configurations'
+    return "configurations"
