@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
 # this work for additional information regarding copyright ownership.
@@ -16,21 +17,21 @@
 from setuptools import setup
 
 setup(
-    name = "ambari-agent",
-    version = "1.0.3-SNAPSHOT",
-    packages = ['ambari_agent'],
-    # metadata for upload to PyPI
-    author = "Apache Software Foundation",
-    author_email = "ambari-dev@incubator.apache.org",
-    description = "Ambari agent",
-    license = "Apache License v2.0",
-    keywords = "hadoop, ambari",
-    url = "http://incubator.apache.org/ambari",
-    long_description = "This package implements the Ambari agent for installing Hadoop on large clusters.",
-    platforms=["any"],
-    entry_points = {
-        "console_scripts": [
-            "ambari-agent = ambari_agent.main:main",
-        ],
-    }
+  name="ambari-agent",
+  version="1.0.3-SNAPSHOT",
+  packages=["ambari_agent"],
+  # metadata for upload to PyPI
+  author="Apache Software Foundation",
+  author_email="ambari-dev@incubator.apache.org",
+  description="Ambari agent",
+  license="Apache License v2.0",
+  keywords="hadoop, ambari",
+  url="http://incubator.apache.org/ambari",
+  long_description="This package implements the Ambari agent for installing Hadoop on large clusters.",
+  platforms=["any"],
+  entry_points={
+    "console_scripts": [
+      "ambari-agent = ambari_agent.main:main",
+    ],
+  },
 )
