@@ -1,4 +1,5 @@
-'''
+#!/usr/bin/env python3
+"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
@@ -14,7 +15,7 @@ distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-'''
+"""
 
 from unittest import TestCase
 
@@ -22,10 +23,9 @@ from resource_management.libraries.functions.get_path_from_url import get_path_f
 
 
 class TestGetPathFromUlr(TestCase):
-
   def test_get_path_from_url(self):
-    self.assertEquals(get_path_from_url("http://test.host:8888/test/path"), "test/path")
-    self.assertEquals(get_path_from_url("http://test.host/test/path"), "test/path")
-    self.assertEquals(get_path_from_url("test.host:8888/test/path"), "test/path")
-    self.assertEquals(get_path_from_url("test.host/test/path"), "test/path")
-    self.assertEquals(get_path_from_url("/test/path"), "test/path")
+    self.assertEqual(get_path_from_url("http://test.host:8888/test/path"), "test/path")
+    self.assertEqual(get_path_from_url("http://test.host/test/path"), "test/path")
+    self.assertEqual(get_path_from_url("test.host:8888/test/path"), "test/path")
+    self.assertEqual(get_path_from_url("test.host/test/path"), "test/path")
+    self.assertEqual(get_path_from_url("/test/path"), "test/path")
