@@ -1,6 +1,6 @@
-#!/usr/bin/env python2.6
+#!/usr/bin/env python3
 
-'''
+"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
@@ -16,11 +16,8 @@ distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-'''
+"""
 
 from ambari_commons.os_check import OSCheck, OSConst
 
-__all__ = [
-  'OSCheck',
-  'OSConst'
-]
+__all__ = ["OSCheck", "OSConst"]
