@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -15,11 +16,6 @@ limitations under the License.
 Ambari Agent
 """
 
-def get_encoded_string(data):
-  try:
-    return data.encode("utf8")
-  except UnicodeDecodeError:
-    return data
 
 def unicode_walk(top, topdown=True, onerror=None, followlinks=False):
   """
@@ -32,20 +28,17 @@ def unicode_walk(top, topdown=True, onerror=None, followlinks=False):
 
   islink, join, isdir = os.path.islink, os.path.join, os.path.isdir
 
-  top = get_encoded_string(top)
-
   try:
     # Note that listdir and error are globals in this module due
     # to earlier import-*.
     names = os.listdir(top)
-  except os.error, err:
+  except os.error as err:
     if onerror is not None:
       onerror(err)
     return
 
   dirs, nondirs = [], []
   for name in names:
-    name = get_encoded_string(name)
     if isdir(join(top, name)):
       dirs.append(name)
     else:
@@ -54,7 +47,6 @@ def unicode_walk(top, topdown=True, onerror=None, followlinks=False):
   if topdown:
     yield top, dirs, nondirs
   for name in dirs:
-    name = get_encoded_string(name)
     new_path = join(top, name)
     if followlinks or not islink(new_path):
       for x in unicode_walk(new_path, topdown, onerror, followlinks):
