@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -8,7 +9,7 @@
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
-#* Unless required by applicable law or agreed to in writing, software
+# * Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
@@ -17,11 +18,16 @@
 import inspect
 import os
 
+
 class ConvertToXml:
   "Template class, allow to output fields in xml format"
+
   def getField(self):
-    return [name for name, obj in inspect.getmembers(self)
-            if not name.startswith("__") and not inspect.isroutine(obj)]
+    return [
+      name
+      for name, obj in inspect.getmembers(self)
+      if not name.startswith("__") and not inspect.isroutine(obj)
+    ]
 
   def attributesToXml(self):
     result = ""
