@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -30,8 +30,10 @@ from os.path import join
 import random
 import string
 
+
 def generate_random_string(size=7, chars=string.ascii_uppercase + string.digits):
-  return ''.join(random.choice(chars) for _ in range(size))
+  return "".join(random.choice(chars) for _ in range(size))
+
 
 class _named_dict(dict):
   """
@@ -39,7 +41,6 @@ class _named_dict(dict):
   """
 
   def __init__(self, _dict):
-
     def repl_list(_list):
       for i, e in enumerate(_list):
         if isinstance(e, list):
@@ -49,7 +50,7 @@ class _named_dict(dict):
       return _list
 
     dict.__init__(self, _dict)
-    for key, value in self.iteritems():
+    for key, value in self.items():
       if isinstance(value, dict):
         self[key] = _named_dict(value)
       if isinstance(value, list):
@@ -61,6 +62,7 @@ class _named_dict(dict):
     else:
       dict.__getattr__(self, item)
 
+
 def copy_tree(src, dest, exclude=None, post_copy=None):
   """
   Copy files form src to dest.
@@ -98,8 +100,9 @@ def copy_tree(src, dest, exclude=None, post_copy=None):
     if post_copy:
       post_copy(_src, _dest)
 
+
 def process_replacements(file_path, config_data, stack_version_changes):
-  file_data = open(file_path, 'r').read().decode('utf-8')
+  file_data = open(file_path, "r").read().decode("utf-8")
 
   # save user-defined text before replacements
   preserved_map = {}
@@ -110,35 +113,42 @@ def process_replacements(file_path, config_data, stack_version_changes):
       preserved_map[rnd] = preserved
 
   # replace user defined values
-  if 'textReplacements' in config_data:
-    for _from, _to in config_data['textReplacements']:
+  if "textReplacements" in config_data:
+    for _from, _to in config_data["textReplacements"]:
       file_data = file_data.replace(_from, _to)
   # replace stack version changes
   # it can be dangerous to replace versions in xml files, because it can be a part of version of some package or service
   # eg 2.1.2.1 with stack version change 2.1->3.0 will result in 3.0.3.0
   if not file_path.endswith(".xml"):
-    for _from, _to in stack_version_changes.iteritems():
+    for _from, _to in stack_version_changes.items():
       file_data = file_data.replace(_from, _to)
       file_data = process_version_replace(file_data, _from, _to)
   # preform common replacements
-  if 'performCommonReplacements' in config_data and config_data.performCommonReplacements:
-    for from_version, to_version in stack_version_changes.iteritems():
-      file_data = file_data.replace('HDP-'+from_version, config_data.stackName+"-"+to_version)
-      file_data = file_data.replace('HDP '+from_version, config_data.stackName+" "+to_version)
-    file_data = file_data.replace('hdp', config_data.stackName.lower())
-    file_data = file_data.replace('HDP', config_data.stackName)
+  if (
+    "performCommonReplacements" in config_data and config_data.performCommonReplacements
+  ):
+    for from_version, to_version in stack_version_changes.items():
+      file_data = file_data.replace(
+        "HDP-" + from_version, config_data.stackName + "-" + to_version
+      )
+      file_data = file_data.replace(
+        "HDP " + from_version, config_data.stackName + " " + to_version
+      )
+    file_data = file_data.replace("hdp", config_data.stackName.lower())
+    file_data = file_data.replace("HDP", config_data.stackName)
   if preserved_map:
-    for _from, _to in preserved_map.iteritems():
+    for _from, _to in preserved_map.items():
       file_data = file_data.replace(_from, _to)
   with open(file_path, "w") as target:
-    target.write(file_data.encode('utf-8'))
+    target.write(file_data.encode("utf-8"))
   return file_path
 
+
 def process_version_replace(text, base_version, version):
-  dash_base_version = base_version.replace('.', '-')
-  dash_version = version.replace('.', '-')
-  underscore_base_version = base_version.replace('.', '_')
-  underscore_version = version.replace('.', '_')
+  dash_base_version = base_version.replace(".", "-")
+  dash_version = version.replace(".", "-")
+  underscore_base_version = base_version.replace(".", "_")
+  underscore_version = version.replace(".", "_")
   if dash_base_version in text:
     text = text.replace(dash_base_version, dash_version)
   if underscore_base_version in text:
@@ -146,13 +156,13 @@ def process_version_replace(text, base_version, version):
   return text
 
 
-def process_metainfo(file_path, config_data, stack_version_changes, common_services = []):
+def process_metainfo(file_path, config_data, stack_version_changes, common_services=[]):
   tree = ET.parse(file_path)
   root = tree.getroot()
 
-  if root.find('versions') is not None or root.find('services') is None:
+  if root.find("versions") is not None or root.find("services") is None:
     # process stack metainfo.xml
-    extends_tag = root.find('extends')
+    extends_tag = root.find("extends")
     if extends_tag is not None:
       version = extends_tag.text
       if version in stack_version_changes:
@@ -163,33 +173,33 @@ def process_metainfo(file_path, config_data, stack_version_changes, common_servi
     modify_active_tag = False
     active_tag_value = None
     for stack in config_data.versions:
-      if stack.version == current_version and 'active' in stack:
+      if stack.version == current_version and "active" in stack:
         modify_active_tag = True
         active_tag_value = stack.active
         break
 
     if modify_active_tag:
-      versions_tag = root.find('versions')
+      versions_tag = root.find("versions")
       if versions_tag is None:
-        versions_tag = ET.SubElement(root, 'versions')
-      active_tag = versions_tag.find('active')
+        versions_tag = ET.SubElement(root, "versions")
+      active_tag = versions_tag.find("active")
       if active_tag is None:
-        active_tag = ET.SubElement(versions_tag, 'active')
+        active_tag = ET.SubElement(versions_tag, "active")
       active_tag.text = active_tag_value
       tree.write(file_path)
   else:
     # Process service metainfo.xml
-    services_tag = root.find('services')
+    services_tag = root.find("services")
     if services_tag is not None:
-      for service_tag in services_tag.findall('service'):
-        name = service_tag.find('name').text
+      for service_tag in services_tag.findall("service"):
+        name = service_tag.find("name").text
         ####################################################################################################
         # Add common service to be copied.
         ####################################################################################################
-        extends_tag = service_tag.find('extends')
+        extends_tag = service_tag.find("extends")
         if extends_tag is not None:
           common_services.append(extends_tag.text)
-        service_version_tag = service_tag.find('version')
+        service_version_tag = service_tag.find("version")
         # file_path <resource_dir>/stacks/<stack_name>/<stack_version>/services/<service_name>/metainfo.xml
         split_path = file_path.split(os.path.sep)
         split_path_len = len(split_path)
@@ -201,12 +211,12 @@ def process_metainfo(file_path, config_data, stack_version_changes, common_servi
                 ######################################################################################################
                 # Update service version
                 ######################################################################################################
-                if 'version' in service:
+                if "version" in service:
                   ####################################################################################################
                   # If explicit service version is provided in the config, override the service version
                   ####################################################################################################
                   if service_version_tag is None:
-                    service_version_tag = ET.SubElement(service_tag, 'version')
+                    service_version_tag = ET.SubElement(service_tag, "version")
                   service_version_tag.text = service.version
                 else:
                   ####################################################################################################
@@ -216,117 +226,136 @@ def process_metainfo(file_path, config_data, stack_version_changes, common_servi
                   if service_version_tag is not None:
                     service_version_split = service_version_tag.text.split(".")
                     if len(stack.baseVersion) < len(service_version_tag.text):
-                      version_suffix = service_version_tag.text[-len(stack.baseVersion):]
+                      version_suffix = service_version_tag.text[
+                        -len(stack.baseVersion) :
+                      ]
                       if version_suffix == stack.baseVersion:
-                        version_prefix = service_version_tag.text[0:-len(stack.baseVersion)]
+                        version_prefix = service_version_tag.text[
+                          0 : -len(stack.baseVersion)
+                        ]
                         service_version_tag.text = version_prefix + stack.version
                 ######################################################################################################
                 # Update service version
                 ######################################################################################################
-                osSpecifics_tag = service_tag.find('osSpecifics')
-                if 'packages' in service:
+                osSpecifics_tag = service_tag.find("osSpecifics")
+                if "packages" in service:
                   if osSpecifics_tag is not None:
                     service_tag.remove(osSpecifics_tag)
-                  osSpecifics_tag = ET.SubElement(service_tag, 'osSpecifics')
-                  for item in service['packages']:
-                    osSpecific_tag = ET.SubElement(osSpecifics_tag, 'osSpecific')
-                    family = item['family']
-                    osFamily_tag = ET.SubElement(osSpecific_tag, 'osFamily')
+                  osSpecifics_tag = ET.SubElement(service_tag, "osSpecifics")
+                  for item in service["packages"]:
+                    osSpecific_tag = ET.SubElement(osSpecifics_tag, "osSpecific")
+                    family = item["family"]
+                    osFamily_tag = ET.SubElement(osSpecific_tag, "osFamily")
                     osFamily_tag.text = family
-                    packages_tag = ET.SubElement(osSpecific_tag, 'packages')
-                    for package in item['packages']:
-                      package_tag = ET.SubElement(packages_tag, 'package')
-                      name_tag = ET.SubElement(package_tag, 'name')
-                      if isinstance(package, basestring):
+                    packages_tag = ET.SubElement(osSpecific_tag, "packages")
+                    for package in item["packages"]:
+                      package_tag = ET.SubElement(packages_tag, "package")
+                      name_tag = ET.SubElement(package_tag, "name")
+                      if isinstance(package, str):
                         name_tag.text = package
                       else:
-                        name_tag.text = package['name']
-                      if 'skipUpgrade' in package:
-                        skipUpgrade_tag = ET.SubElement(package_tag, 'skipUpgrade')
-                        skipUpgrade_tag.text = package['skipUpgrade']
+                        name_tag.text = package["name"]
+                      if "skipUpgrade" in package:
+                        skipUpgrade_tag = ET.SubElement(package_tag, "skipUpgrade")
+                        skipUpgrade_tag.text = package["skipUpgrade"]
                 else:
                   ####################################################################################################
                   # Default: Update package version by replacing stack version in the package name
                   # Example (ex: falcon_2_2_* -> falcon_3_0_*, falcon-2-3-* -> falcon-3-1-*)
                   ####################################################################################################
-                  for packages_tag in service_tag.getiterator('packages'):
-                    for package_tag in packages_tag.getiterator('package'):
-                      name_tag = package_tag.find('name')
+                  for packages_tag in service_tag.getiterator("packages"):
+                    for package_tag in packages_tag.getiterator("package"):
+                      name_tag = package_tag.find("name")
                       for base_version in stack_version_changes:
                         version = stack_version_changes[base_version]
-                        name_tag.text = process_version_replace(name_tag.text, base_version, version)
+                        name_tag.text = process_version_replace(
+                          name_tag.text, base_version, version
+                        )
     tree.write(file_path)
   return file_path
 
+
 def process_upgrade_xml(file_path, target_version, config_data, stack_version_changes):
   # change versions in xml
   tree = ET.parse(file_path)
   root = tree.getroot()
 
-  for target_tag in root.findall('target'):
-    version = '.'.join([el for el in target_tag.text.split('.') if el != '*'])
+  for target_tag in root.findall("target"):
+    version = ".".join([el for el in target_tag.text.split(".") if el != "*"])
     if version in stack_version_changes:
       target_tag.text = target_tag.text.replace(version, stack_version_changes[version])
       tree.write(file_path)
 
-  for target_tag in root.findall('target-stack'):
-    base_stack_name, base_stack_version = target_tag.text.split('-')
-    new_target_stack_text = target_tag.text.replace(base_stack_name, config_data.stackName)
+  for target_tag in root.findall("target-stack"):
+    base_stack_name, base_stack_version = target_tag.text.split("-")
+    new_target_stack_text = target_tag.text.replace(
+      base_stack_name, config_data.stackName
+    )
     if base_stack_version in stack_version_changes:
-      new_target_stack_text = new_target_stack_text.replace(base_stack_version,
-                                                            stack_version_changes[base_stack_version])
+      new_target_stack_text = new_target_stack_text.replace(
+        base_stack_version, stack_version_changes[base_stack_version]
+      )
     target_tag.text = new_target_stack_text
     tree.write(file_path)
 
   # rename upgrade files
   new_file_path = file_path
   if target_version in stack_version_changes:
-    new_file_path = os.path.join(os.path.dirname(file_path),
-                            'upgrade-{0}.xml'.format(stack_version_changes[target_version]))
+    new_file_path = os.path.join(
+      os.path.dirname(file_path), f"upgrade-{stack_version_changes[target_version]}.xml"
+    )
     os.rename(file_path, new_file_path)
   return new_file_path
 
-def process_stack_advisor(file_path, config_data, stack_version_changes):
-  CLASS_NAME_REGEXP = r'([A-Za-z]+)(\d+)StackAdvisor'
 
-  stack_advisor_content = open(file_path, 'r').read()
+def process_stack_advisor(file_path, config_data, stack_version_changes):
+  CLASS_NAME_REGEXP = r"([A-Za-z]+)(\d+)StackAdvisor"
+
+  stack_advisor_content = open(file_path, "r").read()
 
   for stack_name, stack_version in re.findall(CLASS_NAME_REGEXP, stack_advisor_content):
-    what = stack_name + stack_version + 'StackAdvisor'
-    stack_version_dotted = '.'.join(list(stack_version))
+    what = stack_name + stack_version + "StackAdvisor"
+    stack_version_dotted = ".".join(list(stack_version))
     if stack_version_dotted in stack_version_changes:
-      to = config_data.stackName + stack_version_changes[stack_version_dotted].replace('.', '') + 'StackAdvisor'
+      to = (
+        config_data.stackName
+        + stack_version_changes[stack_version_dotted].replace(".", "")
+        + "StackAdvisor"
+      )
     else:
-      to = config_data.stackName + stack_version + 'StackAdvisor'
+      to = config_data.stackName + stack_version + "StackAdvisor"
     stack_advisor_content = stack_advisor_content.replace(what, to)
 
-  with open(file_path, 'w') as f:
+  with open(file_path, "w") as f:
     f.write(stack_advisor_content)
   return file_path
 
+
 def process_repoinfo_xml(file_path, config_data, stack_version_changes, stack):
-  if 'repoinfo' in stack:
+  if "repoinfo" in stack:
     #########################################################################################
     # Update repo info from explicitly defined repo info from config
     # Assumption: All elements in repo info are configured
     #########################################################################################
     root = ET.Element("reposinfo")
-    if 'latest' in stack.repoinfo:
-      latest_tag = ET.SubElement(root, 'latest')
+    if "latest" in stack.repoinfo:
+      latest_tag = ET.SubElement(root, "latest")
       latest_tag.text = stack.repoinfo.latest
-    if 'os' in stack.repoinfo:
-      for family, repos in stack.repoinfo.os.iteritems():
-        os_tag = ET.SubElement(root, 'os')
-        os_tag.set('family', family)
+    if "os" in stack.repoinfo:
+      for family, repos in stack.repoinfo.os.items():
+        os_tag = ET.SubElement(root, "os")
+        os_tag.set("family", family)
         for repo in repos:
-          repo_tag = ET.SubElement(os_tag, 'repo')
-          baseurl_tag = ET.SubElement(repo_tag, 'baseurl')
+          repo_tag = ET.SubElement(os_tag, "repo")
+          baseurl_tag = ET.SubElement(repo_tag, "baseurl")
           baseurl_tag.text = repo.baseurl
-          repoid_tag = ET.SubElement(repo_tag, 'repoid')
+          repoid_tag = ET.SubElement(repo_tag, "repoid")
           repoid_tag.text = repo.repoid
-          reponame_tag= ET.SubElement(repo_tag, 'reponame')
+          reponame_tag = ET.SubElement(repo_tag, "reponame")
           reponame_tag.text = repo.reponame
-    open(file_path,"w").write(minidom.parseString(ET.tostring(root, 'utf-8')).toprettyxml(indent="  "))
+    open(file_path, "w").write(
+      minidom.parseString(ET.tostring(root, "utf-8")).toprettyxml(indent="  ")
+    )
   else:
     #########################################################################################
     # Update repo info with defaults if repo info is not defined in config
@@ -334,59 +363,75 @@ def process_repoinfo_xml(file_path, config_data, stack_version_changes, stack):
     tree = ET.parse(file_path)
     root = tree.getroot()
     remove_list = list()
-    if 'family' in stack:
+    if "family" in stack:
       for os_tag in root.getiterator("os"):
-        os_family = os_tag.get('family')
+        os_family = os_tag.get("family")
         if os_family not in stack.family:
           remove_list.append(os_tag)
     for os_tag in remove_list:
       root.remove(os_tag)
 
     # Update all base urls
-    for baseurl_tag in root.getiterator('baseurl'):
-      baseurl_tag.text = 'http://SET_REPO_URL'
+    for baseurl_tag in root.getiterator("baseurl"):
+      baseurl_tag.text = "http://SET_REPO_URL"
     # Update latest url
-    for latest_tag in root.getiterator('latest'):
-      latest_tag.text = 'http://SET_LATEST_REPO_URL_INFO'
+    for latest_tag in root.getiterator("latest"):
+      latest_tag.text = "http://SET_LATEST_REPO_URL_INFO"
     # Update repo ids
-    for repoid_tag in root.getiterator('repoid'):
-      repoid_tag.text = repoid_tag.text.replace(config_data.baseStackName, config_data.stackName)
+    for repoid_tag in root.getiterator("repoid"):
+      repoid_tag.text = repoid_tag.text.replace(
+        config_data.baseStackName, config_data.stackName
+      )
       for baseVersion in stack_version_changes:
-        repoid_tag.text = repoid_tag.text.replace(baseVersion, stack_version_changes[baseVersion])
+        repoid_tag.text = repoid_tag.text.replace(
+          baseVersion, stack_version_changes[baseVersion]
+        )
     # Update repo name
-    for reponame_tag in root.getiterator('reponame'):
-      reponame_tag.text = reponame_tag.text.replace(config_data.baseStackName, config_data.stackName)
+    for reponame_tag in root.getiterator("reponame"):
+      reponame_tag.text = reponame_tag.text.replace(
+        config_data.baseStackName, config_data.stackName
+      )
     tree.write(file_path)
   return file_path
 
+
 def process_py_files(file_path, config_data, stack_version_changes):
   new_file_path = process_replacements(file_path, config_data, stack_version_changes)
-  if  config_data.baseStackName.lower() in file_path:
-    new_file_path = file_path.replace(config_data.baseStackName.lower(), config_data.stackName.lower())
+  if config_data.baseStackName.lower() in file_path:
+    new_file_path = file_path.replace(
+      config_data.baseStackName.lower(), config_data.stackName.lower()
+    )
     os.rename(file_path, new_file_path)
   return new_file_path
 
+
 def process_xml_files(file_path, config_data, stack_version_changes):
   return process_replacements(file_path, config_data, stack_version_changes)
 
+
 def process_other_files(file_path, config_data, stack_version_changes):
   return process_replacements(file_path, config_data, stack_version_changes)
 
+
 def process_config_xml(file_path, config_data):
   tree = ET.parse(file_path)
   root = tree.getroot()
   #############################################################################################
   # <resource_dir>/common-services/<service_name>/<service_version>/configuration/<config>.xml
   #############################################################################################
-  COMMON_SERVICES_CONFIG_PATH_REGEX = r'common-services/([A-Za-z_-]+)/([0-9\.]+)/configuration/([A-Za-z0-9_-]+).xml'
+  COMMON_SERVICES_CONFIG_PATH_REGEX = (
+    r"common-services/([A-Za-z_-]+)/([0-9\.]+)/configuration/([A-Za-z0-9_-]+).xml"
+  )
   #############################################################################################
   # <resource_dir>/stacks/<stack_name>/<stack_version>/services/<service_name>/configuration/<config>.xml
   #############################################################################################
-  STACK_SERVICE_CONFIG_PATH_REGEX = r'stacks/([A-Za-z_-]+)/([0-9\.]+)/services/([A-Za-z_-]+)/configuration/([A-Za-z0-9_-]+).xml'
+  STACK_SERVICE_CONFIG_PATH_REGEX = r"stacks/([A-Za-z_-]+)/([0-9\.]+)/services/([A-Za-z_-]+)/configuration/([A-Za-z0-9_-]+).xml"
   #############################################################################################
   # <resource_dir>/stacks/<stack_name>/<stack_version>/configuration/<config>.xml
   #############################################################################################
-  STACK_CONFIG_PATH_REGEX = r'stacks/([A-Za-z_-]+)/([0-9\.]+)/configuration/([A-Za-z0-9_-]+).xml'
+  STACK_CONFIG_PATH_REGEX = (
+    r"stacks/([A-Za-z_-]+)/([0-9\.]+)/configuration/([A-Za-z0-9_-]+).xml"
+  )
 
   #########################################################################################
   # Override stack config properties
@@ -399,18 +444,18 @@ def process_config_xml(file_path, config_data):
     path_service_name = match.group(1)
     path_service_version = match.group(2)
     path_config_name = match.group(3)
-    if 'common-services' in config_data:
-      for service in config_data['common-services']:
+    if "common-services" in config_data:
+      for service in config_data["common-services"]:
         if service.name == path_service_name:
           for serviceVersion in service.versions:
             if serviceVersion.version == path_service_version:
-              if 'configurations' in serviceVersion:
-                for conf in serviceVersion['configurations']:
+              if "configurations" in serviceVersion:
+                for conf in serviceVersion["configurations"]:
                   if conf.name == path_config_name:
-                    for property_tag in root.findall('property'):
-                      property_name = property_tag.find('name').text
+                    for property_tag in root.findall("property"):
+                      property_name = property_tag.find("name").text
                       if property_name in conf.properties:
-                        value_tag = property_tag.find('value')
+                        value_tag = property_tag.find("value")
                         value_tag.text = conf.properties[property_name]
   else:
     match = re.search(STACK_SERVICE_CONFIG_PATH_REGEX, file_path)
@@ -426,13 +471,13 @@ def process_config_xml(file_path, config_data):
         if stack.version == path_stack_version:
           for service in stack.services:
             if service.name == path_service_name:
-              if 'configurations' in service:
-                for conf in service['configurations']:
+              if "configurations" in service:
+                for conf in service["configurations"]:
                   if conf.name == path_config_name:
-                    for property_tag in root.findall('property'):
-                      property_name = property_tag.find('name').text
+                    for property_tag in root.findall("property"):
+                      property_name = property_tag.find("name").text
                       if property_name in conf.properties:
-                        value_tag = property_tag.find('value')
+                        value_tag = property_tag.find("value")
                         value_tag.text = conf.properties[property_name]
     else:
       match = re.search(STACK_CONFIG_PATH_REGEX, file_path)
@@ -445,18 +490,19 @@ def process_config_xml(file_path, config_data):
         path_config_name = match.group(3)
         for stack in config_data.versions:
           if stack.version == path_stack_version:
-            if 'configurations' in stack:
-              for conf in stack['configurations']:
+            if "configurations" in stack:
+              for conf in stack["configurations"]:
                 if conf.name == path_config_name:
-                  for property_tag in root.findall('property'):
-                    property_name = property_tag.find('name').text
+                  for property_tag in root.findall("property"):
+                    property_name = property_tag.find("name").text
                     if property_name in conf.properties:
-                      value_tag = property_tag.find('value')
+                      value_tag = property_tag.find("value")
                       value_tag.text = conf.properties[property_name]
 
   tree.write(file_path)
   return file_path
 
+
 class GeneratorHelper(object):
   def __init__(self, config_data, resources_folder, output_folder):
     self.config_data = config_data
@@ -473,9 +519,15 @@ class GeneratorHelper(object):
     self.common_services = []
 
   def copy_stacks(self):
-    original_folder = os.path.join(self.resources_folder, 'stacks', self.config_data.baseStackName)
-    partial_target_folder = os.path.join(self.resources_folder, 'stacks', self.config_data.stackName)
-    target_folder = os.path.join(self.output_folder, 'stacks', self.config_data.stackName)
+    original_folder = os.path.join(
+      self.resources_folder, "stacks", self.config_data.baseStackName
+    )
+    partial_target_folder = os.path.join(
+      self.resources_folder, "stacks", self.config_data.stackName
+    )
+    target_folder = os.path.join(
+      self.output_folder, "stacks", self.config_data.stackName
+    )
 
     for stack in self.config_data.versions:
       original_stack = os.path.join(original_folder, stack.baseVersion)
@@ -483,47 +535,61 @@ class GeneratorHelper(object):
       partial_target_stack = os.path.join(partial_target_folder, stack.version)
 
       desired_services = [service.name for service in stack.services]
-      desired_services.append('stack_advisor.py')  # stack_advisor.py placed in stacks folder
-      base_stack_services = os.listdir(os.path.join(original_stack, 'services'))
-      ignored_files = [service for service in base_stack_services if service not in desired_services]
-      ignored_files.append('.pyc')
+      desired_services.append(
+        "stack_advisor.py"
+      )  # stack_advisor.py placed in stacks folder
+      base_stack_services = os.listdir(os.path.join(original_stack, "services"))
+      ignored_files = [
+        service for service in base_stack_services if service not in desired_services
+      ]
+      ignored_files.append(".pyc")
 
       def post_copy(src, target):
-        if target.endswith('.xml'):
+        if target.endswith(".xml"):
           ####################################################################
           # Add special case handling for specific xml files
           ###################################################################
           # process metainfo.xml
-          if target.endswith('metainfo.xml'):
-            target = process_metainfo(target, self.config_data, self.stack_version_changes, self.common_services)
+          if target.endswith("metainfo.xml"):
+            target = process_metainfo(
+              target, self.config_data, self.stack_version_changes, self.common_services
+            )
           # process repoinfo.xml
-          if target.endswith('repoinfo.xml'):
-            target = process_repoinfo_xml(target, self.config_data, self.stack_version_changes, stack)
-          if os.path.basename(os.path.dirname(target)) == 'configuration':
+          if target.endswith("repoinfo.xml"):
+            target = process_repoinfo_xml(
+              target, self.config_data, self.stack_version_changes, stack
+            )
+          if os.path.basename(os.path.dirname(target)) == "configuration":
             # process configuration xml
             target = process_config_xml(target, self.config_data)
           # process upgrade-x.x.xml
-          _upgrade_re = re.compile('upgrade-(.*)\.xml')
+          _upgrade_re = re.compile("upgrade-(.*)\.xml")
           result = re.search(_upgrade_re, target)
           if result:
             target_version = result.group(1)
-            target = process_upgrade_xml(target, target_version, self.config_data, self.stack_version_changes)
+            target = process_upgrade_xml(
+              target, target_version, self.config_data, self.stack_version_changes
+            )
           ####################################################################
           # Generic processing for xml files
           ###################################################################
           process_xml_files(target, self.config_data, self.stack_version_changes)
           return
-        if target.endswith('.py'):
+        if target.endswith(".py"):
           ####################################################################
           # Add special case handling for specific py files
           ###################################################################
           # process stack_advisor.py
-          if target.endswith('stack_advisor.py'):
-            target = process_stack_advisor(target, self.config_data, self.stack_version_changes)
+          if target.endswith("stack_advisor.py"):
+            target = process_stack_advisor(
+              target, self.config_data, self.stack_version_changes
+            )
           ####################################################################
           # Generic processing for py files
           ###################################################################
-          target = process_py_files(target, self.config_data, self.stack_version_changes)
+          target = process_py_files(
+            target, self.config_data, self.stack_version_changes
+          )
           return
         ####################################################################
         # Generic processing for all other types of files.
@@ -537,29 +603,35 @@ class GeneratorHelper(object):
       copy_tree(partial_target_stack, target_stack, ignored_files, post_copy=None)
 
     # copy default stack advisor
-    shutil.copy(os.path.join(self.resources_folder, 'stacks', 'stack_advisor.py'), os.path.join(target_folder, '../stack_advisor.py'))
+    shutil.copy(
+      os.path.join(self.resources_folder, "stacks", "stack_advisor.py"),
+      os.path.join(target_folder, "../stack_advisor.py"),
+    )
 
-  def copy_common_services(self, common_services = []):
-    ignored_files = ['.pyc']
+  def copy_common_services(self, common_services=[]):
+    ignored_files = [".pyc"]
     if not common_services:
       common_services = self.common_services
     for original_folder in common_services:
       source_folder = os.path.join(self.resources_folder, original_folder)
       target_folder = os.path.join(self.output_folder, original_folder)
       parent_services = []
+
       def post_copy(src, target):
-        if target.endswith('.xml'):
+        if target.endswith(".xml"):
           # process metainfo.xml
-          if target.endswith('metainfo.xml'):
-            process_metainfo(target, self.config_data, self.stack_version_changes, parent_services)
-          if os.path.basename(os.path.dirname(target)) == 'configuration':
+          if target.endswith("metainfo.xml"):
+            process_metainfo(
+              target, self.config_data, self.stack_version_changes, parent_services
+            )
+          if os.path.basename(os.path.dirname(target)) == "configuration":
             # process configuration xml
             target = process_config_xml(target, self.config_data)
           # process generic xml
           process_xml_files(target, self.config_data, self.stack_version_changes)
           return
         # process python files
-        if target.endswith('.py'):
+        if target.endswith(".py"):
           process_py_files(target, self.config_data, self.stack_version_changes)
           return
         ####################################################################
@@ -573,8 +645,8 @@ class GeneratorHelper(object):
         self.copy_common_services(parent_services)
     pass
 
-  def copy_remaining_common_services(self, common_services = []):
-    ignored_files = ['.pyc']
+  def copy_remaining_common_services(self, common_services=[]):
+    ignored_files = [".pyc"]
     source_common_services_path = os.path.join(self.resources_folder, "common-services")
     dest_common_services_path = os.path.join(self.output_folder, "common-services")
 
@@ -588,14 +660,20 @@ class GeneratorHelper(object):
         copy_tree(source, dest, ignored_files, post_copy=None)
 
   def copy_resource_management(self):
-    source_folder = join(os.path.abspath(join(self.resources_folder, "..", "..", "..", "..")),
-                         'ambari-common', 'src', 'main', 'python', 'resource_management')
-    target_folder = join(self.output_folder, 'python', 'resource_management')
-    ignored_files = ['.pyc']
+    source_folder = join(
+      os.path.abspath(join(self.resources_folder, "..", "..", "..", "..")),
+      "ambari-common",
+      "src",
+      "main",
+      "python",
+      "resource_management",
+    )
+    target_folder = join(self.output_folder, "python", "resource_management")
+    ignored_files = [".pyc"]
 
     def post_copy(src, target):
       # process python files
-      if target.endswith('.py'):
+      if target.endswith(".py"):
         # process script.py
         process_py_files(target, self.config_data, self.stack_version_changes)
         return
@@ -603,9 +681,16 @@ class GeneratorHelper(object):
     copy_tree(source_folder, target_folder, ignored_files, post_copy=post_copy)
 
   def copy_ambari_properties(self):
-    source_ambari_properties = join(os.path.abspath(join(self.resources_folder, "..", "..", "..", "..")),
-                         'ambari-server', 'conf', 'unix', "ambari.properties")
-    target_ambari_properties = join(self.output_folder, 'conf', 'unix', 'ambari.properties')
+    source_ambari_properties = join(
+      os.path.abspath(join(self.resources_folder, "..", "..", "..", "..")),
+      "ambari-server",
+      "conf",
+      "unix",
+      "ambari.properties",
+    )
+    target_ambari_properties = join(
+      self.output_folder, "conf", "unix", "ambari.properties"
+    )
     target_dirname = os.path.dirname(target_ambari_properties)
 
     if not os.path.exists(target_dirname):
@@ -614,53 +699,58 @@ class GeneratorHelper(object):
     if "ambariProperties" in self.config_data:
       propertyMap = self.config_data.ambariProperties
 
-    with open(source_ambari_properties, 'r') as in_file:
-      with open(target_ambari_properties, 'w') as out_file:
+    with open(source_ambari_properties, "r") as in_file:
+      with open(target_ambari_properties, "w") as out_file:
         replaced_properties = []
         for line in in_file:
-          property = line.split('=')[0]
+          property = line.split("=")[0]
           if property in propertyMap:
-            out_file.write('='.join([property, propertyMap[property]]))
+            out_file.write("=".join([property, propertyMap[property]]))
             out_file.write(os.linesep)
             replaced_properties.append(property)
           else:
             out_file.write(line)
 
         if len(propertyMap) - len(replaced_properties) > 0:
-          out_file.write(os.linesep)  #make sure we don't break last entry from original properties
+          out_file.write(
+            os.linesep
+          )  # make sure we don't break last entry from original properties
 
         for key in propertyMap:
           if key not in replaced_properties:
-            out_file.write('='.join([key, propertyMap[key]]))
+            out_file.write("=".join([key, propertyMap[key]]))
             out_file.write(os.linesep)
-            
+
   def copy_custom_actions(self):
-    original_folder = os.path.join(self.resources_folder, 'custom_actions')
-    target_folder = os.path.join(self.output_folder, 'custom_actions')
-    ignored_files = ['.pyc']
+    original_folder = os.path.join(self.resources_folder, "custom_actions")
+    target_folder = os.path.join(self.output_folder, "custom_actions")
+    ignored_files = [".pyc"]
 
     def post_copy(src, target):
       # process python files
-      if target.endswith('.py'):
+      if target.endswith(".py"):
         # process script.py
         process_py_files(target, self.config_data, self.stack_version_changes)
         return
 
     copy_tree(original_folder, target_folder, ignored_files, post_copy=post_copy)
 
+
 def main(argv):
-  HELP_STRING = 'GenerateStackDefinition.py -c <config> -r <resources_folder> -o <output_folder>'
-  config = ''
-  resources_folder = ''
-  output_folder = ''
+  HELP_STRING = (
+    "GenerateStackDefinition.py -c <config> -r <resources_folder> -o <output_folder>"
+  )
+  config = ""
+  resources_folder = ""
+  output_folder = ""
   try:
     opts, args = getopt.getopt(argv, "hc:o:r:", ["config=", "out=", "resources="])
   except getopt.GetoptError:
-    print HELP_STRING
+    print(HELP_STRING)
     sys.exit(2)
   for opt, arg in opts:
-    if opt == '-h':
-      print HELP_STRING
+    if opt == "-h":
+      print(HELP_STRING)
       sys.exit()
     elif opt in ("-c", "--config"):
       config = arg
@@ -669,7 +759,7 @@ def main(argv):
     elif opt in ("-o", "--out"):
       output_folder = arg
   if not config or not resources_folder or not output_folder:
-    print HELP_STRING
+    print(HELP_STRING)
     sys.exit(2)
 
   config_data = _named_dict(json.load(open(config, "r")))
