@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -20,13 +20,14 @@ Ambari Agent
 
 """
 
-__all__ = ['default', 'default_string']
+__all__ = ["default", "default_string"]
 from resource_management.libraries.script import Script
 from resource_management.libraries.script.config_dictionary import UnknownConfiguration
 from resource_management.core.logger import Logger
 
+
 def default(name, default_value):
-  subdicts = filter(None, name.split('/'))
+  subdicts = [_f for _f in name.split("/") if _f]
 
   curr_dict = Script.get_config()
   if not curr_dict:
@@ -39,6 +40,7 @@ def default(name, default_value):
 
   return curr_dict
 
+
 def default_string(name, default_value, delimiter):
   default_list = default(name, default_value)
   return delimiter.join(default_list)
