@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """
 Licensed to the Apache Software Foundation (ASF) under one
@@ -18,7 +18,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import ambari_simplejson as json # simplejson is much faster comparing to Python 2.6 json module and has the same functions set.
+import ambari_simplejson as json  # simplejson is much faster comparing to Python 2.6 json module and has the same functions set.
 import glob
 import os
 import time
@@ -47,6 +47,7 @@ def get_flume_status(flume_conf_directory, flume_run_directory):
 
   return processes
 
+
 def get_flume_pid_files(flume_conf_directory, flume_run_directory):
   """
   Gets the flume agent pid files
@@ -59,10 +60,11 @@ def get_flume_pid_files(flume_conf_directory, flume_run_directory):
   meta_files = find_expected_agent_names(flume_conf_directory)
   pid_files = []
   for agent_name in meta_files:
-    pid_files.append(os.path.join(flume_run_directory, agent_name + '.pid'))
+    pid_files.append(os.path.join(flume_run_directory, agent_name + ".pid"))
 
   return pid_files
 
+
 def find_expected_agent_names(flume_conf_directory):
   """
   Gets the names of the flume agents that Ambari is aware of.
@@ -106,25 +108,25 @@ def get_live_status(pid_file, flume_conf_directory):
   pid_file_part = pid_file.split(os.sep).pop()
 
   res = {}
-  res['name'] = pid_file_part
+  res["name"] = pid_file_part
 
   if pid_file_part.endswith(".pid"):
-    res['name'] = pid_file_part[:-4]
+    res["name"] = pid_file_part[:-4]
 
-  res['status'] = 'RUNNING' if is_flume_process_live(pid_file) else 'NOT_RUNNING'
-  res['sources_count'] = 0
-  res['sinks_count'] = 0
-  res['channels_count'] = 0
+  res["status"] = "RUNNING" if is_flume_process_live(pid_file) else "NOT_RUNNING"
+  res["sources_count"] = 0
+  res["sinks_count"] = 0
+  res["channels_count"] = 0
 
-  flume_agent_conf_dir = flume_conf_directory + os.sep + res['name']
-  flume_agent_meta_file = flume_agent_conf_dir + os.sep + 'ambari-meta.json'
+  flume_agent_conf_dir = flume_conf_directory + os.sep + res["name"]
+  flume_agent_meta_file = flume_agent_conf_dir + os.sep + "ambari-meta.json"
 
   try:
     with open(flume_agent_meta_file) as fp:
       meta = json.load(fp)
-      res['sources_count'] = meta['sources_count']
-      res['sinks_count'] = meta['sinks_count']
-      res['channels_count'] = meta['channels_count']
+      res["sources_count"] = meta["sources_count"]
+      res["sinks_count"] = meta["sinks_count"]
+      res["channels_count"] = meta["channels_count"]
   except:
     Logger.logger.exception(format("Error reading {flume_agent_meta_file}: "))
 
