@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -21,7 +21,7 @@ Ambari Agent
 """
 
 __all__ = ["get_kdestroy_path"]
-from find_executable import find_executable
+from resource_management.libraries.functions.find_executable import find_executable
 
 
 def get_kdestroy_path(search_directories=None):
@@ -31,4 +31,4 @@ def get_kdestroy_path(search_directories=None):
   @param search_directories: comma separated list or a list of (absolute paths to) directories to search (in order of preference)
   :return: the path to the found kdestroy executable
   """
-  return find_executable(search_directories, "kdestroy")
\ No newline at end of file
+  return find_executable(search_directories, "kdestroy")
