@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -38,40 +38,49 @@ from resource_management.core import shell
 from resource_management.core import sudo
 from resource_management.core.shell import call
 from resource_management.libraries.functions.version import format_stack_version
-from resource_management.libraries.functions.version_select_util import get_versions_from_stack_root
+from resource_management.libraries.functions.version_select_util import (
+  get_versions_from_stack_root,
+)
 from resource_management.libraries.functions import stack_features
 from resource_management.libraries.functions import StackFeature
 from resource_management.libraries.functions import upgrade_summary
+import importlib
 
-STACK_SELECT_PREFIX = 'ambari-python-wrap'
+STACK_SELECT_PREFIX = "ambari-python-wrap"
 
 # mapping of service check to <stack-selector-tool> component
 SERVICE_CHECK_DIRECTORY_MAP = {
-  "HDFS_SERVICE_CHECK" : "hadoop-client",
-  "TEZ_SERVICE_CHECK" : "hadoop-client",
-  "PIG_SERVICE_CHECK" : "hadoop-client",
-  "HIVE_SERVICE_CHECK" : "hadoop-client",
-  "OOZIE_SERVICE_CHECK" : "hadoop-client",
-  "MAHOUT_SERVICE_CHECK" : "mahout-client",
-  "MAPREDUCE2_SERVICE_CHECK" : "hadoop-client",
-  "YARN_SERVICE_CHECK" : "hadoop-client"
+  "HDFS_SERVICE_CHECK": "hadoop-client",
+  "TEZ_SERVICE_CHECK": "hadoop-client",
+  "PIG_SERVICE_CHECK": "hadoop-client",
+  "HIVE_SERVICE_CHECK": "hadoop-client",
+  "OOZIE_SERVICE_CHECK": "hadoop-client",
+  "MAHOUT_SERVICE_CHECK": "mahout-client",
+  "MAPREDUCE2_SERVICE_CHECK": "hadoop-client",
+  "YARN_SERVICE_CHECK": "hadoop-client",
 }
 
 # <stack-root>/current/hadoop-client/[bin|sbin|libexec|lib]
 # <stack-root>/2.3.0.0-1234/hadoop/[bin|sbin|libexec|lib]
 HADOOP_DIR_TEMPLATE = "{0}/{1}/{2}/{3}"
+HADOOP_REAL_DIR_TEMPLATE = "{0}/{1}/{2}/{3}/{4}"
 
 # <stack-root>/current/hadoop-client
 # <stack-root>/2.3.0.0-1234/hadoop
 HADOOP_HOME_DIR_TEMPLATE = "{0}/{1}/{2}"
+HADOOP_REAL_HOME_DIR_TEMPLATE = "{0}/{1}/{2}/{3}"
+LIB_DIR = "usr/lib"
+BIN_DIR = "usr/bin"
 
 HADOOP_DIR_DEFAULTS = {
   "home": "/usr/lib/hadoop",
+  "hdfs_home": "/usr/lib/hadoop-hdfs",
+  "mapred_home": "/usr/lib/hadoop-mapreduce",
+  "yarn_home": "/usr/lib/hadoop-yarn",
   "libexec": "/usr/lib/hadoop/libexec",
   "sbin": "/usr/lib/hadoop/sbin",
   "bin": "/usr/bin",
   "lib": "/usr/lib/hadoop/lib",
-  "conf": "/etc/hadoop/conf"
 }
 
 PACKAGE_SCOPE_INSTALL = "INSTALL"
@@ -83,12 +92,18 @@ PACKAGE_SCOPE_STACK_SELECT = "STACK-SELECT-PACKAGE"
 _PACKAGE_SCOPE_LEGACY = "LEGACY"
 
 # the valid scopes which can be requested
-_PACKAGE_SCOPES = (PACKAGE_SCOPE_INSTALL, PACKAGE_SCOPE_STANDARD, PACKAGE_SCOPE_PATCH, PACKAGE_SCOPE_STACK_SELECT)
+_PACKAGE_SCOPES = (
+  PACKAGE_SCOPE_INSTALL,
+  PACKAGE_SCOPE_STANDARD,
+  PACKAGE_SCOPE_PATCH,
+  PACKAGE_SCOPE_STACK_SELECT,
+)
 
 # the orchestration types which equal to a partial (non-STANDARD) upgrade
 _PARTIAL_ORCHESTRATION_SCOPES = ("PATCH", "MAINT")
 
-def get_package_name(default_package = None):
+
+def get_package_name(default_package=None):
   """
   Gets the stack-select package name for the service name and
   component from the current command. Not all services/components are used with the
@@ -98,11 +113,13 @@ def get_package_name(default_package = None):
   """
   config = Script.get_config()
 
-  if 'role' not in config or 'serviceName' not in config:
-    raise Fail("Both the role and the service name must be included in the command in order to determine which packages to use with the stack-select tool")
+  if "role" not in config or "serviceName" not in config:
+    raise Fail(
+      "Both the role and the service name must be included in the command in order to determine which packages to use with the stack-select tool"
+    )
 
-  service_name = config['serviceName']
-  component_name = config['role']
+  service_name = config["serviceName"]
+  component_name = config["role"]
 
   # should return a single item
   try:
@@ -118,7 +135,7 @@ def get_package_name(default_package = None):
       raise
 
 
-def is_package_supported(package, supported_packages = None):
+def is_package_supported(package, supported_packages=None):
   """
   Gets whether the specified package is supported by the <stack_select> tool.
   :param package: the package to check
@@ -141,16 +158,16 @@ def get_supported_packages():
   """
   stack_selector_path = stack_tools.get_stack_tool_path(stack_tools.STACK_SELECTOR_NAME)
   command = (STACK_SELECT_PREFIX, stack_selector_path, "packages")
-  code, stdout = shell.call(command, sudo = True,  quiet = True)
+  code, stdout = shell.call(command, sudo=True, quiet=True)
 
   if code != 0 or stdout is None:
-    raise Fail("Unable to query for supported packages using {0}".format(stack_selector_path))
+    raise Fail(f"Unable to query for supported packages using {stack_selector_path}")
 
   # turn the output into lines, stripping each line
   return [line.strip() for line in stdout.splitlines()]
 
 
-def get_packages(scope, service_name = None, component_name = None):
+def get_packages(scope, service_name=None, component_name=None):
   """
   Gets the packages which should be used with the stack's stack-select tool for the
   specified service/component. Not all services/components are used with the stack-select tools,
@@ -164,37 +181,45 @@ def get_packages(scope, service_name = None, component_name = None):
   from resource_management.libraries.functions.default import default
 
   if scope not in _PACKAGE_SCOPES:
-    raise Fail("The specified scope of {0} is not valid".format(scope))
+    raise Fail(f"The specified scope of {scope} is not valid")
 
   config = Script.get_config()
 
   if service_name is None or component_name is None:
-    if 'role' not in config or 'serviceName' not in config:
-      raise Fail("Both the role and the service name must be included in the command in order to determine which packages to use with the stack-select tool")
-
-    service_name = config['serviceName']
-    component_name = config['role']
+    if "role" not in config or "serviceName" not in config:
+      raise Fail(
+        "Both the role and the service name must be included in the command in order to determine which packages to use with the stack-select tool"
+      )
 
+    service_name = config["serviceName"]
+    component_name = config["role"]
 
   stack_name = default("/clusterLevelParams/stack_name", None)
   if stack_name is None:
-    raise Fail("The stack name is not present in the command. Packages for stack-select tool cannot be loaded.")
+    raise Fail(
+      "The stack name is not present in the command. Packages for stack-select tool cannot be loaded."
+    )
 
   stack_packages_config = default("/configurations/cluster-env/stack_packages", None)
   if stack_packages_config is None:
-    raise Fail("The stack packages are not defined on the command. Unable to load packages for the stack-select tool")
+    # TODO temporary disabled, we need to re-enable the error after bigtop-select is provided.
+    Logger.error(
+      "Temporary disable: The stack packages are not defined on the command. Unable to load packages for the stack-select tool"
+    )
+    return None
+    # raise Fail("The stack packages are not defined on the command. Unable to load packages for the stack-select tool")
 
   data = json.loads(stack_packages_config)
 
   if stack_name not in data:
-    raise Fail(
-      "Cannot find stack-select packages for the {0} stack".format(stack_name))
+    raise Fail(f"Cannot find stack-select packages for the {stack_name} stack")
 
   stack_select_key = "stack-select"
   data = data[stack_name]
   if stack_select_key not in data:
     raise Fail(
-      "There are no stack-select packages defined for this command for the {0} stack".format(stack_name))
+      f"There are no stack-select packages defined for this command for the {stack_name} stack"
+    )
 
   # this should now be the dictionary of role name to package name
   data = data[stack_select_key]
@@ -202,13 +227,17 @@ def get_packages(scope, service_name = None, component_name = None):
   component_name = component_name.upper()
 
   if service_name not in data:
-    Logger.info("Skipping stack-select on {0} because it does not exist in the stack-select package structure.".format(service_name))
+    Logger.info(
+      f"Skipping stack-select on {service_name} because it does not exist in the stack-select package structure."
+    )
     return None
 
   data = data[service_name]
 
   if component_name not in data:
-    Logger.info("Skipping stack-select on {0} because it does not exist in the stack-select package structure.".format(component_name))
+    Logger.info(
+      f"Skipping stack-select on {component_name} because it does not exist in the stack-select package structure."
+    )
     return None
 
   # this one scope is not an array, so transform it into one for now so we can
@@ -226,12 +255,15 @@ def get_packages(scope, service_name = None, component_name = None):
       if _PACKAGE_SCOPE_LEGACY in data[component_name]:
         legacy_package = data[component_name][_PACKAGE_SCOPE_LEGACY]
         Logger.info(
-          "The package {0} is not supported by this version of the stack-select tool, defaulting to the legacy package of {1}".format(package, legacy_package))
+          f"The package {package} is not supported by this version of the stack-select tool, defaulting to the legacy package of {legacy_package}"
+        )
 
         # use the legacy package
         packages[index] = legacy_package
       else:
-        raise Fail("The package {0} is not supported by this version of the stack-select tool.".format(package))
+        raise Fail(
+          f"The package {package} is not supported by this version of the stack-select tool."
+        )
 
   # transform the array bcak to a single element
   if scope == PACKAGE_SCOPE_STACK_SELECT:
@@ -249,17 +281,25 @@ def select_all(version_to_select):
   :param version_to_select: the version to <stack-selector-tool> on, such as "2.3" or "2.3.0.0-1234"
   """
   stack_root = Script.get_stack_root()
-  (stack_selector_name, stack_selector_path, stack_selector_package) = stack_tools.get_stack_tool(stack_tools.STACK_SELECTOR_NAME)
+  (stack_selector_name, stack_selector_path, stack_selector_package) = (
+    stack_tools.get_stack_tool(stack_tools.STACK_SELECTOR_NAME)
+  )
   # it's an error, but it shouldn't really stop anything from working
   if version_to_select is None:
-    Logger.error(format("Unable to execute {stack_selector_name} after installing because there was no version specified"))
+    Logger.error(
+      format(
+        "Unable to execute {stack_selector_name} after installing because there was no version specified"
+      )
+    )
     return
 
-  Logger.info("Executing {0} set all on {1}".format(stack_selector_name, version_to_select))
+  Logger.info(f"Executing {stack_selector_name} set all on {version_to_select}")
 
-  command = format('{sudo} {stack_selector_path} set all `ambari-python-wrap {stack_selector_path} versions | grep ^{version_to_select} | tail -1`')
-  only_if_command = format('ls -d {stack_root}/{version_to_select}*')
-  Execute(command, only_if = only_if_command)
+  command = format(
+    "{sudo} {stack_selector_path} set all `ambari-python-wrap {stack_selector_path} versions | grep ^{version_to_select} | tail -1`"
+  )
+  only_if_command = format("ls -d {stack_root}/{version_to_select}*")
+  Execute(command, only_if=only_if_command)
 
 
 def select_packages(version):
@@ -287,8 +327,9 @@ def select_packages(version):
   if stack_select_packages is None:
     return
 
-  Logger.info("The following packages will be stack-selected to version {0} using a {1} orchestration and {2} scope: {3}".format(
-    version, orchestration.upper(), package_scope, ", ".join(stack_select_packages)))
+  Logger.info(
+    f"The following packages will be stack-selected to version {version} using a {orchestration.upper()} orchestration and {package_scope} scope: {', '.join(stack_select_packages)}"
+  )
 
   for stack_select_package_name in stack_select_packages:
     select(stack_select_package_name, version)
@@ -320,8 +361,8 @@ def select(component, version):
   for moduleName in param_modules:
     if moduleName in modules:
       module = modules.get(moduleName)
-      reload(module)
-      Logger.info("After {0}, reloaded module {1}".format(command, moduleName))
+      importlib.reload(module)
+      Logger.info(f"After {command}, reloaded module {moduleName}")
 
 
 def get_role_component_current_stack_version():
@@ -330,10 +371,10 @@ def get_role_component_current_stack_version():
   :return:  the current HDP version of the specified component or None
   """
   role = default("/role", "")
-  role_command =  default("/roleCommand", "")
+  role_command = default("/roleCommand", "")
 
   stack_selector_name = stack_tools.get_stack_tool_name(stack_tools.STACK_SELECTOR_NAME)
-  Logger.info("Checking version for {0} via {1}".format(role, stack_selector_name))
+  Logger.info(f"Checking version for {role} via {stack_selector_name}")
   if role_command == "SERVICE_CHECK" and role in SERVICE_CHECK_DIRECTORY_MAP:
     stack_select_component = SERVICE_CHECK_DIRECTORY_MAP[role]
   else:
@@ -343,17 +384,19 @@ def get_role_component_current_stack_version():
     if not role:
       Logger.error("No role information available.")
     elif not role.lower().endswith("client"):
-      Logger.error("Mapping unavailable for role {0}. Skip checking its version.".format(role))
+      Logger.error(f"Mapping unavailable for role {role}. Skip checking its version.")
     return None
 
   current_stack_version = get_stack_version(stack_select_component)
 
   if current_stack_version is None:
-    Logger.warning("Unable to determine {0} version for {1}".format(
-      stack_selector_name, stack_select_component))
+    Logger.warning(
+      f"Unable to determine {stack_selector_name} version for {stack_select_component}"
+    )
   else:
-    Logger.info("{0} is currently at version {1}".format(
-      stack_select_component, current_stack_version))
+    Logger.info(
+      f"{stack_select_component} is currently at version {current_stack_version}"
+    )
 
   return current_stack_version
 
@@ -370,13 +413,15 @@ def get_hadoop_dir(target):
   stack_version = Script.get_stack_version()
 
   if not target in HADOOP_DIR_DEFAULTS:
-    raise Fail("Target {0} not defined".format(target))
+    raise Fail(f"Target {target} not defined")
 
   hadoop_dir = HADOOP_DIR_DEFAULTS[target]
 
   formatted_stack_version = format_stack_version(stack_version)
 
-  if stack_features.check_stack_feature(StackFeature.ROLLING_UPGRADE, formatted_stack_version):
+  if stack_features.check_stack_feature(
+    StackFeature.ROLLING_UPGRADE, formatted_stack_version
+  ):
     # read the desired version from the component map and use that for building the hadoop home
     version = component_version.get_component_repository_version()
     if version is None:
@@ -384,13 +429,49 @@ def get_hadoop_dir(target):
 
     # home uses a different template
     if target == "home":
-      hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(stack_root, version, "hadoop")
+      hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+        stack_root, version, LIB_DIR, "hadoop"
+      )
       if version is None or sudo.path_isdir(hadoop_dir) is False:
-        hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(stack_root, "current", "hadoop-client")
+        hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(
+          stack_root, "current", "hadoop-client"
+        )
+    elif target == "hdfs_home":
+      hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+        stack_root, version, LIB_DIR, "hadoop-hdfs"
+      )
+      if version is None or sudo.path_isdir(hadoop_dir) is False:
+        hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(
+          stack_root, "current", "hadoop-hdfs-client"
+        )
+    elif target == "mapred_home":
+      hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+        stack_root, version, LIB_DIR, "hadoop-mapreduce"
+      )
+      if version is None or sudo.path_isdir(hadoop_dir) is False:
+        hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(
+          stack_root, "current", "hadoop-mapreduce-client"
+        )
+    elif target == "yarn_home":
+      hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+        stack_root, version, LIB_DIR, "hadoop-yarn"
+      )
+      if version is None or sudo.path_isdir(hadoop_dir) is False:
+        hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(
+          stack_root, "current", "hadoop-yarn-client"
+        )
+    elif target == "bin":
+      hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(stack_root, version, BIN_DIR)
+      if version is None or sudo.path_isdir(hadoop_dir) is False:
+        hadoop_dir = HADOOP_DIR_DEFAULTS[target]
     else:
-      hadoop_dir = HADOOP_DIR_TEMPLATE.format(stack_root, version, "hadoop", target)
+      hadoop_dir = HADOOP_REAL_DIR_TEMPLATE.format(
+        stack_root, version, LIB_DIR, "hadoop", target
+      )
       if version is None or sudo.path_isdir(hadoop_dir) is False:
-        hadoop_dir = HADOOP_DIR_TEMPLATE.format(stack_root, "current", "hadoop-client", target)
+        hadoop_dir = HADOOP_DIR_TEMPLATE.format(
+          stack_root, "current", "hadoop-client", target
+        )
 
   return hadoop_dir
 
@@ -405,13 +486,31 @@ def get_hadoop_dir_for_stack_version(target, stack_version):
 
   stack_root = Script.get_stack_root()
   if not target in HADOOP_DIR_DEFAULTS:
-    raise Fail("Target {0} not defined".format(target))
+    raise Fail(f"Target {target} not defined")
 
   # home uses a different template
   if target == "home":
-    hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(stack_root, stack_version, "hadoop")
+    hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+      stack_root, stack_version, LIB_DIR, "hadoop"
+    )
+  elif target == "hdfs_home":
+    hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+      stack_root, stack_version, LIB_DIR, "hadoop-hdfs"
+    )
+  elif target == "mapred_home":
+    hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+      stack_root, stack_version, LIB_DIR, "hadoop-mapreduce"
+    )
+  elif target == "yarn_home":
+    hadoop_dir = HADOOP_REAL_HOME_DIR_TEMPLATE.format(
+      stack_root, stack_version, LIB_DIR, "hadoop-yarn"
+    )
+  elif target == "bin":
+    hadoop_dir = HADOOP_HOME_DIR_TEMPLATE.format(stack_root, stack_version, BIN_DIR)
   else:
-    hadoop_dir = HADOOP_DIR_TEMPLATE.format(stack_root, stack_version, "hadoop", target)
+    hadoop_dir = HADOOP_REAL_DIR_TEMPLATE.format(
+      stack_root, stack_version, LIB_DIR, "hadoop", target
+    )
 
   return hadoop_dir
 
@@ -423,6 +522,7 @@ def _get_upgrade_stack():
   upgrade is not in progress.
   """
   from resource_management.libraries.functions.default import default
+
   direction = default("/commandParams/upgrade_direction", None)
   stack_name = default("/clusterLevelParams/stack_name", None)
   stack_version = default("/commandParams/version", None)
@@ -432,6 +532,7 @@ def _get_upgrade_stack():
 
   return None
 
+
 def unsafe_get_stack_versions():
   """
   Gets list of stack versions installed on the host.
@@ -440,13 +541,14 @@ def unsafe_get_stack_versions():
   :return: Returns a tuple of (exit code, output, list of installed stack versions).
   """
   stack_selector_path = stack_tools.get_stack_tool_path(stack_tools.STACK_SELECTOR_NAME)
-  code, out = call((STACK_SELECT_PREFIX, stack_selector_path, 'versions'))
+  code, out = call((STACK_SELECT_PREFIX, stack_selector_path, "versions"))
   versions = []
   if 0 == code:
     for line in out.splitlines():
-      versions.append(line.rstrip('\n'))
+      versions.append(line.rstrip("\n"))
   return (code, out, versions)
 
+
 def get_stack_versions(stack_root):
   """
   Gets list of stack versions installed on the host.
@@ -456,31 +558,36 @@ def get_stack_versions(stack_root):
   :return: Returns list of installed stack versions.
   """
   stack_selector_path = stack_tools.get_stack_tool_path(stack_tools.STACK_SELECTOR_NAME)
-  code, out = call((STACK_SELECT_PREFIX, stack_selector_path, 'versions'))
+  code, out = call((STACK_SELECT_PREFIX, stack_selector_path, "versions"))
   versions = []
   if 0 == code:
     for line in out.splitlines():
-      versions.append(line.rstrip('\n'))
+      versions.append(line.rstrip("\n"))
   if not versions:
     versions = get_versions_from_stack_root(stack_root)
   return versions
 
+
 def get_stack_version_before_install(component_name):
   """
   Works in the similar way to '<stack-selector-tool> status component',
   but also works for not yet installed packages.
-  
+
   Note: won't work if doing initial install.
   """
   stack_root = Script.get_stack_root()
   component_dir = HADOOP_HOME_DIR_TEMPLATE.format(stack_root, "current", component_name)
   stack_selector_name = stack_tools.get_stack_tool_name(stack_tools.STACK_SELECTOR_NAME)
   if os.path.islink(component_dir):
-    stack_version = os.path.basename(os.path.dirname(os.readlink(component_dir)))
-    match = re.match('[0-9]+.[0-9]+.[0-9]+.[0-9]+-[0-9]+', stack_version)
+    stack_version = os.path.basename(
+      os.path.dirname(os.path.dirname(os.path.dirname(os.readlink(component_dir))))
+    )
+    match = re.match("[0-9]+.[0-9]+.[0-9]+", stack_version)
     if match is None:
-      Logger.info('Failed to get extracted version with {0} in method get_stack_version_before_install'.format(stack_selector_name))
-      return None # lazy fail
+      Logger.info(
+        f"Failed to get extracted version with {stack_selector_name} in method get_stack_version_before_install"
+      )
+      return None  # lazy fail
     return stack_version
   else:
     return None
