@@ -1,6 +1,5 @@
-#!/usr/bin/env python
-
-'''
+#!/usr/bin/env python3
+"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
@@ -16,10 +15,17 @@ distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-'''
+"""
 
-__all__ = ["get_stack_tool", "get_stack_tool_name", "get_stack_tool_path",
-           "get_stack_tool_package", "get_stack_name", "STACK_SELECTOR_NAME", "CONF_SELECTOR_NAME"]
+__all__ = [
+  "get_stack_tool",
+  "get_stack_tool_name",
+  "get_stack_tool_path",
+  "get_stack_tool_package",
+  "get_stack_name",
+  "STACK_SELECTOR_NAME",
+  "CONF_SELECTOR_NAME",
+]
 
 # simplejson is much faster comparing to Python 2.6 json module and has the same functions set.
 import ambari_simplejson as json
@@ -43,7 +49,9 @@ def get_stack_tool(name):
 
   stack_name = default("/clusterLevelParams/stack_name", None)
   if stack_name is None:
-    Logger.warning("Cannot find the stack name in the command. Stack tools cannot be loaded")
+    Logger.warning(
+      "Cannot find the stack name in the command. Stack tools cannot be loaded"
+    )
     return None, None, None
 
   stack_tools = None
@@ -56,14 +64,16 @@ def get_stack_tool(name):
     return None, None, None
 
   if stack_name not in stack_tools:
-    Logger.warning("Cannot find stack tools for the stack named {0}".format(stack_name))
+    Logger.warning(f"Cannot find stack tools for the stack named {stack_name}")
     return None, None, None
 
   # load the stack tooks keyed by the stack name
   stack_tools = stack_tools[stack_name]
 
   if not stack_tools or not name or name.lower() not in stack_tools:
-    Logger.warning("Cannot find config for {0} stack tool in {1}".format(str(name), str(stack_tools)))
+    Logger.warning(
+      f"Cannot find config for {str(name)} stack tool in {str(stack_tools)}"
+    )
     return None, None, None
 
   tool_config = stack_tools[name.lower()]
@@ -71,6 +81,7 @@ def get_stack_tool(name):
   # Return fixed length (tool_name, tool_path, tool_package) tuple
   return tuple(pad(tool_config[:3], 3))
 
+
 def get_stack_tool_name(name):
   """
   Give a tool selector name get the stack-specific tool name
@@ -111,13 +122,13 @@ def get_stack_root(stack_name, stack_root_json):
   from resource_management.libraries.functions.default import default
 
   if stack_root_json is None:
-    return "/usr/{0}".format(stack_name.lower())
+    return f"/usr/{stack_name.lower()}"
 
   stack_root = json.loads(stack_root_json)
 
   if stack_name not in stack_root:
-    Logger.warning("Cannot determine stack root for stack named {0}".format(stack_name))
-    return "/usr/{0}".format(stack_name.lower())
+    Logger.warning(f"Cannot determine stack root for stack named {stack_name}")
+    return f"/usr/{stack_name.lower()}"
 
   return stack_root[stack_name]
 
@@ -129,7 +140,7 @@ def get_stack_name(stack_formatted):
   if stack_formatted is None:
     return None
 
-  if '-' not in stack_formatted:
+  if "-" not in stack_formatted:
     return stack_formatted
 
-  return stack_formatted.split('-')[0]
\ No newline at end of file
+  return stack_formatted.split("-")[0]
