@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -19,8 +19,10 @@ limitations under the License.
 Ambari Agent
 
 """
+
 import re
 
+
 def _normalize(v, desired_segments=0):
   """
   :param v: Input string of the form "#.#.#" or "#.#.#.#"
@@ -30,7 +32,12 @@ def _normalize(v, desired_segments=0):
   """
   v_list = v.split(".")
   if desired_segments > 0 and len(v_list) < desired_segments:
-    v_list = v_list + ((desired_segments - len(v_list)) * ["0", ])
+    v_list = v_list + (
+      (desired_segments - len(v_list))
+      * [
+        "0",
+      ]
+    )
   return [int(x) for x in v_list]
 
 
@@ -46,25 +53,26 @@ def format_stack_version(value):
 
       if first_occurrence == last_occurence:
         if value[0].isalpha():
-          value = value[first_occurrence + 1:]
+          value = value[first_occurrence + 1 :]
         else:
           value = value[:first_occurrence]
       else:
-        value = value[first_occurrence + 1:last_occurence]
+        value = value[first_occurrence + 1 : last_occurence]
 
+    value = re.sub(r"^\D+", "", value)
+    value = re.sub(r"\D+$", "", value)
+    value = value.strip(".")
 
-    value = re.sub(r'^\D+', '', value)
-    value = re.sub(r'\D+$', '', value)
-    value = value.strip('.')
-
-    strip_dots = value.replace('.', '')
+    strip_dots = value.replace(".", "")
     if strip_dots.isdigit():
       normalized = _normalize(str(value))
       if len(normalized) == 2:
-        normalized = normalized + [0, 0]
-      elif len(normalized) == 3:
-        normalized = normalized + [0, ]
-      normalized = [str(x) for x in normalized]   # need to convert each number into a string
+        normalized = normalized + [
+          0,
+        ]
+      normalized = [
+        str(x) for x in normalized
+      ]  # need to convert each number into a string
       return ".".join(normalized)
   return ""
 
@@ -82,8 +90,15 @@ def compare_versions(version1, version2, format=False):
   v1 = version1 if not format else format_stack_version(version1)
   v2 = version2 if not format else format_stack_version(version2)
 
+  def cmp(a, b):
+    return (a > b) - (a < b)
+
   max_segments = max(len(v1.split(".")), len(v2.split(".")))
-  return cmp(_normalize(v1, desired_segments=max_segments), _normalize(v2, desired_segments=max_segments))
+  return cmp(
+    _normalize(v1, desired_segments=max_segments),
+    _normalize(v2, desired_segments=max_segments),
+  )
+
 
 def get_major_version(full_version):
   """
@@ -91,7 +106,7 @@ def get_major_version(full_version):
   :return: Returns a well-formatted HDP major stack version of the form #.# as a string. If can't get major version
   return None
   """
-  pattern = re.compile(r'^[0-9]+\.[0-9]+')
+  pattern = re.compile(r"^[0-9]+\.[0-9]+")
   major_version = None
 
   m = pattern.search(full_version)
@@ -99,3 +114,31 @@ def get_major_version(full_version):
     major_version = m.group()
 
   return major_version
+
+
+def get_current_component_version():
+  """
+  Returns best available version for the component at different stages (install, start, stop)
+
+  :return best matched version or None
+  :rtype str|None
+  """
+  from resource_management.core.exceptions import Fail
+  from resource_management.libraries.functions.default import default
+  from resource_management.libraries.functions.stack_select import (
+    get_role_component_current_stack_version,
+  )
+  from resource_management.libraries.functions.repository_util import CommandRepository
+
+  version = default("/commandParams/version", None)
+  if not version:
+    repository = CommandRepository(default("/repositoryFile", {}))
+    if not repository.resolved:
+      try:
+        version = get_role_component_current_stack_version()
+      except (Fail, TypeError):
+        pass
+    else:
+      version = repository.version_string
+
+  return version
