@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -31,14 +31,20 @@ from resource_management.core.environment import Environment
 from resource_management.core.logger import Logger
 from resource_management.libraries.functions.is_empty import is_empty
 
+
 class XmlConfigProvider(Provider):
   def action_create(self):
     filename = self.resource.filename
     xml_config_provider_config_dir = self.resource.conf_dir
-    configuration_attrs = {} if is_empty(self.resource.configuration_attributes) else self.resource.configuration_attributes
+    configuration_attrs = (
+      {}
+      if is_empty(self.resource.configuration_attributes)
+      else self.resource.configuration_attributes
+    )
 
     # |e - for html-like escaping of <,>,',"
-    config_content = InlineTemplate('''  <configuration  xmlns:xi="http://www.w3.org/2001/XInclude">
+    config_content = InlineTemplate(
+      """  <configuration  xmlns:xi="http://www.w3.org/2001/XInclude">
     {% for key, value in configurations_dict|dictsort %}
     <property>
       <name>{{ key|e }}</name>
@@ -57,17 +63,26 @@ class XmlConfigProvider(Provider):
     {%- if not xml_include_file is none %}
     <xi:include href="{{xml_include_file|e}}"/>
     {% endif %}
-  </configuration>''', extra_imports=[time, resource_management, resource_management.core, resource_management.core.source],
-                                    configurations_dict=self.resource.configurations,
-                                    configuration_attrs=configuration_attrs, xml_include_file=self.resource.xml_include_file)
+  </configuration>""",
+      extra_imports=[
+        time,
+        resource_management,
+        resource_management.core,
+        resource_management.core.source,
+      ],
+      configurations_dict=self.resource.configurations,
+      configuration_attrs=configuration_attrs,
+      xml_include_file=self.resource.xml_include_file,
+    )
 
     xml_config_dest_file_path = os.path.join(xml_config_provider_config_dir, filename)
-    Logger.info("Generating config: {0}".format(xml_config_dest_file_path))
+    Logger.info(f"Generating config: {xml_config_dest_file_path}")
 
-    File (xml_config_dest_file_path,
-      content = config_content,
-      owner = self.resource.owner,
-      group = self.resource.group,
-      mode = self.resource.mode,
-      encoding = self.resource.encoding
+    File(
+      xml_config_dest_file_path,
+      content=config_content,
+      owner=self.resource.owner,
+      group=self.resource.group,
+      mode=self.resource.mode,
+      encoding=self.resource.encoding,
     )
