@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -21,16 +21,22 @@ Ambari Agent
 """
 
 _all__ = ["XmlConfig"]
-from resource_management.core.base import Resource, ForcedListArgument, ResourceArgument, BooleanArgument
+from resource_management.core.base import (
+  Resource,
+  ForcedListArgument,
+  ResourceArgument,
+  BooleanArgument,
+)
+
 
 class XmlConfig(Resource):
   action = ForcedListArgument(default="create")
   filename = ResourceArgument(default=lambda obj: obj.name)
-  
+
   configurations = ResourceArgument()
   configuration_attributes = ResourceArgument()
   conf_dir = ResourceArgument()
-  
+
   mode = ResourceArgument()
   owner = ResourceArgument()
   group = ResourceArgument()
