@@ -1,10 +1,13 @@
+#!/usr/bin/env python3
 """
 Authentication providers.
 
 Because authentication providers are instantiated and configured in the application scope
 (and not in the request handler), the authenticator implementations must be thread-safe.
 """
+
 import abc
+
 __authors__ = ['"Hans Lellelid" <hans@xmpl.org>']
 __copyright__ = "Copyright 2009 Hans Lellelid"
 __license__ = """Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,15 +23,14 @@ See the License for the specific language governing permissions and
 limitations under the License."""
 
 
-class Authenticator(object):
-    """ Abstract base class for authenticators. """
-    __metaclass__ = abc.ABCMeta
+class Authenticator(object, metaclass=abc.ABCMeta):
+  """Abstract base class for authenticators."""
 
-    @abc.abstractmethod
-    def authenticate(self, login, passcode):
-        """
-        Authenticate the login and passcode.
+  @abc.abstractmethod
+  def authenticate(self, login, passcode):
+    """
+    Authenticate the login and passcode.
 
-        @return: Whether user is authenticated.
-        @rtype: C{bool} 
-        """
+    @return: Whether user is authenticated.
+    @rtype: C{bool}
+    """
