@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -21,15 +21,14 @@ limitations under the License.
 from resource_management import *
 
 
-def mysql_service(daemon_name=None, action='start'):
-
-  logoutput=True
-  if action == 'start':
-    cmd = format('service {daemon_name} start')
-  elif action == 'stop':
-    cmd = format('service {daemon_name} stop')
-  elif action == 'status':
-    cmd = format('service {daemon_name} status')
+def mysql_service(daemon_name=None, action="start"):
+  logoutput = True
+  if action == "start":
+    cmd = format("service {daemon_name} start")
+  elif action == "stop":
+    cmd = format("service {daemon_name} stop")
+  elif action == "status":
+    cmd = format("service {daemon_name} status")
     logoutput = False
     try:
       Execute(cmd)
@@ -40,10 +39,4 @@ def mysql_service(daemon_name=None, action='start'):
     cmd = None
 
   if cmd is not None:
-    Execute(cmd,
-            path="/usr/local/bin/:/bin/:/sbin/",
-            tries=1,
-            logoutput=logoutput)
-
-
-
+    Execute(cmd, path="/usr/local/bin/:/bin/:/sbin/", tries=1, logoutput=logoutput)
