@@ -20,7 +20,6 @@ package org.apache.ambari.server.actionmanager;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -28,6 +27,8 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.locks.ReadWriteLock;
+import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 import org.apache.ambari.annotations.TransactionalLock;
 import org.apache.ambari.annotations.TransactionalLock.LockArea;
@@ -153,6 +154,10 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
   private Cache<Long, HostRoleCommand> hostRoleCommandCache;
   private long cacheLimit; //may be exceeded to store tasks from one request
 
+  //We do lock for writing/reading when HRCs are manipulated/read by different threads
+  //For instance we do lock for writing when aborting all HRCs of a request to avoid reading the same HRCs by agent report processor (so that we lock there for reading too)
+  private final ReadWriteLock hrcOperationsLock = new ReentrantReadWriteLock();
+
   @Inject
   public ActionDBAccessorImpl(@Named("executionCommandCacheSize") long cacheLimit,
                               AmbariEventPublisher eventPublisher) {
@@ -213,32 +218,35 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
    */
   @Override
   public Collection<HostRoleCommandEntity> abortOperation(long requestId) {
-    Collection<HostRoleCommandEntity> abortedHostRoleCommands = Collections.emptyList();
-    long now = System.currentTimeMillis();
+    try {
+      hrcOperationsLock.writeLock().lock();
+      Collection<HostRoleCommandEntity> abortedHostRoleCommands = new ArrayList<>();
+      long now = System.currentTimeMillis();
 
-    // only request commands which actually need to be aborted; requesting all
-    // commands here can cause OOM problems during large requests like upgrades
-    List<HostRoleCommandEntity> commands = hostRoleCommandDAO.findByRequestIdAndStatuses(requestId,
-        HostRoleStatus.STATES_TO_ABORT);
+      // only request commands which actually need to be aborted; requesting all
+      // commands here can cause OOM problems during large requests like upgrades
+      List<HostRoleCommandEntity> commands = hostRoleCommandDAO.findByRequestIdAndStatuses(requestId,
+          HostRoleStatus.SCHEDULED_STATES);
 
-    for (HostRoleCommandEntity command : commands) {
-      command.setStatus(HostRoleStatus.ABORTED);
-      command.setEndTime(now);
-      LOG.info("Aborting command. Hostname " + command.getHostName()
-          + " role " + command.getRole()
-          + " requestId " + command.getRequestId()
-          + " taskId " + command.getTaskId()
-          + " stageId " + command.getStageId());
+      for (HostRoleCommandEntity command : commands) {
+        command.setStatus(HostRoleStatus.ABORTED);
+        command.setEndTime(now);
+        abortedHostRoleCommands.add(hostRoleCommandDAO.merge(command));
+        LOG.info("Aborted command. Hostname " + command.getHostName()
+        + " role " + command.getRole()
+        + " requestId " + command.getRequestId()
+        + " taskId " + command.getTaskId()
+        + " stageId " + command.getStageId());
 
-      auditLog(command, requestId);
+        auditLog(command, requestId);
+        cacheHostRoleCommand(hostRoleCommandFactory.createExisting(command));
+      }
+
+      endRequest(requestId);
+      return abortedHostRoleCommands;
+    } finally {
+      hrcOperationsLock.writeLock().unlock();
     }
-
-    // no need to merge if there's nothing to merge
-    if (!commands.isEmpty()) {
-      abortedHostRoleCommands = hostRoleCommandDAO.mergeAll(commands);
-    }
-    endRequest(requestId);
-    return abortedHostRoleCommands;
   }
 
   /* (non-Javadoc)
@@ -513,14 +521,22 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
     long now = System.currentTimeMillis();
 
     List<Long> requestsToCheck = new ArrayList<>();
-    List<Long> abortedCommandUpdates = new ArrayList<>();
 
-    List<HostRoleCommandEntity> commandEntities = hostRoleCommandDAO.findByPKs(taskReports.keySet());
-    List<HostRoleCommandEntity> commandEntitiesToMerge = new ArrayList<>();
+    List<HostRoleCommandEntity> commandEntities;
+    try {
+      hrcOperationsLock.readLock().lock();
+      commandEntities = hostRoleCommandDAO.findByPKs(taskReports.keySet());
+    } finally {
+      hrcOperationsLock.readLock().unlock();
+    }
     for (HostRoleCommandEntity commandEntity : commandEntities) {
       CommandReport report = taskReports.get(commandEntity.getTaskId());
       HostRoleStatus existingTaskStatus = commandEntity.getStatus();
       HostRoleStatus reportedTaskStatus = HostRoleStatus.valueOf(report.getStatus());
+      if (!existingTaskStatus.isCompletedState()) {
+        //sometimes JPA cache returns a task with incorrect state (i.e. it was aborted just before we queried above); reading it from the DB for the sake of integrity
+        //existingTaskStatus = hostRoleCommandDAO.refreshHostRoleCommand(commandEntity).getStatus();
+      }
       if (!existingTaskStatus.isCompletedState() || existingTaskStatus == HostRoleStatus.ABORTED) {
         // if FAILED and marked for holding then set reportedTaskStatus = HOLDING_FAILED
         if (reportedTaskStatus == HostRoleStatus.FAILED && commandEntity.isRetryAllowed()) {
@@ -538,6 +554,7 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
         }
 
         if (!existingTaskStatus.isCompletedState()) {
+          LOG.debug("Setting status from {} to {} for {}", existingTaskStatus, reportedTaskStatus, commandEntity.getTaskId());
           commandEntity.setStatus(reportedTaskStatus);
         }
         commandEntity.setStdOut(report.getStdOut() == null ? null : report.getStdOut().getBytes());
@@ -545,9 +562,18 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
         commandEntity.setStructuredOut(report.getStructuredOut() == null ? null :
             report.getStructuredOut().getBytes());
         commandEntity.setExitcode(report.getExitCode());
-        if (HostRoleStatus.getCompletedStates().contains(commandEntity.getStatus())) {
+        if (commandEntity.getStatus().isCompletedState()) {
           commandEntity.setEndTime(now);
+        }
 
+        try {
+          hrcOperationsLock.writeLock().lock();
+          hostRoleCommandDAO.merge(commandEntity);
+        } finally {
+          hrcOperationsLock.writeLock().unlock();
+        }
+
+        if (commandEntity.getStatus().isCompletedState()) {
           String actionId = report.getActionId();
           long[] requestStageIds = StageUtils.getRequestStage(actionId);
           long requestId = requestStageIds[0];
@@ -557,19 +583,12 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
             requestsToCheck.add(requestId);
           }
         }
-        commandEntitiesToMerge.add(commandEntity);
       } else {
        LOG.warn(String.format("Request for invalid transition of host role command status received for task id %d from " +
-           "agent: %s -> %s",commandEntity.getTaskId(),existingTaskStatus,reportedTaskStatus));
+           "agent: %s -> %s",commandEntity.getTaskId(), existingTaskStatus, reportedTaskStatus));
       }
     }
 
-    // no need to merge if there's nothing to merge
-    if (!commandEntitiesToMerge.isEmpty()) {
-      hostRoleCommandDAO.mergeAll(commandEntitiesToMerge);
-    }
-
-
     for (Long requestId : requestsToCheck) {
       endRequestIfCompleted(requestId);
     }
@@ -716,34 +735,45 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
       return Collections.emptyList();
     }
 
-    Map<Long, HostRoleCommand> cached = hostRoleCommandCache.getAllPresent(taskIds);
-    List<HostRoleCommand> commands = new ArrayList<>(cached.values());
+    List<HostRoleCommand> commands;
+    try {
+      hrcOperationsLock.readLock().lock();
+      Map<Long, HostRoleCommand> cached = hostRoleCommandCache.getAllPresent(taskIds);
+      commands = new ArrayList<>(cached.values());
 
-    List<Long> absent = new ArrayList<>(taskIds);
-    absent.removeAll(cached.keySet());
+      List<Long> absent = new ArrayList<>(taskIds);
+      absent.removeAll(cached.keySet());
 
-    if (!absent.isEmpty()) {
-      boolean allowStore = hostRoleCommandCache.size() <= cacheLimit;
-
-      for (HostRoleCommandEntity commandEntity : hostRoleCommandDAO.findByPKs(absent)) {
-        HostRoleCommand hostRoleCommand = hostRoleCommandFactory.createExisting(commandEntity);
-        commands.add(hostRoleCommand);
-        if (allowStore) {
-          switch (hostRoleCommand.getStatus()) {
-            case ABORTED:
-            case COMPLETED:
-            case TIMEDOUT:
-            case FAILED:
-              hostRoleCommandCache.put(hostRoleCommand.getTaskId(), hostRoleCommand);
-              break;
-          }
+      if (!absent.isEmpty()) {
+        for (HostRoleCommandEntity commandEntity : hostRoleCommandDAO.findByPKs(absent)) {
+          HostRoleCommand hostRoleCommand = hostRoleCommandFactory.createExisting(commandEntity);
+          commands.add(hostRoleCommand);
+          cacheHostRoleCommand(hostRoleCommand);
         }
       }
+      commands.sort((o1, o2) -> (int) (o1.getTaskId() - o2.getTaskId()));
+    } finally {
+      hrcOperationsLock.readLock().unlock();
     }
-    commands.sort((o1, o2) -> (int) (o1.getTaskId() - o2.getTaskId()));
     return commands;
   }
 
+  private void cacheHostRoleCommand(HostRoleCommand hostRoleCommand) {
+    if (hostRoleCommandCache.size() <= cacheLimit) {
+      switch (hostRoleCommand.getStatus()) {
+      case ABORTED:
+      case COMPLETED:
+      case TIMEDOUT:
+      case FAILED:
+        hostRoleCommandCache.put(hostRoleCommand.getTaskId(), hostRoleCommand);
+        break;
+      default:
+        // NOP
+        break;
+      }
+    }
+  }
+
   @Override
   public List<HostRoleCommand> getTasksByHostRoleAndStatus(String hostname, String role, HostRoleStatus status) {
     return getTasks(hostRoleCommandDAO.findTaskIdsByHostRoleAndStatus(hostname, role, status));
@@ -756,11 +786,16 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
 
   @Override
   public HostRoleCommand getTask(long taskId) {
-    HostRoleCommandEntity commandEntity = hostRoleCommandDAO.findByPK((int) taskId);
-    if (commandEntity == null) {
-      return null;
+    try {
+      hrcOperationsLock.readLock().lock();
+      HostRoleCommandEntity commandEntity = hostRoleCommandDAO.findByPK(taskId);
+      if (commandEntity == null) {
+        return null;
+      }
+      return hostRoleCommandFactory.createExisting(commandEntity);
+    } finally {
+      hrcOperationsLock.readLock().unlock();
     }
-    return hostRoleCommandFactory.createExisting(commandEntity);
   }
 
   @Override
@@ -771,7 +806,7 @@ public class ActionDBAccessorImpl implements ActionDBAccessor {
       return requestDAO.findAllRequestIds(maxResults, ascOrder);
     }
 
-    EnumSet<HostRoleStatus> taskStatuses = null;
+    Set<HostRoleStatus> taskStatuses = null;
     switch( status ){
       case IN_PROGRESS:
         taskStatuses = HostRoleStatus.IN_PROGRESS_STATUSES;
