@@ -61,7 +61,6 @@ import org.apache.ambari.server.orm.entities.RequestEntity;
 import org.apache.ambari.server.serveraction.ServerActionExecutor;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
-import org.apache.ambari.server.state.ConfigHelper;
 import org.apache.ambari.server.state.Host;
 import org.apache.ambari.server.state.HostState;
 import org.apache.ambari.server.state.Service;
@@ -71,7 +70,7 @@ import org.apache.ambari.server.state.ServiceComponentHostEvent;
 import org.apache.ambari.server.state.fsm.InvalidStateTransitionException;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostOpFailedEvent;
 import org.apache.ambari.server.utils.StageUtils;
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -401,14 +400,6 @@ class ActionScheduler implements Runnable {
 
       int i_stage = 0;
 
-      // get the range of requests in progress
-      long iLowestRequestIdInProgress = firstStageInProgressPerRequest.get(0).getRequestId();
-      long iHighestRequestIdInProgress = firstStageInProgressPerRequest.get(
-          firstStageInProgressPerRequest.size() - 1).getRequestId();
-
-      List<String> hostsWithPendingTasks = hostRoleCommandDAO.getHostsWithPendingTasks(
-          iLowestRequestIdInProgress, iHighestRequestIdInProgress);
-
       // filter the stages in progress down to those which can be scheduled in
       // parallel
       List<Stage> stages = filterParallelPerHostStages(firstStageInProgressPerRequest);
@@ -490,7 +481,6 @@ class ActionScheduler implements Runnable {
 
 
         for (ExecutionCommand cmd : commandsToSchedule) {
-          ConfigHelper.processHiddenAttribute(cmd.getConfigurations(), cmd.getConfigurationAttributes(), cmd.getRole(), false);
           processHostRole(request, stage, cmd, commandsToStart, commandsToUpdate);
         }
 
@@ -1232,9 +1222,9 @@ class ActionScheduler implements Runnable {
           cancelHostRoleCommands(tasksToDequeue, reason);
         }
 
-        // abort any stages in progress and holding states that belong to this request;
-        // don't execute this for all stages since that could lead to OOM errors on large requests,
-        // like those for upgrades
+        // abort any stages in progress that belong to this request; don't execute this for all stages since
+        // that could lead to OOM errors on large requests, like those for
+        // upgrades
         List<Stage> stagesInProgress = db.getStagesInProgressForRequest(requestId);
         for (Stage stageInProgress : stagesInProgress) {
           abortOperationsForStage(stageInProgress);
@@ -1268,6 +1258,12 @@ class ActionScheduler implements Runnable {
         }
       }
 
+      if (hostRoleCommand.getStatus().isHoldingState()) {
+        db.abortHostRole(hostRoleCommand.getHostName(),
+            hostRoleCommand.getRequestId(),
+            hostRoleCommand.getStageId(), hostRoleCommand.getRole().name());
+      }
+
       // If host role is an Action, we have to send an event
       if (hostRoleCommand.getRoleCommand().equals(RoleCommand.ACTIONEXECUTE)) {
         String clusterName = hostRoleCommand.getExecutionCommandWrapper().getExecutionCommand().getClusterName();
