@@ -56,6 +56,7 @@ import org.apache.ambari.server.metadata.ActionMetadata;
 import org.apache.ambari.server.orm.dao.KerberosKeytabDAO;
 import org.apache.ambari.server.orm.dao.KerberosKeytabPrincipalDAO;
 import org.apache.ambari.server.orm.entities.KerberosKeytabPrincipalEntity;
+import org.apache.ambari.server.stack.upgrade.Direction;
 import org.apache.ambari.server.state.Alert;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
@@ -69,14 +70,13 @@ import org.apache.ambari.server.state.UpgradeState;
 import org.apache.ambari.server.state.fsm.InvalidStateTransitionException;
 import org.apache.ambari.server.state.host.HostStatusUpdatesReceivedEvent;
 import org.apache.ambari.server.state.scheduler.RequestExecution;
-import org.apache.ambari.server.state.stack.upgrade.Direction;
-import org.apache.ambari.server.state.stack.upgrade.UpgradeType;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostOpFailedEvent;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostOpInProgressEvent;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostOpSucceededEvent;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostStartedEvent;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostStoppedEvent;
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.ambari.spi.upgrade.UpgradeType;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -274,10 +274,10 @@ public class HeartbeatProcessor extends AbstractService{
       Long clusterId = null;
       if (CollectionUtils.isNotEmpty(componentStatuses)) {
         calculateHostStatus = true;
-        for (ComponentStatus componentStatus : componentStatuses) {
-          clusterId = componentStatus.getClusterId();
-          break;
-        }
+        clusterId = componentStatuses.stream()
+            .findFirst()
+            .map(ComponentStatus::getClusterId)
+            .orElse(null);
       }
 
       if (!calculateHostStatus && CollectionUtils.isNotEmpty(reports)) {
@@ -391,16 +391,13 @@ public class HeartbeatProcessor extends AbstractService{
           }
 
           if (writeKeytabsStructuredOut != null) {
-            if (SET_KEYTAB.equalsIgnoreCase(customCommand)) {
-              Map<String, String> keytabs = writeKeytabsStructuredOut.getKeytabs();
-              if (keytabs != null) {
-                for (Map.Entry<String, String> entry : keytabs.entrySet()) {
-                  String principal = entry.getKey();
-                  String keytabPath = entry.getValue();
-                  for (KerberosKeytabPrincipalEntity kkpe: kerberosKeytabPrincipalDAO.findByHostAndKeytab(host.getHostId(), keytabPath)) {
-                    kkpe.setDistributed(true);
-                    kerberosKeytabPrincipalDAO.merge(kkpe);
-                  }
+            Map<String, String> keytabs = writeKeytabsStructuredOut.getKeytabs();
+            if (keytabs != null) {
+              for (Map.Entry<String, String> entry : keytabs.entrySet()) {
+                String keytabPath = entry.getValue();
+                for (KerberosKeytabPrincipalEntity kkpe : kerberosKeytabPrincipalDAO.findByHostAndKeytab(host.getHostId(), keytabPath)) {
+                  kkpe.setDistributed(true);
+                  kerberosKeytabPrincipalDAO.merge(kkpe);
                 }
               }
             }
