@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,7 +18,16 @@
 
 package org.apache.ambari.server.api.predicate;
 
-import java.util.*;
+import java.util.ArrayDeque;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Deque;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -44,6 +53,7 @@ public class QueryLexer {
   public static final String QUERY_FROM      = "from";
   public static final String QUERY_MINIMAL   = "minimal_response";
   public static final String QUERY_SORT      = "sortBy";
+  public static final String QUERY_DOAS      = "doAs";
 
   /**
    * All valid deliminators.
@@ -55,12 +65,12 @@ public class QueryLexer {
    * Map of token type to list of valid handlers for next token.
    */
   private static final Map<Token.TYPE, List<TokenHandler>> TOKEN_HANDLERS =
-      new HashMap<Token.TYPE, List<TokenHandler>>();
+    new HashMap<>();
 
   /**
    * Static set of property names to ignore.
    */
-  private static final Set<String> SET_IGNORE = new HashSet<String>();
+  private static final Set<String> SET_IGNORE = new HashSet<>();
 
 
   /**
@@ -69,7 +79,7 @@ public class QueryLexer {
    */
   public QueryLexer() {
     //todo: refactor handler registration
-    List<TokenHandler> listHandlers = new ArrayList<TokenHandler>();
+    List<TokenHandler> listHandlers = new ArrayList<>();
     listHandlers.add(new LogicalUnaryOperatorTokenHandler());
     listHandlers.add(new OpenBracketTokenHandler());
     listHandlers.add(new PropertyOperandTokenHandler());
@@ -78,26 +88,26 @@ public class QueryLexer {
     TOKEN_HANDLERS.put(Token.TYPE.LOGICAL_OPERATOR, listHandlers);
     TOKEN_HANDLERS.put(Token.TYPE.LOGICAL_UNARY_OPERATOR, listHandlers);
 
-    listHandlers= new ArrayList<TokenHandler>();
+    listHandlers= new ArrayList<>();
     listHandlers.add(new RelationalOperatorTokenHandler());
     listHandlers.add(new RelationalOperatorFuncTokenHandler());
     TOKEN_HANDLERS.put(Token.TYPE.PROPERTY_OPERAND, listHandlers);
 
-    listHandlers = new ArrayList<TokenHandler>();
+    listHandlers = new ArrayList<>();
     listHandlers.add(new ValueOperandTokenHandler());
     TOKEN_HANDLERS.put(Token.TYPE.RELATIONAL_OPERATOR, listHandlers);
 
-    listHandlers = new ArrayList<TokenHandler>();
+    listHandlers = new ArrayList<>();
     listHandlers.add(new CloseBracketTokenHandler());
     listHandlers.add(new ComplexValueOperandTokenHandler());
     TOKEN_HANDLERS.put(Token.TYPE.RELATIONAL_OPERATOR_FUNC, listHandlers);
 
-    listHandlers = new ArrayList<TokenHandler>();
+    listHandlers = new ArrayList<>();
     listHandlers.add(new CloseBracketTokenHandler());
     listHandlers.add(new LogicalOperatorTokenHandler());
     TOKEN_HANDLERS.put(Token.TYPE.BRACKET_CLOSE, listHandlers);
 
-    listHandlers = new ArrayList<TokenHandler>(listHandlers);
+    listHandlers = new ArrayList<>(listHandlers);
     // complex value operands can span multiple tokens
     listHandlers.add(0, new ComplexValueOperandTokenHandler());
     TOKEN_HANDLERS.put(Token.TYPE.VALUE_OPERAND, listHandlers);
@@ -113,7 +123,7 @@ public class QueryLexer {
    * @throws InvalidQueryException if the query is invalid
    */
   public Token[] tokens(String exp) throws InvalidQueryException {
-    return tokens(exp, Collections.<String>emptySet());
+    return tokens(exp, Collections.emptySet());
   }
 
   /**
@@ -161,7 +171,7 @@ public class QueryLexer {
   private List<String> parseStringTokens(String exp) {
     Pattern      pattern       = generatePattern();
     Matcher      matcher       = pattern.matcher(exp);
-    List<String> listStrTokens = new ArrayList<String>();
+    List<String> listStrTokens = new ArrayList<>();
     int pos = 0;
 
     while (matcher.find()) { // while there's a delimiter in the string
@@ -197,9 +207,7 @@ public class QueryLexer {
     return Pattern.compile(sb.toString());
   }
 
-  /**
-   * Add property names that the lexer should ignore.
-   */
+  // Add property names that the lexer should ignore.
   static {
     // ignore values
     SET_IGNORE.add(QUERY_FIELDS);
@@ -209,6 +217,7 @@ public class QueryLexer {
     SET_IGNORE.add(QUERY_FROM);
     SET_IGNORE.add(QUERY_MINIMAL);
     SET_IGNORE.add(QUERY_SORT);
+    SET_IGNORE.add(QUERY_DOAS);
     SET_IGNORE.add("_");
   }
 
@@ -229,7 +238,7 @@ public class QueryLexer {
     /**
      * List of tokens generated by the scan
      */
-    private List<Token> m_listTokens = new ArrayList<Token>();
+    private List<Token> m_listTokens = new ArrayList<>();
 
     /**
      * If non-null, ignore all tokens up to and including this token type.
@@ -239,7 +248,7 @@ public class QueryLexer {
     /**
      * Property names which are to be ignored.
      */
-    private Set<String> m_propertiesToIgnore = new HashSet<String>();
+    private Set<String> m_propertiesToIgnore = new HashSet<>();
 
     /**
      * Bracket score.  This score is the difference between the number of
@@ -255,7 +264,7 @@ public class QueryLexer {
      * tokens and then in subsequent invocations combine/alter/remove/etc
      * these tokens prior to adding them to the context tokens.
      */
-    private Deque<Token> m_intermediateTokens = new ArrayDeque<Token>();
+    private Deque<Token> m_intermediateTokens = new ArrayDeque<>();
 
 
     /**
