@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -31,5 +31,5 @@ public interface LogicalOperator extends Operator {
    * @param right  right operand
    * @return a predicate instance for this operator
    */
-  public Predicate toPredicate(Predicate left, Predicate right);
+  Predicate toPredicate(Predicate left, Predicate right);
 }
