@@ -22,7 +22,6 @@ import java.util.HashSet;
 import java.util.Set;
 
 import org.apache.ambari.server.controller.spi.Resource;
-import org.apache.ambari.server.controller.spi.Resource.Type;
 
 /**
  * An extension version is like a stack version but it contains custom services.  Linking an extension
@@ -31,10 +30,6 @@ import org.apache.ambari.server.controller.spi.Resource.Type;
  */
 public class ExtensionResourceDefinition extends BaseResourceDefinition {
 
-  public ExtensionResourceDefinition(Type resourceType) {
-    super(Resource.Type.Extension);
-  }
-
   public ExtensionResourceDefinition() {
     super(Resource.Type.Extension);
   }
