@@ -22,14 +22,9 @@ import java.util.HashSet;
 import java.util.Set;
 
 import org.apache.ambari.server.controller.spi.Resource;
-import org.apache.ambari.server.controller.spi.Resource.Type;
 
 public class StackResourceDefinition extends BaseResourceDefinition {
 
-  public StackResourceDefinition(Type resourceType) {
-    super(Resource.Type.Stack);
-  }
-
   public StackResourceDefinition() {
     super(Resource.Type.Stack);
   }
