@@ -18,6 +18,8 @@
 
 package org.apache.ambari.server.api.services.stackadvisor;
 
+import static java.util.stream.Collectors.toMap;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -29,9 +31,13 @@ import java.util.Set;
 
 import org.apache.ambari.server.api.services.stackadvisor.recommendations.RecommendationResponse;
 import org.apache.ambari.server.state.ChangedConfigInfo;
+import org.apache.ambari.server.state.StackId;
+import org.apache.ambari.server.topology.Configuration;
 import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.tuple.Pair;
 
 import com.google.common.base.Preconditions;
+import com.google.common.collect.ImmutableMap;
 
 /**
  * Stack advisor request.
@@ -150,6 +156,22 @@ public class StackAdvisorRequest {
     this.stackVersion = stackVersion;
   }
 
+  public StackAdvisorRequestBuilder builder() {
+    return StackAdvisorRequestBuilder.forStack(stackName, stackVersion)
+      .ofType(requestType)
+      .forHosts(hosts)
+      .forServices(services)
+      .forHostComponents(hostComponents)
+      .forHostsGroupBindings(hostGroupBindings)
+      .withComponentHostsMap(componentHostsMap)
+      .withConfigurations(configurations)
+      .withChangedConfigurations(changedConfigurations)
+      .withConfigGroups(configGroups)
+      .withUserContext(userContext)
+      .withGPLLicenseAccepted(gplLicenseAccepted)
+      .withLdapConfig(ldapConfig);
+  }
+
   public static class StackAdvisorRequestBuilder {
     StackAdvisorRequest instance;
 
@@ -157,6 +179,10 @@ public class StackAdvisorRequest {
       this.instance = new StackAdvisorRequest(stackName, stackVersion);
     }
 
+    public static StackAdvisorRequestBuilder forStack(StackId stackId) {
+      return forStack(stackId.getStackName(), stackId.getStackVersion());
+    }
+
     public static StackAdvisorRequestBuilder forStack(String stackName, String stackVersion) {
       return new StackAdvisorRequestBuilder(stackName, stackVersion);
     }
@@ -199,6 +225,15 @@ public class StackAdvisorRequest {
       return this;
     }
 
+    public StackAdvisorRequestBuilder withConfigurations(Configuration configuration) {
+      Map<String, Map<String, String>> properties = configuration.getFullProperties();
+      this.instance.configurations = properties.entrySet().stream()
+        .map( e -> Pair.of(e.getKey(), ImmutableMap.of("properties", e.getValue())))
+        .collect(toMap(Pair::getKey, Pair::getValue));
+      return this;
+    }
+
+
     public StackAdvisorRequestBuilder withChangedConfigurations(
       List<ChangedConfigInfo> changedConfigurations) {
       this.instance.changedConfigurations = changedConfigurations;
@@ -258,6 +293,7 @@ public class StackAdvisorRequest {
   public enum StackAdvisorRequestType {
     HOST_GROUPS("host_groups"),
     CONFIGURATIONS("configurations"),
+    LDAP_CONFIGURATIONS("ldap-configurations"),
     SSO_CONFIGURATIONS("sso-configurations"),
     KERBEROS_CONFIGURATIONS("kerberos-configurations"),
     CONFIGURATION_DEPENDENCIES("configuration-dependencies");
