@@ -52,19 +52,20 @@ import org.apache.ambari.server.controller.internal.AmbariServerConfigurationHan
 import org.apache.ambari.server.controller.spi.Resource;
 import org.apache.ambari.server.state.ServiceInfo;
 import org.apache.ambari.server.utils.DateUtils;
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
-import org.codehaus.jackson.JsonNode;
-import org.codehaus.jackson.map.ObjectMapper;
-import org.codehaus.jackson.map.SerializationConfig;
-import org.codehaus.jackson.node.ArrayNode;
-import org.codehaus.jackson.node.JsonNodeFactory;
-import org.codehaus.jackson.node.ObjectNode;
-import org.codehaus.jackson.node.TextNode;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.fasterxml.jackson.databind.JsonNode;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import com.fasterxml.jackson.databind.SerializationFeature;
+import com.fasterxml.jackson.databind.node.ArrayNode;
+import com.fasterxml.jackson.databind.node.JsonNodeFactory;
+import com.fasterxml.jackson.databind.node.ObjectNode;
+import com.fasterxml.jackson.databind.node.TextNode;
+
 /**
  * Parent for all commands.
  */
@@ -85,6 +86,7 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
       + "?fields=Versions/stack_name,Versions/stack_version,Versions/parent_stack_version"
       + ",services/StackServices/service_name,services/StackServices/service_version"
       + ",services/components/StackServiceComponents,services/components/dependencies/Dependencies/scope"
+      + ",services/components/dependencies/Dependencies/type"
       + ",services/components/dependencies/Dependencies/conditions,services/components/auto_deploy"
       + ",services/configurations/StackConfigurations/property_depends_on"
       + ",services/configurations/dependencies/StackConfigurationDependency/dependency_name"
@@ -129,7 +131,7 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
         .getActualTypeArguments()[0];
 
     this.mapper = new ObjectMapper();
-    this.mapper.configure(SerializationConfig.Feature.INDENT_OUTPUT, true);
+    this.mapper.configure(SerializationFeature.INDENT_OUTPUT, true);
 
     this.recommendationsDir = recommendationsDir;
     this.recommendationsArtifactsLifetime = recommendationsArtifactsLifetime;
@@ -262,17 +264,17 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
 
   private void populateComponentHostsMap(ObjectNode root, Map<String, Set<String>> componentHostsMap) {
     ArrayNode services = (ArrayNode) root.get(SERVICES_PROPERTY);
-    Iterator<JsonNode> servicesIter = services.getElements();
+    Iterator<JsonNode> servicesIter = services.elements();
 
     while (servicesIter.hasNext()) {
       JsonNode service = servicesIter.next();
       ArrayNode components = (ArrayNode) service.get(SERVICES_COMPONENTS_PROPERTY);
-      Iterator<JsonNode> componentsIter = components.getElements();
+      Iterator<JsonNode> componentsIter = components.elements();
 
       while (componentsIter.hasNext()) {
         JsonNode component = componentsIter.next();
         ObjectNode componentInfo = (ObjectNode) component.get(COMPONENT_INFO_PROPERTY);
-        String componentName = componentInfo.get(COMPONENT_NAME_PROPERTY).getTextValue();
+        String componentName = componentInfo.get(COMPONENT_NAME_PROPERTY).asText();
 
         Set<String> componentHosts = componentHostsMap.get(componentName);
         ArrayNode hostnames = componentInfo.putArray(COMPONENT_HOSTNAMES_PROPERTY);
@@ -287,7 +289,7 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
 
   private void populateServiceAdvisors(ObjectNode root) {
     ArrayNode services = (ArrayNode) root.get(SERVICES_PROPERTY);
-    Iterator<JsonNode> servicesIter = services.getElements();
+    Iterator<JsonNode> servicesIter = services.elements();
 
     ObjectNode version = (ObjectNode) root.get("Versions");
     String stackName = version.get("stack_name").asText();
@@ -296,7 +298,7 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
     while (servicesIter.hasNext()) {
       JsonNode service = servicesIter.next();
       ObjectNode serviceVersion = (ObjectNode) service.get(STACK_SERVICES_PROPERTY);
-      String serviceName = serviceVersion.get("service_name").getTextValue();
+      String serviceName = serviceVersion.get("service_name").asText();
       try {
         ServiceInfo serviceInfo = metaInfo.getService(stackName, stackVersion, serviceName);
         if (serviceInfo.getAdvisorFile() != null) {
@@ -437,10 +439,10 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
       if (hostsJSON != null && !hostsJSON.isEmpty()) {
         try {
           JsonNode root = mapper.readTree(hostsJSON);
-          Iterator<JsonNode> iterator = root.get("items").getElements();
+          Iterator<JsonNode> iterator = root.get("items").elements();
           while (iterator.hasNext()) {
             JsonNode next = iterator.next();
-            String hostName = next.get("Hosts").get("host_name").getTextValue();
+            String hostName = next.get("Hosts").get("host_name").asText();
             hostInfoCache.put(hostName, next);
             resultInfos.add(next);
           }
@@ -478,10 +480,10 @@ public abstract class StackAdvisorCommand<T extends StackAdvisorResponse> extend
 
     try {
       JsonNode root = mapper.readTree(hostsJSON);
-      Iterator<JsonNode> iterator = root.get("items").getElements();
+      Iterator<JsonNode> iterator = root.get("items").elements();
       while (iterator.hasNext()) {
         JsonNode next = iterator.next();
-        String hostName = next.get("Hosts").get("host_name").getTextValue();
+        String hostName = next.get("Hosts").get("host_name").asText();
         registeredHosts.add(hostName);
       }
 
