@@ -66,6 +66,7 @@ import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.internal.RequestOperationLevel;
 import org.apache.ambari.server.controller.internal.RequestResourceFilter;
+import org.apache.ambari.server.controller.internal.RequestResourceProvider;
 import org.apache.ambari.server.controller.spi.Resource;
 import org.apache.ambari.server.metadata.ActionMetadata;
 import org.apache.ambari.server.orm.dao.HostRoleCommandDAO;
@@ -98,6 +99,7 @@ import org.apache.commons.lang.math.NumberUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.collect.ImmutableMap;
 import com.google.gson.Gson;
 import com.google.inject.Inject;
 import com.google.inject.Singleton;
@@ -113,14 +115,12 @@ public class AmbariCustomCommandExecutionHelper {
       AmbariCustomCommandExecutionHelper.class);
 
   // TODO: Remove the hard-coded mapping when stack definition indicates which slave types can be decommissioned
-  public static final Map<String, String> masterToSlaveMappingForDecom = new HashMap<>();
-
-  static {
-    masterToSlaveMappingForDecom.put("NAMENODE", "DATANODE");
-    masterToSlaveMappingForDecom.put("RESOURCEMANAGER", "NODEMANAGER");
-    masterToSlaveMappingForDecom.put("HBASE_MASTER", "HBASE_REGIONSERVER");
-    masterToSlaveMappingForDecom.put("JOBTRACKER", "TASKTRACKER");
-  }
+  static final Map<String, String> masterToSlaveMappingForDecom = ImmutableMap.<String, String>builder()
+    .put("NAMENODE", "DATANODE")
+    .put("RESOURCEMANAGER", "NODEMANAGER")
+    .put("HBASE_MASTER", "HBASE_REGIONSERVER")
+    .put("JOBTRACKER", "TASKTRACKER")
+    .build();
 
   public final static String DECOM_INCLUDED_HOSTS = "included_hosts";
   public final static String DECOM_EXCLUDED_HOSTS = "excluded_hosts";
@@ -342,26 +342,13 @@ public class AmbariCustomCommandExecutionHelper {
           new ServiceComponentHostOpInProgressEvent(componentName, hostName, nowTimestamp),
           cluster.getClusterName(), serviceName, retryAllowed, autoSkipFailure);
 
-      Map<String, Map<String, String>> configurations =
-          new TreeMap<>();
-      Map<String, Map<String, Map<String, String>>> configurationAttributes =
-          new TreeMap<>();
-      Map<String, Map<String, String>> configTags = new TreeMap<>();
-
       ExecutionCommand execCmd = stage.getExecutionCommandWrapper(hostName,
           componentName).getExecutionCommand();
 
       // if the command should fetch brand new configuration tags before
       // execution, then we don't need to fetch them now
-      if(actionExecutionContext.getParameters() != null && actionExecutionContext.getParameters().containsKey(KeyNames.REFRESH_CONFIG_TAGS_BEFORE_EXECUTION)){
-        execCmd.setForceRefreshConfigTagsBeforeExecution(true);
-      }
-
-      // when building complex orchestration ahead of time (such as when
-      // performing ugprades), fetching configuration tags can take a very long
-      // time - if it's not needed, then don't do it
-      if (!execCmd.getForceRefreshConfigTagsBeforeExecution()) {
-        configTags = managementController.findConfigurationTagsWithOverrides(cluster, hostName, null);
+      if(actionExecutionContext.getParameters() != null && actionExecutionContext.getParameters().containsKey(KeyNames.OVERRIDE_CONFIGS)){
+        execCmd.setOverrideConfigs(true);
       }
 
       HostRoleCommand cmd = stage.getHostRoleCommand(hostName, componentName);
@@ -381,9 +368,7 @@ public class AmbariCustomCommandExecutionHelper {
 
       execCmd.setComponentVersions(cluster);
 
-      execCmd.setConfigurations(configurations);
-      execCmd.setConfigurationAttributes(configurationAttributes);
-      execCmd.setConfigurationTags(configTags);
+      execCmd.setConfigurations(new TreeMap<>());
 
       // Get the value of credential store enabled from the DB
       Service clusterService = cluster.getService(serviceName);
@@ -466,8 +451,8 @@ public class AmbariCustomCommandExecutionHelper {
         commandTimeout = Math.max(60, commandTimeout);
       }
 
-      if (requestParams != null && requestParams.containsKey("context")) {
-        String requestContext = requestParams.get("context");
+      if (requestParams != null && requestParams.containsKey(RequestResourceProvider.CONTEXT)) {
+        String requestContext = requestParams.get(RequestResourceProvider.CONTEXT);
         if (StringUtils.isNotEmpty(requestContext) && requestContext.toLowerCase().contains("rolling-restart")) {
           Config clusterEnvConfig = cluster.getDesiredConfigByType("cluster-env");
           if (clusterEnvConfig != null) {
@@ -728,29 +713,17 @@ public class AmbariCustomCommandExecutionHelper {
     // [ type -> [ key, value ] ]
     Map<String, Map<String, String>> configurations =
         new TreeMap<>();
-    Map<String, Map<String, Map<String, String>>> configurationAttributes =
-        new TreeMap<>();
-    Map<String, Map<String, String>> configTags = new TreeMap<>();
 
     ExecutionCommand execCmd = stage.getExecutionCommandWrapper(hostname,
         smokeTestRole).getExecutionCommand();
 
     // if the command should fetch brand new configuration tags before
     // execution, then we don't need to fetch them now
-    if(actionParameters != null && actionParameters.containsKey(KeyNames.REFRESH_CONFIG_TAGS_BEFORE_EXECUTION)){
-      execCmd.setForceRefreshConfigTagsBeforeExecution(true);
-    }
-
-    // when building complex orchestration ahead of time (such as when
-    // performing ugprades), fetching configuration tags can take a very long
-    // time - if it's not needed, then don't do it
-    if (!execCmd.getForceRefreshConfigTagsBeforeExecution()) {
-      configTags = managementController.findConfigurationTagsWithOverrides(cluster, hostname, null);
+    if(actionParameters != null && actionParameters.containsKey(KeyNames.OVERRIDE_CONFIGS)){
+      execCmd.setOverrideConfigs(true);
     }
 
     execCmd.setConfigurations(configurations);
-    execCmd.setConfigurationAttributes(configurationAttributes);
-    execCmd.setConfigurationTags(configTags);
 
     // Generate localComponents
     for (ServiceComponentHost sch : cluster.getServiceComponentHosts(hostname)) {
@@ -1040,7 +1013,7 @@ public class AmbariCustomCommandExecutionHelper {
     }
   }
 
-  Set<String> calculateDecommissionedNodes(Service service, String slaveCompType) throws AmbariException {
+  private Set<String> calculateDecommissionedNodes(Service service, String slaveCompType) throws AmbariException {
     Set<String> decommissionedHostsSet = new HashSet<>();
     ServiceComponent serviceComponent = service.getServiceComponent(slaveCompType);
     for (ServiceComponentHost serviceComponentHost : serviceComponent.getServiceComponentHosts().values()) {
@@ -1151,15 +1124,6 @@ public class AmbariCustomCommandExecutionHelper {
           extraParams.put(componentName, requestParams.get(componentName));
         }
 
-        if (resourceFilter.getComponentName().equals(Role.RESOURCEMANAGER.name())){
-          extraParams.putIfAbsent(ALL_DECOMMISSIONED_HOSTS, StringUtils.join(calculateDecommissionedNodes(
-            clusters.getCluster(actionExecutionContext.getClusterName()).getService(Service.Type.YARN.name()),
-              Role.NODEMANAGER.name()), ','));
-        } else if (resourceFilter.getComponentName().equals(Role.NAMENODE.name())){
-          extraParams.putIfAbsent(ALL_DECOMMISSIONED_HOSTS, StringUtils.join(calculateDecommissionedNodes(
-            clusters.getCluster(actionExecutionContext.getClusterName()).getService(Service.Type.HDFS.name()),
-              Role.DATANODE.name()), ','));
-        }
         // If command should be retried upon failure then add the option and also the default duration for retry
         if (requestParams.containsKey(KeyNames.COMMAND_RETRY_ENABLED)) {
           extraParams.put(KeyNames.COMMAND_RETRY_ENABLED, requestParams.get(KeyNames.COMMAND_RETRY_ENABLED));
@@ -1179,8 +1143,8 @@ public class AmbariCustomCommandExecutionHelper {
           extraParams.put(KeyNames.LOG_OUTPUT, requestParams.get(KeyNames.LOG_OUTPUT));
         }
 
-        if(requestParams.containsKey(KeyNames.REFRESH_CONFIG_TAGS_BEFORE_EXECUTION)){
-          actionExecutionContext.getParameters().put(KeyNames.REFRESH_CONFIG_TAGS_BEFORE_EXECUTION, requestParams.get(KeyNames.REFRESH_CONFIG_TAGS_BEFORE_EXECUTION));
+        if(requestParams.containsKey(KeyNames.OVERRIDE_CONFIGS)){
+          actionExecutionContext.getParameters().put(KeyNames.OVERRIDE_CONFIGS, requestParams.get(KeyNames.OVERRIDE_CONFIGS));
         }
 
         RequestOperationLevel operationLevel = actionExecutionContext.getOperationLevel();
@@ -1252,10 +1216,6 @@ public class AmbariCustomCommandExecutionHelper {
       }
 
       clusterHostInfoJson = StageUtils.getGson().toJson(clusterHostInfo);
-
-      if (null == stackId && null != cluster) {
-        stackId = cluster.getDesiredStackVersion();
-      }
     }
 
     String hostParamsStageJson = StageUtils.getGson().toJson(hostParamsStage);
