@@ -138,6 +138,10 @@ public interface KerberosHelper {
    * The kerberos-env property name declaring whether to manage auth-to-local rules or not
    */
   String MANAGE_AUTH_TO_LOCAL_RULES = "manage_auth_to_local";
+  /**
+   * The kerberos-env property name declaring whether the Hadoop auth_to_local rules should be included for all components of an installed service even if the component itself is not installed
+   */
+  String INCLUDE_ALL_COMPONENTS_IN_AUTH_TO_LOCAL_RULES = "include_all_components_in_auth_to_local_rules";
   /**
    * The kerberos-env property name declaring whether auth-to-local rules should be case-insensitive or not
    */
@@ -158,6 +162,11 @@ public interface KerberosHelper {
    */
   String ALLOW_RETRY = "allow_retry_on_failure";
 
+  /**
+   * Used as key in config maps to store component to host assignment mapping.
+   */
+  String CLUSTER_HOST_INFO = "clusterHostInfo";
+
   /**
    * Toggles Kerberos security to enable it or remove it depending on the state of the cluster.
    * <p/>
