@@ -41,6 +41,7 @@ public class StackServiceResponse {
   private String comments;
   private String serviceVersion;
   private ServiceInfo.Selection selection;
+  private String maintainer;
   private boolean serviceCheckSupported;
   private List<String> customCommands;
 
@@ -77,10 +78,16 @@ public class StackServiceResponse {
    */
   private boolean credentialStoreRequired;
 
+  /**
+   * Whether the service supports rolling restart.
+   * */
+  private boolean rollingRestartSupported;
+
   private boolean isSupportDeleteViaUI;
 
   private final boolean ssoIntegrationSupported;
   private final boolean ssoIntegrationRequiresKerberos;
+  private final boolean ldapIntegrationSupported;
 
   /**
    * Constructor.
@@ -100,6 +107,7 @@ public class StackServiceResponse {
     requiredServices = service.getRequiredServices();
     serviceCheckSupported = null != service.getCommandScript();
     selection = service.getSelection();
+    maintainer = service.getMaintainer();
 
     // the custom command names defined at the service (not component) level
     List<CustomCommandDefinition> definitions = service.getCustomCommands();
@@ -119,6 +127,8 @@ public class StackServiceResponse {
     isSupportDeleteViaUI = service.isSupportDeleteViaUI();
     ssoIntegrationSupported = service.isSingleSignOnSupported();
     ssoIntegrationRequiresKerberos = service.isKerberosRequiredForSingleSignOnIntegration();
+    ldapIntegrationSupported = service.isLdapSupported();
+    rollingRestartSupported = service.isRollingRestartSupported();
   }
 
   @ApiModelProperty(name = "selection")
@@ -130,6 +140,11 @@ public class StackServiceResponse {
     this.selection = selection;
   }
 
+  @ApiModelProperty(name = "maintainer")
+  public String getMaintainer(){
+    return maintainer;
+  }
+
   @ApiModelProperty(name = "stack_name")
   public String getStackName() {
     return stackName;
@@ -353,6 +368,23 @@ public class StackServiceResponse {
     return ssoIntegrationRequiresKerberos;
   }
 
+  /**
+   * Indicates if this service supports LDAP integration.
+   */
+  @ApiModelProperty(name = "ldap_integration_supported")
+  public boolean isLdapIntegrationSupported() {
+    return ldapIntegrationSupported;
+  }
+
+  @ApiModelProperty(name = "rolling_restart_supported")
+  public boolean isRollingRestartSupported() {
+    return rollingRestartSupported;
+  }
+
+  public void setRollingRestartSupported(boolean rollingRestartSupported) {
+    this.rollingRestartSupported = rollingRestartSupported;
+  }
+
   public interface StackServiceResponseSwagger extends ApiModel {
     @ApiModelProperty(name = "StackServices")
     public StackServiceResponse getStackServiceResponse();
