@@ -18,6 +18,7 @@
 
 package org.apache.ambari.server.controller.internal;
 
+import static java.util.Collections.emptyMap;
 import static org.apache.ambari.server.controller.metrics.MetricsServiceProvider.MetricsService.GANGLIA;
 import static org.apache.ambari.server.controller.metrics.MetricsServiceProvider.MetricsService.TIMELINE_METRICS;
 
@@ -67,8 +68,8 @@ import org.apache.ambari.server.state.DesiredConfig;
 import org.apache.ambari.server.state.Host;
 import org.apache.ambari.server.state.Service;
 import org.apache.ambari.server.state.ServiceComponentHost;
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.MapUtils;
+import org.apache.commons.collections4.CollectionUtils;
+import org.apache.commons.collections4.MapUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -968,13 +969,14 @@ public abstract class AbstractProviderModule implements ProviderModule,
               ConfigurationResourceProvider.TYPE,
               ConfigurationResourceProvider.TAG), configPredicate);
     } catch (NoSuchResourceException e) {
-      LOG.info("Resource for the desired config not found. " + e);
-      return Collections.emptyMap();
+      LOG.info("Resource for the desired config not found.", e);
+      return emptyMap();
     }
-    for (Resource res : configResources) {
-      return res.getPropertiesMap().get(PROPERTIES_CATEGORY);
-    }
-    return Collections.emptyMap();
+    return configResources.stream()
+        .findFirst()
+        .map(res -> res.getPropertiesMap()
+            .get(PROPERTIES_CATEGORY))
+        .orElse(emptyMap());
   }
 
   private Map<String, String> getDesiredConfigMap(String clusterName, String versionTag,
