@@ -76,6 +76,7 @@ import org.apache.ambari.server.state.DesiredConfig;
 import org.apache.ambari.server.state.PropertyInfo.PropertyType;
 import org.apache.ambari.server.state.Service;
 import org.apache.ambari.server.state.ServiceComponent;
+import org.apache.ambari.server.state.ServiceComponentHost;
 import org.apache.ambari.server.state.ServiceInfo;
 import org.apache.ambari.server.state.ServiceOsSpecific;
 import org.apache.ambari.server.state.StackId;
@@ -116,7 +117,7 @@ public class ClientConfigResourceProvider extends AbstractControllerResourceProv
   /**
    * The key property ids for a ClientConfig resource.
    */
-  private static Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
+  private static final Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
       .put(Resource.Type.Cluster, COMPONENT_CLUSTER_NAME_PROPERTY_ID)
       .put(Resource.Type.Service, COMPONENT_SERVICE_NAME_PROPERTY_ID)
       .put(Resource.Type.Component, COMPONENT_COMPONENT_NAME_PROPERTY_ID)
@@ -126,7 +127,7 @@ public class ClientConfigResourceProvider extends AbstractControllerResourceProv
   /**
    * The property ids for a ClientConfig resource.
    */
-  private static Set<String> propertyIds = Sets.newHashSet(
+  private static final Set<String> propertyIds = Sets.newHashSet(
       COMPONENT_CLUSTER_NAME_PROPERTY_ID,
       COMPONENT_SERVICE_NAME_PROPERTY_ID,
       COMPONENT_COMPONENT_NAME_PROPERTY_ID,
@@ -400,10 +401,17 @@ public class ClientConfigResourceProvider extends AbstractControllerResourceProv
 
         TreeMap<String, String> clusterLevelParams = null;
         TreeMap<String, String> ambariLevelParams = null;
+        TreeMap<String, String> topologyCommandParams = new TreeMap<>();
         if (getManagementController() instanceof AmbariManagementControllerImpl){
           AmbariManagementControllerImpl controller = ((AmbariManagementControllerImpl)getManagementController());
           clusterLevelParams = controller.getMetadataClusterLevelParams(cluster, stackId);
           ambariLevelParams = controller.getMetadataAmbariLevelParams();
+
+          Service s = cluster.getService(serviceName);
+          ServiceComponent sc = s.getServiceComponent(componentName);
+          ServiceComponentHost sch = sc.getServiceComponentHost(response.getHostname());
+
+          topologyCommandParams = controller.getTopologyCommandParams(cluster.getClusterId(), serviceName, componentName, sch);
         }
         TreeMap<String, String> agentLevelParams = new TreeMap<>();
         agentLevelParams.put("hostname", hostName);
@@ -414,6 +422,7 @@ public class ClientConfigResourceProvider extends AbstractControllerResourceProv
         commandParams.put("env_configs_list", envConfigs);
         commandParams.put("properties_configs_list", propertiesConfigs);
         commandParams.put("output_file", componentName + "-configs" + Configuration.DEF_ARCHIVE_EXTENSION);
+        commandParams.putAll(topologyCommandParams);
 
         Map<String, Object> jsonContent = new TreeMap<>();
         jsonContent.put("configurations", configurations);
