@@ -42,12 +42,10 @@ import org.apache.ambari.server.agent.stomp.TopologyHolder;
 import org.apache.ambari.server.agent.stomp.dto.HostLevelParamsCluster;
 import org.apache.ambari.server.agent.stomp.dto.TopologyCluster;
 import org.apache.ambari.server.agent.stomp.dto.TopologyHost;
-import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.controller.ConfigurationRequest;
 import org.apache.ambari.server.controller.HostRequest;
 import org.apache.ambari.server.controller.HostResponse;
-import org.apache.ambari.server.controller.MaintenanceStateHelper;
 import org.apache.ambari.server.controller.RequestStatusResponse;
 import org.apache.ambari.server.controller.ServiceComponentHostRequest;
 import org.apache.ambari.server.controller.spi.NoSuchParentResourceException;
@@ -85,7 +83,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.Sets;
+import com.google.common.collect.ImmutableSet;
 import com.google.inject.Inject;
 import com.google.inject.assistedinject.Assisted;
 import com.google.inject.assistedinject.AssistedInject;
@@ -163,7 +161,7 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
   /**
    * The key property ids for a Host resource.
    */
-  public static Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
+  public static final Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
       .put(Resource.Type.Host, HOST_HOST_NAME_PROPERTY_ID)
       .put(Resource.Type.Cluster, HOST_CLUSTER_NAME_PROPERTY_ID)
       .build();
@@ -171,7 +169,7 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
   /**
    * The property ids for a Host resource.
    */
-  public static Set<String> propertyIds = Sets.newHashSet(
+  public static final Set<String> propertyIds = ImmutableSet.of(
       HOST_CLUSTER_NAME_PROPERTY_ID,
       HOST_CPU_COUNT_PROPERTY_ID,
       HOST_DESIRED_CONFIGS_PROPERTY_ID,
@@ -196,9 +194,6 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
       HOST_TOTAL_MEM_PROPERTY_ID,
       HOST_ATTRIBUTES_PROPERTY_ID);
 
-  @Inject
-  private MaintenanceStateHelper maintenanceStateHelper;
-
   @Inject
   private OsFamily osFamily;
 
@@ -214,8 +209,6 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
   @Inject
   private RecoveryConfigHelper recoveryConfigHelper;
 
-  @Inject
-  private AmbariMetaInfo ambariMetaInfo;
 
   // ----- Constructors ----------------------------------------------------
 
@@ -249,12 +242,9 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
     if (isHostGroupRequest(request)) {
       createResponse = submitHostRequests(request);
     } else {
-      createResources(new Command<Void>() {
-        @Override
-        public Void invoke() throws AmbariException, AuthorizationException {
-          createHosts(request);
-          return null;
-        }
+      createResources((Command<Void>) () -> {
+        createHosts(request);
+        return null;
       });
     }
     notifyCreate(Resource.Type.Host, request);
@@ -264,7 +254,7 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
 
   @Override
   protected Set<Resource> getResourcesAuthorized(Request request, Predicate predicate)
-      throws SystemException, UnsupportedPropertyException, NoSuchResourceException, NoSuchParentResourceException {
+      throws SystemException, NoSuchResourceException, NoSuchParentResourceException {
 
     final Set<HostRequest> requests = new HashSet<>();
 
@@ -277,12 +267,7 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
       }
     }
 
-    Set<HostResponse> responses = getResources(new Command<Set<HostResponse>>() {
-      @Override
-      public Set<HostResponse> invoke() throws AmbariException {
-        return getHosts(requests);
-      }
-    });
+    Set<HostResponse> responses = getResources(() -> getHosts(requests));
 
     Set<String>   requestedIds = getRequestPropertyIds(request, predicate);
     Set<Resource> resources    = new HashSet<>();
@@ -357,12 +342,9 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
       requests.add(getRequest(propertyMap));
     }
 
-    modifyResources(new Command<Void>() {
-      @Override
-      public Void invoke() throws AmbariException, AuthorizationException {
-        updateHosts(requests);
-        return null;
-      }
+    modifyResources((Command<Void>) () -> {
+      updateHosts(requests);
+      return null;
     });
 
     notifyUpdate(Resource.Type.Host, request, predicate);
@@ -375,18 +357,12 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
       throws SystemException, UnsupportedPropertyException, NoSuchResourceException, NoSuchParentResourceException {
 
     final Set<HostRequest> requests = new HashSet<>();
-    Map<String, String> requestInfoProperties = request.getRequestInfoProperties();
 
     for (Map<String, Object> propertyMap : getPropertyMaps(predicate)) {
       requests.add(getRequest(propertyMap));
     }
 
-    DeleteStatusMetaData deleteStatusMetaData = modifyResources(new Command<DeleteStatusMetaData>() {
-      @Override
-      public DeleteStatusMetaData invoke() throws AmbariException {
-        return deleteHosts(requests, request.isDryRunRequest());
-      }
-    });
+    DeleteStatusMetaData deleteStatusMetaData = modifyResources(() -> deleteHosts(requests, request.isDryRunRequest()));
 
     if (!request.isDryRunRequest()) {
       notifyDelete(Resource.Type.Host, predicate);
@@ -542,16 +518,11 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
           addedTopologies.put(clusterId, new TopologyCluster());
         }
         Host addedHost = clusters.getHost(hostRequest.getHostname());
-        addedTopologies.get(clusterId).addTopologyHost(new TopologyHost(addedHost.getHostId(),
-            addedHost.getHostName(),
-            addedHost.getRackInfo(),
-            addedHost.getIPv4()));
+        addedTopologies.get(clusterId).addTopologyHost(new TopologyHost(addedHost.getHostId(), addedHost.getHostName(),
+            addedHost.getRackInfo(), addedHost.getIPv4()));
         HostLevelParamsUpdateEvent hostLevelParamsUpdateEvent = new HostLevelParamsUpdateEvent(addedHost.getHostId(),
             clusterId,
-            new HostLevelParamsCluster(
-            getManagementController().retrieveHostRepositories(cl, addedHost),
-            recoveryConfigHelper.getRecoveryConfig(cl.getClusterName(),
-                addedHost.getHostName()),
+            new HostLevelParamsCluster( recoveryConfigHelper.getRecoveryConfig(cl.getClusterName(), addedHost.getHostName()),
             getManagementController().getBlueprintProvisioningStates(cl.getClusterId(), addedHost.getHostId())
         ));
         hostLevelParamsUpdateEvents.add(hostLevelParamsUpdateEvent);
@@ -684,8 +655,7 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
                                        Collection<String> skipInstallForComponents,
                                        Collection<String> dontSkipInstallForComponents, final boolean skipFailure,
                                        boolean useClusterHostInfo)
-      throws ResourceAlreadyExistsException,
-      SystemException,
+      throws SystemException,
       NoSuchParentResourceException,
       UnsupportedPropertyException {
 
@@ -695,8 +665,7 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
   }
 
   public RequestStatusResponse start(final String cluster, final String hostname)
-      throws ResourceAlreadyExistsException,
-      SystemException,
+      throws SystemException,
       NoSuchParentResourceException,
       UnsupportedPropertyException {
 
@@ -985,7 +954,6 @@ public class HostResourceProvider extends AbstractControllerResourceProvider {
     Set<String> hostsClusters = new HashSet<>();
     Set<String> hostNames = new HashSet<>();
     Set<Long> hostIds = new HashSet<>();
-    Set<Cluster> allClustersWithHosts = new HashSet<>();
     TreeMap<String, TopologyCluster> topologyUpdates = new TreeMap<>();
     for (HostRequest hostRequest : requests) {
       // Assume the user also wants to delete it entirely, including all clusters.
