@@ -152,7 +152,7 @@ public class RequestResourceProvider extends AbstractControllerResourceProvider
   /**
    * The key property ids for a Request resource.
    */
-  private static Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
+  private static final Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
       .put(Resource.Type.Request, REQUEST_ID_PROPERTY_ID)
       .put(Resource.Type.Cluster, REQUEST_CLUSTER_NAME_PROPERTY_ID)
       .build();
@@ -261,9 +261,7 @@ public class RequestResourceProvider extends AbstractControllerResourceProvider
             }
           } else {
             // A custom action has been requested
-            ActionDefinition actionDefinition = (actionName == null)
-                ? null
-                : getManagementController().getAmbariMetaInfo().getActionDefinition(actionName);
+            ActionDefinition actionDefinition = getManagementController().getAmbariMetaInfo().getActionDefinition(actionName);
 
             Set<RoleAuthorization> permissions = (actionDefinition == null)
                 ? null
@@ -424,7 +422,7 @@ public class RequestResourceProvider extends AbstractControllerResourceProvider
     // Cluster name may be empty for custom actions
     String clusterNameStr = (String) propertyMap.get(REQUEST_CLUSTER_NAME_PROPERTY_ID);
     String requestIdStr = (String) propertyMap.get(REQUEST_ID_PROPERTY_ID);
-    long requestId = Integer.valueOf(requestIdStr);
+    long requestId = Integer.parseInt(requestIdStr);
     String requestStatusStr = (String) propertyMap.get(REQUEST_STATUS_PROPERTY_ID);
     HostRoleStatus requestStatus = null;
     if (requestStatusStr != null) {
@@ -714,9 +712,7 @@ public class RequestResourceProvider extends AbstractControllerResourceProvider
         // !!! this call will result in mixed results of cluster and non-cluster.  this
         // will get fixed in a future iteration, as the host_role_command table does not
         // currently have direct cluster affinity, and changing that is a tad destructive.
-        requestIds = actionManager.getRequestsByStatus(status,
-          maxResults != null ? maxResults : BaseRequest.DEFAULT_PAGE_SIZE,
-                ascOrder != null ? ascOrder : false);
+        requestIds = actionManager.getRequestsByStatus(status, maxResults, ascOrder);
       }
 
       LOG.debug("List<Long> requestIds = actionManager.getRequestsByStatus = {}", requestIds.size());
