@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -27,5 +27,5 @@ public interface ResourceProviderObserver {
    *
    * @param event the event
    */
-  public void update(ResourceProviderEvent event);
+  void update(ResourceProviderEvent event);
 }
