@@ -17,6 +17,7 @@
  */
 package org.apache.ambari.server.controller.internal;
 
+import java.io.UncheckedIOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -69,7 +70,6 @@ import org.apache.ambari.server.serveraction.kerberos.KerberosMissingAdminCreden
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
 import org.apache.ambari.server.state.MaintenanceState;
-import org.apache.ambari.server.state.RepositoryType;
 import org.apache.ambari.server.state.Service;
 import org.apache.ambari.server.state.ServiceComponent;
 import org.apache.ambari.server.state.ServiceComponentHost;
@@ -77,7 +77,11 @@ import org.apache.ambari.server.state.ServiceInfo;
 import org.apache.ambari.server.state.StackId;
 import org.apache.ambari.server.state.State;
 import org.apache.ambari.server.topology.STOMPComponentsDeleteHandler;
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.ambari.server.topology.addservice.AddServiceOrchestrator;
+import org.apache.ambari.server.topology.addservice.AddServiceRequest;
+import org.apache.ambari.server.utils.LoggingPreconditions;
+import org.apache.ambari.spi.RepositoryType;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.Validate;
 import org.slf4j.Logger;
@@ -93,6 +97,7 @@ import com.google.inject.assistedinject.AssistedInject;
 public class ServiceResourceProvider extends AbstractControllerResourceProvider {
 
   private static final Logger LOG = LoggerFactory.getLogger(ServiceResourceProvider.class);
+  private static final LoggingPreconditions CHECK = new LoggingPreconditions(LOG);
 
   public static final String SERVICE_CLUSTER_NAME_PROPERTY_ID = PropertyHelper.getPropertyId(
       "ServiceInfo", "cluster_name");
@@ -136,6 +141,17 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
   private static final String KERBEROS_ENABLED_PROPERTY_ID = PropertyHelper.getPropertyId(
       "ServiceInfo", "kerberos_enabled");
 
+  private static final String LDAP_INTEGRATION_SUPPORTED_PROPERTY_ID = PropertyHelper.getPropertyId(
+      "ServiceInfo", "ldap_integration_supported");
+
+  private static final String LDAP_INTEGRATION_ENABLED_PROPERTY_ID = PropertyHelper.getPropertyId(
+      "ServiceInfo", "ldap_integration_enabled");
+
+  private static final String LDAP_INTEGRATION_DESIRED_PROPERTY_ID = PropertyHelper.getPropertyId(
+      "ServiceInfo", "ldap_integration_desired");
+
+  public static final String OPERATION_TYPE = "operation_type";
+
   protected static final String SERVICE_REPOSITORY_STATE = "ServiceInfo/repository_state";
 
   //Parameters from the predicate
@@ -143,7 +159,7 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
   private static final String QUERY_PARAMETERS_RECONFIGURE_CLIENT = "params/reconfigure_client";
   private static final String QUERY_PARAMETERS_START_DEPENDENCIES = "params/start_dependencies";
 
-  private static Set<String> pkPropertyIds =
+  private static final Set<String> pkPropertyIds =
     new HashSet<>(Arrays.asList(new String[]{
       SERVICE_CLUSTER_NAME_PROPERTY_ID,
       SERVICE_SERVICE_NAME_PROPERTY_ID}));
@@ -181,6 +197,14 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
     PROPERTY_IDS.add(SSO_INTEGRATION_REQUIRES_KERBEROS_PROPERTY_ID);
     PROPERTY_IDS.add(KERBEROS_ENABLED_PROPERTY_ID);
 
+    PROPERTY_IDS.add(LDAP_INTEGRATION_SUPPORTED_PROPERTY_ID);
+    PROPERTY_IDS.add(LDAP_INTEGRATION_ENABLED_PROPERTY_ID);
+    PROPERTY_IDS.add(LDAP_INTEGRATION_DESIRED_PROPERTY_ID);
+
+    PROPERTY_IDS.add(OPERATION_TYPE);
+    PROPERTY_IDS.add(ClusterResourceProvider.SECURITY);
+    PROPERTY_IDS.add(ClusterResourceProvider.CREDENTIALS);
+
     // keys
     KEY_PROPERTY_IDS.put(Resource.Type.Service, SERVICE_SERVICE_NAME_PROPERTY_ID);
     KEY_PROPERTY_IDS.put(Resource.Type.Cluster, SERVICE_CLUSTER_NAME_PROPERTY_ID);
@@ -197,6 +221,9 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
   @Inject
   private STOMPComponentsDeleteHandler STOMPComponentsDeleteHandler;
 
+  @Inject
+  private AddServiceOrchestrator addServiceOrchestrator;
+
   /**
    * Used to lookup the repository when creating services.
    */
@@ -232,6 +259,15 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
              ResourceAlreadyExistsException,
              NoSuchParentResourceException {
 
+    if (request.getProperties().size() == 1) {
+      Map<String, Object> requestProperties = request.getProperties().iterator().next();
+      if (isAddServiceRequest(requestProperties)) {
+        RequestStatusResponse response = processAddServiceRequest(requestProperties, request.getRequestInfoProperties());
+        notifyCreate(Resource.Type.Service, request);
+        return getRequestStatus(response);
+      }
+    }
+
     final Set<ServiceRequest> requests = new HashSet<>();
     for (Map<String, Object> propertyMap : request.getProperties()) {
       requests.add(getRequest(propertyMap));
@@ -308,6 +344,11 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
       setResourceProperty(resource, KERBEROS_ENABLED_PROPERTY_ID,
           response.isKerberosEnabled(), requestedIds);
 
+      setResourceProperty(resource, LDAP_INTEGRATION_SUPPORTED_PROPERTY_ID, response.isLdapIntegrationSupported(), requestedIds);
+      setResourceProperty(resource, LDAP_INTEGRATION_ENABLED_PROPERTY_ID, response.isLdapIntegrationEnabled(), requestedIds);
+      setResourceProperty(resource, LDAP_INTEGRATION_DESIRED_PROPERTY_ID, response.isLdapIntegrationDesired(), requestedIds);
+      
+
       Map<String, Object> serviceSpecificProperties = getServiceSpecificProperties(
           response.getClusterName(), response.getServiceName(), requestedIds);
 
@@ -376,6 +417,7 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
         }
       }
     }
+    unsupportedProperties.removeAll(AddServiceRequest.TOP_LEVEL_PROPERTIES);
     return unsupportedProperties;
   }
 
@@ -1190,4 +1232,27 @@ public class ServiceResourceProvider extends AbstractControllerResourceProvider
     }
 
   }
+
+  private static boolean isAddServiceRequest(Map<String, Object> properties) {
+    return AddServiceRequest.OperationType.ADD_SERVICE.name().equals(properties.get(OPERATION_TYPE));
+  }
+
+  private RequestStatusResponse processAddServiceRequest(Map<String, Object> requestProperties, Map<String, String> requestInfoProperties) throws NoSuchParentResourceException {
+    AddServiceRequest request = createAddServiceRequest(requestInfoProperties);
+    String clusterName = String.valueOf(requestProperties.get(SERVICE_CLUSTER_NAME_PROPERTY_ID));
+    try {
+      return addServiceOrchestrator.processAddServiceRequest(getManagementController().getClusters().getCluster(clusterName), request);
+    } catch (AmbariException e) {
+      throw new NoSuchParentResourceException(e.getMessage(), e);
+    }
+  }
+
+  private static AddServiceRequest createAddServiceRequest(Map<String, String> requestInfoProperties) {
+    try {
+      return AddServiceRequest.of(requestInfoProperties.get(Request.REQUEST_INFO_BODY_PROPERTY));
+    } catch (UncheckedIOException e) {
+      return CHECK.wrapInUnchecked(e, IllegalArgumentException::new, "Could not parse input as valid Add Service request: " + e.getCause().getMessage());
+    }
+  }
+
 }
