@@ -81,7 +81,7 @@ public class StackLevelConfigurationResourceProvider extends
   /**
    * The key property ids for a StackLevelConfiguration resource.
    */
-  private static Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
+  private static final Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
       .put(Type.Stack, STACK_NAME_PROPERTY_ID)
       .put(Type.StackVersion, STACK_VERSION_PROPERTY_ID)
       .put(Type.StackLevelConfiguration, PROPERTY_NAME_PROPERTY_ID)
@@ -90,7 +90,7 @@ public class StackLevelConfigurationResourceProvider extends
   /**
    * The property ids for a StackLevelConfiguration resource.
    */
-  private static Set<String> propertyIds = Sets.newHashSet(
+  private static final Set<String> propertyIds = Sets.newHashSet(
       STACK_NAME_PROPERTY_ID,
       STACK_VERSION_PROPERTY_ID,
       PROPERTY_NAME_PROPERTY_ID,
