@@ -27,6 +27,7 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.ambari.server.AmbariException;
+import org.apache.ambari.server.DuplicateResourceException;
 import org.apache.ambari.server.ObjectNotFoundException;
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.controller.UserRequest;
@@ -121,11 +122,11 @@ public class UserResourceProvider extends AbstractControllerResourceProvider imp
   /**
    * The key property ids for a User resource.
    */
-  private static Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
+  private static final Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
       .put(Resource.Type.User, USER_USERNAME_PROPERTY_ID)
       .build();
 
-  private static Set<String> propertyIds = Sets.newHashSet(
+  private static final Set<String> propertyIds = Sets.newHashSet(
       USER_USERNAME_PROPERTY_ID,
       USER_DISPLAY_NAME_PROPERTY_ID,
       USER_LOCAL_USERNAME_PROPERTY_ID,
@@ -170,7 +171,7 @@ public class UserResourceProvider extends AbstractControllerResourceProvider imp
       public Void invoke() throws AmbariException {
         try {
           createUsers(requests);
-        } catch (ResourceAlreadyExistsException | AuthorizationException e) {
+        } catch (AuthorizationException e) {
           throw new AmbariException(e.getMessage(), e);
         }
         return null;
@@ -354,7 +355,7 @@ public class UserResourceProvider extends AbstractControllerResourceProvider imp
    * @param requests the request objects which define the user.
    * @throws AmbariException when the user cannot be created.
    */
-  private void createUsers(Set<UserRequest> requests) throws AmbariException, ResourceAlreadyExistsException, AuthorizationException {
+  private void createUsers(Set<UserRequest> requests) throws AmbariException, AuthorizationException {
     // First check for obvious issues... then try to create the accounts.  This will help to avoid
     // some accounts being created and some not due to an issue with one or more of the users.
     for (UserRequest request : requests) {
@@ -371,7 +372,7 @@ public class UserResourceProvider extends AbstractControllerResourceProvider imp
         } else {
           message = "One or more of the requested usernames already exists.";
         }
-        throw new ResourceAlreadyExistsException(message);
+        throw new DuplicateResourceException(message);
       }
     }
 
@@ -383,7 +384,7 @@ public class UserResourceProvider extends AbstractControllerResourceProvider imp
       // Setting a user's the password here is to allow for backward compatibility with pre-Ambari-3.0
       // versions so that the contract for REST API V1 is maintained.
       if (!StringUtils.isEmpty(password)) {
-        users.validatePassword(password);
+        users.validatePassword(password, username);
       }
 
       UserEntity userEntity = users.createUser(username, localUserName, displayName, request.isActive());
