@@ -111,7 +111,7 @@ public class ViewInstanceResourceProvider extends AbstractAuthorizedResourceProv
   /**
    * The key property ids for a view instance resource.
    */
-  private static Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
+  private static final Map<Resource.Type, String> keyPropertyIds = ImmutableMap.<Resource.Type, String>builder()
       .put(Resource.Type.View, VIEW_NAME)
       .put(Resource.Type.ViewVersion, VERSION)
       .put(Resource.Type.ViewInstance, INSTANCE_NAME)
@@ -120,7 +120,7 @@ public class ViewInstanceResourceProvider extends AbstractAuthorizedResourceProv
   /**
    * The property ids for a view instance resource.
    */
-  private static Set<String> propertyIds = Sets.newHashSet(
+  private static final Set<String> propertyIds = Sets.newHashSet(
     VIEW_NAME,
     VERSION,
     INSTANCE_NAME,
