@@ -52,6 +52,8 @@ import org.apache.ambari.server.orm.entities.WidgetLayoutUserWidgetEntity;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.commons.lang.StringUtils;
 
+import com.google.common.collect.ImmutableMap;
+import com.google.common.collect.ImmutableSet;
 import com.google.inject.Inject;
 
 /**
@@ -76,37 +78,31 @@ public class WidgetLayoutResourceProvider extends AbstractControllerResourceProv
   }
 
   @SuppressWarnings("serial")
-  private static Set<String> pkPropertyIds = new HashSet<String>() {
-    {
-      add(WIDGETLAYOUT_ID_PROPERTY_ID);
-    }
-  };
+  private static final Set<String> pkPropertyIds = ImmutableSet.<String>builder()
+    .add(WIDGETLAYOUT_ID_PROPERTY_ID)
+    .build();
 
   @SuppressWarnings("serial")
-  private static ReadWriteLock lock = new ReentrantReadWriteLock();
+  private static final ReadWriteLock lock = new ReentrantReadWriteLock();
 
   @SuppressWarnings("serial")
-  public static Set<String> propertyIds = new HashSet<String>() {
-    {
-      add(WIDGETLAYOUT_ID_PROPERTY_ID);
-      add(WIDGETLAYOUT_SECTION_NAME_PROPERTY_ID);
-      add(WIDGETLAYOUT_LAYOUT_NAME_PROPERTY_ID);
-      add(WIDGETLAYOUT_CLUSTER_NAME_PROPERTY_ID);
-      add(WIDGETLAYOUT_WIDGETS_PROPERTY_ID);
-      add(WIDGETLAYOUT_SCOPE_PROPERTY_ID);
-      add(WIDGETLAYOUT_USERNAME_PROPERTY_ID);
-      add(WIDGETLAYOUT_DISPLAY_NAME_PROPERTY_ID);
-    }
-  };
+  public static final Set<String> propertyIds = ImmutableSet.<String>builder()
+    .add(WIDGETLAYOUT_ID_PROPERTY_ID)
+    .add(WIDGETLAYOUT_SECTION_NAME_PROPERTY_ID)
+    .add(WIDGETLAYOUT_LAYOUT_NAME_PROPERTY_ID)
+    .add(WIDGETLAYOUT_CLUSTER_NAME_PROPERTY_ID)
+    .add(WIDGETLAYOUT_WIDGETS_PROPERTY_ID)
+    .add(WIDGETLAYOUT_SCOPE_PROPERTY_ID)
+    .add(WIDGETLAYOUT_USERNAME_PROPERTY_ID)
+    .add(WIDGETLAYOUT_DISPLAY_NAME_PROPERTY_ID)
+    .build();
 
   @SuppressWarnings("serial")
-  public static Map<Type, String> keyPropertyIds = new HashMap<Type, String>() {
-    {
-      put(Type.WidgetLayout, WIDGETLAYOUT_ID_PROPERTY_ID);
-      put(Type.Cluster, WIDGETLAYOUT_CLUSTER_NAME_PROPERTY_ID);
-      put(Type.User, WIDGETLAYOUT_USERNAME_PROPERTY_ID);
-    }
-  };
+  public static final Map<Type, String> keyPropertyIds = ImmutableMap.<Type, String>builder()
+    .put(Type.WidgetLayout, WIDGETLAYOUT_ID_PROPERTY_ID)
+    .put(Type.Cluster, WIDGETLAYOUT_CLUSTER_NAME_PROPERTY_ID)
+    .put(Type.User, WIDGETLAYOUT_USERNAME_PROPERTY_ID)
+    .build();
 
   @Inject
   private static WidgetDAO widgetDAO;
@@ -201,14 +197,11 @@ public class WidgetLayoutResourceProvider extends AbstractControllerResourceProv
   public Set<Resource> getResources(Request request, Predicate predicate)
       throws SystemException, UnsupportedPropertyException, NoSuchResourceException, NoSuchParentResourceException {
     final Set<Resource> resources = new HashSet<>();
-    final Set<String> requestedIds = getRequestPropertyIds(request, predicate);
     final Set<Map<String, Object>> propertyMaps = getPropertyMaps(predicate);
 
-    List<WidgetEntity> widgetEntities = new ArrayList<>();
     List<WidgetLayoutEntity> layoutEntities = new ArrayList<>();
 
     for (Map<String, Object> propertyMap: propertyMaps) {
-      String userName = getUserName(propertyMap);
       if (propertyMap.get(WIDGETLAYOUT_ID_PROPERTY_ID) != null) {
         final Long id;
         try {
@@ -229,7 +222,7 @@ public class WidgetLayoutResourceProvider extends AbstractControllerResourceProv
     for (WidgetLayoutEntity layoutEntity : layoutEntities) {
       Resource resource = new ResourceImpl(Type.WidgetLayout);
       resource.setProperty(WIDGETLAYOUT_ID_PROPERTY_ID, layoutEntity.getId());
-      String clusterName = null;
+      String clusterName;
       try {
         clusterName = getManagementController().getClusters().getClusterById(layoutEntity.getClusterId()).getClusterName();
       } catch (AmbariException e) {
