@@ -21,7 +21,7 @@ package org.apache.ambari.server.controller.logging;
 
 import java.util.List;
 
-import org.codehaus.jackson.annotate.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonProperty;
 
 public class HostComponentLoggingInfo {
 
