@@ -452,7 +452,7 @@ public abstract class GangliaPropertyProvider extends MetricsPropertyProvider {
 
           while(val!=null && !"[~EOM]".equals(val)) {
             if (val.startsWith("[~r]")) {
-              Integer repeat = Integer.valueOf(val.substring(4)) - 1;
+              int repeat = Integer.parseInt(val.substring(4)) - 1;
               for (int i = 0; i < repeat; ++i) {
                 if (! "[~n]".equals(lastVal)) {
                   GangliaMetric.TemporalMetric tm = new GangliaMetric.TemporalMetric(lastVal, time);
