@@ -18,35 +18,36 @@
 package org.apache.ambari.server.controller.metrics.timeline.cache;
 
 import java.io.IOException;
-import java.net.ConnectException;
 import java.net.SocketTimeoutException;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apache.hadoop.metrics2.sink.timeline.TimelineMetrics;
+import org.ehcache.Cache;
+import org.ehcache.core.internal.statistics.DefaultStatisticsService;
+import org.ehcache.core.statistics.CacheStatistics;
+import org.ehcache.spi.loaderwriter.CacheLoadingException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import net.sf.ehcache.CacheException;
-import net.sf.ehcache.Ehcache;
-import net.sf.ehcache.Element;
-import net.sf.ehcache.constructs.blocking.LockTimeoutException;
-import net.sf.ehcache.constructs.blocking.UpdatingCacheEntryFactory;
-import net.sf.ehcache.constructs.blocking.UpdatingSelfPopulatingCache;
-import net.sf.ehcache.statistics.StatisticsGateway;
-
-public class TimelineMetricCache extends UpdatingSelfPopulatingCache {
-
+public class TimelineMetricCache {
+  private final Cache<TimelineAppMetricCacheKey, TimelineMetricsCacheValue> cache;
+  private final DefaultStatisticsService statisticsService;
+  private final TimelineMetricCacheEntryFactory cacheEntryFactory;
+  public static final String TIMELINE_METRIC_CACHE_INSTANCE_NAME = "timelineMetricCache";
   private final static Logger LOG = LoggerFactory.getLogger(TimelineMetricCache.class);
   private static AtomicInteger printCacheStatsCounter = new AtomicInteger(0);
 
   /**
-   * Creates a SelfPopulatingCache.
+   * Creates a TimelineMetricCache.
    *
    * @param cache @Cache
-   * @param factory @CacheEntryFactory
+   * @param cacheEntryFactory @CacheEntryFactory
+   * @param statisticsService @DefaultStatisticsService
    */
-  public TimelineMetricCache(Ehcache cache, UpdatingCacheEntryFactory factory) throws CacheException {
-    super(cache, factory);
+  public TimelineMetricCache(Cache<TimelineAppMetricCacheKey, TimelineMetricsCacheValue> cache, TimelineMetricCacheEntryFactory cacheEntryFactory, DefaultStatisticsService statisticsService) {
+    this.cache = cache;
+    this.cacheEntryFactory = cacheEntryFactory;
+    this.statisticsService = statisticsService;
   }
 
   /**
@@ -63,26 +64,22 @@ public class TimelineMetricCache extends UpdatingSelfPopulatingCache {
     // Make sure key is valid
     validateKey(key);
 
-    Element element = null;
+    TimelineMetricsCacheValue value = null;
     try {
-      element = get(key);
-    } catch (LockTimeoutException le) {
-      // Ehcache masks the Socket Timeout to look as a LockTimeout
-      Throwable t = le.getCause();
-      if (t instanceof CacheException) {
-        t = t.getCause();
-        if (t instanceof SocketTimeoutException) {
-          throw new SocketTimeoutException(t.getMessage());
-        }
-        if (t instanceof ConnectException) {
-          throw new ConnectException(t.getMessage());
-        }
+      value = cache.get(key);
+    } catch (CacheLoadingException cle) {
+      Throwable t = cle.getCause();
+      if(t instanceof SocketTimeoutException) {
+        throw new SocketTimeoutException(t.getMessage());
       }
+      if(t instanceof IOException) {
+        throw new IOException(t.getMessage());
+      }
+      throw cle;
     }
 
     TimelineMetrics timelineMetrics = new TimelineMetrics();
-    if (element != null && element.getObjectValue() != null) {
-      TimelineMetricsCacheValue value = (TimelineMetricsCacheValue) element.getObjectValue();
+    if (value != null) {
       if (LOG.isDebugEnabled()) {
         LOG.debug("Returning value from cache: {}", value);
       }
@@ -92,51 +89,21 @@ public class TimelineMetricCache extends UpdatingSelfPopulatingCache {
     if (LOG.isDebugEnabled()) {
       // Print stats every 100 calls - Note: Supported in debug mode only
       if (printCacheStatsCounter.getAndIncrement() == 0) {
-        StatisticsGateway statistics = this.getStatistics();
-        LOG.debug("Metrics cache stats => \n, Evictions = {}, Expired = {}, Hits = {}, Misses = {}, Hit ratio = {}, Puts = {}, Size in MB = {}",
-          statistics.cacheEvictedCount(), statistics.cacheExpiredCount(), statistics.cacheHitCount(), statistics.cacheMissCount(), statistics.cacheHitRatio(),
-          statistics.cachePutCount(), statistics.getLocalHeapSizeInBytes() / 1048576);
+        CacheStatistics cacheStatistics = statisticsService.getCacheStatistics(TIMELINE_METRIC_CACHE_INSTANCE_NAME);
+        if(cacheStatistics == null) {
+          LOG.warn("Cache statistics not available.");
+          return timelineMetrics;
+        }
+        LOG.debug("Metrics cache stats => \n, Evictions = {}, Expired = {}, Hits = {}, Misses = {}, Hit ratio = {}, Puts = {}",
+                cacheStatistics.getCacheEvictions(), cacheStatistics.getCacheExpirations(), cacheStatistics.getCacheHits(), cacheStatistics.getCacheMisses(), cacheStatistics.getCacheHitPercentage(), cacheStatistics.getCachePuts()
+        );
       } else {
         printCacheStatsCounter.compareAndSet(100, 0);
       }
     }
-
     return timelineMetrics;
   }
 
-  /**
-   * Set new time bounds on the cache key so that update can use the new
-   * query window. We do this quietly which means regular get/update logic is
-   * not invoked.
-   */
-  @Override
-  public Element get(Object key) throws LockTimeoutException {
-    Element element = this.getQuiet(key);
-    if (element != null) {
-      if (LOG.isTraceEnabled()) {
-        LOG.trace("key : {}", element.getObjectKey());
-        LOG.trace("value : {}", element.getObjectValue());
-      }
-
-      // Set new time boundaries on the key
-      TimelineAppMetricCacheKey existingKey = (TimelineAppMetricCacheKey) element.getObjectKey();
-
-      LOG.debug("Existing temporal info: {} for : {}", existingKey.getTemporalInfo(), existingKey.getMetricNames());
-
-      TimelineAppMetricCacheKey newKey = (TimelineAppMetricCacheKey) key;
-      existingKey.setTemporalInfo(newKey.getTemporalInfo());
-
-      LOG.debug("New temporal info: {} for : {}", newKey.getTemporalInfo(), existingKey.getMetricNames());
-
-      if (existingKey.getSpec() == null || !existingKey.getSpec().equals(newKey.getSpec())) {
-        existingKey.setSpec(newKey.getSpec());
-        LOG.debug("New spec: {} for : {}", newKey.getSpec(), existingKey.getMetricNames());
-      }
-    }
-
-    return super.get(key);
-  }
-
   private void validateKey(TimelineAppMetricCacheKey key) throws IllegalArgumentException {
     StringBuilder msg = new StringBuilder("Invalid metric key requested.");
     boolean throwException = false;
