@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -27,5 +27,5 @@ public interface PredicateVisitorAcceptor {
    *
    * @param visitor  the visitor
    */
-  public void accept(PredicateVisitor visitor);
+  void accept(PredicateVisitor visitor);
 }
