@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,8 +17,6 @@
  */
 package org.apache.ambari.server.controller.spi;
 
-import org.apache.ambari.server.controller.internal.SortRequestImpl;
-
 import java.util.List;
 
 /**
@@ -29,17 +27,17 @@ public interface SortRequest {
   /**
    * Get a list of @SortRequestProperty.
    */
-  public List<SortRequestProperty> getProperties();
+  List<SortRequestProperty> getProperties();
 
   /**
    * Get a list of propertyIds
    */
-  public List<String> getPropertyIds();
+  List<String> getPropertyIds();
 
   /**
    * Enumeration for order of sorting
    */
-  public enum Order {
+  enum Order {
     ASC,
     DESC
   }
