@@ -36,8 +36,10 @@ import org.apache.ambari.server.controller.spi.Resource;
 import org.apache.ambari.server.controller.spi.SortRequest;
 import org.apache.ambari.server.controller.spi.TemporalInfo;
 import org.apache.commons.lang.StringUtils;
-import org.codehaus.jackson.map.ObjectMapper;
-import org.codehaus.jackson.type.TypeReference;
+
+import com.fasterxml.jackson.core.type.TypeReference;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import com.google.common.collect.ImmutableList;
 
 /**
  * Utility class that provides Property helper methods.
@@ -53,10 +55,10 @@ public class PropertyHelper {
    * Aggregate functions implicitly supported by the Metrics Service
    */
   public static final List<String> AGGREGATE_FUNCTION_IDENTIFIERS =
-    Arrays.asList("._sum", "._max", "._min", "._avg", "._rate");
+    ImmutableList.of("._sum", "._max", "._min", "._avg", "._rate");
 
   private static final List<Resource.InternalType> REPORT_METRIC_RESOURCES =
-    Arrays.asList(Resource.InternalType.Cluster, Resource.InternalType.Host);
+    ImmutableList.of(Resource.InternalType.Cluster, Resource.InternalType.Host);
 
   private static final Map<Resource.InternalType, Set<String>> PROPERTY_IDS = new HashMap<>();
   private static final Map<Resource.InternalType, Map<String, Map<String, PropertyInfo>>> JMX_PROPERTY_IDS = readPropertyProviderIds(JMX_PROPERTIES_FILE);
@@ -93,8 +95,8 @@ public class PropertyHelper {
   private static final Pattern METRIC_CATEGORY_TOKENIZE_REGEX = Pattern.compile("/+(?=([^\"\\\\\\\\]*(\\\\\\\\.|\"([^\"\\\\\\\\]*\\\\\\\\.)*[^\"\\\\\\\\]*\"))*[^\"]*$)");
 
   static {
-    RPC_METRIC_SUFFIXES.put("metrics/rpc/", Arrays.asList("client", "datanode", "healthcheck"));
-    RPC_METRIC_SUFFIXES.put("metrics/rpcdetailed/", Arrays.asList("client", "datanode", "healthcheck"));
+    RPC_METRIC_SUFFIXES.put("metrics/rpc/", ImmutableList.of("client", "datanode", "healthcheck"));
+    RPC_METRIC_SUFFIXES.put("metrics/rpcdetailed/", ImmutableList.of("client", "datanode", "healthcheck"));
   }
 
   public static String getPropertyId(String category, String name) {
