@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,21 +18,26 @@
 package org.apache.ambari.server.events.listeners.alerts;
 
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 import java.util.concurrent.locks.Lock;
 
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.EagerSingleton;
+import org.apache.ambari.server.api.query.render.AlertSummaryGroupedRenderer;
 import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.MaintenanceStateHelper;
-import org.apache.ambari.server.controller.RootServiceResponseFactory.Components;
-import org.apache.ambari.server.controller.RootServiceResponseFactory.Services;
+import org.apache.ambari.server.controller.RootComponent;
+import org.apache.ambari.server.controller.RootService;
 import org.apache.ambari.server.events.AlertEvent;
 import org.apache.ambari.server.events.AlertReceivedEvent;
 import org.apache.ambari.server.events.AlertStateChangeEvent;
+import org.apache.ambari.server.events.AlertUpdateEvent;
 import org.apache.ambari.server.events.InitialAlertEvent;
 import org.apache.ambari.server.events.publishers.AlertEventPublisher;
+import org.apache.ambari.server.events.publishers.STOMPUpdatePublisher;
 import org.apache.ambari.server.orm.RequiresSession;
 import org.apache.ambari.server.orm.dao.AlertDefinitionDAO;
 import org.apache.ambari.server.orm.dao.AlertsDAO;
@@ -45,10 +50,13 @@ import org.apache.ambari.server.state.AlertState;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
 import org.apache.ambari.server.state.ConfigHelper;
+import org.apache.ambari.server.state.Host;
 import org.apache.ambari.server.state.MaintenanceState;
+import org.apache.ambari.server.state.alert.AlertHelper;
 import org.apache.ambari.server.state.alert.SourceType;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.math.NumberUtils;
+import org.eclipse.jetty.util.StringUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -58,7 +66,6 @@ import com.google.common.util.concurrent.Striped;
 import com.google.inject.Inject;
 import com.google.inject.Provider;
 import com.google.inject.Singleton;
-import com.google.inject.persist.Transactional;
 
 /**
  * The {@link AlertReceivedListener} class handles {@link AlertReceivedEvent}
@@ -86,7 +93,10 @@ public class AlertReceivedListener {
    * Used for looking up whether an alert has a valid service/component/host
    */
   @Inject
-  Provider<Clusters> m_clusters;
+  private Provider<Clusters> m_clusters;
+
+  @Inject
+  private STOMPUpdatePublisher STOMPUpdatePublisher;
 
   /**
    * Used to calculate the maintenance state of new alerts being created.
@@ -98,6 +108,9 @@ public class AlertReceivedListener {
   @Inject
   private Provider<MaintenanceStateHelper> m_maintenanceStateHelper;
 
+  @Inject
+  private AlertHelper alertHelper;
+
   /**
    * Receives and publishes {@link AlertEvent} instances.
    */
@@ -129,7 +142,7 @@ public class AlertReceivedListener {
   @Subscribe
   @AllowConcurrentEvents
   @RequiresSession
-  public void onAlertEvent(AlertReceivedEvent event) {
+  public void onAlertEvent(AlertReceivedEvent event) throws AmbariException {
     if (LOG.isDebugEnabled()) {
       LOG.debug(event.toString());
     }
@@ -143,32 +156,34 @@ public class AlertReceivedListener {
     List<AlertCurrentEntity> toCreateHistoryAndMerge = new ArrayList<>();
 
     List<AlertEvent> alertEvents = new ArrayList<>(20);
+    Map<Long, Map<String, AlertSummaryGroupedRenderer.AlertDefinitionSummary>> alertUpdates = new HashMap<>();
 
     for (Alert alert : alerts) {
-      // jobs that were running when a service/component/host was changed
-      // which invalidate the alert should not be reported
-      if (!isValid(alert)) {
-        continue;
-      }
-
-      String clusterName = alert.getCluster();
-      Long clusterId = getClusterIdByName(clusterName);
+      Long clusterId = alert.getClusterId();
       if (clusterId == null) {
         // check event
         clusterId = event.getClusterId();
       }
 
-      AlertDefinitionEntity definition = m_definitionDao.findByName(clusterId,
-        alert.getName());
+      AlertDefinitionEntity definition = m_definitionDao.findByName(clusterId, alert.getName());
 
       if (null == definition) {
         LOG.warn(
-          "Received an alert for {} which is a definition that does not exist anymore",
-          alert.getName());
+          "Received an alert for {} which is a definition that does not exist in cluster id={}",
+          alert.getName(), clusterId);
 
         continue;
       }
 
+      alert.setComponent(definition.getComponentName());
+      alert.setLabel(definition.getComponentName());
+      alert.setService(definition.getServiceName());
+
+      // jobs that were running when a service/component/host was changed
+      // which invalidate the alert should not be reported
+      if (!isValid(alert)) {
+        continue;
+      }
       // it's possible that a definition which is disabled will still have a
       // running alert returned; this will ensure we don't record it
       if (!definition.getEnabled()) {
@@ -179,6 +194,14 @@ public class AlertReceivedListener {
         continue;
       }
 
+      updateAlertDetails(alert, definition);
+
+      // jobs that were running when a service/component/host was changed
+      // which invalidate the alert should not be reported
+      if (!isValid(alert)) {
+        continue;
+      }
+
       AlertCurrentEntity current;
       AlertState alertState = alert.getState();
 
@@ -214,19 +237,14 @@ public class AlertReceivedListener {
 
           // this new alert must reflect the correct MM state for the
           // service/component/host
-          MaintenanceState maintenanceState = MaintenanceState.OFF;
-          try {
-            maintenanceState = m_maintenanceStateHelper.get().getEffectiveState(clusterId, alert);
-          } catch (Exception exception) {
-            LOG.error("Unable to determine the maintenance mode state for {}, defaulting to OFF",
-                alert, exception);
-          }
+          MaintenanceState maintenanceState = getMaintenanceState(alert, clusterId);
 
           current = new AlertCurrentEntity();
           current.setMaintenanceState(maintenanceState);
           current.setAlertHistory(history);
           current.setLatestTimestamp(alert.getTimestamp());
           current.setOriginalTimestamp(alert.getTimestamp());
+          clearStaleAlerts(alert.getHostName(), definition.getDefinitionId());
 
           // brand new alert instances being received are always HARD
           current.setFirmness(AlertFirmness.HARD);
@@ -235,6 +253,14 @@ public class AlertReceivedListener {
 
           // create the event to fire later
           alertEvents.add(new InitialAlertEvent(clusterId, alert, current));
+
+          if (!alertUpdates.containsKey(clusterId)) {
+            alertUpdates.put(clusterId, new HashMap<>());
+          }
+          Map<String, AlertSummaryGroupedRenderer.AlertDefinitionSummary> summaries = alertUpdates.get(clusterId);
+
+          AlertSummaryGroupedRenderer.updateSummary(summaries, definition.getDefinitionId(),
+              definition.getDefinitionName(), alertState, alert.getTimestamp(), maintenanceState, alert.getText());
         } finally {
           // release the lock for this alert
           lock.unlock();
@@ -244,6 +270,7 @@ public class AlertReceivedListener {
 
         // update the timestamp no matter what
         current.setLatestTimestamp(alert.getTimestamp());
+        clearStaleAlerts(alert.getHostName(), definition.getDefinitionId());
 
         // only update some fields if the alert isn't SKIPPED
         if (alertState != AlertState.SKIPPED) {
@@ -258,7 +285,7 @@ public class AlertReceivedListener {
           // still SOFT, then we transition it to HARD - we also need to fire an
           // event
           AlertFirmness firmness = current.getFirmness();
-          int repeatTolerance = getRepeatTolerance(definition, clusterName);
+          int repeatTolerance = getRepeatTolerance(definition, clusterId);
           if (firmness == AlertFirmness.SOFT && occurrences >= repeatTolerance) {
             current.setFirmness(AlertFirmness.HARD);
 
@@ -303,6 +330,8 @@ public class AlertReceivedListener {
         current.setOriginalTimestamp(alert.getTimestamp());
         current.setLatestText(alert.getText());
 
+        clearStaleAlerts(alert.getHostName(), definition.getDefinitionId());
+
         current.setAlertHistory(history);
 
         // figure out how to set the occurrences correctly
@@ -329,7 +358,7 @@ public class AlertReceivedListener {
 
         // set the firmness of the new alert state based on the state, type,
         // occurrences, and repeat tolerance
-        AlertFirmness firmness = calculateFirmnessForStateChange(clusterName, definition,
+        AlertFirmness firmness = calculateFirmnessForStateChange(clusterId, definition,
             alertState, current.getOccurrences());
 
         current.setFirmness(firmness);
@@ -339,34 +368,65 @@ public class AlertReceivedListener {
 
         // create the event to fire later
         alertEvents.add(new AlertStateChangeEvent(clusterId, alert, current, oldState, oldFirmness));
+
+        // create alert update to fire event to UI
+        MaintenanceState maintenanceState = getMaintenanceState(alert, clusterId);
+
+        if (!alertUpdates.containsKey(clusterId)) {
+          alertUpdates.put(clusterId, new HashMap<>());
+        }
+        Map<String, AlertSummaryGroupedRenderer.AlertDefinitionSummary> summaries = alertUpdates.get(clusterId);
+
+        AlertSummaryGroupedRenderer.updateSummary(summaries, definition.getDefinitionId(),
+            definition.getDefinitionName(), alertState, alert.getTimestamp(), maintenanceState, alert.getText());
       }
     }
 
     // invokes the EntityManager create/merge on various entities in a single
     // transaction
-    saveEntities(toMerge, toCreateHistoryAndMerge);
+    m_alertsDao.saveEntities(toMerge, toCreateHistoryAndMerge);
 
     // broadcast events
     for (AlertEvent eventToFire : alertEvents) {
       m_alertEventPublisher.publish(eventToFire);
     }
+    if (!alertUpdates.isEmpty()) {
+      STOMPUpdatePublisher.publish(new AlertUpdateEvent(alertUpdates));
+    }
   }
 
-  /**
-   * Gets the cluster ID given a name.
-   *
-   * @param clusterName
-   * @return
-   */
-  private Long getClusterIdByName(String clusterName) {
-    try {
-      return m_clusters.get().getCluster(clusterName).getClusterId();
-    } catch (AmbariException e) {
-      LOG.warn("Cluster lookup failed for cluster named {}", clusterName);
-      return null;
+  private void clearStaleAlerts(String hostName, Long definitionId) throws AmbariException {
+    if (StringUtil.isNotBlank(hostName)) {
+      Host host = m_clusters.get().getHosts().stream().filter(h -> h.getHostName().equals(hostName))
+          .findFirst().orElse(null);
+      if (host != null) {
+        alertHelper.clearStaleAlert(host.getHostId(), definitionId);
+      }
+    } else {
+      alertHelper.clearStaleAlert(definitionId);
     }
   }
 
+  private void updateAlertDetails(Alert alert, AlertDefinitionEntity definition) {
+    if (alert.getService() == null) {
+      alert.setService(definition.getServiceName());
+    }
+    if (alert.getComponent() == null) {
+      alert.setComponent(definition.getComponentName());
+    }
+  }
+
+  private MaintenanceState getMaintenanceState(Alert alert, Long clusterId) {
+    MaintenanceState maintenanceState = MaintenanceState.OFF;
+    try {
+      maintenanceState = m_maintenanceStateHelper.get().getEffectiveState(clusterId, alert);
+    } catch (Exception exception) {
+      LOG.error("Unable to determine the maintenance mode state for {}, defaulting to OFF",
+          alert, exception);
+    }
+    return maintenanceState;
+  }
+
   /**
    * Gets the {@link AlertCurrentEntity} which cooresponds to the new alert being received, if any.
    *
@@ -384,32 +444,6 @@ public class AlertReceivedListener {
     }
   }
 
-  /**
-   * Saves alert and alert history entities in single transaction
-   * @param toMerge - merge alert only
-   * @param toCreateHistoryAndMerge - create new history, merge alert
-   */
-  @Transactional
-  void saveEntities(List<AlertCurrentEntity> toMerge,
-      List<AlertCurrentEntity> toCreateHistoryAndMerge) {
-    for (AlertCurrentEntity entity : toMerge) {
-      m_alertsDao.merge(entity, m_configuration.isAlertCacheEnabled());
-    }
-
-    for (AlertCurrentEntity entity : toCreateHistoryAndMerge) {
-      m_alertsDao.create(entity.getAlertHistory());
-      m_alertsDao.merge(entity);
-
-      if (LOG.isDebugEnabled()) {
-        LOG.debug(
-            "Alert State Merged: CurrentId {}, CurrentTimestamp {}, HistoryId {}, HistoryState {}",
-            entity.getAlertId(), entity.getLatestTimestamp(),
-            entity.getAlertHistory().getAlertId(),
-            entity.getAlertHistory().getAlertState());
-      }
-    }
-  }
-
   /**
    * Gets whether the specified alert is valid for its reported cluster,
    * service, component, and host. This method is necessary for the following
@@ -428,29 +462,30 @@ public class AlertReceivedListener {
    *         cluster/service/component/host.
    */
   private boolean isValid(Alert alert) {
-    String clusterName = alert.getCluster();
+    Long clusterId = alert.getClusterId();
     String serviceName = alert.getService();
     String componentName = alert.getComponent();
     String hostName = alert.getHostName();
 
     // AMBARI/AMBARI_SERVER is always a valid service/component combination
-    String ambariServiceName = Services.AMBARI.name();
-    String ambariServerComponentName = Components.AMBARI_SERVER.name();
-    String ambariAgentComponentName = Components.AMBARI_AGENT.name();
+    String ambariServiceName = RootService.AMBARI.name();
+    String ambariServerComponentName = RootComponent.AMBARI_SERVER.name();
+    String ambariAgentComponentName = RootComponent.AMBARI_AGENT.name();
     if (ambariServiceName.equals(serviceName) && ambariServerComponentName.equals(componentName)) {
       return true;
     }
 
     // if the alert is not bound to a cluster, then it's most likely a
     // host alert and is always valid as long as the host exists
-    if (StringUtils.isBlank(clusterName)) {
+    Clusters clusters = m_clusters.get();
+    if (clusterId == null) {
       // no cluster, no host; return true out of respect for the unknown alert
       if (StringUtils.isBlank(hostName)) {
         return true;
       }
 
       // if a host is reported, it must be registered to some cluster somewhere
-      if (!m_clusters.get().hostExists(hostName)) {
+      if (!clusters.hostExists(hostName)) {
         LOG.error("Unable to process alert {} for an invalid host named {}",
             alert.getName(), hostName);
         return false;
@@ -465,22 +500,14 @@ public class AlertReceivedListener {
     // - this is not for AMBARI_SERVER component
     final Cluster cluster;
     try {
-      cluster = m_clusters.get().getCluster(clusterName);
+      cluster = clusters.getCluster(clusterId);
       if (null == cluster) {
-        LOG.error("Unable to process alert {} for an invalid cluster named {}",
-            alert.getName(), clusterName);
-
+        LOG.error("Unable to process alert {} for cluster id={}", alert.getName(), clusterId);
         return false;
       }
     } catch (AmbariException ambariException) {
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("Unable to process alert {} for an invalid cluster named {}",
-            alert.getName(), clusterName, ambariException);
-      } else {
-        LOG.error("Unable to process alert {} for an invalid cluster named {}",
-            alert.getName(), clusterName);
-      }
-
+      String msg = String.format("Unable to process alert %s for cluster id=%s", alert.getName(), clusterId);
+      LOG.error(msg, ambariException);
       return false;
     }
 
@@ -492,11 +519,11 @@ public class AlertReceivedListener {
     // the agent's host is still a part of the reported cluster
     if (ambariServiceName.equals(serviceName) && ambariAgentComponentName.equals(componentName)) {
       // agents MUST report a hostname
-      if (StringUtils.isBlank(hostName) || !m_clusters.get().hostExists(hostName)
-          || !m_clusters.get().isHostMappedToCluster(clusterName, hostName)) {
+      if (StringUtils.isBlank(hostName) || !clusters.hostExists(hostName)
+          || !clusters.isHostMappedToCluster(clusterId, hostName)) {
         LOG.warn(
             "Unable to process alert {} for cluster {} and host {} because the host is not a part of the cluster.",
-            alert.getName(), clusterName, hostName);
+            alert.getName(), hostName);
 
         return false;
       }
@@ -510,7 +537,7 @@ public class AlertReceivedListener {
     // - not for the AMBARI service
     if (StringUtils.isNotBlank(hostName)) {
       // if valid hostname
-      if (!m_clusters.get().hostExists(hostName)) {
+      if (!clusters.hostExists(hostName)) {
         LOG.warn("Unable to process alert {} for an invalid host named {}",
             alert.getName(), hostName);
         return false;
@@ -557,8 +584,8 @@ public class AlertReceivedListener {
     history.setAlertInstance(alert.getInstance());
     history.setAlertState(alert.getState());
     history.setAlertText(alert.getText());
-    history.setAlertTimestamp(Long.valueOf(alert.getTimestamp()));
-    history.setClusterId(Long.valueOf(clusterId));
+    history.setAlertTimestamp(alert.getTimestamp());
+    history.setClusterId(clusterId);
     history.setComponentName(alert.getComponent());
     history.setServiceName(alert.getService());
 
@@ -588,12 +615,12 @@ public class AlertReceivedListener {
    *          the definition to read any repeat tolerance overrides from.
    * @param state
    *          the state of the {@link AlertCurrentEntity}.
-   * @param the
+   * @param occurrences the
    *          occurrences of the alert in the current state (used for
    *          calculation firmness when moving between non-OK states)
    * @return
    */
-  private AlertFirmness calculateFirmnessForStateChange(String clusterName, AlertDefinitionEntity definition,
+  private AlertFirmness calculateFirmnessForStateChange(Long clusterId, AlertDefinitionEntity definition,
       AlertState state, long occurrences) {
     // OK is always HARD since the alert has fulfilled the conditions
     if (state == AlertState.OK) {
@@ -605,7 +632,7 @@ public class AlertReceivedListener {
       return AlertFirmness.HARD;
     }
 
-    int tolerance = getRepeatTolerance(definition, clusterName);
+    int tolerance = getRepeatTolerance(definition, clusterId);
     if (tolerance <= 1) {
       return AlertFirmness.HARD;
     }
@@ -624,13 +651,11 @@ public class AlertReceivedListener {
    * Otherwise, it uses {@link ConfigHelper#CLUSTER_ENV_ALERT_REPEAT_TOLERANCE},
    * defaulting to {@code 1} if not found.
    *
-   * @param definition
-   *          the definition (not {@code null}).
-   * @param clusterName
-   *          the name of the cluster (not {@code null}).
+   * @param definition the definition (not {@code null}).
+   * @param clusterId the ID of the cluster (not {@code null}).
    * @return the repeat tolerance for the alert
    */
-  private int getRepeatTolerance(AlertDefinitionEntity definition, String clusterName) {
+  private int getRepeatTolerance(AlertDefinitionEntity definition, Long clusterId) {
 
     // if the definition overrides the global value, then use that
     if (definition.isRepeatToleranceEnabled()) {
@@ -639,12 +664,14 @@ public class AlertReceivedListener {
 
     int repeatTolerance = 1;
     try {
-      Cluster cluster = m_clusters.get().getCluster(clusterName);
+      Cluster cluster = m_clusters.get().getCluster(clusterId);
       String value = cluster.getClusterProperty(ConfigHelper.CLUSTER_ENV_ALERT_REPEAT_TOLERANCE, "1");
       repeatTolerance = NumberUtils.toInt(value, 1);
     } catch (AmbariException ambariException) {
-      LOG.warn("Unable to read {}/{} from cluster {}, defaulting to 1", ConfigHelper.CLUSTER_ENV,
-          ConfigHelper.CLUSTER_ENV_ALERT_REPEAT_TOLERANCE, clusterName, ambariException);
+      String msg = String.format("Unable to read %s/%s from cluster %s, defaulting to 1",
+        ConfigHelper.CLUSTER_ENV, ConfigHelper.CLUSTER_ENV_ALERT_REPEAT_TOLERANCE, clusterId
+      );
+      LOG.warn(msg, ambariException);
     }
 
     return repeatTolerance;
