@@ -61,7 +61,7 @@ import org.apache.ambari.server.utils.StageUtils;
 import org.apache.ambari.server.utils.ThreadPools;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.codec.digest.DigestUtils;
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.io.IOUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -109,8 +109,12 @@ public class AgentCommandsPublisher {
             if (ac instanceof ExecutionCommand) {
               try {
                 clusterId = Long.valueOf(((ExecutionCommand)ac).getClusterId());
-                if (!clusterDesiredConfigs.containsKey(clusterId)) {
-                  clusterDesiredConfigs.put(clusterId, clusters.getCluster(clusterId).getDesiredConfigs());
+                if (clusterId >= 0) {
+                  if (!clusterDesiredConfigs.containsKey(clusterId)) {
+                    clusterDesiredConfigs.put(clusterId, clusters.getCluster(clusterId).getDesiredConfigs());
+                  }
+                } else {
+                  LOG.warn("The cluster not found or has not been created yet. clusterID={}.", clusterId);
                 }
               } catch (NumberFormatException|AmbariException e) {
                 LOG.error("Exception on sendAgentCommand", e);
