@@ -104,9 +104,11 @@ public class DBAccessorImpl implements DBAccessor {
       connection.setAutoCommit(true); //enable autocommit
 
       //TODO create own mapping and platform classes for supported databases
-      String vendorName = connection.getMetaData().getDatabaseProductName()
-              + connection.getMetaData().getDatabaseMajorVersion();
-      String dbPlatform = DBPlatformHelper.getDBPlatform(vendorName, new AbstractSessionLog() {
+      String vendorName = connection.getMetaData().getDatabaseProductName();
+      String majorVersion = Integer.toString(connection.getMetaData().getDatabaseMajorVersion());
+      String minorVersion = Integer.toString(connection.getMetaData().getDatabaseMinorVersion());
+
+      String dbPlatform = DBPlatformHelper.getDBPlatform(vendorName, majorVersion, minorVersion, new AbstractSessionLog() {
         @Override
         public void log(SessionLogEntry sessionLogEntry) {
           LOG.debug(sessionLogEntry.getMessage());
@@ -394,7 +396,7 @@ public class DBAccessorImpl implements DBAccessor {
     if (!duplicatedColumns.isEmpty()) {
       throw new IllegalStateException(
               String.format("Request for columns [%s] existing in table [%s] returned too many results [%s] for columns [%s]",
-                      columnName, tableName, duplicatedColumns.size(), duplicatedColumns.toString()));
+                      Arrays.toString(columnName), tableName, duplicatedColumns.size(), duplicatedColumns.toString()));
     }
 
     return columnsList.size() == 0;
@@ -1120,9 +1122,7 @@ public class DBAccessorImpl implements DBAccessor {
       ScriptRunner scriptRunner = new ScriptRunner(getConnection(), false, false);
       scriptRunner.runScript(br);
     } finally {
-      if (br != null) {
-        br.close();
-      }
+      br.close();
     }
   }
 
@@ -1664,7 +1664,7 @@ public class DBAccessorImpl implements DBAccessor {
     }
     builder.append(requestedColumnNames[0]);
     for (int i = 1; i < requestedColumnNames.length; i++) {
-      builder.append(", ").append(requestedColumnNames[1]);
+      builder.append(", ").append(requestedColumnNames[i]);
     }
 
     // Append the source table
