@@ -18,6 +18,8 @@
 
 package org.apache.ambari.server.orm.entities;
 
+import java.util.Objects;
+
 import javax.persistence.Column;
 import javax.persistence.Entity;
 import javax.persistence.EnumType;
@@ -201,7 +203,7 @@ public class HostVersionEntity {
     }
 
     HostVersionEntity other = (HostVersionEntity) obj;
-    if (id != null ? id != other.id : other.id != null) {
+    if (!Objects.equals(id, other.id)) {
       return false;
     }
     if (hostEntity != null ? !hostEntity.equals(other.hostEntity) : other.hostEntity != null) {
