@@ -18,6 +18,7 @@
 package org.apache.ambari.server.orm.entities;
 
 import java.util.List;
+import java.util.Objects;
 
 import javax.persistence.Basic;
 import javax.persistence.CascadeType;
@@ -256,15 +257,12 @@ public class WidgetEntity {
 
     WidgetEntity that = (WidgetEntity) o;
 
-    if (id != that.id) return false;
-
-    return true;
+    return Objects.equals(id, that.id);
   }
 
   @Override
   public int hashCode() {
-    int result = null != id ? id.hashCode() : 0;
-    return result;
+    return Objects.hashCode(id);
   }
 
 }
