@@ -100,8 +100,7 @@ public class AmbariLdapBindAuthenticator extends AbstractLdapAuthenticator {
       } else {
         processedLdapUserName = ldapUserName;
       }
-      if (!processedLdapUserName.equals(loginName.toLowerCase()))
-      {
+      if (!processedLdapUserName.equals(loginName.toLowerCase())) {
         AuthorizationHelper.addLoginNameAlias(processedLdapUserName, loginName.toLowerCase());
       }
     }
