@@ -64,7 +64,7 @@ import org.apache.ambari.server.security.ldap.LdapBatchDto;
 import org.apache.ambari.server.security.ldap.LdapGroupDto;
 import org.apache.ambari.server.security.ldap.LdapUserDto;
 import org.apache.ambari.server.security.ldap.LdapUserGroupMemberDto;
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -312,11 +312,28 @@ public class Users {
     userDAO.create(userEntity);
 
     // execute user initialization hook if required ()
-    hookServiceProvider.get().execute(hookContextFactory.createUserHookContext(validatedUserName));
+    executeUserHook(validatedUserName);
 
     return userEntity;
   }
 
+  /**
+   * Triggers the post user creation hook, if enabled
+   *
+   * @param username the username of the user to process
+   */
+  public void executeUserHook(String username) {
+    hookServiceProvider.get().execute(hookContextFactory.createUserHookContext(username));
+  }
+
+  /**
+   * Triggers the post user creation hook, if enabled
+   *
+   * @param userGroupsMap a map of user names to relevant groups
+   */
+  public void executeUserHook(Map<String, Set<String>> userGroupsMap) {
+    hookServiceProvider.get().execute(hookContextFactory.createBatchUserHookContext(userGroupsMap));
+  }
 
   /**
    * Removes a user from the Ambari database.
@@ -1242,11 +1259,11 @@ public class Users {
           throw new AmbariException("Wrong current password provided");
         }
 
-        validatePassword(newKey);
+        validatePassword(newKey, userAuthenticationEntity.getUser().getUserName(), userAuthenticationEntity.getFullAuthenticationKey());
 
         // If we get here the authenticated user is authorized to change the password for the subject
         // user and the correct current password was supplied (if required).
-        userAuthenticationEntity.setAuthenticationKey(passwordEncoder.encode(newKey));
+        userAuthenticationEntity.updateAuthenticationKey(passwordEncoder.encode(newKey), configuration.getPasswordPolicyHistoryCount());
       } else {
         // If we get here the authenticated user is authorized to change the key for the subject.
         userAuthenticationEntity.setAuthenticationKey(newKey);
@@ -1441,7 +1458,7 @@ public class Users {
   public void addLocalAuthentication(UserEntity userEntity, String password, boolean persist) throws AmbariException {
 
     // Ensure the password meets configured minimal requirements, if any
-    validatePassword(password);
+    validatePassword(password, userEntity.getUserName());
 
     // Encode the password..
     String encodedPassword = passwordEncoder.encode(password);
@@ -1742,7 +1759,7 @@ public class Users {
    * <p>
    *
    * @param password the password
-   * @throws  IllegalArgumentException if password does not meet the password policy requirements
+   * @throws IllegalArgumentException if password does not meet the password policy requirements
    */
   public void validatePassword(String password) {
     if (StringUtils.isEmpty(password)) {
@@ -1755,6 +1772,49 @@ public class Users {
     }
   }
 
+  /**
+   * Validates the password meets configured requirements according ambari.properties and it does not contain the username.
+   *
+   * <p>
+   *
+   * @param password the password
+   * @param userName the username
+   * @throws  IllegalArgumentException if password does not meet the password policy requirements
+   */
+  public void validatePassword(String password, String userName) {
+    validatePassword(password);
+    if (StringUtils.isNotEmpty(userName) && Pattern.compile(Pattern.quote(userName), Pattern.CASE_INSENSITIVE).matcher(password).find()) {
+      final String msg = "The password does not meet the Ambari user password policy : password cannot contain the username";
+      throw new IllegalArgumentException(msg);
+    }
+  }
+
+  /**
+   * Validates the password meets configured requirements according ambari.properties, does not contain the username and different from previous passwords
+   *
+   * <p>
+   *
+   * @param password the password
+   * @param userName the username
+   * @param authenticationKey the authenticationKey associated with previous passwords
+   * @throws  IllegalArgumentException if password does not meet the password policy requirements
+   */
+  public void validatePassword(String password, String userName, String authenticationKey) {
+    validatePassword(password, userName);
+    boolean isMatched = false;
+    String[] previousPasswords = StringUtils.split(authenticationKey, ",");
+    for (String previousPassword : previousPasswords) {
+      if (passwordEncoder.matches(password, previousPassword)) {
+        isMatched = true;
+        break;
+      }
+    }
+    if (isMatched) {
+      final String msg = "The password does not meet the Ambari user password policy : new password can not be same as previous " + configuration.getPasswordPolicyHistoryCount() + " passwords.";
+      throw new IllegalArgumentException(msg);
+    }
+  }
+
   /**
    * Validator is an interface to be implemented by authentication type specific validators to ensure
    * new user authentication records meet the specific requirements for the relative authentication
