@@ -49,9 +49,9 @@ import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.security.authorization.internal.InternalAuthenticationToken;
+import org.apache.ambari.server.stack.upgrade.orchestrate.UpgradeServiceSummary;
+import org.apache.ambari.server.stack.upgrade.orchestrate.UpgradeSummary;
 import org.apache.ambari.server.state.ServiceInfo;
-import org.apache.ambari.server.state.UpgradeContext.UpgradeServiceSummary;
-import org.apache.ambari.server.state.UpgradeContext.UpgradeSummary;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.security.core.context.SecurityContextHolder;
