@@ -18,6 +18,20 @@
 
 package org.apache.ambari.server.serveraction.kerberos;
 
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.OutputStream;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.EnumSet;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+
 import org.apache.ambari.server.security.credential.PrincipalKeyCredential;
 import org.apache.ambari.server.utils.ShellCommandUtil;
 import org.apache.commons.codec.binary.Base64;
@@ -32,21 +46,6 @@ import org.apache.directory.shared.kerberos.components.EncryptionKey;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.OutputStream;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.EnumSet;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-
 /**
  * KerberosOperationHandler is an abstract class providing basic implementations of common Kerberos
  * operations (like generating secure passwords) and placeholders for KDC-specific operations
@@ -68,22 +67,7 @@ public abstract class KerberosOperationHandler {
   /**
    * Kerberos-env configuration property name: group
    */
-  public final static String KERBEROS_ENV_USER_PRINCIPAL_GROUP = "group";
-
-  /**
-   * Kerberos-env configuration property name: password_chat_timeout
-   */
-  public final static String KERBEROS_ENV_PASSWORD_CHAT_TIMEOUT = "password_chat_timeout";
-
-  /**
-   * Default timeout for password chat
-   */
-  public final static int DEFAULT_PASSWORD_CHAT_TIMEOUT = 5;
-
-  /**
-   * Kerberos-env configuration property name: set_password_expiry
-   */
-  public final static String KERBEROS_ENV_SET_PASSWORD_EXPIRY = "set_password_expiry";
+  public final static String KERBEROS_ENV_USER_PRINCIPAL_GROUP = "ipa_user_group";
 
   /**
    * Kerberos-env configuration property name: ad_create_attributes_template
@@ -110,6 +94,11 @@ public abstract class KerberosOperationHandler {
    */
   public final static String KERBEROS_ENV_ADMIN_SERVER_HOST = "admin_server_host";
 
+  /**
+   * Kerberos-env configuration property name: kadmin_principal_name
+   */
+  public final static String KERBEROS_ENV_KADMIN_PRINCIPAL_NAME = "kadmin_principal_name";
+
   /**
    * Kerberos-env configuration property name: executable_search_paths
    */
@@ -213,7 +202,7 @@ public abstract class KerberosOperationHandler {
 
   private PrincipalKeyCredential administratorCredential = null;
   private String defaultRealm = null;
-  private Set<EncryptionType> keyEncryptionTypes = new HashSet<EncryptionType>(DEFAULT_CIPHERS);
+  private Set<EncryptionType> keyEncryptionTypes = new HashSet<>(DEFAULT_CIPHERS);
   private boolean open = false;
 
   /**
@@ -233,16 +222,26 @@ public abstract class KerberosOperationHandler {
    * @param defaultRealm            a String declaring the default Kerberos realm (or domain)
    * @param kerberosConfiguration   a Map of key/value pairs containing data from the kerberos-env configuration set
    */
-  public abstract void open(PrincipalKeyCredential administratorCredential, String defaultRealm, Map<String, String> kerberosConfiguration)
-      throws KerberosOperationException;
+  public void open(PrincipalKeyCredential administratorCredential, String defaultRealm, Map<String, String> kerberosConfiguration)
+      throws KerberosOperationException {
+
+    setAdministratorCredential(administratorCredential);
+    setDefaultRealm(defaultRealm);
+
+    if (kerberosConfiguration != null) {
+      setKeyEncryptionTypes(translateEncryptionTypes(kerberosConfiguration.get(KERBEROS_ENV_ENCRYPTION_TYPES), "\\s+"));
+      setExecutableSearchPaths(kerberosConfiguration.get(KERBEROS_ENV_EXECUTABLE_SEARCH_PATHS));
+    }
+  }
 
   /**
    * Closes and cleans up any resources used by this KerberosOperationHandler
    * <p/>
    * It is expected that this KerberosOperationHandler will not be used after this call.
    */
-  public abstract void close()
-      throws KerberosOperationException;
+  public void close() throws KerberosOperationException {
+    setOpen(false);
+  }
 
   /**
    * Test to see if the specified principal exists in a previously configured KDC
@@ -250,10 +249,11 @@ public abstract class KerberosOperationHandler {
    * The implementation is specific to a particular type of KDC.
    *
    * @param principal a String containing the principal to test
+   * @param service   a boolean value indicating whether the principal is for a service or not
    * @return true if the principal exists; false otherwise
    * @throws KerberosOperationException
    */
-  public abstract boolean principalExists(String principal)
+  public abstract boolean principalExists(String principal, boolean service)
       throws KerberosOperationException;
 
   /**
@@ -278,11 +278,12 @@ public abstract class KerberosOperationHandler {
    *
    * @param principal a String containing the principal to update
    * @param password  a String containing the password to set
+   * @param service   a boolean value indicating whether the principal is for a service or not
    * @return an Integer declaring the new key number
    * @throws KerberosOperationException
    * @throws KerberosPrincipalDoesNotExistException if the principal does not exist
    */
-  public abstract Integer setPrincipalPassword(String principal, String password)
+  public abstract Integer setPrincipalPassword(String principal, String password, boolean service)
       throws KerberosOperationException;
 
   /**
@@ -291,10 +292,11 @@ public abstract class KerberosOperationHandler {
    * The implementation is specific to a particular type of KDC.
    *
    * @param principal a String containing the principal to remove
+   * @param service   a boolean value indicating whether the principal is for a service or not
    * @return true if the principal was successfully removed; otherwise false
    * @throws KerberosOperationException
    */
-  public abstract boolean removePrincipal(String principal)
+  public abstract boolean removePrincipal(String principal, boolean service)
       throws KerberosOperationException;
 
   /**
@@ -314,7 +316,7 @@ public abstract class KerberosOperationHandler {
     if (credential == null) {
       throw new KerberosOperationException("Missing KDC administrator credential");
     } else {
-      return principalExists(credential.getPrincipal());
+      return principalExists(credential.getPrincipal(), false);
     }
   }
 
@@ -338,8 +340,8 @@ public abstract class KerberosOperationHandler {
       throw new KerberosOperationException(String.format("Failed to create keytab file for %s, missing password", principal));
     }
 
-    Set<EncryptionType> ciphers = new HashSet<EncryptionType>(keyEncryptionTypes);
-    List<KeytabEntry> keytabEntries = new ArrayList<KeytabEntry>();
+    Set<EncryptionType> ciphers = new HashSet<>(keyEncryptionTypes);
+    List<KeytabEntry> keytabEntries = new ArrayList<>();
     Keytab keytab = new Keytab();
 
 
@@ -442,12 +444,12 @@ public abstract class KerberosOperationHandler {
    */
   protected Keytab mergeKeytabs(Keytab keytab, Keytab updates) {
     List<KeytabEntry> keytabEntries = (keytab == null)
-        ? Collections.<KeytabEntry>emptyList()
-        : new ArrayList<KeytabEntry>(keytab.getEntries());
+        ? Collections.emptyList()
+        : new ArrayList<>(keytab.getEntries());
     List<KeytabEntry> updateEntries = (updates == null)
-        ? Collections.<KeytabEntry>emptyList()
-        : new ArrayList<KeytabEntry>(updates.getEntries());
-    List<KeytabEntry> mergedEntries = new ArrayList<KeytabEntry>();
+        ? Collections.emptyList()
+        : new ArrayList<>(updates.getEntries());
+    List<KeytabEntry> mergedEntries = new ArrayList<>();
 
     if (keytabEntries.isEmpty()) {
       mergedEntries.addAll(updateEntries);
@@ -569,11 +571,11 @@ public abstract class KerberosOperationHandler {
    * @param keyEncryptionTypes a Set of EncryptionKey values or null to indicate the default set
    */
   public void setKeyEncryptionTypes(Set<EncryptionType> keyEncryptionTypes) {
-    this.keyEncryptionTypes = new HashSet<EncryptionType>(
+    this.keyEncryptionTypes = Collections.unmodifiableSet(new HashSet<>(
         (keyEncryptionTypes == null)
             ? DEFAULT_CIPHERS
             : keyEncryptionTypes
-    );
+    ));
   }
 
 
@@ -620,7 +622,7 @@ public abstract class KerberosOperationHandler {
     List<String> searchPaths = null;
 
     if (delimitedExecutableSearchPaths != null) {
-      searchPaths = new ArrayList<String>();
+      searchPaths = new ArrayList<>();
       for (String path : delimitedExecutableSearchPaths.split(",")) {
         path = path.trim();
         if (!path.isEmpty()) {
@@ -681,11 +683,6 @@ public abstract class KerberosOperationHandler {
         fos = new FileOutputStream(tempFile);
         fos.write(Base64.decodeBase64(keytabData));
         success = true;
-      } catch (FileNotFoundException e) {
-        String message = String.format("Failed to write to temporary keytab file %s: %s",
-            tempFile.getAbsolutePath(), e.getLocalizedMessage());
-        LOG.error(message, e);
-        throw new KerberosOperationException(message, e);
       } catch (IOException e) {
         String message = String.format("Failed to write to temporary keytab file %s: %s",
             tempFile.getAbsolutePath(), e.getLocalizedMessage());
@@ -719,8 +716,8 @@ public abstract class KerberosOperationHandler {
    * <p/>
    * See {@link org.apache.ambari.server.utils.ShellCommandUtil#runCommand(String[], Map<String,String>)}
    *
-   * @param command an array of String value representing the command and its arguments
-   * @param envp a map of string, string of environment variables
+   * @param command            an array of String value representing the command and its arguments
+   * @param envp               a map of string, string of environment variables
    * @param interactiveHandler a handler to provide responses to queries from the command,
    *                           or null if no queries are expected
    * @return a ShellCommandUtil.Result declaring the result of the operation
@@ -757,7 +754,7 @@ public abstract class KerberosOperationHandler {
    * @see #executeCommand(String[], Map, ShellCommandUtil.InteractiveHandler)
    */
   protected ShellCommandUtil.Result executeCommand(String[] command)
-          throws KerberosOperationException {
+      throws KerberosOperationException {
     return executeCommand(command, null);
   }
 
@@ -766,7 +763,7 @@ public abstract class KerberosOperationHandler {
    * <p/>
    * See {@link org.apache.ambari.server.utils.ShellCommandUtil#runCommand(String[])}
    *
-   * @param command an array of String value representing the command and its arguments
+   * @param command            an array of String value representing the command and its arguments
    * @param interactiveHandler a handler to provide responses to queries from the command,
    *                           or null if no queries are expected
    * @return a ShellCommandUtil.Result declaring the result of the operation
@@ -808,7 +805,12 @@ public abstract class KerberosOperationHandler {
       encryptionTypes = ENCRYPTION_TYPE_TRANSLATION_MAP.get(name.toLowerCase());
     }
 
-    return (encryptionTypes == null) ? Collections.<EncryptionType>emptySet() : encryptionTypes;
+    if (encryptionTypes == null) {
+      LOG.warn("The given encryption type name ({}) is not supported.", name);
+      return Collections.emptySet();
+    }
+
+    return encryptionTypes;
   }
 
   /**
@@ -818,9 +820,11 @@ public abstract class KerberosOperationHandler {
    * @param names     a String containing a delimited list of encryption type names
    * @param delimiter a String declaring the delimiter to use to split names, if null, " " is used.
    * @return a Set of EncryptionType values
+   * @throws KerberosOperationException When all the encryption type names are not supported
    */
-  protected Set<EncryptionType> translateEncryptionTypes(String names, String delimiter) {
-    Set<EncryptionType> encryptionTypes = new HashSet<EncryptionType>();
+  protected Set<EncryptionType> translateEncryptionTypes(String names, String delimiter)
+      throws KerberosOperationException {
+    Set<EncryptionType> encryptionTypes = new HashSet<>();
 
     if (!StringUtils.isEmpty(names)) {
       for (String name : names.split((delimiter == null) ? "\\s+" : delimiter)) {
@@ -828,6 +832,9 @@ public abstract class KerberosOperationHandler {
       }
     }
 
+    if (encryptionTypes.isEmpty()) {
+      throw new KerberosOperationException("All the encryption type names you set are not supported. Aborting.");
+    }
     return encryptionTypes;
   }
 
