@@ -180,7 +180,11 @@ public class ConfigurationDirectory extends StackDefinitionDirectory {
           LOG.error("Failed to load value from property file. Properties file {} does not exist", propertyFilePath);
         }
       } else {
-        LOG.error("Failed to load value from property file. Properties directory {} does not exist", propertiesDirFile.getAbsolutePath());
+        if (propertiesDirFile == null) {
+          LOG.error("Failed to load value from property file. Properties directory is null");
+        } else {
+          LOG.error("Failed to load value from property file. Properties directory {} does not exist", propertiesDirFile.getAbsolutePath());
+        }
       }
     }
     props.add(pi);
