@@ -30,10 +30,11 @@ import java.util.Set;
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.state.ThemeInfo;
 import org.apache.ambari.server.state.theme.Theme;
-import org.codehaus.jackson.map.ObjectMapper;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.fasterxml.jackson.databind.ObjectMapper;
+
 public class ThemeModule extends BaseModule<ThemeModule, ThemeInfo> implements Validable {
 
   private static final Logger LOG = LoggerFactory.getLogger(ThemeModule.class);
