@@ -37,10 +37,10 @@ import org.apache.ambari.server.orm.entities.ClusterEntity;
 import org.apache.ambari.server.orm.entities.PrivilegeEntity;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
 import org.apache.ambari.server.orm.entities.UpgradeEntity;
-import org.apache.ambari.server.security.authorization.AuthorizationException;
 import org.apache.ambari.server.state.configgroup.ConfigGroup;
 import org.apache.ambari.server.state.repository.VersionDefinitionXml;
 import org.apache.ambari.server.state.scheduler.RequestExecution;
+import org.apache.ambari.spi.ClusterInformation;
 
 import com.google.common.collect.ListMultimap;
 
@@ -270,12 +270,20 @@ public interface Cluster {
   Map<String, Config> getConfigsByType(String configType);
 
   /**
-   * Gets all properties types that mach the specified type.
+   * Gets all properties types that matches the specified type for the current stack.
    * @param configType the config type to return
    * @return properties types for given config type
    */
   Map<PropertyInfo.PropertyType, Set<String>> getConfigPropertiesTypes(String configType);
 
+  /**
+   * Gets all properties types that matches the specified type for the given stack.
+   * @param configType the config type to return
+   * @param stackId the stack to scan properties for
+   * @return properties types for given config type
+   */
+  Map<PropertyInfo.PropertyType, Set<String>> getConfigPropertiesTypes(String configType, StackId stackId);
+
   /**
    * Gets the specific config that matches the specified type and tag.  This not
    * necessarily a DESIRED configuration that applies to a cluster.
@@ -511,7 +519,7 @@ public interface Cluster {
    * @param id
    * @throws AmbariException
    */
-  void deleteConfigGroup(Long id) throws AmbariException, AuthorizationException;
+  void deleteConfigGroup(Long id) throws AmbariException;
 
   /**
    * Find all config groups associated with the give hostname
@@ -528,6 +536,13 @@ public interface Cluster {
    */
   ConfigGroup getConfigGroupsById(Long configId);
 
+  /**
+   * Find all config groups associated with the give service name
+   * @param serviceName
+   * @return Map of config group id to config group
+   */
+  Map<Long, ConfigGroup> getConfigGroupsByServiceName(String serviceName);
+
   /**
    * Add a @RequestExecution to the cluster
    * @param requestExecution
@@ -727,4 +742,12 @@ public interface Cluster {
    * @return a mapping of service to component version, or an empty map.
    */
   Map<String, Map<String, String>> getComponentVersionMap();
+
+  /**
+   * Builds a {@link ClusterInformation} instance from a {@link Cluster}.
+   *
+   * @return the {@link ClusterInformation} instance comprised of simple POJOs
+   *         and SPI classes.
+   */
+  ClusterInformation buildClusterInformation();
 }
