@@ -58,11 +58,12 @@ import org.apache.ambari.server.stack.StackDirectory;
 import org.apache.ambari.server.state.PropertyInfo.PropertyType;
 import org.apache.ambari.server.state.configgroup.ConfigGroup;
 import org.apache.ambari.server.utils.SecretReference;
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.MapUtils;
+import org.apache.commons.collections4.CollectionUtils;
+import org.apache.commons.collections4.MapUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.math.NumberUtils;
 import org.apache.commons.lang3.StringEscapeUtils;
+import org.apache.commons.lang3.tuple.Pair;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -172,7 +173,7 @@ public class ConfigHelper {
    * @throws AmbariException
    */
   public Map<String, Map<String, String>> getEffectiveDesiredTags(
-      Cluster cluster, String hostName) throws AmbariException {
+          Cluster cluster, String hostName) throws AmbariException {
 
     return getEffectiveDesiredTags(cluster, hostName, null);
   }
@@ -188,7 +189,7 @@ public class ConfigHelper {
    * @throws AmbariException
    */
   public Map<String, Map<String, String>> getEffectiveDesiredTags(Cluster cluster, String hostName,
-      @Nullable Map<String, DesiredConfig> desiredConfigs) throws AmbariException {
+                                                                  @Nullable Map<String, DesiredConfig> desiredConfigs) throws AmbariException {
     Host host = null;
     if (hostName != null) {
       try {
@@ -220,7 +221,7 @@ public class ConfigHelper {
    * @return a map of tag type to tag names with overrides
    */
   private Map<String, Map<String, String>> getEffectiveDesiredTags(Cluster cluster, Map<String,
-    DesiredConfig> clusterDesired, Map<String, HostConfig> hostConfigOverrides) {
+          DesiredConfig> clusterDesired, Map<String, HostConfig> hostConfigOverrides) {
 
     if (null == cluster) {
       clusterDesired = new HashMap<>();
@@ -267,6 +268,7 @@ public class ConfigHelper {
             }
           }
         }
+
         resolved.put(type, tags);
       }
     }
@@ -281,7 +283,7 @@ public class ConfigHelper {
       Entry<PropertyInfo, String> property = iterator.next();
       PropertyInfo propertyInfo = property.getKey();
       String propertyValue = property.getValue();
-      if (property == null || propertyValue == null || propertyValue.toLowerCase().equals("null") || propertyValue.isEmpty()) {
+      if (propertyValue == null || propertyValue.toLowerCase().equals("null") || propertyValue.isEmpty()) {
         LOG.error(String.format("Excluding property %s from %s, because of invalid or empty value!", propertyInfo.getName(), filteredListName));
         iterator.remove();
       } else {
@@ -1131,7 +1133,7 @@ public class ConfigHelper {
                                String authenticatedUserName,
                                String serviceVersionNote)  throws AmbariException {
     updateConfigType(cluster, stackId, controller, configType, updates, removals, authenticatedUserName,
-      serviceVersionNote, null, true);
+            serviceVersionNote, null, true);
   }
 
   public void updateBulkConfigType(Cluster cluster, StackId stackId, AmbariManagementController controller,
@@ -1148,14 +1150,14 @@ public class ConfigHelper {
     configTypes.forEach(configType -> {
       try {
         Boolean updated = updateConfigType(
-          cluster, stackId, controller,
-          configType,
-          updates.get(configType),
-          removals.get(configType),
-          authenticatedUserName,
-          serviceVersionNote,
-          desiredConfig,
-          false
+                cluster, stackId, controller,
+                configType,
+                updates.get(configType),
+                removals.get(configType),
+                authenticatedUserName,
+                serviceVersionNote,
+                desiredConfig,
+                false
         );
         LOG.info("Bulk config update. Working with {}...{}", configType, updated ? "updated" : "not updated");
         doUpdateAgentConfigs[0] = doUpdateAgentConfigs[0] || updated;
@@ -1201,8 +1203,8 @@ public class ConfigHelper {
     }
 
     Config oldConfig = (desiredConfig != null && desiredConfig.containsKey(configType))
-      ? cluster.getConfig(configType, desiredConfig.get(configType).getTag())
-      : cluster.getDesiredConfigByType(configType);
+            ? cluster.getConfig(configType, desiredConfig.get(configType).getTag())
+            : cluster.getDesiredConfigByType(configType);
     Map<String, String> oldConfigProperties;
     Map<String, String> properties = new HashMap<>();
     Map<String, Map<String, String>> propertiesAttributes = new HashMap<>();
@@ -1234,13 +1236,15 @@ public class ConfigHelper {
     }
 
     if ((oldConfigProperties == null || !Maps.difference(oldConfigProperties, properties).areEqual())
-      && createConfigType(cluster, stackId, controller, configType, properties, propertiesAttributes,
-      authenticatedUserName, serviceVersionNote)) {
+            && createConfigType(cluster, stackId, controller, configType, properties, propertiesAttributes,
+            authenticatedUserName, serviceVersionNote)) {
       if (doUpdateAgentConfigs) {
         updateAgentConfigs(Collections.singleton(cluster.getClusterName()));
       }
-        return true;
+
+      return true;
     }
+
     return false;
   }
 
@@ -1582,7 +1586,8 @@ public class ConfigHelper {
           currentConfigEvents.put(host.getHostId(), m_agentConfigsHolder.get().getCurrentData(hostId));
         }
         if (!previousConfigEvents.containsKey(host.getHostId())) {
-          previousConfigEvents.put(host.getHostId(), m_agentConfigsHolder.get().getData(hostId));
+          previousConfigEvents.put(host.getHostId(),
+              m_agentConfigsHolder.get().initializeDataIfNeeded(hostId, true));
         }
       }
     }
@@ -1738,15 +1743,22 @@ public class ConfigHelper {
       String type = changedConfigType.getKey();
       stale |= (serviceInfo.hasConfigDependency(type) || componentInfo.hasConfigType(type));
       if (stale) {
-        changedProperties.addAll(changedConfigType.getValue());
+        for (String propertyName : changedConfigType.getValue()) {
+          changedProperties.add(type + "/" + propertyName);
+        }
       }
     }
 
     String refreshCommand = calculateRefreshCommand(stackInfo.getRefreshCommandConfiguration(), sch, changedProperties);
 
+    Map<String, HostConfig> actual = sch.getActualConfigs();
+
+    Map<String, Map<String, String>> desired = getEffectiveDesiredTags(cluster, sch.getHostName(),cluster.getDesiredConfigs());
+
     if (STALE_CONFIGS_CACHE_ENABLED) {
       if (refreshCommand != null) {
-        int staleHash = Objects.hashCode(cluster.getDesiredConfigs().hashCode(),
+        int staleHash = Objects.hashCode(actual.hashCode(),
+            desired.hashCode(),
             sch.getHostName(),
             sch.getServiceComponentName(),
             sch.getServiceName());
@@ -2105,6 +2117,7 @@ public class ConfigHelper {
         LOG.debug("For configs update on host {} will be used following cluster desired configs {}", hostId, clusterDesiredConfigs.toString());
         LOG.debug("For configs update on host {} will be used following effective desired tags {}", hostId, configTags.toString());
       }
+
       getAndMergeHostConfigs(configurations, configTags, cl);
       configurations = unescapeConfigNames(configurations);
       getAndMergeHostConfigAttributes(configurationAttributes, configTags, cl);
@@ -2113,11 +2126,10 @@ public class ConfigHelper {
       SortedMap<String, SortedMap<String, String>> configurationsTreeMap = sortConfigutations(configurations);
       SortedMap<String, SortedMap<String, SortedMap<String, String>>> configurationAttributesTreeMap =
           sortConfigurationAttributes(configurationAttributes);
-      clustersConfigs.put(
-        Long.toString(cl.getClusterId()),
-        new ClusterConfigs(configurationsTreeMap, configurationAttributesTreeMap)
-      );
+      clustersConfigs.put(Long.toString(cl.getClusterId()),
+          new ClusterConfigs(configurationsTreeMap, configurationAttributesTreeMap));
     }
+
     return new AgentConfigsUpdateEvent(hostId, clustersConfigs);
   }
 
@@ -2150,7 +2162,6 @@ public class ConfigHelper {
 
   public SortedMap<String, SortedMap<String, SortedMap<String, String>>> sortConfigurationAttributes(
       Map<String, Map<String, Map<String, String>>> configurationAttributes) {
-
     SortedMap<String, SortedMap<String, SortedMap<String, String>>> configurationAttributesTreeMap = new TreeMap<>();
     configurationAttributes.forEach((k, v) -> {
       SortedMap<String, SortedMap<String, String>> c = new TreeMap<>();
@@ -2171,16 +2182,14 @@ public class ConfigHelper {
    * @return a map of the existing configurations
    * @throws AmbariException
    */
-  public Map<String, Map<String, String>> calculateExistingConfigurations(
-    AmbariManagementController ambariManagementController, Cluster cluster) throws AmbariException {
-
+  public Map<String, Map<String, String>> calculateExistingConfigurations(AmbariManagementController ambariManagementController, Cluster cluster) throws AmbariException {
     final Map<String, Map<String, String>> configurations = new HashMap<>();
     for (Host host : cluster.getHosts()) {
       configurations.putAll(calculateExistingConfigurations(
-        ambariManagementController,
-        cluster,
-        host.getHostName(),
-        null
+              ambariManagementController,
+              cluster,
+              host.getHostName(),
+              null
       ));
     }
     return configurations;
@@ -2197,8 +2206,8 @@ public class ConfigHelper {
    * @throws AmbariException
    */
   public Map<String, Map<String, String>> calculateExistingConfigurations(
-    AmbariManagementController ambariManagementController, Cluster cluster,  String hostname,
-    @Nullable Map<String, DesiredConfig> desiredConfigs) throws AmbariException {
+          AmbariManagementController ambariManagementController, Cluster cluster,  String hostname,
+          @Nullable Map<String, DesiredConfig> desiredConfigs) throws AmbariException {
 
     // For a configuration type, both tag and an actual configuration can be stored
     // Configurations from the tag is always expanded and then over-written by the actual
@@ -2206,7 +2215,7 @@ public class ConfigHelper {
     // global:{a1:A2,b1:B1,c1:C1}
     final Map<String, Map<String, String>> configurations = new HashMap<>();
     final Map<String, Map<String, String>> configurationTags = ambariManagementController
-      .findConfigurationTagsWithOverrides(cluster, hostname, desiredConfigs);
+            .findConfigurationTagsWithOverrides(cluster, hostname, desiredConfigs);
     final Map<String, Map<String, String>> configProperties = getEffectiveConfigProperties(cluster, configurationTags);
 
     // Apply the configurations saved with the Execution Cmd on top of
@@ -2230,4 +2239,15 @@ public class ConfigHelper {
     return configurations;
   }
 
+  /**
+   * Determines the existing configurations for the cluster, both properties and attributes.
+   */
+  public Pair<Map<String, Map<String, String>>, Map<String, Map<String, Map<String, String>>>> calculateExistingConfigs(Cluster cluster) throws AmbariException {
+    Map<String, Map<String, String>> desiredConfigTags = getEffectiveDesiredTags(cluster, null);
+    return Pair.of(
+      getEffectiveConfigProperties(cluster, desiredConfigTags),
+      getEffectiveConfigAttributes(cluster, desiredConfigTags)
+    );
+  }
+
 }
