@@ -34,7 +34,6 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlElementWrapper;
 import javax.xml.bind.annotation.XmlList;
-import javax.xml.bind.annotation.XmlTransient;
 
 import org.apache.ambari.server.controller.StackConfigurationResponse;
 import org.w3c.dom.Element;
@@ -48,9 +47,7 @@ public class PropertyInfo {
   @XmlElement(name = "display-name")
   private String displayName;
 
-  @XmlTransient
   private String filename;
-
   private boolean deleted;
 
   @XmlElement(name="on-ambari-upgrade", required = true)
@@ -190,6 +187,13 @@ public class PropertyInfo {
     for (Element propertyAttribute : propertyAttributes) {
       attributes.put(propertyAttribute.getTagName(), propertyAttribute.getFirstChild().getNodeValue());
     }
+
+    // inject "hidden" property_value_attribute into property_attributes, see AMBARI-17223
+    String hidden = getPropertyValueAttributes().getHidden();
+    if (hidden != null) {
+      attributes.putIfAbsent("hidden", hidden);
+    }
+
     return attributes;
   }
 
