@@ -47,9 +47,9 @@ import org.apache.ambari.server.stack.Validable;
 import org.apache.ambari.server.state.stack.MetricDefinition;
 import org.apache.ambari.server.state.stack.StackRoleCommandOrder;
 import org.apache.commons.lang.StringUtils;
-import org.codehaus.jackson.annotate.JsonIgnore;
-import org.codehaus.jackson.map.annotate.JsonFilter;
 
+import com.fasterxml.jackson.annotation.JsonFilter;
+import com.fasterxml.jackson.annotation.JsonIgnore;
 import com.google.common.base.Function;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Lists;
@@ -59,7 +59,7 @@ import com.google.common.collect.Multimaps;
 
 @XmlAccessorType(XmlAccessType.FIELD)
 @JsonFilter("propertiesfilter")
-public class ServiceInfo implements Validable, Cloneable {
+public class ServiceInfo implements Validable {
 
   public static final AbstractMap.SimpleEntry<String, String> DEFAULT_SERVICE_INSTALLABLE_PROPERTY = new AbstractMap.SimpleEntry<>("installable", "true");
   public static final AbstractMap.SimpleEntry<String, String> DEFAULT_SERVICE_MANAGED_PROPERTY = new AbstractMap.SimpleEntry<>("managed", "true");
@@ -77,6 +77,7 @@ public class ServiceInfo implements Validable, Cloneable {
   private String comment;
   private String serviceType;
   private Selection selection;
+  private String maintainer;
 
   /**
    * Default to Python if not specified.
@@ -166,6 +167,12 @@ public class ServiceInfo implements Validable, Cloneable {
   @XmlElements(@XmlElement(name = "sso"))
   private SingleSignOnInfo singleSignOnInfo;
 
+  /**
+   * LDAP support information
+   */
+  @XmlElements(@XmlElement(name = "ldap"))
+  private ServiceLdapInfo ldapInfo;
+
   public Boolean isRestartRequiredAfterChange() {
     return restartRequiredAfterChange;
   }
@@ -195,7 +202,6 @@ public class ServiceInfo implements Validable, Cloneable {
   @XmlTransient
   private File widgetsDescriptorFile = null;
 
-  @XmlTransient
   private StackRoleCommandOrder roleCommandOrder;
 
   @XmlTransient
@@ -239,7 +245,7 @@ public class ServiceInfo implements Validable, Cloneable {
 
   @Override
   public void addErrors(Collection<String> errors) {
-    this.errorSet.addAll(errors);
+    errorSet.addAll(errors);
   }
 
   /**
@@ -283,7 +289,6 @@ public class ServiceInfo implements Validable, Cloneable {
    * at getter.
    * Added at schema ver 2
    */
-  @XmlTransient
   private volatile Map<String, ServiceOsSpecific> serviceOsSpecificsMap;
 
   /**
@@ -330,6 +335,12 @@ public class ServiceInfo implements Validable, Cloneable {
   @XmlTransient
   private File serverActionsFolder;
 
+  /**
+   * Used to determine if rolling restart is supported
+   * */
+  @XmlElement(name = "rollingRestartSupported")
+  private boolean rollingRestartSupported;
+
   public boolean isDeleted() {
     return isDeleted;
   }
@@ -352,11 +363,11 @@ public class ServiceInfo implements Validable, Cloneable {
     }
     // If set to null and has a parent, then the value would have already been resolved and set.
     // Otherwise, return the default value (true).
-    return this.supportDeleteViaUIInternal;
+    return supportDeleteViaUIInternal;
   }
 
   public void setSupportDeleteViaUI(boolean supportDeleteViaUI) {
-    this.supportDeleteViaUIInternal = supportDeleteViaUI;
+    supportDeleteViaUIInternal = supportDeleteViaUI;
   }
 
   public String getName() {
@@ -384,7 +395,7 @@ public class ServiceInfo implements Validable, Cloneable {
   }
 
   public void setServiceAdvisorType(ServiceAdvisorType type) {
-    this.serviceAdvisorType = type;
+    serviceAdvisorType = type;
   }
 
   public ServiceAdvisorType getServiceAdvisorType() {
@@ -428,6 +439,18 @@ public class ServiceInfo implements Validable, Cloneable {
     return selection == null;
   }
 
+  public String getMaintainer() {
+    return maintainer;
+  }
+
+  public void setMaintainer(String maintainer) {
+    this.maintainer = maintainer;
+  }
+
+  public boolean isMaintainerEmpty() {
+    return maintainer == null;
+  }
+
   public String getComment() {
     return comment;
   }
@@ -471,56 +494,6 @@ public class ServiceInfo implements Validable, Cloneable {
     this.properties = properties;
   }
 
-  @Override
-  public Object clone() throws CloneNotSupportedException {
-    ServiceInfo clone = (ServiceInfo) super.clone();
-    clone.setSchemaVersion(schemaVersion);
-    clone.setName(name);
-    clone.setDisplayName(displayName);
-    clone.setVersion(version);
-    clone.setComment(comment);
-    clone.setServiceType(serviceType);
-    clone.setSelection(selection);
-    clone.components = components;
-    clone.setDeleted(isDeleted);
-    clone.setConfigDependencies(configDependencies);
-    clone.setExcludedConfigTypes(excludedConfigTypes);
-    clone.setMonitoringService(monitoringService);
-    clone.setRestartRequiredAfterChange(restartRequiredAfterChange);
-    clone.setRestartRequiredAfterRackChange(restartRequiredAfterRackChange);
-    clone.setParent(parent);
-    if(metricsFile != null) {
-      clone.metricsFileName = metricsFile.getName();
-    }
-    if(widgetsDescriptorFile != null) {
-      clone.widgetsFileName = widgetsDescriptorFile.getName();
-    }
-    clone.setCredentialStoreInfo(credentialStoreInfo);
-    clone.setServicePropertyList(servicePropertyList);
-    clone.configDir = configDir;
-
-    clone.themesDir = themesDir;
-    clone.setThemesMap(themesMap);
-    if(this.themesMap != null) {
-      clone.themes = new ArrayList(this.themesMap.values());
-    }
-
-    clone.quickLinksConfigurationsDir = quickLinksConfigurationsDir;
-    clone.setQuickLinksConfigurationsMap(quickLinksConfigurationsMap);
-    if(this.quickLinksConfigurationsMap != null) {
-      clone.quickLinksConfigurations = new ArrayList(this.quickLinksConfigurationsMap.values());
-    }
-
-    clone.serviceOsSpecificsMap =  serviceOsSpecificsMap;
-    if(this.serviceOsSpecificsMap != null) {
-      clone.serviceOsSpecifics = new ArrayList<>(serviceOsSpecificsMap.values());
-    }
-
-    clone.setCommandScript(commandScript);
-    clone.setRequiredServices(requiredServices);
-    return clone;
-  }
-
   public List<ComponentInfo> getComponents() {
     if (components == null) {
       components = new ArrayList<>();
@@ -738,6 +711,7 @@ public class ServiceInfo implements Validable, Cloneable {
   /**
    * @deprecated Use {@link #getSingleSignOnEnabledTest()} instead
    */
+  @Deprecated
   public String getSingleSignOnEnabledConfiguration() {
     return singleSignOnInfo != null ? singleSignOnInfo.getEnabledConfiguration() : null;
   }
@@ -753,6 +727,38 @@ public class ServiceInfo implements Validable, Cloneable {
     return singleSignOnInfo != null && singleSignOnInfo.isKerberosRequired();
   }
 
+  /**
+   * Gets a new value for LDAP integration support
+   */
+  public ServiceLdapInfo getLdapInfo() {
+    return ldapInfo;
+  }
+
+  /**
+   * Sets a new value for LDAP integration support
+   *
+   * @param ldapInfo
+   *          a {@link ServiceLdapInfo}
+   */
+  public void setLdapInfo(ServiceLdapInfo ldapInfo) {
+    this.ldapInfo = ldapInfo;
+  }
+
+  /**
+   * @return whether this service supports single sign-on integration
+   */
+  public boolean isLdapSupported() {
+    return (ldapInfo != null) && ldapInfo.isSupported();
+  }
+
+  /**
+   * @return the configuration specification that can be used to determine if LDAP
+   *         has been enabled or not.
+   */
+  public String getLdapEnabledTest() {
+    return ldapInfo != null ? ldapInfo.getLdapEnabledTest() : null;
+  }
+
   @Override
   public String toString() {
     StringBuilder sb = new StringBuilder();
@@ -807,7 +813,7 @@ public class ServiceInfo implements Validable, Cloneable {
    * @param typeAttributes attributes associated with the type
    */
   public synchronized void setTypeAttributes(String type, Map<String, Map<String, String>> typeAttributes) {
-    if (this.configTypes == null) {
+    if (configTypes == null) {
       configTypes = new HashMap<>();
     }
     configTypes.put(type, typeAttributes);
@@ -1089,6 +1095,14 @@ public class ServiceInfo implements Validable, Cloneable {
     return kerberosDescriptorFile;
   }
 
+  public boolean isRollingRestartSupported() {
+    return rollingRestartSupported;
+  }
+
+  public void setRollingRestartSupported(boolean rollingRestartSupported) {
+    this.rollingRestartSupported = rollingRestartSupported;
+  }
+
   /**
    * @return the widgets descriptor file, or <code>null</code> if none exists
    */
@@ -1357,6 +1371,32 @@ public class ServiceInfo implements Validable, Cloneable {
         }
       }
     }
+
+    if (ldapInfo != null && ldapInfo.isSupported() && StringUtils.isBlank(ldapInfo.getLdapEnabledTest())) {
+      setValid(false);
+      addError("LDAP support is indicated for service " + getName() + " but no test configuration has been set by ldapEnabledTest.");
+    }
+  }
+
+  /**
+   * Gets whether this service advertises a version based on whether at least
+   * one of its components advertises a version.
+   *
+   * @return {@code true} if at least 1 component of this service advertises a
+   *         version, {@code false} otherwise.
+   */
+  public boolean isVersionAdvertised() {
+    if (null == components) {
+      return false;
+    }
+
+    for (ComponentInfo componentInfo : components) {
+      if (componentInfo.isVersionAdvertised()) {
+        return true;
+      }
+    }
+
+    return false;
   }
 
   public enum Selection {
