@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -31,6 +31,7 @@ public class ActionId {
     this.actionType = actionType;
   }
 
+  @Override
   public String toString() {
     return "[ actionId=" + actionId
         + ", actionType=" + actionType + "]";
