@@ -85,7 +85,6 @@ import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.annotations.VisibleForTesting;
 import com.google.gson.Gson;
 import com.google.gson.reflect.TypeToken;
 import com.google.inject.Inject;
@@ -321,12 +320,6 @@ public class HostImpl implements Host {
     maintMap = ensureMaintMap(hostEntity.getHostStateEntity());
   }
 
-  @VisibleForTesting
-  HostImpl(HostEntity hostEntity, Gson gson, HostDAO hostDAO, HostStateDAO hostStateDAO, AmbariEventPublisher publisher) {
-    this(hostEntity, gson, hostDAO, hostStateDAO);
-    this.ambariEventPublisher = publisher;
-  }
-
   @Override
   public int compareTo(Object o) {
     if ((o != null ) && (o instanceof Host)) {
@@ -952,7 +945,8 @@ public class HostImpl implements Host {
   @Override
   public long getTimeInState() {
     HostStateEntity hostStateEntity = getHostStateEntity();
-    return hostStateEntity != null ? hostStateEntity.getTimeInState() :  null;
+    Long timeInState = hostStateEntity != null ? hostStateEntity.getTimeInState() :  null;
+    return timeInState != null ? timeInState : 0L;
   }
 
   @Override
@@ -964,27 +958,18 @@ public class HostImpl implements Host {
     }
   }
 
+
   @Override
   public String getStatus() {
     return status;
   }
 
-  /**
-   * Sets the Host's status.
-   *
-   * @param status Host Status string representation of the Host's status
-   * @throws IllegalArgumentException if <code>status</code> is <code>null</code> or {@link HealthStatus} enum has no such constant name.
-   */
   @Override
   public void setStatus(String status) {
-    if (status == null) {
-      throw new IllegalArgumentException("Host status cannot be null");
-    }
-    String newStatus = HealthStatus.valueOf(status).name();
-    if (!newStatus.equals(this.status)) {
-      ambariEventPublisher.publish(new HostStatusUpdateEvent(getHostName(), newStatus));
-      this.status = newStatus;
+    if (!Objects.equals(this.status, status)) {
+      ambariEventPublisher.publish(new HostStatusUpdateEvent(getHostName(), status));
     }
+    this.status = status;
   }
 
   @Override
@@ -1339,8 +1324,8 @@ public class HostImpl implements Host {
     // for every host component, if it matches the desired repo and has reported
     // the correct version then we're good
     for (HostComponentStateEntity hostComponentState : hostComponentStates) {
-      ServiceComponentDesiredStateEntity desiredComponentState = hostComponentState.getServiceComponentDesiredStateEntity();
-      RepositoryVersionEntity desiredRepositoryVersion = desiredComponentState.getDesiredRepositoryVersion();
+      ServiceComponentDesiredStateEntity desiredComponmentState = hostComponentState.getServiceComponentDesiredStateEntity();
+      RepositoryVersionEntity desiredRepositoryVersion = desiredComponmentState.getDesiredRepositoryVersion();
 
       ComponentInfo componentInfo = ambariMetaInfo.getComponent(
           desiredRepositoryVersion.getStackName(), desiredRepositoryVersion.getStackVersion(),
