@@ -19,7 +19,7 @@ package org.apache.ambari.server.state.repository;
 
 import java.util.Set;
 
-import org.codehaus.jackson.annotate.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonProperty;
 
 /**
  * Used when formulating manifest info for API consumption.
@@ -51,5 +51,36 @@ public class ManifestServiceInfo {
     m_versions = versions;
   }
 
+  public void setM_name(String m_name) {
+    this.m_name = m_name;
+  }
+
+  public String getM_name() {
+    return m_name;
+  }
+
+  public void setM_display(String m_display) {
+    this.m_display = m_display;
+  }
+
+  public String getM_display() {
+    return m_display;
+  }
+
+  public void setM_comment(String m_comment) {
+    this.m_comment = m_comment;
+  }
+
+  public String getM_comment() {
+    return m_comment;
+  }
+
+  public void setM_versions(Set<String> m_versions) {
+    this.m_versions = m_versions;
+  }
+
+  public Set<String> getM_versions() {
+    return m_versions;
+  }
 
 }
