@@ -17,6 +17,8 @@
  */
 package org.apache.ambari.server.state.scheduler;
 
+import java.util.Collection;
+
 import org.apache.ambari.server.controller.RequestScheduleResponse;
 
 /**
@@ -160,6 +162,10 @@ public interface RequestExecution {
    */
   String getRequestBody(Long batchId);
 
+  /**
+   * Get the requests IDs for the batch
+   */
+  Collection<Long> getBatchRequestRequestsIDs(long batchId);
   /**
    * Get batch request with specified order id
    */
@@ -184,6 +190,8 @@ public interface RequestExecution {
   enum Status {
     SCHEDULED,
     COMPLETED,
-    DISABLED
+    DISABLED,
+    ABORTED,
+    PAUSED
   }
 }
