@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -197,7 +197,7 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
    */
   public AlertNoticeDispatchService() {
     m_executor = new ThreadPoolExecutor(0, 2, 5L, TimeUnit.MINUTES,
-        new LinkedBlockingQueue<Runnable>(), new AlertDispatchThreadFactory(),
+      new LinkedBlockingQueue<>(), new AlertDispatchThreadFactory(),
         new ThreadPoolExecutor.CallerRunsPolicy());
 
     GsonBuilder gsonBuilder = new GsonBuilder();
@@ -271,34 +271,14 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
    */
   @Override
   protected void runOneIteration() throws Exception {
-    List<AlertNoticeEntity> pending = m_dao.findPendingNotices();
-    if (pending.size() == 0) {
+    Map<AlertTargetEntity, List<AlertNoticeEntity>> aggregateMap;
+    try {
+      aggregateMap = getGroupedNotices();
+    } catch (Exception e) {
+      LOG.error("Caught exception during alert notices preparing.", e);
       return;
     }
 
-    LOG.info("There are {} pending alert notices about to be dispatched...",
-        pending.size());
-
-    Map<AlertTargetEntity, List<AlertNoticeEntity>> aggregateMap =
-        new HashMap<AlertTargetEntity, List<AlertNoticeEntity>>(pending.size());
-
-    // combine all histories by target
-    for (AlertNoticeEntity notice : pending) {
-      AlertTargetEntity target = notice.getAlertTarget();
-
-      List<AlertNoticeEntity> notices = aggregateMap.get(target);
-      if (null == notices) {
-        notices = new ArrayList<AlertNoticeEntity>();
-        aggregateMap.put(target, notices);
-      }
-
-      // at this point, notices have been processed but not yet delivered
-      notice.setNotifyState(NotificationState.DISPATCHED);
-      notice = m_dao.merge(notice);
-
-      notices.add(notice);
-    }
-
     // now that all of the notices are grouped by target, dispatch them
     Set<AlertTargetEntity> targets = aggregateMap.keySet();
     for (AlertTargetEntity target : targets) {
@@ -312,59 +292,9 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
 
         // create a single digest notification if supported
         if (dispatcher.isDigestSupported()) {
-          AlertNotification notification = buildNotificationFromTarget(target);
-          notification.CallbackIds = new ArrayList<String>(notices.size());
-          List<AlertHistoryEntity> histories = new ArrayList<AlertHistoryEntity>(
-                  notices.size());
-
-          // add callback IDs so that the notices can be marked as DELIVERED or
-          // FAILED, and create a list of just the alert histories
-          for (AlertNoticeEntity notice : notices) {
-            AlertHistoryEntity history = notice.getAlertHistory();
-            histories.add(history);
-
-            notification.CallbackIds.add(notice.getUuid());
-          }
-
-          // populate the subject and body fields; if there is a problem
-          // generating the content, then mark the notices as FAILED
-          try {
-            renderDigestNotificationContent(dispatcher, notification, histories, target);
-
-            // dispatch
-            DispatchRunnable runnable = new DispatchRunnable(dispatcher, notification);
-            m_executor.execute(runnable);
-          } catch (Exception exception) {
-            LOG.error("Unable to create notification for alerts", exception);
-
-            // there was a problem generating content for the target; mark all
-            // notices as FAILED and skip this target
-            // mark these as failed
-            notification.Callback.onFailure(notification.CallbackIds);
-          }
+          createSingleNotice(dispatcher, target, notices);
         } else {
-          // the dispatcher does not support digest, each notice must have a 1:1
-          // notification created for it
-          for (AlertNoticeEntity notice : notices) {
-            AlertNotification notification = buildNotificationFromTarget(target);
-            AlertHistoryEntity history = notice.getAlertHistory();
-            notification.CallbackIds = Collections.singletonList(notice.getUuid());
-
-            // populate the subject and body fields; if there is a problem
-            // generating the content, then mark the notices as FAILED
-            try {
-              renderNotificationContent(dispatcher, notification, history, target);
-
-              // dispatch
-              DispatchRunnable runnable = new DispatchRunnable(dispatcher, notification);
-              m_executor.execute(runnable);
-            } catch (Exception exception) {
-              LOG.error("Unable to create notification for alert", exception);
-
-              // mark these as failed
-              notification.Callback.onFailure(notification.CallbackIds);
-            }
-          }
+          createSeparateNotices(dispatcher, target, notices);
         }
       } catch (Exception e) {
         LOG.error("Caught exception during Alert Notice dispatching.", e);
@@ -372,6 +302,111 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
     }
   }
 
+  /**
+   * Retrieves all pending notices to dispatch and groups them by target.
+   * @return grouped notices.
+   */
+  private Map<AlertTargetEntity, List<AlertNoticeEntity>> getGroupedNotices() {
+    List<AlertNoticeEntity> pending = m_dao.findPendingNotices();
+    if (pending.size() == 0) {
+      return Collections.EMPTY_MAP;
+    }
+
+    LOG.info("There are {} pending alert notices about to be dispatched...",
+        pending.size());
+
+    Map<AlertTargetEntity, List<AlertNoticeEntity>> aggregateMap = new HashMap<>(pending.size());
+
+    // combine all histories by target
+    for (AlertNoticeEntity notice : pending) {
+      AlertTargetEntity target = notice.getAlertTarget();
+
+      List<AlertNoticeEntity> notices = aggregateMap.get(target);
+      if (null == notices) {
+        notices = new ArrayList<>();
+        aggregateMap.put(target, notices);
+      }
+
+      // at this point, notices have been processed but not yet delivered
+      notice.setNotifyState(NotificationState.DISPATCHED);
+      notice = m_dao.merge(notice);
+
+      notices.add(notice);
+    }
+    return aggregateMap;
+  }
+
+  /**
+   * Creates a single digest notification. Should be used when dispatcher supports digest.
+   * @param dispatcher dispatches the created notifications.
+   * @param target where notifications will be sent.
+   * @param notices notices should be dispatched.
+   */
+  private void createSingleNotice(NotificationDispatcher dispatcher, AlertTargetEntity target,
+                                           List<AlertNoticeEntity> notices) {
+    AlertNotification notification = buildNotificationFromTarget(target);
+    notification.CallbackIds = new ArrayList<>(notices.size());
+    List<AlertHistoryEntity> histories = new ArrayList<>(
+        notices.size());
+
+    // add callback IDs so that the notices can be marked as DELIVERED or
+    // FAILED, and create a list of just the alert histories
+    for (AlertNoticeEntity notice : notices) {
+      AlertHistoryEntity history = notice.getAlertHistory();
+      histories.add(history);
+
+      notification.CallbackIds.add(notice.getUuid());
+    }
+
+
+    // populate the subject and body fields; if there is a problem
+    // generating the content, then mark the notices as FAILED
+    try {
+      renderDigestNotificationContent(dispatcher, notification, histories, target);
+
+      // dispatch
+      DispatchRunnable runnable = new DispatchRunnable(dispatcher, notification);
+      m_executor.execute(runnable);
+    } catch (Exception exception) {
+      LOG.error("Unable to create notification for alerts", exception);
+
+      // there was a problem generating content for the target; mark all
+      // notices as FAILED and skip this target
+      // mark these as failed
+      notification.Callback.onFailure(notification.CallbackIds);
+    }
+  }
+
+  /**
+   * If the dispatcher does not support digest, each notice must have a 1:1 notification created for it.
+   * @param dispatcher dispatches the created notifications.
+   * @param target where notifications will be sent.
+   * @param notices notices should be dispatched.
+   */
+  private void createSeparateNotices(NotificationDispatcher dispatcher, AlertTargetEntity target,
+                                      List<AlertNoticeEntity> notices) {
+    for (AlertNoticeEntity notice : notices) {
+      AlertNotification notification = buildNotificationFromTarget(target);
+      AlertHistoryEntity history = notice.getAlertHistory();
+      notification.CallbackIds = Collections.singletonList(notice.getUuid());
+
+      // populate the subject and body fields; if there is a problem
+      // generating the content, then mark the notices as FAILED
+      try {
+        renderNotificationContent(dispatcher, notification, history, target);
+
+        // dispatch
+        DispatchRunnable runnable = new DispatchRunnable(dispatcher, notification);
+        m_executor.execute(runnable);
+      } catch (Exception exception) {
+        LOG.error("Unable to create notification for alert", exception);
+
+        // mark these as failed
+        notification.Callback.onFailure(notification.CallbackIds);
+      }
+    }
+  }
+
   /**
    * {@inheritDoc}
    * <p/>
@@ -419,8 +454,8 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
 
     // create recipients
     if (null != targetProperties.Recipients) {
-      List<Recipient> recipients = new ArrayList<Recipient>(
-          targetProperties.Recipients.size());
+      List<Recipient> recipients = new ArrayList<>(
+        targetProperties.Recipients.size());
 
       for (String stringRecipient : targetProperties.Recipients) {
         Recipient recipient = new Recipient();
@@ -606,7 +641,7 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
         JsonDeserializationContext context) throws JsonParseException {
 
       AlertTargetProperties properties = new AlertTargetProperties();
-      properties.Properties = new HashMap<String, String>();
+      properties.Properties = new HashMap<>();
 
       final JsonObject jsonObject = json.getAsJsonObject();
       Set<Entry<String, JsonElement>> entrySet = jsonObject.entrySet();
@@ -849,12 +884,12 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
     /**
      * The hosts that have at least 1 alert reported.
      */
-    private final Set<String> m_hosts = new HashSet<String>();
+    private final Set<String> m_hosts = new HashSet<>();
 
     /**
      * The services that have at least 1 alert reported.
      */
-    private final Set<String> m_services = new HashSet<String>();
+    private final Set<String> m_services = new HashSet<>();
 
     /**
      * All of the alerts for the {@link Notification}.
@@ -865,17 +900,17 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
      * A mapping of service to alerts where the alerts are also grouped by state
      * for that service.
      */
-    private final Map<String, Map<AlertState, List<AlertHistoryEntity>>> m_alertsByServiceAndState = new HashMap<String, Map<AlertState, List<AlertHistoryEntity>>>();
+    private final Map<String, Map<AlertState, List<AlertHistoryEntity>>> m_alertsByServiceAndState = new HashMap<>();
 
     /**
      * A mapping of all services by state.
      */
-    private final Map<String, Set<String>> m_servicesByState = new HashMap<String, Set<String>>();
+    private final Map<String, Set<String>> m_servicesByState = new HashMap<>();
 
     /**
      * A mapping of all alerts by the service that owns them.
      */
-    private final Map<String, List<AlertHistoryEntity>> m_alertsByService = new HashMap<String, List<AlertHistoryEntity>>();
+    private final Map<String, List<AlertHistoryEntity>> m_alertsByService = new HashMap<>();
 
     /**
      * Constructor.
@@ -902,13 +937,13 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
         // group alerts by service name & state
         Map<AlertState, List<AlertHistoryEntity>> service = m_alertsByServiceAndState.get(serviceName);
         if (null == service) {
-          service = new HashMap<AlertState, List<AlertHistoryEntity>>();
+          service = new HashMap<>();
           m_alertsByServiceAndState.put(serviceName, service);
         }
 
         List<AlertHistoryEntity> alertList = service.get(alertState);
         if (null == alertList) {
-          alertList = new ArrayList<AlertHistoryEntity>();
+          alertList = new ArrayList<>();
           service.put(alertState, alertList);
         }
 
@@ -917,7 +952,7 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
         // group services by alert states
         Set<String> services = m_servicesByState.get(alertState.name());
         if (null == services) {
-          services = new HashSet<String>();
+          services = new HashSet<>();
           m_servicesByState.put(alertState.name(), services);
         }
 
@@ -926,7 +961,7 @@ public class AlertNoticeDispatchService extends AbstractScheduledService {
         // group alerts by service
         List<AlertHistoryEntity> alertsByService = m_alertsByService.get(serviceName);
         if (null == alertsByService) {
-          alertsByService = new ArrayList<AlertHistoryEntity>();
+          alertsByService = new ArrayList<>();
           m_alertsByService.put(serviceName, alertsByService);
         }
 
