@@ -20,8 +20,7 @@ package org.apache.ambari.server.state.stack;
 import java.util.List;
 import java.util.Map;
 
-import org.codehaus.jackson.annotate.JsonProperty;
-
+import com.fasterxml.jackson.annotation.JsonProperty;
 import com.google.gson.annotations.SerializedName;
 
 public class WidgetLayoutInfo {
