@@ -65,12 +65,15 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
   public void validateTopology() throws InvalidTopologyException {
     LOGGER.info("Validating topology for blueprint: [{}]", blueprint.getName());
     Collection<HostGroup> hostGroups = blueprint.getHostGroups().values();
-    Map<String, Map<String, Collection<DependencyInfo>>> missingDependencies = new HashMap<>();
+    Map<String, Map<String, Collection<DependencyInfo>>> dependenciesValidationIssues = new HashMap<>();
 
     for (HostGroup group : hostGroups) {
-      Map<String, Collection<DependencyInfo>> missingGroupDependencies = validateHostGroup(group);
-      if (!missingGroupDependencies.isEmpty()) {
-        missingDependencies.put(group.getName(), missingGroupDependencies);
+      Map<String, Collection<DependencyInfo>> groupDependenciesValidationIssues =
+          validateHostGroup(group, "inclusive");
+
+      groupDependenciesValidationIssues.putAll(validateHostGroup(group, "exclusive"));
+      if (!groupDependenciesValidationIssues.isEmpty()) {
+        dependenciesValidationIssues.put(group.getName(), groupDependenciesValidationIssues);
       }
     }
 
@@ -90,8 +93,8 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
       }
     }
 
-    if (!missingDependencies.isEmpty() || !cardinalityFailures.isEmpty()) {
-      generateInvalidTopologyException(missingDependencies, cardinalityFailures);
+    if (!dependenciesValidationIssues.isEmpty() || !cardinalityFailures.isEmpty()) {
+      generateInvalidTopologyException(dependenciesValidationIssues, cardinalityFailures);
     }
   }
 
@@ -138,8 +141,6 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
 
 
     for (HostGroup hostGroup : blueprint.getHostGroups().values()) {
-      Collection<String> processedServices = new HashSet<>();
-      Map<String, Collection<String>> allRequiredProperties = new HashMap<>();
       Map<String, Map<String, String>> operationalConfiguration = new HashMap<>(clusterConfigurations);
 
       operationalConfiguration.putAll(hostGroup.getConfiguration().getProperties());
@@ -230,9 +231,9 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
     return cardinalityFailures;
   }
 
-  private Map<String, Collection<DependencyInfo>> validateHostGroup(HostGroup group) {
+  private Map<String, Collection<DependencyInfo>> validateHostGroup(HostGroup group, String dependencyValidationType) {
     LOGGER.info("Validating hostgroup: {}", group.getName());
-    Map<String, Collection<DependencyInfo>> missingDependencies = new HashMap<>();
+    Map<String, Collection<DependencyInfo>> dependenciesIssues = new HashMap<>();
 
     for (String component : new HashSet<>(group.getComponentNames())) {
       LOGGER.debug("Processing component: {}", component);
@@ -262,10 +263,15 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
         }
 
         String         dependencyScope = dependency.getScope();
+        String         dependencyType  = dependency.getType();
         String         componentName   = dependency.getComponentName();
         AutoDeployInfo autoDeployInfo  = dependency.getAutoDeploy();
         boolean        resolved        = false;
 
+        if (dependencyValidationType != null && !dependencyValidationType.equals(dependencyType)) {
+          continue;
+        }
+
         //check if conditions are met, if any
         if(dependency.hasDependencyConditions()) {
           boolean conditionsSatisfied = true;
@@ -284,24 +290,33 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
               componentName, new Cardinality("1+"), autoDeployInfo);
 
           resolved = missingDependencyInfo.isEmpty();
+          if (dependencyType.equals("exclusive")) {
+            resolved = !resolved;
+          }
         } else if (dependencyScope.equals("host")) {
-          if (group.getComponentNames().contains(componentName) || (autoDeployInfo != null && autoDeployInfo.isEnabled())) {
-            resolved = true;
-            group.addComponent(componentName);
+          if (dependencyType.equals("exclusive")) {
+            if (!group.getComponentNames().contains(componentName)) {
+              resolved = true;
+            }
+          } else {
+            if (group.getComponentNames().contains(componentName) || (autoDeployInfo != null && autoDeployInfo.isEnabled())) {
+              resolved = true;
+              group.addComponent(componentName);
+            }
           }
         }
 
         if (! resolved) {
-          Collection<DependencyInfo> missingCompDependencies = missingDependencies.get(component);
-          if (missingCompDependencies == null) {
-            missingCompDependencies = new HashSet<>();
-            missingDependencies.put(component, missingCompDependencies);
+          Collection<DependencyInfo> compDependenciesIssues = dependenciesIssues.get(component);
+          if (compDependenciesIssues == null) {
+            compDependenciesIssues = new HashSet<>();
+            dependenciesIssues.put(component, compDependenciesIssues);
           }
-          missingCompDependencies.add(dependency);
+          compDependenciesIssues.add(dependency);
         }
       }
     }
-    return missingDependencies;
+    return dependenciesIssues;
   }
 
   /**
@@ -381,13 +396,15 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
   /**
    * Generate an exception for topology validation failure.
    *
-   * @param missingDependencies  missing dependency information
+   * @param dependenciesIssues  dependency issues information,
+   *                            like component needs to be co-hosted,
+   *                            or components can't be installed on the same host
    * @param cardinalityFailures  missing service component information
    *
    * @throws IllegalArgumentException  Always thrown and contains information regarding the topology validation failure
    *                                   in the msg
    */
-  private void generateInvalidTopologyException(Map<String, Map<String, Collection<DependencyInfo>>> missingDependencies,
+  private void generateInvalidTopologyException(Map<String, Map<String, Collection<DependencyInfo>>> dependenciesIssues,
                                                 Collection<String> cardinalityFailures) throws InvalidTopologyException {
 
     //todo: encapsulate some of this in exception?
@@ -395,8 +412,8 @@ public class BlueprintValidatorImpl implements BlueprintValidator {
     if (! cardinalityFailures.isEmpty()) {
       msg += "  Invalid service component count: " + cardinalityFailures;
     }
-    if (! missingDependencies.isEmpty()) {
-      msg += "  Unresolved component dependencies: " + missingDependencies;
+    if (! dependenciesIssues.isEmpty()) {
+      msg += " Component dependencies issues: " + dependenciesIssues;
     }
     msg += ".  To disable topology validation and create the blueprint, " +
         "add the following to the end of the url: '?validate_topology=false'";
