@@ -24,8 +24,13 @@ public class TopologyValidatorFactory {
   List<TopologyValidator> validators;
 
   public TopologyValidatorFactory() {
-    validators = ImmutableList.of(new RequiredConfigPropertiesValidator(), new RequiredPasswordValidator(), new HiveServiceValidator(),
-      new StackConfigTypeValidator(), new UnitValidator(UnitValidatedProperty.ALL));
+    validators = ImmutableList.of(
+      new RequiredConfigPropertiesValidator(),
+      new RequiredPasswordValidator(),
+      new HiveServiceValidator(),
+      new StackConfigTypeValidator(),
+      new UnitValidator(UnitValidatedProperty.ALL),
+      new NameNodeHaValidator());
   }
 
   public TopologyValidator createConfigurationValidatorChain() {
