@@ -45,6 +45,8 @@ import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeMap;
 import java.util.TreeSet;
+import java.util.function.BiFunction;
+import java.util.function.Function;
 
 import javax.xml.bind.JAXBException;
 
@@ -63,13 +65,14 @@ import org.apache.ambari.server.state.ServiceComponent;
 import org.apache.ambari.server.state.svccomphost.ServiceComponentHostInstallEvent;
 import org.apache.ambari.server.topology.TopologyManager;
 import org.apache.commons.lang.StringUtils;
-import org.codehaus.jackson.JsonGenerationException;
-import org.codehaus.jackson.map.JsonMappingException;
-import org.codehaus.jackson.map.ObjectMapper;
-import org.codehaus.jackson.map.SerializationConfig;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.fasterxml.jackson.core.JsonGenerationException;
+import com.fasterxml.jackson.databind.JsonMappingException;
+import com.fasterxml.jackson.databind.MapperFeature;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import com.fasterxml.jackson.databind.SerializationFeature;
 import com.google.common.base.Joiner;
 import com.google.common.collect.Sets;
 import com.google.gson.Gson;
@@ -234,7 +237,6 @@ public class StageUtils {
     finalAttribute.put("dfs.block.size", "true");
     hdfsSiteAttributes.put("final", finalAttribute);
     configurationAttributes.put("hdfsSite", hdfsSiteAttributes);
-    execCmd.setConfigurationAttributes(configurationAttributes);
     Map<String, String> params = new TreeMap<>();
     params.put("jdklocation", "/x/y/z");
     params.put("stack_version", "1.2.0");
@@ -256,8 +258,8 @@ public class StageUtils {
 
   public static <T> T fromJson(String json, Class<T> clazz) throws IOException {
     ObjectMapper mapper = new ObjectMapper();
-    mapper.configure(SerializationConfig.Feature.INDENT_OUTPUT, true);
-    mapper.configure(SerializationConfig.Feature.USE_ANNOTATIONS, true);
+    mapper.configure(SerializationFeature.INDENT_OUTPUT, true);
+    mapper.configure(MapperFeature.USE_ANNOTATIONS, true);
     InputStream is = new ByteArrayInputStream(json.getBytes(Charset.forName("UTF8")));
     return mapper.readValue(is, clazz);
   }
@@ -342,18 +344,16 @@ public class StageUtils {
 
         for (String hostName : serviceComponent.getServiceComponentHosts().keySet()) {
 
-          if (roleName != null) {
-            SortedSet<Integer> hostsForComponentsHost = hostRolesInfo.get(roleName);
+          SortedSet<Integer> hostsForComponentsHost = hostRolesInfo.get(roleName);
 
-            if (hostsForComponentsHost == null) {
-              hostsForComponentsHost = new TreeSet<>();
-              hostRolesInfo.put(roleName, hostsForComponentsHost);
-            }
-
-            int hostIndex = hostsList.indexOf(hostName);
-            //Add index of host to current host role
-            hostsForComponentsHost.add(hostIndex);
+          if (hostsForComponentsHost == null) {
+            hostsForComponentsHost = new TreeSet<>();
+            hostRolesInfo.put(roleName, hostsForComponentsHost);
           }
+
+          int hostIndex = hostsList.indexOf(hostName);
+          //Add index of host to current host role
+          hostsForComponentsHost.add(hostIndex);
         }
       }
     }
@@ -365,41 +365,23 @@ public class StageUtils {
 
       for (String hostComponent : hostComponents) {
         String roleName = getClusterHostInfoKey(hostComponent);
-        if (null == roleName) {
-          roleName = additionalComponentToClusterInfoKeyMap.get(hostComponent);
-        }
-        if (null == roleName) {
-          // even though all mappings are being added, componentToClusterInfoKeyMap is
-          // a higher priority lookup
-          for (Service service : cluster.getServices().values()) {
-            for (ServiceComponent sc : service.getServiceComponents().values()) {
-              if (sc.getName().equals(hostComponent)) {
-                roleName = hostComponent.toLowerCase() + "_hosts";
-                additionalComponentToClusterInfoKeyMap.put(hostComponent, roleName);
-              }
-            }
-          }
+        SortedSet<Integer> hostsForComponentsHost = hostRolesInfo.get(roleName);
+
+        if (hostsForComponentsHost == null) {
+          hostsForComponentsHost = new TreeSet<>();
+          hostRolesInfo.put(roleName, hostsForComponentsHost);
         }
 
-        if (roleName != null) {
-          SortedSet<Integer> hostsForComponentsHost = hostRolesInfo.get(roleName);
-
-          if (hostsForComponentsHost == null) {
-            hostsForComponentsHost = new TreeSet<>();
-            hostRolesInfo.put(roleName, hostsForComponentsHost);
-          }
-
-          int hostIndex = hostsList.indexOf(hostname);
-          if (hostIndex != -1) {
-            if (!hostsForComponentsHost.contains(hostIndex)) {
-              hostsForComponentsHost.add(hostIndex);
-            }
-          } else {
-            //todo: I don't think that this can happen
-            //todo: determine if it can and if so, handle properly
-            //todo: if it 'cant' should probably enforce invariant
-            throw new RuntimeException("Unable to get host index for host: " + hostname);
+        int hostIndex = hostsList.indexOf(hostname);
+        if (hostIndex != -1) {
+          if (!hostsForComponentsHost.contains(hostIndex)) {
+            hostsForComponentsHost.add(hostIndex);
           }
+        } else {
+          //todo: I don't think that this can happen
+          //todo: determine if it can and if so, handle properly
+          //todo: if it 'cant' should probably enforce invariant
+          throw new RuntimeException("Unable to get host index for host: " + hostname);
         }
       }
     }
@@ -598,7 +580,7 @@ public class StageUtils {
    */
   public static void useAmbariJdkInCommandParams(Map<String, String> commandParams, Configuration configuration) {
     if (StringUtils.isNotEmpty(configuration.getJavaHome()) && !configuration.getJavaHome().equals(configuration.getStackJavaHome())) {
-      commandParams.put(AMBARI_JAVA_HOME, configuration.getJavaHome());
+      commandParams.put(AMBARI_JAVA_HOME, configuration.getAmbariJavaHome());
       commandParams.put(AMBARI_JAVA_VERSION, String.valueOf(configuration.getJavaVersion()));
       if (StringUtils.isNotEmpty(configuration.getJDKName())) { // if not custom jdk
         commandParams.put(AMBARI_JDK_NAME, configuration.getJDKName());
@@ -636,4 +618,26 @@ public class StageUtils {
       }
     }
   }
+
+  /**
+   * Create a component -> hosts mapping that can be used for clusterHostInfo.
+   * Component names are transformed to clusterHostInfo keys ("_hosts" is appended).
+   * List of hosts is comma-separated.
+   *
+   * @param services collection of services to create the mapping for
+   * @param componentsLookup function to find components of a given service
+   * @param hostAssignmentLookup function to find hosts of a given (service, component) pair
+   * @return component names
+   */
+  public static Map<String, String> createComponentHostMap(Collection<String> services, Function<String, Collection<String>> componentsLookup, BiFunction<String, String, Collection<String>> hostAssignmentLookup) {
+    Map<String, String> componentHostsMap = new HashMap<>();
+    for (String service : services) {
+      Collection<String> components = componentsLookup.apply(service);
+      for (String component : components) {
+        Collection<String> hosts = hostAssignmentLookup.apply(service, component);
+        componentHostsMap.put(getClusterHostInfoKey(component), StringUtils.join(hosts, ","));
+      }
+    }
+    return componentHostsMap;
+  }
 }
