@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,9 +18,16 @@
 
 package org.apache.ambari.server.view;
 
-import com.google.inject.Guice;
-import com.google.inject.Injector;
-import com.google.inject.persist.Transactional;
+import java.io.StringWriter;
+import java.io.Writer;
+import java.lang.reflect.InvocationTargetException;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Map.Entry;
+
 import org.apache.ambari.server.orm.entities.PermissionEntity;
 import org.apache.ambari.server.orm.entities.ViewEntity;
 import org.apache.ambari.server.orm.entities.ViewInstanceEntity;
@@ -47,24 +54,18 @@ import org.apache.ambari.view.ViewInstanceDefinition;
 import org.apache.ambari.view.cluster.Cluster;
 import org.apache.ambari.view.events.Event;
 import org.apache.ambari.view.events.Listener;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.directory.api.util.Strings;
 import org.apache.hadoop.security.authentication.util.KerberosName;
 import org.apache.hadoop.security.authentication.util.KerberosUtil;
 import org.apache.velocity.VelocityContext;
 import org.apache.velocity.app.Velocity;
 import org.apache.velocity.exception.ParseErrorException;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
-import java.io.StringWriter;
-import java.io.Writer;
-import java.lang.reflect.InvocationTargetException;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Map;
-import java.util.Map.Entry;
+import com.google.inject.Guice;
+import com.google.inject.Injector;
+import com.google.inject.persist.Transactional;
 
 /**
  * View context implementation.
@@ -74,7 +75,7 @@ public class ViewContextImpl implements ViewContext, ViewController {
   /**
    * Logger.
    */
-  private static final Log LOG = LogFactory.getLog(ViewContextImpl.class);
+  private static final Logger LOG = LoggerFactory.getLogger(ViewContextImpl.class);
 
   public static final String HADOOP_SECURITY_AUTH_TO_LOCAL = "hadoop.security.auth_to_local";
   public static final String CORE_SITE = "core-site";
@@ -338,16 +339,16 @@ public class ViewContextImpl implements ViewContext, ViewController {
 
   @Override
   public Collection<ViewDefinition> getViewDefinitions() {
-    return Collections.<ViewDefinition>unmodifiableCollection(viewRegistry.getDefinitions());
+    return Collections.unmodifiableCollection(viewRegistry.getDefinitions());
   }
 
   @Override
   public Collection<ViewInstanceDefinition> getViewInstanceDefinitions() {
-    Collection<ViewInstanceEntity> instanceDefinitions = new HashSet<ViewInstanceEntity>();
+    Collection<ViewInstanceEntity> instanceDefinitions = new HashSet<>();
     for (ViewEntity viewEntity : viewRegistry.getDefinitions()) {
       instanceDefinitions.addAll(viewRegistry.getInstanceDefinitions(viewEntity));
     }
-    return Collections.<ViewInstanceDefinition>unmodifiableCollection(instanceDefinitions);
+    return Collections.unmodifiableCollection(instanceDefinitions);
   }
 
   @Override
@@ -428,7 +429,7 @@ public class ViewContextImpl implements ViewContext, ViewController {
   private Map<String, String> getPropertyValues() {
     Map<String, String> properties = viewInstanceEntity.getPropertyMap();
 
-    Map<String, ParameterConfig> parameters = new HashMap<String, ParameterConfig>();
+    Map<String, ParameterConfig> parameters = new HashMap<>();
 
     for (ParameterConfig paramConfig : viewEntity.getConfiguration().getParameters()) {
       parameters.put(paramConfig.getName(), paramConfig);
