@@ -1,6 +1,6 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
-'''
+"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
@@ -16,14 +16,14 @@ distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-'''
+"""
 
 import os
 import re
 import time
 
-#Apache License Header
-ASF_LICENSE_HEADER = '''
+# Apache License Header
+ASF_LICENSE_HEADER = """
 # Copyright 2011 The Apache Software Foundation
 #
 # Licensed to the Apache Software Foundation (ASF) under one
@@ -41,7 +41,8 @@ ASF_LICENSE_HEADER = '''
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-'''
+"""
+
 
 # A Python replacement for java.util.Properties
 # Based on http://code.activestate.com/recipes
@@ -52,9 +53,9 @@ class Properties(object):
     self._origprops = {}
     self._keymap = {}
 
-    self.othercharre = re.compile(r'(?<!\\)(\s*\=)|(?<!\\)(\s*\:)')
-    self.othercharre2 = re.compile(r'(\s*\=)|(\s*\:)')
-    self.bspacere = re.compile(r'\\(?!\s$)')
+    self.othercharre = re.compile(r"(?<!\\)(\s*\=)|(?<!\\)(\s*\:)")
+    self.othercharre2 = re.compile(r"(\s*\=)|(\s*\:)")
+    self.bspacere = re.compile(r"\\(?!\s$)")
 
   def __parse(self, lines):
     lineno = 0
@@ -64,7 +65,7 @@ class Properties(object):
       line = line.strip()
       if not line:
         continue
-      if line[0] == '#':
+      if line[0] == "#":
         continue
       escaped = False
       sepidx = -1
@@ -74,10 +75,10 @@ class Properties(object):
         first, last = m.span()
         start, end = 0, first
         flag = 1
-        wspacere = re.compile(r'(?<![\\\=\:])(\s)')
+        wspacere = re.compile(r"(?<![\\\=\:])(\s)")
       else:
         if self.othercharre2.search(line):
-          wspacere = re.compile(r'(?<![\\])(\s)')
+          wspacere = re.compile(r"(?<![\\])(\s)")
         start, end = 0, len(line)
       m2 = wspacere.search(line, start, end)
       if m2:
@@ -86,15 +87,15 @@ class Properties(object):
       elif m:
         first, last = m.span()
         sepidx = last - 1
-      while line[-1] == '\\':
-        nextline = i.next()
+      while line[-1] == "\\":
+        nextline = next(i)
         nextline = nextline.strip()
         lineno += 1
         line = line[:-1] + nextline
       if sepidx != -1:
-        key, value = line[:sepidx], line[sepidx + 1:]
+        key, value = line[:sepidx], line[sepidx + 1 :]
       else:
-        key, value = line, ''
+        key, value = line, ""
       self.process_pair(key, value)
 
   def process_pair(self, key, value):
@@ -106,18 +107,18 @@ class Properties(object):
     keyparts = self.bspacere.split(key)
     strippable = False
     lastpart = keyparts[-1]
-    if lastpart.find('\\ ') != -1:
-      keyparts[-1] = lastpart.replace('\\', '')
-    elif lastpart and lastpart[-1] == ' ':
+    if lastpart.find("\\ ") != -1:
+      keyparts[-1] = lastpart.replace("\\", "")
+    elif lastpart and lastpart[-1] == " ":
       strippable = True
-    key = ''.join(keyparts)
+    key = "".join(keyparts)
     if strippable:
       key = key.strip()
       oldkey = oldkey.strip()
     oldvalue = self.unescape(oldvalue)
     value = self.unescape(value)
     self._props[key] = None if value is None else value.strip()
-    if self._keymap.has_key(key):
+    if key in self._keymap:
       oldkey = self._keymap.get(key)
       self._origprops[oldkey] = None if oldvalue is None else oldvalue.strip()
     else:
@@ -127,25 +128,23 @@ class Properties(object):
   def unescape(self, value):
     newvalue = value
     if not value is None:
-      newvalue = value.replace('\:', ':')
-      newvalue = newvalue.replace('\=', '=')
+      newvalue = value.replace("\:", ":")
+      newvalue = newvalue.replace("\=", "=")
     return newvalue
 
   def removeOldProp(self, key):
-    if self._origprops.has_key(key):
+    if key in self._origprops:
       del self._origprops[key]
     pass
 
   def removeProp(self, key):
-    if self._props.has_key(key):
+    if key in self._props:
       del self._props[key]
     pass
 
   def load(self, stream):
-    if type(stream) is not file:
-      raise TypeError, 'Argument should be a file object!'
-    if stream.mode != 'r':
-      raise ValueError, 'Stream should be opened in read-only mode!'
+    if stream.mode != "r":
+      raise ValueError("Stream should be opened in read-only mode!")
     try:
       self.fileName = os.path.abspath(stream.name)
       lines = stream.readlines()
@@ -154,7 +153,7 @@ class Properties(object):
       raise
 
   def get_property(self, key):
-    return self._props.get(key, '')
+    return self._props.get(key, "")
 
   def propertyNames(self):
     return self._props.keys()
@@ -172,14 +171,14 @@ class Properties(object):
       if hasattr(self._props, name):
         return getattr(self._props, name)
       else:
-        raise NotImplementedError("The method '{}' is not implemented.".format(name))
+        raise NotImplementedError(f"The method '{name}' is not implemented.")
 
   def __contains__(self, key):
-    return  key in self._props
+    return key in self._props
 
   def sort_props(self):
     tmp_props = {}
-    for key in sorted(self._props.iterkeys()):
+    for key in sorted(self._props.keys()):
       tmp_props[key] = self._props[key]
     self._props = tmp_props
     pass
@@ -187,27 +186,27 @@ class Properties(object):
   def sort_origprops(self):
     tmp_props = self._origprops.copy()
     self._origprops.clear()
-    for key in sorted(tmp_props.iterkeys()):
+    for key in sorted(tmp_props.keys()):
       self._origprops[key] = tmp_props[key]
     pass
 
   def store(self, out, header=""):
-    """ Write the properties list to the stream 'out' along
+    """Write the properties list to the stream 'out' along
     with the optional 'header'
     This function will attempt to close the file handler once it's done.
     """
-    if out.mode[0] != 'w':
-      raise ValueError, 'Steam should be opened in write mode!'
+    if out.mode[0] != "w":
+      raise ValueError("Steam should be opened in write mode!")
     try:
-      out.write(''.join(('#', ASF_LICENSE_HEADER, '\n')))
-      out.write(''.join(('#', header, '\n')))
+      out.write("".join(("#", ASF_LICENSE_HEADER, "\n")))
+      out.write("".join(("#", header, "\n")))
       # Write timestamp
-      tstamp = time.strftime('%a %b %d %H:%M:%S %Z %Y', time.localtime())
-      out.write(''.join(('#', tstamp, '\n')))
+      tstamp = time.strftime("%a %b %d %H:%M:%S %Z %Y", time.localtime())
+      out.write("".join(("#", tstamp, "\n")))
       # Write properties from the pristine dictionary
       for prop, val in self._origprops.items():
         if val is not None:
-          out.write(''.join((prop, '=', val, '\n')))
+          out.write("".join((prop, "=", val, "\n")))
     except IOError:
       raise
     finally:
@@ -215,21 +214,21 @@ class Properties(object):
         out.close()
 
   def store_ordered(self, out, header=""):
-    """ Write the properties list to the stream 'out' along
-    with the optional 'header' """
-    if out.mode[0] != 'w':
-      raise ValueError, 'Steam should be opened in write mode!'
+    """Write the properties list to the stream 'out' along
+    with the optional 'header'"""
+    if out.mode[0] != "w":
+      raise ValueError("Steam should be opened in write mode!")
     try:
-      out.write(''.join(('#', ASF_LICENSE_HEADER, '\n')))
-      out.write(''.join(('#', header, '\n')))
+      out.write("".join(("#", ASF_LICENSE_HEADER, "\n")))
+      out.write("".join(("#", header, "\n")))
       # Write timestamp
-      tstamp = time.strftime('%a %b %d %H:%M:%S %Z %Y', time.localtime())
-      out.write(''.join(('#', tstamp, '\n')))
+      tstamp = time.strftime("%a %b %d %H:%M:%S %Z %Y", time.localtime())
+      out.write("".join(("#", tstamp, "\n")))
       # Write properties from the pristine dictionary
-      for key in sorted(self._origprops.iterkeys()):
+      for key in sorted(self._origprops.keys()):
         val = self._origprops[key]
         if val is not None:
-          out.write(''.join((key, '=', val, '\n')))
+          out.write("".join((key, "=", val, "\n")))
       out.close()
     except IOError:
       raise
