@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -17,6 +17,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 
 """
+
 import signal
 import os
 import re
@@ -32,8 +33,11 @@ from resource_management.core.logger import Logger
 from resource_management.libraries.functions import conf_select
 from resource_management.libraries.functions import stack_tools
 from resource_management.libraries.functions.stack_select import get_stack_versions
-from resource_management.libraries.functions.repo_version_history \
-    import read_actual_version_from_history_file, write_actual_version_to_history_file, REPO_VERSION_HISTORY_FILE
+from resource_management.libraries.functions.repo_version_history import (
+  read_actual_version_from_history_file,
+  write_actual_version_to_history_file,
+  REPO_VERSION_HISTORY_FILE,
+)
 from resource_management.core.resources.system import Link
 from resource_management.libraries.functions import StackFeature
 from resource_management.libraries.functions.repository_util import CommandRepository
@@ -66,7 +70,7 @@ class InstallPackages(Script):
     config = Script.get_config()
 
     try:
-      command_repository = CommandRepository(config['repositoryFile'])
+      command_repository = CommandRepository(config["repositoryFile"])
     except KeyError:
       raise Fail("The command repository indicated by 'repositoryFile' was not found")
 
@@ -78,8 +82,8 @@ class InstallPackages(Script):
 
     # Select dict that contains parameters
     try:
-      package_list = json.loads(config['roleParams']['package_list'])
-      stack_id = config['roleParams']['stack_id']
+      package_list = json.loads(config["roleParams"]["package_list"])
+      stack_id = config["roleParams"]["stack_id"]
     except KeyError:
       pass
 
@@ -100,20 +104,23 @@ class InstallPackages(Script):
       if not command_repository.items:
         Logger.warning(
           "Repository list is empty. Ambari may not be managing the repositories for {0}.".format(
-            self.repository_version))
+            self.repository_version
+          )
+        )
       else:
         Logger.info(
-          "Will install packages for repository version {0}".format(self.repository_version))
+          f"Will install packages for repository version {self.repository_version}"
+        )
         new_repo_files = Script.repository_util.create_repo_files()
         self.repo_files.update(new_repo_files)
     except Exception as err:
-      Logger.logger.exception("Cannot install repository files. Error: {0}".format(str(err)))
+      Logger.logger.exception(f"Cannot install repository files. Error: {str(err)}")
       num_errors += 1
 
     # Build structured output with initial values
     self.structured_output = {
-      'package_installation_result': 'FAIL',
-      'repository_version_id': command_repository.version_id
+      "package_installation_result": "FAIL",
+      "repository_version_id": command_repository.version_id,
     }
 
     self.put_structured_out(self.structured_output)
@@ -124,7 +131,9 @@ class InstallPackages(Script):
         self.repo_mgr.print_uncompleted_transaction_hint()
         num_errors += 1
     except Exception as e:  # we need to ignore any exception
-      Logger.warning("Failed to check for uncompleted package manager transactions: " + str(e))
+      Logger.warning(
+        "Failed to check for uncompleted package manager transactions: " + str(e)
+      )
 
     if num_errors > 0:
       raise Fail("Failed to distribute repositories/install packages")
@@ -136,20 +145,20 @@ class InstallPackages(Script):
       is_package_install_successful = False
       ret_code = self.install_packages(package_list)
       if ret_code == 0:
-        self.structured_output['package_installation_result'] = 'SUCCESS'
+        self.structured_output["package_installation_result"] = "SUCCESS"
         self.put_structured_out(self.structured_output)
         is_package_install_successful = True
       else:
         num_errors += 1
     except Exception as err:
       num_errors += 1
-      Logger.logger.exception("Could not install packages. Error: {0}".format(str(err)))
+      Logger.logger.exception(f"Could not install packages. Error: {str(err)}")
 
     try:
       lzo_utils.install_lzo_if_needed()
     except Exception as err:
       num_errors += 1
-      Logger.logger.exception("Could not install LZO packages. Error: {0}".format(str(err)))
+      Logger.logger.exception(f"Could not install LZO packages. Error: {str(err)}")
 
     # Provide correct exit code
     if num_errors > 0:
@@ -157,8 +166,10 @@ class InstallPackages(Script):
 
     self._fix_default_links_for_current()
     # if installing a version of HDP that needs some symlink love, then create them
-    if is_package_install_successful and 'actual_version' in self.structured_output:
-      self._relink_configurations_with_conf_select(stack_id, self.structured_output['actual_version'])
+    if is_package_install_successful and "actual_version" in self.structured_output:
+      self._relink_configurations_with_conf_select(
+        stack_id, self.structured_output["actual_version"]
+      )
 
   def _fix_default_links_for_current(self):
     """
@@ -179,18 +190,23 @@ class InstallPackages(Script):
 
     :return: None
     """
-    Logger.info("Attempting to fix any configuration symlinks which are not in the correct state")
+    Logger.info(
+      "Attempting to fix any configuration symlinks which are not in the correct state"
+    )
     from resource_management.libraries.functions import stack_select
+
     restricted_packages = conf_select.get_restricted_packages()
 
     if 0 == len(restricted_packages):
       Logger.info("There are no restricted conf-select packages for this installation")
     else:
-      Logger.info("Restricting conf-select packages to {0}".format(restricted_packages))
+      Logger.info(f"Restricting conf-select packages to {restricted_packages}")
 
-    for package_name, directories in conf_select.get_package_dirs().iteritems():
-      Logger.info("Attempting to fix the default conf links for {0}".format(package_name))
-      Logger.info("The following directories will be fixed for {0}: {1}".format(package_name, str(directories)))
+    for package_name, directories in conf_select.get_package_dirs().items():
+      Logger.info(f"Attempting to fix the default conf links for {package_name}")
+      Logger.info(
+        f"The following directories will be fixed for {package_name}: {str(directories)}"
+      )
 
       component_name = None
       for directory_struct in directories:
@@ -200,15 +216,20 @@ class InstallPackages(Script):
       if component_name:
         stack_version = stack_select.get_stack_version_before_install(component_name)
       else:
-        Logger.warning("Unable to fix {0} since stack using outdated stack_packages.json".format(package_name))
+        Logger.warning(
+          f"Unable to fix {package_name} since stack using outdated stack_packages.json"
+        )
         return
 
       if 0 == len(restricted_packages) or package_name in restricted_packages:
         if stack_version:
-          conf_select.convert_conf_directories_to_symlinks(package_name, stack_version, directories)
+          conf_select.convert_conf_directories_to_symlinks(
+            package_name, stack_version, directories
+          )
         else:
           Logger.warning(
-            "Unable to fix {0} since there is no known installed version for this component".format(package_name))
+            f"Unable to fix {package_name} since there is no known installed version for this component"
+          )
 
   def _relink_configurations_with_conf_select(self, stack_id, stack_version):
     """
@@ -222,19 +243,25 @@ class InstallPackages(Script):
       Logger.info("Cannot create config links when stack_id is not defined")
       return
 
-    args = stack_id.upper().split('-')
+    args = stack_id.upper().split("-")
     if len(args) != 2:
-      Logger.info("Unrecognized stack id {0}, cannot create config links".format(stack_id))
+      Logger.info(f"Unrecognized stack id {stack_id}, cannot create config links")
       return
 
     target_stack_version = args[1]
-    if not (target_stack_version and check_stack_feature(StackFeature.CONFIG_VERSIONING, target_stack_version)):
-      Logger.info("Configuration symlinks are not needed for {0}".format(stack_version))
+    if not (
+      target_stack_version
+      and check_stack_feature(StackFeature.CONFIG_VERSIONING, target_stack_version)
+    ):
+      Logger.info(f"Configuration symlinks are not needed for {stack_version}")
       return
 
     # After upgrading hdf-select package from HDF-2.X to HDF-3.Y, we need to create this symlink
-    if self.stack_name.upper() == "HDF" \
-            and not sudo.path_exists("/usr/bin/conf-select") and sudo.path_exists("/usr/bin/hdfconf-select"):
+    if (
+      self.stack_name.upper() == "HDF"
+      and not sudo.path_exists("/usr/bin/conf-select")
+      and sudo.path_exists("/usr/bin/hdfconf-select")
+    ):
       Link("/usr/bin/conf-select", to="/usr/bin/hdfconf-select")
 
     restricted_packages = conf_select.get_restricted_packages()
@@ -242,12 +269,13 @@ class InstallPackages(Script):
     if 0 == len(restricted_packages):
       Logger.info("There are no restricted conf-select packages for this installation")
     else:
-      Logger.info("Restricting conf-select packages to {0}".format(restricted_packages))
+      Logger.info(f"Restricting conf-select packages to {restricted_packages}")
 
-    for package_name, directories in conf_select.get_package_dirs().iteritems():
+    for package_name, directories in conf_select.get_package_dirs().items():
       if 0 == len(restricted_packages) or package_name in restricted_packages:
-        conf_select.convert_conf_directories_to_symlinks(package_name, stack_version, directories)
-
+        conf_select.convert_conf_directories_to_symlinks(
+          package_name, stack_version, directories
+        )
 
   def compute_actual_version(self):
     """
@@ -263,41 +291,53 @@ class InstallPackages(Script):
       if m:
         # Contains a build number
         self.repo_version_with_build_number = self.repository_version
-        self.structured_output['actual_version'] = self.repo_version_with_build_number  # This is the best value known so far.
+        self.structured_output["actual_version"] = (
+          self.repo_version_with_build_number
+        )  # This is the best value known so far.
         self.put_structured_out(self.structured_output)
 
     Logger.info("Attempting to determine actual version with build number.")
-    Logger.info("Old versions: {0}".format(self.old_versions))
+    Logger.info(f"Old versions: {self.old_versions}")
 
     new_versions = get_stack_versions(self.stack_root_folder)
-    Logger.info("New versions: {0}".format(new_versions))
+    Logger.info(f"New versions: {new_versions}")
 
     deltas = set(new_versions) - set(self.old_versions)
-    Logger.info("Deltas: {0}".format(deltas))
+    Logger.info(f"Deltas: {deltas}")
 
     # Get version without build number
-    normalized_repo_version = self.repository_version.split('-')[0]
+    normalized_repo_version = self.repository_version.split("-")[0]
 
     if 1 == len(deltas):
       self.actual_version = next(iter(deltas)).strip()
-      self.structured_output['actual_version'] = self.actual_version
+      self.structured_output["actual_version"] = self.actual_version
       self.put_structured_out(self.structured_output)
       write_actual_version_to_history_file(normalized_repo_version, self.actual_version)
       Logger.info(
         "Found actual version {0} by checking the delta between versions before and after installing packages".format(
-          self.actual_version))
+          self.actual_version
+        )
+      )
     else:
       # If the first install attempt does a partial install and is unable to report this to the server,
       # then a subsequent attempt will report an empty delta. For this reason, we search for a best fit version for the repo version
-      Logger.info("Cannot determine actual version installed by checking the delta between versions "
-                  "before and after installing package")
-      Logger.info("Will try to find for the actual version by searching for best possible match in the list of versions installed")
-      self.actual_version = self.find_best_fit_version(new_versions, self.repository_version)
+      Logger.info(
+        "Cannot determine actual version installed by checking the delta between versions "
+        "before and after installing package"
+      )
+      Logger.info(
+        "Will try to find for the actual version by searching for best possible match in the list of versions installed"
+      )
+      self.actual_version = self.find_best_fit_version(
+        new_versions, self.repository_version
+      )
       if self.actual_version is not None:
         self.actual_version = self.actual_version.strip()
-        self.structured_output['actual_version'] = self.actual_version
+        self.structured_output["actual_version"] = self.actual_version
         self.put_structured_out(self.structured_output)
-        Logger.info("Found actual version {0} by searching for best possible match".format(self.actual_version))
+        Logger.info(
+          f"Found actual version {self.actual_version} by searching for best possible match"
+        )
       else:
         msg = "Could not determine actual version installed. Try reinstalling packages again."
         raise Fail(msg)
@@ -308,23 +348,27 @@ class InstallPackages(Script):
     log the partially completed version to REPO_VERSION_HISTORY_FILE.
     :return:
     """
-    Logger.info("Installation of packages failed. Checking if installation was partially complete")
-    Logger.info("Old versions: {0}".format(self.old_versions))
+    Logger.info(
+      "Installation of packages failed. Checking if installation was partially complete"
+    )
+    Logger.info(f"Old versions: {self.old_versions}")
 
     new_versions = get_stack_versions(self.stack_root_folder)
-    Logger.info("New versions: {0}".format(new_versions))
+    Logger.info(f"New versions: {new_versions}")
 
     deltas = set(new_versions) - set(self.old_versions)
-    Logger.info("Deltas: {0}".format(deltas))
+    Logger.info(f"Deltas: {deltas}")
 
     # Get version without build number
-    normalized_repo_version = self.repository_version.split('-')[0]
+    normalized_repo_version = self.repository_version.split("-")[0]
 
     if 1 == len(deltas):
       # Some packages were installed successfully. Log this version to REPO_VERSION_HISTORY_FILE
       partial_install_version = next(iter(deltas)).strip()
-      write_actual_version_to_history_file(normalized_repo_version, partial_install_version)
-      Logger.info("Version {0} was partially installed. ".format(partial_install_version))
+      write_actual_version_to_history_file(
+        normalized_repo_version, partial_install_version
+      )
+      Logger.info(f"Version {partial_install_version} was partially installed. ")
 
   def find_best_fit_version(self, versions, repo_version):
     """
@@ -343,19 +387,22 @@ class InstallPackages(Script):
     build_num_match = re.search("[\d\.]+-\d+", repo_version)
     if build_num_match and repo_version in versions:
       # If repo version has build number and is found in the list of versions, return it as the matching version
-      Logger.info("Best Fit Version: Resolved from repo version with valid build number: {0}".format(repo_version))
+      Logger.info(
+        f"Best Fit Version: Resolved from repo version with valid build number: {repo_version}"
+      )
       return repo_version
 
     # Get version without build number
-    normalized_repo_version = repo_version.split('-')[0]
+    normalized_repo_version = repo_version.split("-")[0]
 
     # Find all versions that match the normalized repo version
-    match_versions = filter(lambda x: x.startswith(normalized_repo_version), versions)
+    match_versions = [x for x in versions if x.startswith(normalized_repo_version)]
     if match_versions:
-
       if len(match_versions) == 1:
         # Resolved without conflicts
-        Logger.info("Best Fit Version: Resolved from normalized repo version without conflicts: {0}".format(match_versions[0]))
+        Logger.info(
+          f"Best Fit Version: Resolved from normalized repo version without conflicts: {match_versions[0]}"
+        )
         return match_versions[0]
 
       # Resolve conflicts using REPO_VERSION_HISTORY_FILE
@@ -363,13 +410,14 @@ class InstallPackages(Script):
 
       # Validate history version retrieved is valid
       if history_version in match_versions:
-        Logger.info("Best Fit Version: Resolved from normalized repo version using {0}: {1}".format(REPO_VERSION_HISTORY_FILE, history_version))
+        Logger.info(
+          f"Best Fit Version: Resolved from normalized repo version using {REPO_VERSION_HISTORY_FILE}: {history_version}"
+        )
         return history_version
 
     # No matching version
     return None
 
-
   def install_packages(self, package_list):
     """
     Actually install the packages using the package manager.
@@ -377,15 +425,21 @@ class InstallPackages(Script):
     :return: Returns 0 if no errors were found, and 1 otherwise.
     """
     ret_code = 0
-    
+
     config = self.get_config()
-    agent_stack_retry_on_unavailability = cbool(config['ambariLevelParams']['agent_stack_retry_on_unavailability'])
-    agent_stack_retry_count = cint(config['ambariLevelParams']['agent_stack_retry_count'])
+    agent_stack_retry_on_unavailability = cbool(
+      config["ambariLevelParams"]["agent_stack_retry_on_unavailability"]
+    )
+    agent_stack_retry_count = cint(
+      config["ambariLevelParams"]["agent_stack_retry_count"]
+    )
 
     # Install packages
     packages_were_checked = False
     packages_installed_before = []
-    stack_selector_package = stack_tools.get_stack_tool_package(stack_tools.STACK_SELECTOR_NAME)
+    stack_selector_package = stack_tools.get_stack_tool_package(
+      stack_tools.STACK_SELECTOR_NAME
+    )
 
     try:
       # install the stack-selector; we need to supply the action as "upgrade" here since the normal
@@ -394,58 +448,73 @@ class InstallPackages(Script):
       # the stack comes with one. Also, scope the install by repository since we need to pick a
       # specific repo that the stack-select tools are coming out of in case there are multiple
       # patches installed
-      repositories = config['repositoryFile']['repositories']
-      command_repos = CommandRepository(config['repositoryFile'])
-      command_repos.items = [x for x in command_repos.items if not x.applicable_services]
-      repository_ids = [repository['repoId'] for repository in repositories]
+      repositories = config["repositoryFile"]["repositories"]
+      command_repos = CommandRepository(config["repositoryFile"])
+      repository_ids = [repository["repoId"] for repository in repositories]
       repos_to_use = {}
+
+      if not command_repos.items:
+        raise ValueError("No repositories passed with the command")
+
       for repo_id in repository_ids:
         if repo_id in self.repo_files:
           repos_to_use[repo_id] = self.repo_files[repo_id]
 
-      self.repo_mgr.upgrade_package(stack_selector_package, RepoCallContext(
-        ignore_errors=False,
-        use_repos=repos_to_use,
-        retry_on_repo_unavailability=agent_stack_retry_on_unavailability,
-        retry_count=agent_stack_retry_count))
+      self.repo_mgr.upgrade_package(
+        stack_selector_package,
+        RepoCallContext(
+          ignore_errors=False,
+          use_repos=repos_to_use,
+          retry_on_repo_unavailability=agent_stack_retry_on_unavailability,
+          retry_count=agent_stack_retry_count,
+        ),
+      )
 
       packages_installed_before = self.repo_mgr.installed_packages()
       packages_installed_before = [package[0] for package in packages_installed_before]
       packages_were_checked = True
       filtered_package_list = self.filter_package_list(package_list)
       try:
-        available_packages_in_repos = self.repo_mgr.get_available_packages_in_repos(command_repos)
+        available_packages_in_repos = self.repo_mgr.get_available_packages_in_repos(
+          command_repos
+        )
       except Exception:
         available_packages_in_repos = []
 
       installation_context = RepoCallContext(
         ignore_errors=False,
         retry_on_repo_unavailability=agent_stack_retry_on_unavailability,
-        retry_count=agent_stack_retry_count
+        retry_count=agent_stack_retry_count,
       )
 
       for package in filtered_package_list:
-        name = self.get_package_from_available(package['name'], available_packages_in_repos)
+        name = self.get_package_from_available(
+          package["name"], available_packages_in_repos
+        )
 
         # This enables upgrading non-versioned packages, despite the fact they exist.
         # Needed by 'mahout' which is non-version but have to be updated
         self.repo_mgr.upgrade_package(name, installation_context)
     except Exception as err:
       ret_code = 1
-      Logger.logger.error("Package Manager failed to install packages: {0}".format(str(err)))
+      Logger.logger.error(f"Package Manager failed to install packages: {str(err)}")
 
       # Remove already installed packages in case of fail
       if packages_were_checked and packages_installed_before:
         packages_installed_after = self.repo_mgr.installed_packages()
         packages_installed_after = [package[0] for package in packages_installed_after]
         packages_installed_before = set(packages_installed_before)
-        new_packages_installed = [package for package in packages_installed_after if package not in packages_installed_before]
+        new_packages_installed = [
+          package
+          for package in packages_installed_after
+          if package not in packages_installed_before
+        ]
 
         if OSCheck.is_ubuntu_family():
-          package_version_string = self.repository_version.replace('.', '-')
+          package_version_string = self.repository_version.replace(".", "-")
         else:
-          package_version_string = self.repository_version.replace('-', '_')
-          package_version_string = package_version_string.replace('.', '_')
+          package_version_string = self.repository_version.replace("-", "_")
+          package_version_string = package_version_string.replace(".", "_")
 
         for package in new_packages_installed:
           if package_version_string and (package_version_string in package):
@@ -454,31 +523,41 @@ class InstallPackages(Script):
     if not self.repo_mgr.verify_dependencies():
       ret_code = 1
       Logger.logger.error("Failure while verifying dependencies")
-      Logger.logger.error("*******************************************************************************")
-      Logger.logger.error("Manually verify and fix package dependencies and then re-run install_packages")
-      Logger.logger.error("*******************************************************************************")
+      Logger.logger.error(
+        "*******************************************************************************"
+      )
+      Logger.logger.error(
+        "Manually verify and fix package dependencies and then re-run install_packages"
+      )
+      Logger.logger.error(
+        "*******************************************************************************"
+      )
 
     # Compute the actual version in order to save it in structured out
     try:
       if ret_code == 0:
-         self.compute_actual_version()
+        self.compute_actual_version()
       else:
         self.check_partial_install()
     except Fail as err:
       ret_code = 1
-      Logger.logger.exception("Failure while computing actual version. Error: {0}".format(str(err)))
+      Logger.logger.exception(
+        f"Failure while computing actual version. Error: {str(err)}"
+      )
     return ret_code
 
   def abort_handler(self, signum, frame):
-    Logger.error("Caught signal {0}, will handle it gracefully. Compute the actual version if possible before exiting.".format(signum))
+    Logger.error(
+      f"Caught signal {signum}, will handle it gracefully. Compute the actual version if possible before exiting."
+    )
     self.check_partial_install()
-    
+
   def filter_package_list(self, package_list):
     """
     Note: that we have skipUpgrade option in metainfo.xml to filter packages,
     as well as condition option to filter them conditionally,
     so use this method only if, for some reason the metainfo option cannot be used.
-  
+
     :param package_list: original list
     :return: filtered package_list
     """
