@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -19,6 +19,7 @@ limitations under the License.
 Ambari Agent
 
 """
+
 from resource_management import *
 from resource_management import Script, Repository, format
 from ambari_commons.os_check import OSCheck
@@ -26,18 +27,15 @@ import ambari_simplejson as json
 from resource_management.core.logger import Logger
 
 
-
 class UpdateRepo(Script):
-
   UBUNTU_REPO_COMPONENTS_POSTFIX = "main"
 
   def actionexecute(self, env):
     config = Script.get_config()
     structured_output = {}
 
-
     try:
-      repo_info = config['repositoryFile']
+      repo_info = config["repositoryFile"]
 
       for item in repo_info["repositories"]:
         base_url = item["baseUrl"]
@@ -46,25 +44,40 @@ class UpdateRepo(Script):
         distribution = item["distribution"] if "distribution" in item else None
         components = item["components"] if "components" in item else None
 
-        repo_rhel_suse = config['configurations']['cluster-env']['repo_suse_rhel_template']
-        repo_ubuntu = config['configurations']['cluster-env']['repo_ubuntu_template']
+        repo_rhel_suse = config["configurations"]["cluster-env"][
+          "repo_suse_rhel_template"
+        ]
+        repo_ubuntu = config["configurations"]["cluster-env"]["repo_ubuntu_template"]
 
-        template = repo_rhel_suse if OSCheck.is_suse_family() or OSCheck.is_redhat_family() else repo_ubuntu
-        ubuntu_components = [distribution if distribution else repo_name] + \
-                            [components.replace(",", " ") if components else self.UBUNTU_REPO_COMPONENTS_POSTFIX]
-
-        Repository(repo_id,
-                 action = "prepare",
-                 base_url = base_url,
-                 mirror_list = None,
-                 repo_file_name = repo_name,
-                 repo_template = template,
-                 components = ubuntu_components, # ubuntu specific
+        template = (
+          repo_rhel_suse
+          if OSCheck.is_suse_family() or OSCheck.is_redhat_family()
+          else repo_ubuntu
         )
-        structured_output["repo_update"] = {"exit_code" : 0, "message": format("Repository files successfully updated!")}
+        ubuntu_components = [distribution if distribution else repo_name] + [
+          components.replace(",", " ")
+          if components
+          else self.UBUNTU_REPO_COMPONENTS_POSTFIX
+        ]
+
+        Repository(
+          repo_id,
+          action="prepare",
+          base_url=base_url,
+          mirror_list=None,
+          repo_file_name=repo_name,
+          repo_template=template,
+          components=ubuntu_components,  # ubuntu specific
+        )
+        structured_output["repo_update"] = {
+          "exit_code": 0,
+          "message": format("Repository files successfully updated!"),
+        }
       Repository(None, action="create")
-    except Exception, exception:
-      Logger.logger.exception("ERROR: There was an unexpected error while updating repositories")
+    except Exception as exception:
+      Logger.logger.exception(
+        "ERROR: There was an unexpected error while updating repositories"
+      )
       raise Fail("Failed to update repo files!")
 
     self.put_structured_out(structured_output)
