@@ -1,5 +1,5 @@
-#!/usr/bin/env python
-'''
+#!/usr/bin/env python3
+"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
@@ -15,13 +15,13 @@ distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-'''
+"""
 
 import optparse
 import sys
 import os
 import logging
-import urllib2
+import urllib.request, urllib.error, urllib.parse
 import json
 import datetime
 import time
@@ -33,18 +33,16 @@ from flask.ext.cors import CORS
 from flask_restful import Resource, Api, reqparse
 
 
-
 class Params:
-
   ACTION = None
-  AMS_HOSTNAME = 'localhost'
-  AMS_PORT = '6188'
+  AMS_HOSTNAME = "localhost"
+  AMS_PORT = "6188"
   AMS_APP_ID = None
   AMS_APP_ID_FORMATTED = None
   HOSTS_FILE = None
   METRICS_FILE = None
   OUT_DIR = None
-  PRECISION = 'minutes'
+  PRECISION = "minutes"
   START_TIME = None
   END_TIME = None
   METRICS = []
@@ -60,22 +58,34 @@ class Params:
   @staticmethod
   def get_collector_uri(metricNames, hostname=None):
     if hostname:
-      return 'http://{0}:{1}/ws/v1/timeline/metrics?metricNames={2}&hostname={3}&appId={4}&startTime={5}&endTime={6}&precision={7}' \
-        .format(Params.AMS_HOSTNAME, Params.AMS_PORT, metricNames, hostname, Params.AMS_APP_ID,
-                Params.START_TIME, Params.END_TIME, Params.PRECISION)
+      return "http://{0}:{1}/ws/v1/timeline/metrics?metricNames={2}&hostname={3}&appId={4}&startTime={5}&endTime={6}&precision={7}".format(
+        Params.AMS_HOSTNAME,
+        Params.AMS_PORT,
+        metricNames,
+        hostname,
+        Params.AMS_APP_ID,
+        Params.START_TIME,
+        Params.END_TIME,
+        Params.PRECISION,
+      )
     else:
-      return 'http://{0}:{1}/ws/v1/timeline/metrics?metricNames={2}&appId={3}&startTime={4}&endTime={5}&precision={6}' \
-        .format(Params.AMS_HOSTNAME, Params.AMS_PORT, metricNames, Params.AMS_APP_ID, Params.START_TIME,
-                Params.END_TIME, Params.PRECISION)
+      return "http://{0}:{1}/ws/v1/timeline/metrics?metricNames={2}&appId={3}&startTime={4}&endTime={5}&precision={6}".format(
+        Params.AMS_HOSTNAME,
+        Params.AMS_PORT,
+        metricNames,
+        Params.AMS_APP_ID,
+        Params.START_TIME,
+        Params.END_TIME,
+        Params.PRECISION,
+      )
+
 
 class Utils:
-
   @staticmethod
   def setup_logger(verbose, log_file):
-
     global logger
-    logger = logging.getLogger('AmbariMetricsExport')
-    formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
+    logger = logging.getLogger("AmbariMetricsExport")
+    formatter = logging.Formatter("%(asctime)s %(levelname)s %(message)s")
     if log_file:
       filehandler = logging.FileHandler(log_file)
     consolehandler = logging.StreamHandler()
@@ -94,12 +104,12 @@ class Utils:
 
   @staticmethod
   def get_data_from_url(collector_uri):
-    req = urllib2.Request(collector_uri)
+    req = urllib.request.Request(collector_uri)
     connection = None
     try:
-      connection = urllib2.urlopen(req)
+      connection = urllib.request.urlopen(req)
     except Exception as e:
-      logger.error('Error on metrics GET request: %s' % collector_uri)
+      logger.error(f"Error on metrics GET request: {collector_uri}")
       logger.error(str(e))
     # Validate json before dumping
     response_data = None
@@ -107,17 +117,20 @@ class Utils:
       try:
         response_data = json.loads(connection.read())
       except Exception as e:
-        logger.warn('Error parsing json data returned from URI: %s' % collector_uri)
+        logger.warn(f"Error parsing json data returned from URI: {collector_uri}")
         logger.debug(str(e))
 
     return response_data
 
   @staticmethod
   def get_epoch(input):
-    if (len(input) == 13):
+    if len(input) == 13:
       return int(input)
-    elif (len(input) == 20):
-      return int(time.mktime(datetime.datetime.strptime(input, '%Y-%m-%dT%H:%M:%SZ').timetuple()) * 1000)
+    elif len(input) == 20:
+      return int(
+        time.mktime(datetime.datetime.strptime(input, "%Y-%m-%dT%H:%M:%SZ").timetuple())
+        * 1000
+      )
     else:
       return -1
 
@@ -141,40 +154,48 @@ class Utils:
 
       if os.path.exists(conf_file):
         json = Utils.read_json_file(conf_file)
-        Params.AMS_APP_ID = json['APP_ID']
-        Params.START_TIME = json['START_TIME']
-        Params.END_TIME = json['END_TIME']
-        Params.AGGREGATE = json['AGGREGATE']
+        Params.AMS_APP_ID = json["APP_ID"]
+        Params.START_TIME = json["START_TIME"]
+        Params.END_TIME = json["END_TIME"]
+        Params.AGGREGATE = json["AGGREGATE"]
       else:
-        logger.warn('Not found config file in {0}'.format(os.path.join(Params.INPUT_DIR), "configs"))
-        logger.info('Aborting...')
+        logger.warn(
+          "Not found config file in {0}".format(
+            os.path.join(Params.INPUT_DIR), "configs"
+          )
+        )
+        logger.info("Aborting...")
         sys.exit(1)
 
   @staticmethod
   def set_configs():
     conf_file = os.path.join(Params.OUT_DIR, "configs")
     aggregate = True if not Params.HOSTS else False
-    properties = {"APP_ID" : Params.AMS_APP_ID, "START_TIME" : Params.START_TIME, "END_TIME" : Params.END_TIME, "AGGREGATE" : aggregate}
+    properties = {
+      "APP_ID": Params.AMS_APP_ID,
+      "START_TIME": Params.START_TIME,
+      "END_TIME": Params.END_TIME,
+      "AGGREGATE": aggregate,
+    }
 
-    with open(conf_file, 'w') as file:
+    with open(conf_file, "w") as file:
       file.write(json.dumps(properties))
 
-class AmsMetricsProcessor:
 
+class AmsMetricsProcessor:
   @staticmethod
   def write_metrics_to_file(metrics, host=None):
-
     for metric in metrics:
       uri = Params.get_collector_uri(metric, host)
-      logger.info('Request URI: %s' % str(uri))
+      logger.info(f"Request URI: {str(uri)}")
       metrics_json = Utils.get_data_from_url(uri)
       if metrics_json:
         if host:
           path = os.path.join(Params.OUT_DIR, host, metric)
         else:
           path = os.path.join(Params.OUT_DIR, metric)
-        logger.info('Writing metric file: %s' % path)
-        with open(path, 'w') as file:
+        logger.info(f"Writing metric file: {path}")
+        with open(path, "w") as file:
           file.write(json.dumps(metrics_json))
 
   @staticmethod
@@ -182,18 +203,31 @@ class AmsMetricsProcessor:
     app_metrics_metadata = []
     for metric in Params.METRICS:
       if not Params.AGGREGATE:
-        app_metrics_metadata.append({"metricname": metric, "seriesStartTime": Params.START_TIME, "supportsAggregation": "false", "type": "UNDEFINED"})
+        app_metrics_metadata.append(
+          {
+            "metricname": metric,
+            "seriesStartTime": Params.START_TIME,
+            "supportsAggregation": "false",
+            "type": "UNDEFINED",
+          }
+        )
       else:
-        app_metrics_metadata.append({"metricname": metric, "seriesStartTime": Params.START_TIME, "supportsAggregation": "false"})
-    logger.debug("Adding {0} to metadata".format(metric))
+        app_metrics_metadata.append(
+          {
+            "metricname": metric,
+            "seriesStartTime": Params.START_TIME,
+            "supportsAggregation": "false",
+          }
+        )
+    logger.debug(f"Adding {metric} to metadata")
 
-    return {Params.AMS_APP_ID : app_metrics_metadata}
+    return {Params.AMS_APP_ID: app_metrics_metadata}
 
   @staticmethod
   def get_hosts_with_components():
     hosts_with_components = {}
     if Params.AGGREGATE:
-      return {"fakehostname" : [Params.AMS_APP_ID]}
+      return {"fakehostname": [Params.AMS_APP_ID]}
     else:
       for host in Params.HOSTS:
         hosts_with_components[host] = [Params.AMS_APP_ID]
@@ -202,10 +236,9 @@ class AmsMetricsProcessor:
   @staticmethod
   def get_metrics_dirs(d):
     for o in os.listdir(d):
-      if 'ambari_metrics_export_' in o and os.path.isdir(os.path.join(d, o)):
+      if "ambari_metrics_export_" in o and os.path.isdir(os.path.join(d, o)):
         yield os.path.join(d, o)
 
-
   @staticmethod
   def ger_metrics_from_input_dir():
     metrics_for_hosts = {}
@@ -233,25 +266,25 @@ class AmsMetricsProcessor:
   @staticmethod
   def export_ams_metrics():
     if not os.path.exists(Params.METRICS_FILE):
-      logger.error('Metrics file is required.')
+      logger.error("Metrics file is required.")
       sys.exit(1)
-    logger.info('Reading metrics file.')
-    with open(Params.METRICS_FILE, 'r') as file:
+    logger.info("Reading metrics file.")
+    with open(Params.METRICS_FILE, "r") as file:
       for line in file:
         Params.METRICS.append(line.strip())
-    logger.info('Reading hosts file.')
+    logger.info("Reading hosts file.")
 
-    logger.info('Reading hosts file.')
+    logger.info("Reading hosts file.")
     if Params.HOSTS_FILE and os.path.exists(Params.HOSTS_FILE):
-      with open(Params.HOSTS_FILE, 'r') as file:
+      with open(Params.HOSTS_FILE, "r") as file:
         for line in file:
           Params.HOSTS.append(line.strip())
     else:
-      logger.info('No hosts file found, aggregate metrics will be exported.')
+      logger.info("No hosts file found, aggregate metrics will be exported.")
 
     if Params.HOSTS:
       for host in Params.HOSTS:
-        os.makedirs(os.path.join(Params.OUT_DIR, host)) # create host dir
+        os.makedirs(os.path.join(Params.OUT_DIR, host))  # create host dir
         AmsMetricsProcessor.write_metrics_to_file(Params.METRICS, host)
     else:
       os.makedirs(os.path.join(Params.OUT_DIR))
@@ -268,25 +301,38 @@ class AmsMetricsProcessor:
       self.hosts_with_components = self.get_hosts_with_components()
 
 
-class FlaskServer():
-  def __init__ (self, ams_metrics_processor):
+class FlaskServer:
+  def __init__(self, ams_metrics_processor):
     self.ams_metrics_processor = ams_metrics_processor
     app = Flask(__name__)
     api = Api(app)
     cors = CORS(app)
 
-    api.add_resource(HostsResource, '/ws/v1/timeline/metrics/hosts', resource_class_kwargs={'ams_metrics_processor': self.ams_metrics_processor})
-    api.add_resource(MetadataResource, '/ws/v1/timeline/metrics/metadata', resource_class_kwargs={'ams_metrics_processor': self.ams_metrics_processor})
-    api.add_resource(MetricsResource, '/ws/v1/timeline/metrics', resource_class_kwargs={'ams_metrics_processor': self.ams_metrics_processor})
+    api.add_resource(
+      HostsResource,
+      "/ws/v1/timeline/metrics/hosts",
+      resource_class_kwargs={"ams_metrics_processor": self.ams_metrics_processor},
+    )
+    api.add_resource(
+      MetadataResource,
+      "/ws/v1/timeline/metrics/metadata",
+      resource_class_kwargs={"ams_metrics_processor": self.ams_metrics_processor},
+    )
+    api.add_resource(
+      MetricsResource,
+      "/ws/v1/timeline/metrics",
+      resource_class_kwargs={"ams_metrics_processor": self.ams_metrics_processor},
+    )
 
-    logger.info("Start Flask server. Server URL = " + Params.FLASK_SERVER_NAME + ":5000")
+    logger.info(
+      "Start Flask server. Server URL = " + Params.FLASK_SERVER_NAME + ":5000"
+    )
+
+    app.run(debug=Params.VERBOSE, host=Params.FLASK_SERVER_NAME, port=5000)
 
-    app.run(debug=Params.VERBOSE,
-            host=Params.FLASK_SERVER_NAME,
-            port=5000)
 
 class MetadataResource(Resource):
-  def __init__ (self, ams_metrics_processor):
+  def __init__(self, ams_metrics_processor):
     self.ams_metrics_processor = ams_metrics_processor
 
   def get(self):
@@ -295,8 +341,9 @@ class MetadataResource(Resource):
     else:
       abort(404)
 
+
 class HostsResource(Resource):
-  def __init__ (self, ams_metrics_processor):
+  def __init__(self, ams_metrics_processor):
     self.ams_metrics_processor = ams_metrics_processor
 
   def get(self):
@@ -305,8 +352,9 @@ class HostsResource(Resource):
     else:
       abort(404)
 
+
 class MetricsResource(Resource):
-  def __init__ (self, ams_metrics_processor):
+  def __init__(self, ams_metrics_processor):
     self.ams_metrics_processor = ams_metrics_processor
 
   def get(self):
@@ -324,15 +372,26 @@ class MetricsResource(Resource):
       separator = ""
       operation = ""
 
-    metric_dict = {"metrics" : []}
+    metric_dict = {"metrics": []}
 
     if "hostname" in args and args["hostname"] != "":
       host_names = args["hostname"].split(",")
-      metric_dict = {"metrics" : []}
+      metric_dict = {"metrics": []}
       for host_name in host_names:
         if metric_name in self.ams_metrics_processor.metrics_for_hosts[host_name]:
-          if len(self.ams_metrics_processor.metrics_for_hosts[host_name][metric_name]["metrics"]) > 0:
-            metric_dict["metrics"].append(self.ams_metrics_processor.metrics_for_hosts[host_name][metric_name]["metrics"][0])
+          if (
+            len(
+              self.ams_metrics_processor.metrics_for_hosts[host_name][metric_name][
+                "metrics"
+              ]
+            )
+            > 0
+          ):
+            metric_dict["metrics"].append(
+              self.ams_metrics_processor.metrics_for_hosts[host_name][metric_name][
+                "metrics"
+              ][0]
+            )
         else:
           continue
 
@@ -345,85 +404,149 @@ class MetricsResource(Resource):
     else:
       for host in self.ams_metrics_processor.metrics_for_hosts:
         for metric in self.ams_metrics_processor.metrics_for_hosts[host]:
-            if metric_name == metric and len(self.ams_metrics_processor.metrics_for_hosts[host][metric_name]["metrics"]) > 0:
-              metric_dict = self.ams_metrics_processor.metrics_for_hosts[host][metric_name]
-              break
+          if (
+            metric_name == metric
+            and len(
+              self.ams_metrics_processor.metrics_for_hosts[host][metric_name]["metrics"]
+            )
+            > 0
+          ):
+            metric_dict = self.ams_metrics_processor.metrics_for_hosts[host][
+              metric_name
+            ]
+            break
 
     if metric_dict:
       metrics_json_new = copy.deepcopy(metric_dict)
-      for i in range (0, len(metrics_json_new["metrics"])):
+      for i in range(0, len(metrics_json_new["metrics"])):
         metrics_json_new["metrics"][i]["metricname"] += separator + operation
       return jsonify(metrics_json_new)
-    else :
+    else:
       abort(404)
       return
 
+
 #
 # Main.
 #
 def main():
   parser = optparse.OptionParser(usage="usage: %prog [options]")
-  parser.set_description('This python program is a Ambari thin client and '
-                         'supports export of ambari metric data for an app '
-                         'from Ambari Metrics Service to a output dir. '
-                         'The metrics will be exported to a file with name of '
-                         'the metric and in a directory with the name as the '
-                         'hostname under the output dir. '
-                         'Also this python program is a thin REST server '
-                         'that implements a subset of the Ambari Metrics Service metrics server interfaces. '
-                         'You can use it to visualize information exported by the AMS thin client')
+  parser.set_description(
+    "This python program is a Ambari thin client and "
+    "supports export of ambari metric data for an app "
+    "from Ambari Metrics Service to a output dir. "
+    "The metrics will be exported to a file with name of "
+    "the metric and in a directory with the name as the "
+    "hostname under the output dir. "
+    "Also this python program is a thin REST server "
+    "that implements a subset of the Ambari Metrics Service metrics server interfaces. "
+    "You can use it to visualize information exported by the AMS thin client"
+  )
 
   d = datetime.datetime.now()
-  time_suffix = '{0}-{1}-{2}-{3}-{4}-{5}'.format(d.year, d.month, d.day,
-                                                 d.hour, d.minute, d.second)
-  print 'Time: %s' % time_suffix
+  time_suffix = f"{d.year}-{d.month}-{d.day}-{d.hour}-{d.minute}-{d.second}"
+  print(f"Time: {time_suffix}")
 
-  logfile = os.path.join('/tmp', 'ambari_metrics_export.out')
+  logfile = os.path.join("/tmp", "ambari_metrics_export.out")
 
-  output_dir = os.path.join('/tmp', 'ambari_metrics_export_' + time_suffix)
+  output_dir = os.path.join("/tmp", "ambari_metrics_export_" + time_suffix)
 
-  parser.add_option("-a", "--action", dest="action", default="set_action", help="Use action 'export' for exporting AMS metrics. "
-                                                                         "Use action 'run' for run REST server")
-  parser.add_option("-v", "--verbose", dest="verbose", action="store_true",
-                    default=False, help="output verbosity.")
-  parser.add_option("-l", "--logfile", dest="log_file", default=logfile,
-                    metavar='FILE', help="Log file. [default: %s]" % logfile)
+  parser.add_option(
+    "-a",
+    "--action",
+    dest="action",
+    default="set_action",
+    help="Use action 'export' for exporting AMS metrics. "
+    "Use action 'run' for run REST server",
+  )
+  parser.add_option(
+    "-v",
+    "--verbose",
+    dest="verbose",
+    action="store_true",
+    default=False,
+    help="output verbosity.",
+  )
+  parser.add_option(
+    "-l",
+    "--logfile",
+    dest="log_file",
+    default=logfile,
+    metavar="FILE",
+    help=f"Log file. [default: {logfile}]",
+  )
 
   export_options_group = OptionGroup(parser, "Required options for action 'export'")
-  #export metrics -----------------------------------------------------
-  export_options_group.add_option("-s", "--host", dest="server_hostname",
-                    help="AMS host name.")
-  export_options_group.add_option("-p", "--port", dest="server_port",
-                    default="6188", help="AMS port. [default: 6188]")
-  export_options_group.add_option("-c", "--app-id", dest="app_id",
-                    help="AMS app id.")
-  export_options_group.add_option("-m", "--metrics-file", dest="metrics_file",
-                    help="Metrics file with metric names to query. New line separated.")
-  export_options_group.add_option("-f", "--host-file", dest="hosts_file",
-                    help="Host file with hostnames to query. New line separated.")
-  export_options_group.add_option("-r", "--precision", dest="precision",
-                    default='minutes', help="AMS API precision, default = minutes.")
-  export_options_group.add_option("-b", "--start_time", dest="start_time",
-                    help="Start time in milliseconds since epoch or UTC timestamp in YYYY-MM-DDTHH:mm:ssZ format.")
-  export_options_group.add_option("-e", "--end_time", dest="end_time",
-                    help="End time in milliseconds since epoch or UTC timestamp in YYYY-MM-DDTHH:mm:ssZ format.")
-  export_options_group.add_option("-o", "--output-dir", dest="output_dir", default=output_dir,
-                    help="Output dir. [default: %s]" % output_dir)
+  # export metrics -----------------------------------------------------
+  export_options_group.add_option(
+    "-s", "--host", dest="server_hostname", help="AMS host name."
+  )
+  export_options_group.add_option(
+    "-p", "--port", dest="server_port", default="6188", help="AMS port. [default: 6188]"
+  )
+  export_options_group.add_option("-c", "--app-id", dest="app_id", help="AMS app id.")
+  export_options_group.add_option(
+    "-m",
+    "--metrics-file",
+    dest="metrics_file",
+    help="Metrics file with metric names to query. New line separated.",
+  )
+  export_options_group.add_option(
+    "-f",
+    "--host-file",
+    dest="hosts_file",
+    help="Host file with hostnames to query. New line separated.",
+  )
+  export_options_group.add_option(
+    "-r",
+    "--precision",
+    dest="precision",
+    default="minutes",
+    help="AMS API precision, default = minutes.",
+  )
+  export_options_group.add_option(
+    "-b",
+    "--start_time",
+    dest="start_time",
+    help="Start time in milliseconds since epoch or UTC timestamp in YYYY-MM-DDTHH:mm:ssZ format.",
+  )
+  export_options_group.add_option(
+    "-e",
+    "--end_time",
+    dest="end_time",
+    help="End time in milliseconds since epoch or UTC timestamp in YYYY-MM-DDTHH:mm:ssZ format.",
+  )
+  export_options_group.add_option(
+    "-o",
+    "--output-dir",
+    dest="output_dir",
+    default=output_dir,
+    help=f"Output dir. [default: {output_dir}]",
+  )
   parser.add_option_group(export_options_group)
-  #start Flask server -----------------------------------------------------
+  # start Flask server -----------------------------------------------------
 
   run_server_option_group = OptionGroup(parser, "Required options for action 'run'")
 
-  run_server_option_group.add_option("-i", "--input-dir", dest="input_dir",
-                    default='/tmp', help="Input directory for AMS metrics exports. [default: /tmp]")
-  run_server_option_group.add_option("-n", "--flask-server_name", dest="server_name",
-                    help="Flask server name, default = 127.0.0.1", default="127.0.0.1")
+  run_server_option_group.add_option(
+    "-i",
+    "--input-dir",
+    dest="input_dir",
+    default="/tmp",
+    help="Input directory for AMS metrics exports. [default: /tmp]",
+  )
+  run_server_option_group.add_option(
+    "-n",
+    "--flask-server_name",
+    dest="server_name",
+    help="Flask server name, default = 127.0.0.1",
+    default="127.0.0.1",
+  )
 
   parser.add_option_group(run_server_option_group)
   (options, args) = parser.parse_args()
 
-
-  #export metrics -----------------------------------------------------
+  # export metrics -----------------------------------------------------
   Params.ACTION = options.action
 
   Params.VERBOSE = options.verbose
@@ -431,7 +554,6 @@ def main():
   Utils.setup_logger(options.verbose, options.log_file)
 
   if Params.ACTION == "export":
-
     Params.AMS_HOSTNAME = options.server_hostname
 
     Params.AMS_PORT = options.server_port
@@ -447,20 +569,28 @@ def main():
 
     Params.PRECISION = options.precision
 
-    Params.OUT_DIR = output_dir if options.output_dir == output_dir else os.path.join(options.output_dir, 'ambari_metrics_export_' + time_suffix)
+    Params.OUT_DIR = (
+      output_dir
+      if options.output_dir == output_dir
+      else os.path.join(options.output_dir, "ambari_metrics_export_" + time_suffix)
+    )
 
     if Params.START_TIME == -1:
-      logger.warn('No start time provided, or it is in the wrong format. Please '
-                  'provide milliseconds since epoch or a value in YYYY-MM-DDTHH:mm:ssZ format')
-      logger.info('Aborting...')
+      logger.warn(
+        "No start time provided, or it is in the wrong format. Please "
+        "provide milliseconds since epoch or a value in YYYY-MM-DDTHH:mm:ssZ format"
+      )
+      logger.info("Aborting...")
       sys.exit(1)
 
     Params.END_TIME = Utils.get_epoch(options.end_time)
 
     if Params.END_TIME == -1:
-      logger.warn('No end time provided, or it is in the wrong format. Please '
-                  'provide milliseconds since epoch or a value in YYYY-MM-DDTHH:mm:ssZ format')
-      logger.info('Aborting...')
+      logger.warn(
+        "No end time provided, or it is in the wrong format. Please "
+        "provide milliseconds since epoch or a value in YYYY-MM-DDTHH:mm:ssZ format"
+      )
+      logger.info("Aborting...")
       sys.exit(1)
 
     Params.START_TIME = Utils.get_epoch(options.start_time)
@@ -468,9 +598,8 @@ def main():
     ams_metrics_processor = AmsMetricsProcessor()
     ams_metrics_processor.process()
 
-
   elif Params.ACTION == "run":
-  #start Flask server -----------------------------------------------------
+    # start Flask server -----------------------------------------------------
     Params.INPUT_DIR = options.input_dir
 
     Params.FLASK_SERVER_NAME = options.server_name
@@ -480,9 +609,11 @@ def main():
     FlaskServer(ams_metrics_processor)
 
   else:
-    logger.warn('Action \'{0}\' not supported. Please use action \'export\' for exporting AMS metrics '
-                'or use action \'run\' for starting REST server'.format(Params.ACTION))
-    logger.info('Aborting...')
+    logger.warn(
+      "Action '{0}' not supported. Please use action 'export' for exporting AMS metrics "
+      "or use action 'run' for starting REST server".format(Params.ACTION)
+    )
+    logger.info("Aborting...")
     sys.exit(1)
 
 
