@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -17,26 +17,49 @@ See the License for the specific language governing permissions and
 limitations under the License.
 
 """
-import sys
-from resource_management import *
 
+# Python Imports
+import sys
+
+# Local Imports
 from hive import hive
 
+# Ambari Commons & Resource Management Imports
+from resource_management.core.exceptions import ClientComponentHasNoStatus
+from resource_management.core.logger import Logger
+from resource_management.libraries.script.script import Script
+from resource_management.libraries.functions import stack_select
+from resource_management.libraries.functions.constants import StackFeature
+from resource_management.libraries.functions.stack_features import check_stack_feature
+
+
 class HiveClient(Script):
   def install(self, env):
     import params
-    self.install_packages(env, exclude_packages=params.hive_exclude_packages)
+
+    self.install_packages(env)
     self.configure(env)
 
-  def configure(self, env):
-    import params
-    env.set_params(params)
-
-    hive(name='client')
-
-
   def status(self, env):
     raise ClientComponentHasNoStatus()
 
+  def configure(self, env):
+    import params
+
+    env.set_params(params)
+    hive(name="client")
+
+  def pre_upgrade_restart(self, env, upgrade_type=None):
+    Logger.info("Executing Hive client Stack Upgrade pre-restart")
+
+    import params
+
+    env.set_params(params)
+    if params.version and check_stack_feature(
+      StackFeature.ROLLING_UPGRADE, params.version
+    ):
+      stack_select.select_packages(params.version)
+
+
 if __name__ == "__main__":
   HiveClient().execute()
