@@ -42,6 +42,7 @@ import org.apache.ambari.server.orm.GuiceJpaInitializer;
 import org.apache.ambari.server.orm.InMemoryDefaultTestModule;
 import org.apache.ambari.server.orm.OrmTestHelper;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
+import org.apache.ambari.server.security.encryption.Encryptor;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
 import org.apache.ambari.server.state.Config;
@@ -121,7 +122,7 @@ public class TestHeartbeatMonitor {
     Configuration configuration = mock(Configuration.class);
     when(configuration.getHeartbeatMonitorInterval()).thenReturn(10);
     HeartbeatMonitor hm = new HeartbeatMonitor(fsm, am, 10, injector);
-    HeartBeatHandler handler = new HeartBeatHandler(configuration, fsm, am, injector);
+    HeartBeatHandler handler = new HeartBeatHandler(configuration, fsm, am, Encryptor.NONE, injector);
     Register reg = new Register();
     reg.setHostname(hostname);
     reg.setResponseId(12);
@@ -191,7 +192,7 @@ public class TestHeartbeatMonitor {
       heartbeatMonitorWakeupIntervalMS, injector);
     Configuration configuration = mock(Configuration.class);
     when(configuration.getHeartbeatMonitorInterval()).thenReturn(60000);
-    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, injector);
+    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, Encryptor.NONE, injector);
     Register reg = new Register();
     reg.setHostname(hostname1);
     reg.setResponseId(12);
@@ -312,7 +313,7 @@ public class TestHeartbeatMonitor {
       heartbeatMonitorWakeupIntervalMS, injector);
     Configuration configuration = mock(Configuration.class);
     when(configuration.getHeartbeatMonitorInterval()).thenReturn(60000);
-    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, injector);
+    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, Encryptor.NONE, injector);
     Register reg = new Register();
     reg.setHostname(hostname1);
     reg.setResponseId(12);
@@ -409,8 +410,7 @@ public class TestHeartbeatMonitor {
       heartbeatMonitorWakeupIntervalMS, injector);
     Configuration configuration = mock(Configuration.class);
     when(configuration.getHeartbeatMonitorInterval()).thenReturn(60000);
-    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am,
-        injector);
+    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, Encryptor.NONE, injector);
     Register reg = new Register();
     reg.setHostname(hostname1);
     reg.setResponseId(12);
@@ -487,7 +487,7 @@ public class TestHeartbeatMonitor {
     HeartbeatMonitor hm = new HeartbeatMonitor(clusters, am, 10, injector);
     Configuration configuration = mock(Configuration.class);
     when(configuration.getHeartbeatMonitorInterval()).thenReturn(10);
-    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, injector);
+    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, Encryptor.NONE, injector);
 
     Register reg = new Register();
     reg.setHostname(hostname1);
@@ -611,7 +611,7 @@ public class TestHeartbeatMonitor {
       heartbeatMonitorWakeupIntervalMS, injector);
     Configuration configuration = mock(Configuration.class);
     when(configuration.getHeartbeatMonitorInterval()).thenReturn(60000);
-    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, injector);
+    HeartBeatHandler handler = new HeartBeatHandler(configuration, clusters, am, Encryptor.NONE, injector);
     Register reg = new Register();
     reg.setHostname(hostname1);
     reg.setResponseId(12);
