@@ -705,8 +705,8 @@ public class StaleAlertRunnableTest {
      */
     @Override
     public void configure(Binder binder) {
-      PartialNiceMockBinder.newBuilder().addConfigsBindings().addLdapBindings()
-          .addAlertDefinitionBinding().build().configure(binder);
+      PartialNiceMockBinder.newBuilder().addConfigsBindings()
+          .addAlertDefinitionBinding().addLdapBindings().build().configure(binder);
 
       binder.bind(AlertsDAO.class).toInstance(createNiceMock(AlertsDAO.class));
       binder.bind(HostRoleCommandDAO.class).toInstance(createNiceMock(HostRoleCommandDAO.class));
