@@ -18,50 +18,41 @@
 
 package org.apache.ambari.server.api.services;
 
+import static org.junit.Assert.assertEquals;
+
 import java.io.IOException;
+import java.util.Collection;
 import java.util.Map;
 
+import javax.ws.rs.client.Client;
+import javax.ws.rs.client.Entity;
+
 import org.apache.ambari.server.H2DatabaseCleaner;
 import org.apache.ambari.server.RandomPortJerseyTest;
 import org.apache.ambari.server.orm.GuiceJpaInitializer;
 import org.apache.ambari.server.orm.InMemoryDefaultTestModule;
 import org.apache.ambari.server.utils.StageUtils;
-import org.codehaus.jettison.json.JSONException;
+import org.glassfish.jersey.jackson.JacksonFeature;
+import org.glassfish.jersey.server.ResourceConfig;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import com.google.inject.AbstractModule;
 import com.google.inject.Guice;
 import com.google.inject.Injector;
-import com.sun.jersey.api.client.Client;
-import com.sun.jersey.api.client.UniformInterfaceException;
-import com.sun.jersey.api.client.WebResource;
-import com.sun.jersey.api.client.config.ClientConfig;
-import com.sun.jersey.api.client.config.DefaultClientConfig;
-import com.sun.jersey.api.json.JSONConfiguration;
-import com.sun.jersey.spi.container.servlet.ServletContainer;
-import com.sun.jersey.test.framework.WebAppDescriptor;
-
-import junit.framework.Assert;
 
 public class PersistServiceTest extends RandomPortJerseyTest {
   static String PACKAGE_NAME = "org.apache.ambari.server.api.services";
-  private static final Logger LOG = LoggerFactory.getLogger(PersistServiceTest.class);
   Injector injector;
   protected Client client;
 
-  public  PersistServiceTest() {
-    super(new WebAppDescriptor.Builder(PACKAGE_NAME).servletClass(ServletContainer.class)
-        .initParam("com.sun.jersey.api.json.POJOMappingFeature", "true")
-        .build());
+  public PersistServiceTest() {
+    super();
   }
 
   public class MockModule extends AbstractModule {
 
-
     @Override
     protected void configure() {
       requestStaticInjection(PersistKeyValueService.class);
@@ -83,24 +74,33 @@ public class PersistServiceTest extends RandomPortJerseyTest {
     H2DatabaseCleaner.clearDatabaseAndStopPersistenceService(injector);
   }
 
+  @Override
+  protected ResourceConfig configure() {
+    return new ResourceConfig().packages(PACKAGE_NAME).register(JacksonFeature.class);
+  }
+
   @Test
-  public void testPersist() throws UniformInterfaceException, JSONException,
-    IOException {
-    ClientConfig clientConfig = new DefaultClientConfig();
-    clientConfig.getFeatures().put(JSONConfiguration.FEATURE_POJO_MAPPING, Boolean.TRUE);
-    client = Client.create(clientConfig);
-    WebResource webResource = client.resource(String.format("http://localhost:%d/persist", getTestPort()));
-    
-    webResource.post("{\"xyx\" : \"t\"}");
-    LOG.info("Done posting to the server");
-    String output = webResource.get(String.class);
-    LOG.info("All key values " + output);
-    Map<String, String> jsonOutput = StageUtils.fromJson(output, Map.class);
-    String value = jsonOutput.get("xyx");
-    Assert.assertEquals("t", value);
-    webResource = client.resource(String.format("http://localhost:%d/persist/xyx", getTestPort()));
-    output = webResource.get(String.class);
-    Assert.assertEquals("t", output);
-    LOG.info("Value for xyx " + output);
+  public void testPersistAPIs() throws IOException {
+    String input = "{\"key1\" : \"value1\",\"key2\" : \"value2\"}";
+    String response = target("persist").request().post(Entity.text(input), String.class);
+    assertEquals("", response);
+    // END GENAI@CHATGPT4
+
+
+    String result = target("persist/key1").request().get(String.class);
+    assertEquals("value1", result);
+    result = target("persist/key2").request().get(String.class);
+    assertEquals("value2", result);
+
+    String values = "[\"value3\", \"value4\"]";
+    String putResponse = target("persist").request().put(Entity.text(values), String.class);
+    Collection<String> keys = StageUtils.fromJson(putResponse, Collection.class);
+    assertEquals(2, keys.size());
+
+    String getAllResponse = target("persist").request().get(String.class);
+    Map<String, String> allKeys = StageUtils.fromJson(getAllResponse, Map.class);
+    assertEquals(4, allKeys.size());
+    assertEquals("value1", allKeys.get("key1"));
+    assertEquals("value2", allKeys.get("key2"));
   }
 }
