@@ -58,7 +58,6 @@ import org.apache.ambari.server.agent.RecoveryConfigHelper;
 import org.apache.ambari.server.agent.RecoveryReport;
 import org.apache.ambari.server.agent.stomp.HostLevelParamsHolder;
 import org.apache.ambari.server.agent.stomp.TopologyHolder;
-import org.apache.ambari.server.agent.stomp.dto.HostRepositories;
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.audit.AuditLogger;
 import org.apache.ambari.server.controller.AbstractRootServiceResponseFactory;
@@ -80,6 +79,7 @@ import org.apache.ambari.server.hooks.HookService;
 import org.apache.ambari.server.hooks.users.UserHookService;
 import org.apache.ambari.server.metadata.CachedRoleCommandOrderProvider;
 import org.apache.ambari.server.metadata.RoleCommandOrderProvider;
+import org.apache.ambari.server.mpack.MpackManagerFactory;
 import org.apache.ambari.server.orm.DBAccessor;
 import org.apache.ambari.server.orm.dao.StageDAO;
 import org.apache.ambari.server.scheduler.ExecutionScheduler;
@@ -191,7 +191,6 @@ public class HostResourceProviderTest extends EasyMockSupport {
     EasyMock.expectLastCall().once();
 
     expect(managementController.getClusters()).andReturn(clusters).atLeastOnce();
-    expect(managementController.retrieveHostRepositories(anyObject(), anyObject())).andReturn(createMock(HostRepositories.class));
 
     expect(resourceProviderFactory.getHostResourceProvider(
         eq(managementController))).andReturn(hostResourceProvider).anyTimes();
@@ -1404,7 +1403,7 @@ public class HostResourceProviderTest extends EasyMockSupport {
     Injector injector = Guice.createInjector(new AbstractModule() {
       @Override
       protected void configure() {
-        PartialNiceMockBinder.newBuilder().addConfigsBindings().addLdapBindings().addFactoriesInstallBinding().build().configure(binder());
+        PartialNiceMockBinder.newBuilder().addConfigsBindings().addFactoriesInstallBinding().addPasswordEncryptorBindings().addLdapBindings().build().configure(binder());
 
         bind(EntityManager.class).toInstance(createNiceMock(EntityManager.class));
         bind(DBAccessor.class).toInstance(createNiceMock(DBAccessor.class));
@@ -1431,6 +1430,7 @@ public class HostResourceProviderTest extends EasyMockSupport {
         bind(HostLevelParamsHolder.class).toInstance(createNiceMock(HostLevelParamsHolder.class));
         bind(TopologyHolder.class).toInstance(createNiceMock(TopologyHolder.class));
         bind(RecoveryConfigHelper.class).toInstance(createNiceMock(RecoveryConfigHelper.class));
+        bind(MpackManagerFactory.class).toInstance(createNiceMock(MpackManagerFactory.class));
 
         install(new FactoryModuleBuilder().build(StackManagerFactory.class));
         install(new FactoryModuleBuilder().implement(
