@@ -70,8 +70,8 @@ public class ScaleClusterRequestTest {
   private static final ResourceProvider hostResourceProvider = createMock(ResourceProvider.class);
   private static final HostGroup hostGroup1 = createNiceMock(HostGroup.class);
   private static final Configuration blueprintConfig = new Configuration(
-      Collections.<String, Map<String, String>>emptyMap(),
-      Collections.<String, Map<String, Map<String, String>>>emptyMap());
+      Collections.emptyMap(),
+      Collections.emptyMap());
 
   @Before
   public void setUp() throws Exception {
@@ -89,7 +89,7 @@ public class ScaleClusterRequestTest {
     expect(blueprint.getHostGroup(GROUP3_NAME)).andReturn(hostGroup1).anyTimes();
     expect(blueprint.getName()).andReturn(BLUEPRINT_NAME).anyTimes();
     expect(hostResourceProvider.checkPropertyIds(Collections.singleton("test/prop"))).
-        andReturn(Collections.<String>emptySet()).once();
+        andReturn(Collections.emptySet()).once();
 
     replay(blueprintFactory, blueprint, hostResourceProvider, hostGroup1);
   }
@@ -307,7 +307,7 @@ public class ScaleClusterRequestTest {
   public void test_NoHostNameOrHostCount() throws Exception {
     Map<String, Object> properties = createScaleClusterPropertiesGroup1_HostName(CLUSTER_NAME, BLUEPRINT_NAME);
     // remove host name
-    properties.remove("Hosts/host_name");
+    properties.remove(HostResourceProvider.HOST_HOST_NAME_PROPERTY_ID);
 
     // reset default host resource provider expectations to none
     reset(hostResourceProvider);
@@ -405,4 +405,4 @@ public class ScaleClusterRequestTest {
 
     return properties;
   }
-}
\ No newline at end of file
+}
