@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,6 +18,23 @@
 
 package org.apache.ambari.server.controller.internal;
 
+import static org.easymock.EasyMock.capture;
+import static org.easymock.EasyMock.expect;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.powermock.api.easymock.PowerMock.createNiceMock;
+import static org.powermock.api.easymock.PowerMock.replay;
+import static org.powermock.api.easymock.PowerMock.verifyAll;
+
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
+
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.controller.StackConfigurationRequest;
@@ -27,41 +44,18 @@ import org.apache.ambari.server.controller.StackServiceComponentRequest;
 import org.apache.ambari.server.controller.StackServiceComponentResponse;
 import org.apache.ambari.server.controller.StackServiceRequest;
 import org.apache.ambari.server.controller.StackServiceResponse;
-import org.apache.ambari.server.state.*;
+import org.apache.ambari.server.state.PropertyDependencyInfo;
 import org.apache.ambari.server.state.PropertyInfo;
+import org.apache.ambari.server.state.ValueAttributesInfo;
 import org.apache.ambari.server.topology.Configuration;
 import org.easymock.Capture;
 import org.easymock.EasyMock;
 import org.easymock.EasyMockSupport;
-import org.hamcrest.CoreMatchers;
-import org.hamcrest.Matcher;
 import org.junit.Test;
-import org.mockito.Matchers;
 
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.Map;
-import java.util.Set;
-
-import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Sets;
 
-import static org.easymock.EasyMock.capture;
-import static org.easymock.EasyMock.expect;
-import static org.easymock.EasyMock.anyObject;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-import static org.powermock.api.easymock.PowerMock.createNiceMock;
-import static org.powermock.api.easymock.PowerMock.replay;
-import static org.powermock.api.easymock.PowerMock.verifyAll;
-
 /**
  * Stack unit tests.
  */
@@ -71,12 +65,12 @@ public class StackTest {
   public void testTestXmlExtensionStrippedOff() throws Exception {
     AmbariManagementController controller = createNiceMock(AmbariManagementController.class);
     AmbariMetaInfo metaInfo = createNiceMock(AmbariMetaInfo.class);
-    Capture<Set<StackServiceRequest>> stackServiceRequestCapture = new Capture<Set<StackServiceRequest>>();
+    Capture<Set<StackServiceRequest>> stackServiceRequestCapture = EasyMock.newCapture();
     StackServiceResponse stackServiceResponse = createNiceMock(StackServiceResponse.class);
-    Capture<Set<StackServiceComponentRequest>> stackComponentRequestCapture = new Capture<Set<StackServiceComponentRequest>>();
+    Capture<Set<StackServiceComponentRequest>> stackComponentRequestCapture = EasyMock.newCapture();
     StackServiceComponentResponse stackComponentResponse = createNiceMock(StackServiceComponentResponse.class);
-    Capture<Set<StackConfigurationRequest>> stackConfigurationRequestCapture = new Capture<Set<StackConfigurationRequest>>();
-    Capture<Set<StackLevelConfigurationRequest>> stackLevelConfigurationRequestCapture = new Capture<Set<StackLevelConfigurationRequest>>();
+    Capture<Set<StackConfigurationRequest>> stackConfigurationRequestCapture = EasyMock.newCapture();
+    Capture<Set<StackLevelConfigurationRequest>> stackLevelConfigurationRequestCapture = EasyMock.newCapture();
     StackConfigurationResponse stackConfigurationResponse = EasyMock.createNiceMock(StackConfigurationResponse.class);
 
     expect(controller.getStackServices(capture(stackServiceRequestCapture))).
@@ -85,8 +79,8 @@ public class StackTest {
     expect(controller.getAmbariMetaInfo()).andReturn(metaInfo).anyTimes();
 
     expect(stackServiceResponse.getServiceName()).andReturn("service1").anyTimes();
-    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.<String>emptySet());
-    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.<String, Map<String,Map<String,String>>>emptyMap());
+    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.emptySet());
+    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.emptyMap());
 
     expect(controller.getStackComponents(capture(stackComponentRequestCapture))).
         andReturn(Collections.singleton(stackComponentResponse)).anyTimes();
@@ -99,18 +93,18 @@ public class StackTest {
 
     // no stack level configs for this test
     expect(controller.getStackLevelConfigurations(capture(stackLevelConfigurationRequestCapture))).
-        andReturn(Collections.<StackConfigurationResponse>emptySet()).anyTimes();
+        andReturn(Collections.emptySet()).anyTimes();
 
     expect(stackConfigurationResponse.getPropertyName()).andReturn("prop1").anyTimes();
     expect(stackConfigurationResponse.getPropertyValue()).andReturn("prop1Val").anyTimes();
     expect(stackConfigurationResponse.getType()).andReturn("test-site.xml").anyTimes();
     expect(stackConfigurationResponse.getPropertyType()).andReturn(
-        Collections.<org.apache.ambari.server.state.PropertyInfo.PropertyType>emptySet()).anyTimes();
-    expect(stackConfigurationResponse.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap()).anyTimes();
+        Collections.emptySet()).anyTimes();
+    expect(stackConfigurationResponse.getPropertyAttributes()).andReturn(Collections.emptyMap()).anyTimes();
     expect(stackConfigurationResponse.isRequired()).andReturn(true).anyTimes();
 
     expect(metaInfo.getComponentDependencies("test", "1.0", "service1", "component1")).
-        andReturn(Collections.<DependencyInfo>emptyList()).anyTimes();
+        andReturn(Collections.emptyList()).anyTimes();
 
 
     replay(controller, stackServiceResponse, stackComponentResponse, stackConfigurationResponse, metaInfo);
@@ -138,13 +132,13 @@ public class StackTest {
   public void testConfigPropertyReadsInDependencies() throws Exception {
     EasyMockSupport mockSupport = new EasyMockSupport();
 
-    Set<PropertyDependencyInfo> setOfDependencyInfo = new HashSet<PropertyDependencyInfo>();
+    Set<PropertyDependencyInfo> setOfDependencyInfo = new HashSet<>();
 
     StackConfigurationResponse mockResponse = mockSupport.createMock(StackConfigurationResponse.class);
     expect(mockResponse.getPropertyName()).andReturn("test-property-one");
     expect(mockResponse.getPropertyValue()).andReturn("test-value-one");
-    expect(mockResponse.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap());
-    expect(mockResponse.getPropertyType()).andReturn(Collections.<PropertyInfo.PropertyType>emptySet());
+    expect(mockResponse.getPropertyAttributes()).andReturn(Collections.emptyMap());
+    expect(mockResponse.getPropertyType()).andReturn(Collections.emptySet());
     expect(mockResponse.getType()).andReturn("test-type-one");
     expect(mockResponse.getDependsOnProperties()).andReturn(setOfDependencyInfo);
     expect(mockResponse.getPropertyValueAttributes()).andReturn(new ValueAttributesInfo());
@@ -166,12 +160,12 @@ public class StackTest {
   public void testGetRequiredProperties_serviceAndPropertyType() throws Exception {
     AmbariManagementController controller = createNiceMock(AmbariManagementController.class);
     AmbariMetaInfo metaInfo = createNiceMock(AmbariMetaInfo.class);
-    Capture<Set<StackServiceRequest>> stackServiceRequestCapture = new Capture<Set<StackServiceRequest>>();
+    Capture<Set<StackServiceRequest>> stackServiceRequestCapture = EasyMock.newCapture();
     StackServiceResponse stackServiceResponse = createNiceMock(StackServiceResponse.class);
-    Capture<Set<StackServiceComponentRequest>> stackComponentRequestCapture = new Capture<Set<StackServiceComponentRequest>>();
+    Capture<Set<StackServiceComponentRequest>> stackComponentRequestCapture = EasyMock.newCapture();
     StackServiceComponentResponse stackComponentResponse = createNiceMock(StackServiceComponentResponse.class);
-    Capture<Set<StackConfigurationRequest>> stackConfigurationRequestCapture = new Capture<Set<StackConfigurationRequest>>();
-    Capture<Set<StackLevelConfigurationRequest>> stackLevelConfigurationRequestCapture = new Capture<Set<StackLevelConfigurationRequest>>();
+    Capture<Set<StackConfigurationRequest>> stackConfigurationRequestCapture = EasyMock.newCapture();
+    Capture<Set<StackLevelConfigurationRequest>> stackLevelConfigurationRequestCapture = EasyMock.newCapture();
     StackConfigurationResponse stackConfigurationResponse = EasyMock.createNiceMock(StackConfigurationResponse.class);
     StackConfigurationResponse stackConfigurationResponse2 = EasyMock.createNiceMock(StackConfigurationResponse.class);
 
@@ -181,8 +175,8 @@ public class StackTest {
     expect(controller.getAmbariMetaInfo()).andReturn(metaInfo).anyTimes();
 
     expect(stackServiceResponse.getServiceName()).andReturn("service1").anyTimes();
-    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.<String>emptySet());
-    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.<String, Map<String,Map<String,String>>>emptyMap());
+    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.emptySet());
+    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.emptyMap());
 
     expect(controller.getStackComponents(capture(stackComponentRequestCapture))).
         andReturn(Collections.singleton(stackComponentResponse)).anyTimes();
@@ -191,19 +185,19 @@ public class StackTest {
     expect(stackComponentResponse.getComponentCategory()).andReturn("test-site.xml").anyTimes();
 
     expect(controller.getStackConfigurations(capture(stackConfigurationRequestCapture))).
-        andReturn(new HashSet<StackConfigurationResponse>(Arrays.asList(
-            stackConfigurationResponse, stackConfigurationResponse2))).anyTimes();
+        andReturn(new HashSet<>(Arrays.asList(
+          stackConfigurationResponse, stackConfigurationResponse2))).anyTimes();
 
     // no stack level configs for this test
     expect(controller.getStackLevelConfigurations(capture(stackLevelConfigurationRequestCapture))).
-        andReturn(Collections.<StackConfigurationResponse>emptySet()).anyTimes();
+        andReturn(Collections.emptySet()).anyTimes();
 
     expect(stackConfigurationResponse.getPropertyName()).andReturn("prop1").anyTimes();
     expect(stackConfigurationResponse.getPropertyValue()).andReturn(null).anyTimes();
     expect(stackConfigurationResponse.getType()).andReturn("test-site.xml").anyTimes();
     expect(stackConfigurationResponse.getPropertyType()).andReturn(
         Collections.singleton(PropertyInfo.PropertyType.PASSWORD)).anyTimes();
-    expect(stackConfigurationResponse.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap()).anyTimes();
+    expect(stackConfigurationResponse.getPropertyAttributes()).andReturn(Collections.emptyMap()).anyTimes();
     expect(stackConfigurationResponse.isRequired()).andReturn(true).anyTimes();
 
     // not a PASSWORD property type so shouldn't be returned
@@ -212,11 +206,11 @@ public class StackTest {
     expect(stackConfigurationResponse2.getType()).andReturn("test-site.xml").anyTimes();
     expect(stackConfigurationResponse2.getPropertyType()).andReturn(
         Collections.singleton(PropertyInfo.PropertyType.USER)).anyTimes();
-    expect(stackConfigurationResponse2.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap()).anyTimes();
+    expect(stackConfigurationResponse2.getPropertyAttributes()).andReturn(Collections.emptyMap()).anyTimes();
     expect(stackConfigurationResponse2.isRequired()).andReturn(true).anyTimes();
 
     expect(metaInfo.getComponentDependencies("test", "1.0", "service1", "component1")).
-        andReturn(Collections.<DependencyInfo>emptyList()).anyTimes();
+        andReturn(Collections.emptyList()).anyTimes();
 
     replay(controller, stackServiceResponse, stackComponentResponse, stackConfigurationResponse,
         stackConfigurationResponse2, metaInfo);
@@ -266,14 +260,14 @@ public class StackTest {
 
     expect(controller.getAmbariMetaInfo()).andReturn(metaInfo).anyTimes();
 
-    expect(controller.getStackServices(anyObject(Set.class))).andReturn(Collections.singleton(stackServiceResponse)).anyTimes();
+    expect(controller.getStackServices(EasyMock.anyObject())).andReturn(Collections.singleton(stackServiceResponse)).anyTimes();
     expect(stackServiceResponse.getServiceName()).andReturn(testServiceName).anyTimes();
-    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.<String>emptySet());
+    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.emptySet());
 
     // stack components
     expect(stackComponentResponse.getComponentName()).andReturn("component1").anyTimes();
     expect(stackComponentResponse.getComponentCategory()).andReturn(testSiteConfigFile).anyTimes();
-    expect(controller.getStackComponents(anyObject(Set.class))).andReturn(Collections.singleton(stackComponentResponse)).anyTimes();
+    expect(controller.getStackComponents(EasyMock.anyObject())).andReturn(Collections.singleton(stackComponentResponse)).anyTimes();
 
     // stack configurations
 
@@ -282,25 +276,25 @@ public class StackTest {
     expect(stackConfigurationResponse1.getPropertyValue()).andReturn(null).anyTimes();
     expect(stackConfigurationResponse1.getType()).andReturn(testSiteConfigFile).anyTimes();
     expect(stackConfigurationResponse1.getPropertyType()).andReturn(Collections.singleton(PropertyInfo.PropertyType.TEXT)).anyTimes();
-    expect(stackConfigurationResponse1.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap()).anyTimes();
+    expect(stackConfigurationResponse1.getPropertyAttributes()).andReturn(Collections.emptyMap()).anyTimes();
     expect(stackConfigurationResponse1.isRequired()).andReturn(true).anyTimes();
 
     expect(stackConfigurationResponse2.getPropertyName()).andReturn("prop2").anyTimes();
     expect(stackConfigurationResponse2.getPropertyValue()).andReturn(null).anyTimes();
     expect(stackConfigurationResponse2.getType()).andReturn(testSiteConfigFile).anyTimes();
     expect(stackConfigurationResponse2.getPropertyType()).andReturn(Collections.singleton(PropertyInfo.PropertyType.USER)).anyTimes();
-    expect(stackConfigurationResponse2.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap()).anyTimes();
+    expect(stackConfigurationResponse2.getPropertyAttributes()).andReturn(Collections.emptyMap()).anyTimes();
     expect(stackConfigurationResponse2.isRequired()).andReturn(true).anyTimes();
 
-    expect(controller.getStackConfigurations(anyObject(Set.class))).andReturn(Sets.newHashSet(stackConfigurationResponse1, stackConfigurationResponse2)).anyTimes();
+    expect(controller.getStackConfigurations(EasyMock.anyObject())).andReturn(Sets.newHashSet(stackConfigurationResponse1, stackConfigurationResponse2)).anyTimes();
 
     // empty stack service config type
-    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.singletonMap(testEmptyConfigType, Collections.<String, Map<String,String>>emptyMap()));
+    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.singletonMap(testEmptyConfigType, Collections.emptyMap()));
 
     // no stack level configs for this test
-    expect(controller.getStackLevelConfigurations(anyObject(Set.class))).andReturn(Collections.<StackConfigurationResponse>emptySet()).anyTimes();
+    expect(controller.getStackLevelConfigurations(EasyMock.anyObject())).andReturn(Collections.emptySet()).anyTimes();
 
-    expect(metaInfo.getComponentDependencies("test", "1.0", "service1", "component1")).andReturn(Collections.<DependencyInfo>emptyList()).anyTimes();
+    expect(metaInfo.getComponentDependencies("test", "1.0", "service1", "component1")).andReturn(Collections.emptyList()).anyTimes();
 
     replay(controller, stackServiceResponse, stackComponentResponse, stackConfigurationResponse1, stackConfigurationResponse2, metaInfo);
 
@@ -335,32 +329,32 @@ public class StackTest {
 
     expect(controller.getAmbariMetaInfo()).andReturn(metaInfo).anyTimes();
 
-    expect(controller.getStackServices(anyObject(Set.class))).andReturn(Collections.singleton(stackServiceResponse)).anyTimes();
+    expect(controller.getStackServices(EasyMock.anyObject())).andReturn(Collections.singleton(stackServiceResponse)).anyTimes();
     expect(stackServiceResponse.getServiceName()).andReturn(testServiceName).anyTimes();
 
     // Config type test-site is excluded for the service service1
-    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.<String>singleton(testSiteConfigType));
+    expect(stackServiceResponse.getExcludedConfigTypes()).andReturn(Collections.singleton(testSiteConfigType));
 
     // stack components
     expect(stackComponentResponse.getComponentName()).andReturn("component1").anyTimes();
     expect(stackComponentResponse.getComponentCategory()).andReturn(testSiteConfigFile).anyTimes();
-    expect(controller.getStackComponents(anyObject(Set.class))).andReturn(Collections.singleton(stackComponentResponse)).anyTimes();
+    expect(controller.getStackComponents(EasyMock.anyObject())).andReturn(Collections.singleton(stackComponentResponse)).anyTimes();
 
     expect(stackConfigurationResponse1.getPropertyName()).andReturn("prop1").anyTimes();
     expect(stackConfigurationResponse1.getPropertyValue()).andReturn(null).anyTimes();
     expect(stackConfigurationResponse1.getType()).andReturn(testSiteConfigFile).anyTimes();
     expect(stackConfigurationResponse1.getPropertyType()).andReturn(Collections.singleton(PropertyInfo.PropertyType.TEXT)).anyTimes();
-    expect(stackConfigurationResponse1.getPropertyAttributes()).andReturn(Collections.<String, String>emptyMap()).anyTimes();
+    expect(stackConfigurationResponse1.getPropertyAttributes()).andReturn(Collections.emptyMap()).anyTimes();
     expect(stackConfigurationResponse1.isRequired()).andReturn(true).anyTimes();
 
-    expect(controller.getStackConfigurations(anyObject(Set.class))).andReturn(Collections.singleton(stackConfigurationResponse1)).anyTimes();
+    expect(controller.getStackConfigurations(EasyMock.anyObject())).andReturn(Collections.singleton(stackConfigurationResponse1)).anyTimes();
 
     // empty stack service config type
-    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.singletonMap(testEmptyConfigType, Collections.<String, Map<String, String>>emptyMap()));
+    expect(stackServiceResponse.getConfigTypes()).andReturn(Collections.singletonMap(testEmptyConfigType, Collections.emptyMap()));
 
     // no stack level configs for this test
-    expect(controller.getStackLevelConfigurations(anyObject(Set.class))).andReturn(Collections.<StackConfigurationResponse>emptySet()).anyTimes();
-    expect(metaInfo.getComponentDependencies("test", "1.0", "service1", "component1")).andReturn(Collections.<DependencyInfo>emptyList()).anyTimes();
+    expect(controller.getStackLevelConfigurations(EasyMock.anyObject())).andReturn(Collections.emptySet()).anyTimes();
+    expect(metaInfo.getComponentDependencies("test", "1.0", "service1", "component1")).andReturn(Collections.emptyList()).anyTimes();
 
     replay(controller, stackServiceResponse, stackComponentResponse, stackConfigurationResponse1, metaInfo);
 
