@@ -31,6 +31,7 @@ import java.util.Set;
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.H2DatabaseCleaner;
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
+import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.ResourceProviderFactory;
 import org.apache.ambari.server.controller.predicate.AndPredicate;
 import org.apache.ambari.server.controller.spi.Predicate;
@@ -73,7 +74,10 @@ public class VersionDefinitionResourceProviderTest {
 
   @Before
   public void before() throws Exception {
-    injector = Guice.createInjector(new InMemoryDefaultTestModule());
+    InMemoryDefaultTestModule module = new InMemoryDefaultTestModule();
+    module.getProperties().put(Configuration.VDF_FROM_FILESYSTEM.getKey(), "true");
+
+    injector = Guice.createInjector(module);
     injector.getInstance(GuiceJpaInitializer.class);
 
     AmbariMetaInfo ami = injector.getInstance(AmbariMetaInfo.class);
