@@ -60,6 +60,8 @@ import org.powermock.api.easymock.PowerMock;
 import org.springframework.security.access.AccessDeniedException;
 import org.springframework.security.core.context.SecurityContextHolder;
 
+import com.google.gson.Gson;
+import com.google.gson.GsonBuilder;
 import com.google.inject.Binder;
 import com.google.inject.Guice;
 import com.google.inject.Injector;
@@ -257,22 +259,18 @@ public class WidgetResourceProviderTest {
     Assert.assertEquals(null, entity.getDefaultSectionName());
     Assert.assertEquals("GAUGE", entity.getWidgetType());
     Assert.assertEquals("admin", entity.getAuthor());
-    Assert.assertEquals("[\n" +
-            "  {\n" +
-            "    \"name\": \"value\",\n" +
-            "    \"name2\": \"value2\"\n" +
-            "  }\n" +
-            "]", entity.getMetrics());
-    Assert.assertEquals("[\n" +
-            "  {\n" +
-            "    \"name\": \"value\",\n" +
-            "    \"name2\": \"value2\"\n" +
-            "  }\n" +
-            "]", entity.getWidgetValues());
-    Assert.assertEquals("{\n" +
-            "  \"property2\": \"value2\",\n" +
-            "  \"property1\": \"value1\"\n" +
-            "}", entity.getProperties());
+
+    Gson gson = new GsonBuilder().setPrettyPrinting().create();
+    String expectedMetrics = gson.toJson(testSet);
+    String expectedWidgetValues = gson.toJson(testSet);
+    Map<String, String> propertiesMap = new HashMap<>();
+    propertiesMap.put("property1", "value1");
+    propertiesMap.put("property2", "value2");
+    String expectedProperties = gson.toJson(propertiesMap);
+
+    Assert.assertEquals(expectedMetrics, entity.getMetrics());
+    Assert.assertEquals(expectedWidgetValues, entity.getWidgetValues());
+    Assert.assertEquals(expectedProperties, entity.getProperties());
 
     verify(amc, clusters, cluster, dao);
   }
@@ -363,12 +361,7 @@ public class WidgetResourceProviderTest {
     Assert.assertFalse(oldName.equals(entity.getWidgetName()));
     Assert.assertFalse(oldMetrics.equals(entity.getMetrics()));
     Assert.assertFalse(oldProperties.equals(entity.getProperties()));
-    Assert.assertEquals("[\n" +
-            "  {\n" +
-            "    \"name\": \"new_value\",\n" +
-            "    \"new_name\": \"new_value2\"\n" +
-            "  }\n" +
-            "]",entity.getMetrics());
+    Assert.assertEquals("[{\"name\":\"new_value\",\"new_name\":\"new_value2\"}]",entity.getMetrics());
     // Depends on hashing, string representation can be different
     Assert.assertTrue(CollectionPresentationUtils.isJsonsEquals("{\"new_property\":\"new_value2\",\"property1\":\"new_value1\"}", entity.getProperties()));
     Assert.assertEquals("widget name2",entity.getWidgetName());
