@@ -491,30 +491,35 @@ public class RestMetricsPropertyProviderTest {
     RestMetricsPropertyProvider restMetricsPropertyProvider = createRestMetricsPropertyProvider(metricDefinition, componentMetrics, streamProvider,
         metricsHostProvider);
 
-    // set the provider timeout to 50 millis
-    restMetricsPropertyProvider.setPopulateTimeout(50L);
+    // set the provider timeout to -1 millis to guarantee timeout
+    restMetricsPropertyProvider.setPopulateTimeout(-1L);
+    try {
+      Resource resource = new ResourceImpl(Resource.Type.HostComponent);
 
-    Resource resource = new ResourceImpl(Resource.Type.HostComponent);
+      resource.setProperty("HostRoles/cluster_name", "c1");
+      resource.setProperty(HOST_COMPONENT_HOST_NAME_PROPERTY_ID, "domu-12-31-39-0e-34-e1.compute-1.internal");
+      resource.setProperty(HOST_COMPONENT_COMPONENT_NAME_PROPERTY_ID, "STORM_REST_API");
 
-    resource.setProperty("HostRoles/cluster_name", "c1");
-    resource.setProperty(HOST_COMPONENT_HOST_NAME_PROPERTY_ID, "domu-12-31-39-0e-34-e1.compute-1.internal");
-    resource.setProperty(HOST_COMPONENT_COMPONENT_NAME_PROPERTY_ID, "STORM_REST_API");
+      resources.add(resource);
 
-    resources.add(resource);
+      // request with an empty set should get all supported properties
+      Request request = PropertyHelper.getReadRequest(Collections.emptySet());
 
-    // request with an empty set should get all supported properties
-    Request request = PropertyHelper.getReadRequest(Collections.emptySet());
+      Set<Resource> resourceSet = restMetricsPropertyProvider.populateResources(resources, request, null);
 
-    Set<Resource> resourceSet = restMetricsPropertyProvider.populateResources(resources, request, null);
+      // make sure that the thread running the stream provider has completed
+      Thread.sleep(150L);
 
-    // make sure that the thread running the stream provider has completed
-    Thread.sleep(150L);
+      Assert.assertEquals(0, resourceSet.size());
 
-    Assert.assertEquals(0, resourceSet.size());
-
-    // assert that properties never get set on the resource
-    Assert.assertNull(resource.getPropertyValue("metrics/api/cluster/summary/tasks.total"));
-    Assert.assertNull(resource.getPropertyValue("metrics/api/cluster/summary/supervisors"));
+      // assert that properties never get set on the resource
+      Assert.assertNull(resource.getPropertyValue("metrics/api/cluster/summary/tasks.total"));
+      Assert.assertNull(resource.getPropertyValue("metrics/api/cluster/summary/supervisors"));
+    } finally {
+      // reset default value
+      restMetricsPropertyProvider.setPopulateTimeout(injector.getInstance(Configuration.class)
+          .getPropertyProvidersCompletionServiceTimeout());
+    }
   }
 
   public static class TestMetricsHostProvider implements MetricHostProvider {
