@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,6 +18,15 @@
 
 package org.apache.ambari.server.orm.entities;
 
+import static org.easymock.EasyMock.createNiceMock;
+
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Properties;
+import java.util.Set;
+
 import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.spi.Resource;
 import org.apache.ambari.server.security.SecurityHelper;
@@ -41,15 +50,6 @@ import org.junit.Assert;
 import org.junit.Test;
 import org.springframework.security.core.GrantedAuthority;
 
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
-
-import static org.easymock.EasyMock.createNiceMock;
-
 /**
  * ViewInstanceEntity tests.
  */
@@ -443,7 +443,7 @@ public class ViewInstanceEntityTest {
   }
 
   public static Set<ViewInstanceEntity> getViewInstanceEntities(ViewEntity viewDefinition) throws Exception {
-    Set<ViewInstanceEntity> entities = new HashSet<ViewInstanceEntity>();
+    Set<ViewInstanceEntity> entities = new HashSet<>();
 
     InstanceConfig instanceConfig = InstanceConfigTest.getInstanceConfigs().get(0);
     entities.add(new ViewInstanceEntity(viewDefinition, instanceConfig));
