@@ -33,7 +33,6 @@ import static org.easymock.EasyMock.verify;
 import static org.powermock.api.easymock.PowerMock.mockStatic;
 
 import java.lang.reflect.Field;
-import java.lang.reflect.Modifier;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -42,6 +41,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.TreeMap;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
@@ -262,8 +262,7 @@ public class TopologyManagerTest {
 
     group1ServiceComponents.put("service1", Arrays.asList("component1", "component3"));
     group1ServiceComponents.put("service2", Collections.singleton("component2"));
-    group2ServiceComponents.put("service2", Collections.singleton("component3"));
-    group2ServiceComponents.put("service2", Collections.singleton("component4"));
+    group2ServiceComponents.put("service2",  Arrays.asList("component3", "component4"));
 
     expect(securityConfiguration.getType()).andReturn(SecurityType.KERBEROS).anyTimes();
 
@@ -408,9 +407,6 @@ public class TopologyManagerTest {
 
     Field controllerField = AmbariContext.class.getDeclaredField("controller");
     controllerField.setAccessible(true);
-    Field modifiersField = Field.class.getDeclaredField("modifiers");
-    modifiersField.setAccessible(true);
-    modifiersField.setInt(controllerField, controllerField.getModifiers() & ~Modifier.FINAL);
     controllerField.set(null, ambariManagementController);
 
   }
@@ -490,7 +486,11 @@ public class TopologyManagerTest {
     expect(ambariContext.isTopologyResolved(CLUSTER_ID)).andReturn(true).anyTimes();
 
     expect(blueprint.getSecurity()).andReturn(securityConfiguration).anyTimes();
+    expect(securityConfiguration.getDescriptor()).andReturn(Optional.empty());
     expect(request.getCredentialsMap()).andReturn(Collections.singletonMap(TopologyManager.KDC_ADMIN_CREDENTIAL, credential));
+    expect(credential.getAlias()).andReturn("").anyTimes();
+    expect(credential.getKey()).andReturn("").anyTimes();
+    expect(credential.getPrincipal()).andReturn("").anyTimes();
 
     bpConfiguration.setProperty(KerberosHelper.KERBEROS_ENV, KerberosHelper.KDC_TYPE, "none");
 
@@ -516,7 +516,11 @@ public class TopologyManagerTest {
     expect(ambariContext.isTopologyResolved(CLUSTER_ID)).andReturn(true).anyTimes();
 
     expect(blueprint.getSecurity()).andReturn(securityConfiguration).anyTimes();
+    expect(securityConfiguration.getDescriptor()).andReturn(Optional.empty());
     expect(request.getCredentialsMap()).andReturn(Collections.singletonMap(TopologyManager.KDC_ADMIN_CREDENTIAL, credential));
+    expect(credential.getAlias()).andReturn("").anyTimes();
+    expect(credential.getKey()).andReturn("").anyTimes();
+    expect(credential.getPrincipal()).andReturn("").anyTimes();
 
     bpConfiguration.setProperty(KerberosHelper.KERBEROS_ENV, KerberosHelper.MANAGE_IDENTITIES, "false");
 
