@@ -69,10 +69,13 @@ var files = [
   'test/controllers/main/admin/stack_and_upgrade_controller_test',
   'test/controllers/main/admin/stack_upgrade_history_controller_test',
   'test/controllers/main/admin/serviceAccounts_controller_test',
+  'test/controllers/main/admin/federation/step1_controller_test',
+  'test/controllers/main/admin/federation/step3_controller_test',
+  'test/controllers/main/admin/federation/step4_controller_test',
+  'test/controllers/main/admin/federation/wizard_controller_test',
   'test/controllers/main/admin/highAvailability_controller_test',
   'test/controllers/main/admin/highAvailability/progress_controller_test',
   'test/controllers/main/admin/highAvailability/progress_popup_controller_test',
-  'test/controllers/main/admin/highAvailability/nameNode/rollback_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step1_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step2_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step3_controller_test',
@@ -83,8 +86,6 @@ var files = [
   'test/controllers/main/admin/highAvailability/nameNode/step8_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step9_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/wizard_controller_test',
-  'test/controllers/main/admin/highAvailability/nameNode/rollbackHA/step2_controller_test',
-  'test/controllers/main/admin/highAvailability/nameNode/rollbackHA/rollback_wizard_controller_test',
   'test/controllers/main/admin/highAvailability/resourceManager/step3_controller_test',
   'test/controllers/main/admin/highAvailability/resourceManager/step4_controller_test',
   'test/controllers/main/admin/highAvailability/resourceManager/wizard_controller_test',
@@ -96,20 +97,16 @@ var files = [
   'test/controllers/main/admin/highAvailability/hawq/removeStandby/wizard_controller_test',
   'test/controllers/main/admin/highAvailability/hawq/activateStandby/step2_controller_test',
   'test/controllers/main/admin/highAvailability/hawq/activateStandby/step3_controller_test',
-  'test/controllers/main/admin/highAvailability/hawq/activateStandby/wizard_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/progress_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/step1_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/step2_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/step3_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/step4_controller_test',
-  'test/controllers/main/admin/highAvailability/journalNode/step5_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/step6_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/step7_controller_test',
   'test/controllers/main/admin/highAvailability/journalNode/wizard_controller_test',
-  'test/controllers/main/admin/highAvailability/rangerAdmin/step1_controller_test',
   'test/controllers/main/admin/highAvailability/rangerAdmin/step3_controller_test',
   'test/controllers/main/admin/highAvailability/rangerAdmin/step4_controller_test',
-  'test/controllers/main/admin/highAvailability/rangerAdmin/wizard_controller_test',
   'test/controllers/main/dashboard/config_history_controller_test',
   'test/controllers/main/charts/heatmap_test',
   'test/controllers/main/charts/heatmap_metrics/heatmap_metric_test',
@@ -119,6 +116,7 @@ var files = [
   'test/controllers/main/host/host_alerts_controller_test',
   'test/controllers/main/host/configs_service_test',
   'test/controllers/main/host/details_test',
+  'test/controllers/main/host/combo_search_box_test',
   'test/controllers/main/host/addHost/step4_controller_test',
   'test/controllers/main/service/add_controller_test',
   'test/controllers/main/service/manage_config_groups_controller_test',
@@ -133,6 +131,7 @@ var files = [
   'test/controllers/main/service/widgets/create/step1_controller_test',
   'test/controllers/main/service/widgets/create/step2_controller_test',
   'test/controllers/main/service/widgets/create/step3_controller_test',
+  'test/controllers/main/service/widgets/edit_controller_test',
   'test/controllers/main/dashboard_test',
   'test/controllers/main/host_test',
   'test/controllers/main/service/item_test',
@@ -167,6 +166,8 @@ var files = [
   'test/mappers/alert_instances_mapper_test',
   'test/mappers/alert_definitions_mapper_test',
   'test/mappers/alert_definition_summary_mapper_test',
+  'test/mappers/alert_notification_mapper_test',
+  'test/mappers/cluster_mapper_test',
   'test/mappers/server_data_mapper_test',
   'test/mappers/hosts_mapper_test',
   'test/mappers/service_mapper_test',
@@ -175,8 +176,10 @@ var files = [
   'test/mappers/users_mapper_test',
   'test/mappers/stack_mapper_test',
   'test/mappers/stack_service_mapper_test',
+  'test/mappers/stack_version_mapper_test',
   'test/mappers/repository_version_mapper_test',
   'test/mappers/stack_upgrade_history_mapper_test',
+  'test/mappers/widget_mapper_test',
   'test/mappers/configs/config_groups_mapper_test',
   'test/mappers/configs/service_config_version_mapper_test',
   'test/mappers/configs/themes_mapper_test',
@@ -211,12 +214,11 @@ var files = [
   'test/mixins/common/persist_test',
   'test/mixins/main/host/details/host_components/decommissionable_test',
   'test/mixins/main/host/details/host_components/install_component_test',
-  'test/mixins/main/service/groups_mapping_test',
-  'test/mixins/main/service/themes_mapping_test',
   'test/mixins/main/service/configs/widget_popover_support_test',
-  'test/mixins/main/service/configs/hive_interactive_check_test',
   'test/mixins/main/service/configs/config_overridable_test',
   'test/mixins/main/service/configs/component_actions_by_configs_test',
+  'test/mixins/main/service/groups_mapping_test',
+  'test/mixins/main/service/themes_mapping_test',
   'test/mixins/routers/redirections_test',
   'test/mixins/wizard/addSeccurityConfigs_test',
   'test/mixins/wizard/assign_master_components_test',
@@ -230,17 +232,18 @@ var files = [
   'test/utils/array_utils_test',
   'test/utils/batch_scheduled_requests_test',
   'test/utils/blueprint_test',
+  'test/utils/chart_utils_test',
   'test/utils/config_test',
   'test/utils/configs_collection_test',
   'test/utils/credentials_test',
   'test/utils/date/date_test',
   'test/utils/date/timezone_test',
   'test/utils/data_manipulation_test',
-  'test/utils/config_test',
   'test/utils/db_test',
   'test/utils/ember_computed_test',
   'test/utils/ember_reopen_test',
-  'test/utils/form_field_test',
+  'test/utils/errors/assertions_test',
+  'test/utils/errors/definitions_test',
   'test/utils/file_utils_test',
   'test/utils/handlebars_helpers_test',
   'test/utils/host_progress_popup_test',
@@ -260,6 +263,12 @@ var files = [
   'test/utils/configs/database_test',
   'test/utils/configs/config_initializer_test',
   'test/utils/configs/add_component_config_initializer_test',
+  'test/utils/configs/move_rm_config_initializer_test',
+  'test/utils/configs/hosts_based_initializer_test',
+  'test/utils/configs/move_hm_config_initializer_test',
+  'test/utils/configs/move_namenode_config_initializer_test',
+  'test/utils/configs/nn_ha_config_initializer_test',
+  'test/utils/configs/rm_ha_config_initializer_test',
   'test/utils/configs/modification_handlers/modification_handler_test',
   'test/utils/configs/modification_handlers/misc_test',
   'test/utils/load_timer_test',
@@ -272,9 +281,14 @@ var files = [
   'test/views/common/configs/widgets/slider_config_widget_view_test',
   'test/views/common/configs/widgets/toggle_config_widget_view_test',
   'test/views/common/helpers/format_word_break_view_test',
+  'test/views/common/helpers/format_null_view_test',
+  'test/views/common/helpers/status_icon_view_test',
+  'test/views/common/helpers/pluralize_view_test',
   'test/views/common/ajax_default_error_popup_body_test',
+  'test/views/common/assign_master_components_view_test',
   'test/views/common/filter_combo_cleanable_test',
   'test/views/common/filter_view_test',
+  'test/views/common/metric_test',
   'test/views/common/pagination_view_test',
   'test/views/common/table_view_test',
   'test/views/common/quick_link_view_test',
@@ -292,6 +306,9 @@ var files = [
   'test/views/common/modal_popups/edit_dashboard_widget_popup_test',
   'test/views/common/modal_popups/hosts_table_list_popup_test',
   'test/views/common/modal_popups/dependent_configs_list_popup_test',
+  'test/views/common/modal_popups/invalid_KDC_popup_test',
+  'test/views/common/modal_popups/manage_kdc_credentials_popup_test',
+  'test/views/common/modal_popups/select_groups_popup_test',
   'test/views/main/admin_test',
   'test/views/main/dashboard_test',
   'test/views/main/menu_test',
@@ -302,12 +319,12 @@ var files = [
   'test/views/main/alerts/manage_alert_notifications_view_test',
   'test/views/main/alerts/definition_details_view_test',
   'test/views/main/alerts/definition_configs_view_test',
+  'test/views/main/alerts/alert_definition/alert_definition_summary_test',
+  'test/views/main/alerts/alert_instances_popup_view_test',
   'test/views/main/alerts/alert_search_box_test',
   'test/views/main/alerts/add_alert_definition/step1_view_test',
   'test/views/main/alerts/add_alert_definition/step3_view_test',
   'test/views/main/alerts/manage_alert_groups/select_definitions_popup_body_view_test',
-  'test/views/main/alerts/alert_definition/alert_definition_state_test',
-  'test/views/main/alerts/alert_definition/alert_definition_summary_test',
   'test/views/main/admin/stack_upgrade/upgrade_version_box_view_test',
   'test/views/main/admin/stack_upgrade/upgrade_version_column_view_test',
   'test/views/main/admin/stack_upgrade/upgrade_group_view_test',
@@ -319,25 +336,30 @@ var files = [
   'test/views/main/admin/stack_upgrade/services_view_test',
   'test/views/main/admin/stack_upgrade/menu_view_test',
   'test/views/main/admin/stack_upgrade/failed_hosts_modal_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/add_metastore_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_atlas_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_components_installation_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_host_version_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_maintenance_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_prev_upgrade_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_service_warning_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_view_test',
+  'test/views/main/admin/stack_upgrade/custom_cluster_checks/custom_services_checks_view_test',
   'test/views/main/admin/service_auto_start_test',
-  'test/controllers/main/admin/federation/step1_controller_test',
-  'test/controllers/main/admin/federation/step3_controller_test',
-  'test/controllers/main/admin/federation/step4_controller_test',
-  'test/controllers/main/admin/federation/wizard_controller_test',
-  'test/views/main/dashboard/cluster_metrics/cpu_test',
   'test/views/main/dashboard/config_history_view_test',
   'test/views/main/dashboard/config_history_search_box_test',
   'test/views/main/dashboard/widget_test',
   'test/views/main/dashboard/widgets_test',
-  'test/views/main/dashboard/widgets/flume_agent_live_test',
-  'test/views/main/dashboard/widgets/hbase_master_heap_test',
-  'test/views/main/dashboard/widgets/hbase_links_test',
-  'test/views/main/dashboard/widgets/hdfs_capacity_test',
-  'test/views/main/dashboard/widgets/hdfs_links_test',
   'test/views/main/dashboard/widgets/text_widget_test',
   'test/views/main/dashboard/widgets/text_widget_single_threshold_test',
   'test/views/main/dashboard/widgets/uptime_text_widget_test',
   'test/views/main/dashboard/widgets/node_managers_live_test',
+  'test/views/main/dashboard/widgets/flume_agent_live_test',
+  'test/views/main/dashboard/widgets/hbase_master_heap_test',
+  'test/views/main/dashboard/widgets/namenode_heap_test',
+  'test/views/main/dashboard/widgets/resource_manager_heap_test',
+  'test/views/main/dashboard/widgets/supervisor_live_test',
+  'test/views/main/dashboard/widgets/hbase_links_test',
   'test/views/main/dashboard/widgets/datanode_live_test',
   'test/views/main/dashboard/widgets/hawqsegment_live_test',
   'test/views/main/dashboard/widgets/pxf_live_test',
@@ -347,12 +369,7 @@ var files = [
   'test/views/main/dashboard/widgets/links_widget_test',
   'test/views/main/dashboard/widgets/pie_chart_widget_test',
   'test/views/main/dashboard/widgets/namenode_cpu_test',
-  'test/views/main/dashboard/widgets/namenode_heap_test',
-  'test/views/main/dashboard/widgets/supervisor_live_test',
-  'test/views/main/dashboard/widgets/resource_manager_heap_test',
   'test/views/main/dashboard/widgets/cluster_metrics_widget_test',
-  'test/views/main/dashboard/widgets/yarn_containers_test',
-  'test/views/main/dashboard/widgets/yarn_memory_test',
   'test/views/main/host/details_test',
   'test/views/main/host/summary_test',
   'test/views/main/host/menu_test',
@@ -372,15 +389,15 @@ var files = [
   'test/views/main/host/details/host_component_views/regionserver_view_test',
   'test/views/main/host/details/host_component_views/tasktracker_view_test',
   'test/views/main/host/metrics/disk_test',
-  'test/views/main/host/metrics/cpu_test',
-  'test/views/main/host/metrics/load_test',
-  'test/views/main/host/metrics/memory_test',
-  'test/views/main/host/metrics/network_test',
-  'test/views/main/host/metrics/processes_test',
   'test/views/main/charts/heatmap_test',
   'test/views/main/charts/heatmap/heatmap_host_test',
   'test/views/main/service/item_test',
-  'test/views/main/service/manage_config_groups_view_test',
+  'test/views/main/service/reassign/step1_view_test',
+  'test/views/main/service/reassign/step2_view_test',
+  'test/views/main/service/reassign/step3_view_test',
+  'test/views/main/service/reassign/step4_view_test',
+  'test/views/main/service/reassign/step5_view_test',
+  // 'test/views/main/service/manage_config_groups_view_test',
   'test/views/main/service/reassign_view_test',
   'test/views/main/service/reconfigure_test',
   'test/views/main/service/service_test',
@@ -391,39 +408,18 @@ var files = [
   'test/views/main/service/info/component_list_view_test',
   'test/views/main/service/info/metrics/ambari_metrics/regionserver_base_test',
   'test/views/main/service/info/metrics/flume/flume_agent_metrics_section_test',
-  'test/views/main/service/info/metrics/flume/channel_fill_pct_test',
-  'test/views/main/service/info/metrics/flume/channel_size_test',
-  'test/views/main/service/info/metrics/flume/channel_size_mma_test',
-  'test/views/main/service/info/metrics/flume/channel_sum_test',
-  'test/views/main/service/info/metrics/flume/cpu_user_test',
-  'test/views/main/service/info/metrics/flume/flume_incoming_mma_test',
-  'test/views/main/service/info/metrics/flume/flume_incoming_sum_test',
   'test/views/main/service/info/metrics/flume/flume_metric_graph_test',
   'test/views/main/service/info/metrics/flume/flume_metric_graphs_test',
-  'test/views/main/service/info/metrics/flume/flume_outgoing_mma_test',
-  'test/views/main/service/info/metrics/flume/flume_outgoing_sum_test',
-  'test/views/main/service/info/metrics/flume/gc_test',
-  'test/views/main/service/info/metrics/flume/jvm_heap_test',
-  'test/views/main/service/info/metrics/flume/jvm_threads_runnable_test',
-  'test/views/main/service/info/metrics/flume/sink_connection_failed_test',
-  'test/views/main/service/info/metrics/flume/sink_drain_success_test',
-  'test/views/main/service/info/metrics/flume/source_accepted_test',
-  'test/views/main/service/info/summary/hdfs/common_widgets_test',
   'test/views/main/service/info/summary/hdfs/slaves_test',
   'test/views/main/service/info/summary/hdfs/widgets_test',
-  'test/views/main/service/reassign/step1_view_test',
-  'test/views/main/service/reassign/step2_view_test',
-  'test/views/main/service/reassign/step3_view_test',
-  'test/views/main/service/reassign/step4_view_test',
-  'test/views/main/service/reassign/step5_view_test',
   'test/views/main/service/services/hdfs_test',
   'test/views/main/service/services/hbase_test',
   'test/views/main/service/services/ranger_test',
   'test/views/main/service/services/storm_test',
   'test/views/main/service/services/yarn_test',
   'test/views/main/service/services/hive_test',
-  'test/views/main/service/services/onefs_test',
   'test/views/main/service/services/mapreduce2_test',
+  'test/views/main/service/services/onefs_test',
   'test/views/main/service/services/zookeeper_test',
   'test/views/main/service/services/flume_test',
   'test/views/main/service/widgets/create/expression_view_test',
@@ -440,18 +436,14 @@ var files = [
   'test/views/main/admin/highAvailability/resourceManager/wizard_view_test',
   'test/views/main/admin/highAvailability/nameNode/wizard_view_test',
   'test/views/main/admin/highAvailability/progress_view_test',
-  'test/views/main/admin/highAvailability/nameNode/rollbackHA/step1_view_test',
-  'test/views/main/admin/highAvailability/nameNode/rollbackHA/step2_view_test',
-  'test/views/main/admin/highAvailability/nameNode/rollbackHA/rollback_wizard_view_test',
+  'test/views/main/admin/highAvailability/journalNode/progress_view_test',
   'test/views/main/admin/highAvailability/journalNode/step2_view_test',
   'test/views/main/admin/highAvailability/journalNode/step3_view_test',
   'test/views/main/admin/highAvailability/journalNode/step5_view_test',
-  'test/views/main/admin/highAvailability/journalNode/progress_view_test',
-  'test/views/main/admin/kerberos/progress_view_test',
-  'test/views/main/admin/kerberos/disable_view_test',
-  'test/views/main/admin/kerberos/step1_view_test',
-  'test/views/main/admin/kerberos/step3_view_test',
   'test/views/common/host_progress_popup_body_view_test',
+  'test/views/common/configs/config_category_container_view_test',
+  'test/views/common/configs/service_config_layout_tab_compare_view_test',
+  'test/views/common/configs/service_config_layout_tab_view_test',
   'test/views/common/configs/config_versions_control_view_test',
   'test/views/common/configs/config_versions_dropdown_view_test',
   'test/views/common/configs/overriddenProperty_view_test',
@@ -460,10 +452,18 @@ var files = [
   'test/views/common/configs/service_configs_by_category_view_test',
   'test/views/common/configs/custom_category_views/notification_configs_view_test',
   'test/views/common/controls_view_test',
+  'test/views/common/editable_list_test',
   'test/views/common/configs/widgets/time_interval_spinner_view_test',
   'test/views/common/form/spinner_input_view_test',
+  'test/views/common/form/datepicker_view_test',
+  'test/views/common/form/dropdown_view_test',
+  'test/views/common/form/field_view_test',
   'test/views/common/form/manage_kdc_credentials_form_test',
   'test/views/common/log_file_search_view_test',
+  'test/views/common/log_search_ui_link_view_test',
+  'test/views/common/log_tail_view_test',
+  'test/views/common/not-scrollable-textarea_test',
+  'test/views/common/service_restart_view_test',
   'test/views/common/search_box_view_test',
   'test/views/wizard/step3/hostLogPopupBody_view_test',
   'test/views/wizard/step3/hostWarningPopupBody_view_test',
@@ -481,12 +481,14 @@ var files = [
   'test/views/wizard/step9/hostLogPopupBody_view_test',
   'test/views/wizard/step7/assign_master_view_test',
   'test/views/wizard/step7/accounts_tab_view_test',
-  'test/views/wizard/step7/directories_tab_view_test',
   'test/views/wizard/step7/credentials_tab_view_test',
+  'test/views/wizard/step7/databases_tab_view_test',
+  'test/views/wizard/step7/directories_tab_view_test',
   'test/views/wizard/step10_view_test',
   'test/views/application_test',
   'test/views/installer_test',
   'test/views/login_test',
+  'test/views/main/cluster_metrics/cpu_test',
   'test/models/service/flume_test',
   'test/models/service/hdfs_test',
   'test/models/service/yarn_test',
@@ -495,18 +497,15 @@ var files = [
   'test/models/alerts/alert_group_test',
   'test/models/alerts/alert_instance_test',
   'test/models/alerts/alert_notification_test',
-  'test/models/authentication_test',
   'test/models/client_component_test',
   'test/models/cluster_states_test',
   'test/models/cluster_test',
-  'test/models/form_test',
   'test/models/host_test',
   'test/models/host_component_test',
   'test/models/hosts_test',
   'test/models/master_component_test',
   'test/models/operating_system_test',
   'test/models/repository_test',
-  'test/models/root_service_test',
   'test/models/stack_service_component_test',
   'test/models/service_test',
   'test/models/slave_component_test',
@@ -575,6 +574,9 @@ describe('Ambari Web Unit tests', function() {
     });
     sinon.stub(App.updater, 'run', Em.K);
     sinon.stub(App.updater, 'immediateRun', Em.K);
+    sinon.stub(App.ModalPopup, 'show', function (options) {
+      return this.create(options);
+    });
   });
 
   afterEach(function () {
@@ -582,11 +584,18 @@ describe('Ambari Web Unit tests', function() {
     $.ajax.restore();
     App.updater.run.restore();
     App.updater.immediateRun.restore();
+    App.ModalPopup.show.restore();
   });
 
   files.forEach(function (file) {
     describe(file, function() {
-      require(file);
+      try {
+        require(file);
+      } catch (error) {
+        it('Execution of test suite was terminated', function () {
+          throw error;
+        });
+      }
     });
   });
 
