@@ -102,7 +102,7 @@ App.ClusterController = Em.Controller.extend(App.ReloadPopupMixin, {
   loadClusterName: function (reload, deferred) {
     var dfd = deferred || $.Deferred();
 
-    if (App.get('clusterName') && !reload) {
+    if (App.get('clusterName') && App.get('clusterId') && !reload) {
       App.set('clusterName', this.get('clusterName'));
       this.set('isClusterNameLoaded', true);
       dfd.resolve();
@@ -378,13 +378,6 @@ App.ClusterController = Em.Controller.extend(App.ReloadPopupMixin, {
     return "ABORTED" === status;
   },
 
-  loadRootService: function () {
-    return App.ajax.send({
-      name: 'service.ambari',
-      sender: this
-    });
-  },
-
   requestHosts: function (realUrl, callback) {
     var testHostUrl = '/data/hosts/HDP2/hosts.json';
     var url = this.getUrl(testHostUrl, realUrl);
