@@ -685,10 +685,11 @@ App.UpdateController = Em.Controller.extend({
   },
 
   configsChangedHandler: function(event) {
-    if (event.configs && event.configs.someProperty('type', 'cluster-env')) {
-      this.updateClusterEnv();
-    }
-    App.router.get('configurationController').updateConfigTags();
+    App.router.get('configurationController').updateConfigTags().always(() => {
+      if (event.configs && event.configs.someProperty('type', 'cluster-env')) {
+        this.updateClusterEnv();
+      }
+    });
   },
 
   //TODO - update service auto-start to use this
@@ -710,7 +711,7 @@ App.UpdateController = Em.Controller.extend({
   },
 
   updateWizardWatcher: function(callback) {
-    App.router.get('wizardWatcherController').getUser().complete(callback);
+    App.router.get('wizardWatcherController').getUser().then(callback);
   },
 
   /**
