@@ -144,7 +144,7 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
     var self = this;
     var stackServices = App.StackService.find().mapProperty('serviceName');
     if (!(stackServices.length && App.StackService.find().objectAt(0).get('stackVersion') === App.get('currentStackVersionNumber'))) {
-      this.loadServiceComponents().complete(function () {
+      this.loadServiceComponents().then(function () {
         self.set('content.services', App.StackService.find().forEach(function (item) {
           // user the service version from VersionDefinition
           var serviceInStack = App.Stack.find().findProperty('isSelected').get('stackServices').findProperty('name', item.get('serviceName'));
@@ -239,7 +239,7 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
         sender: this,
         success: 'loadStacksSuccessCallback',
         error: 'loadStacksErrorCallback'
-      }).complete(function () {
+      }).then(function () {
         dfd.resolve(false);
       });
     }
@@ -308,15 +308,22 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
     if (!data.items || !data.items.length) {
       this.setSelected(true, params.dfd);
     }
-    data.items.sortProperty('VersionDefinition.stack_version').reverse().forEach(function (versionDefinition) {
-      // to display repos panel, should map all available operating systems including empty ones
-      var stackInfo = {};
-      stackInfo.isStacksExistInDb = isStacksExistInDb;
-      stackInfo.stacks = stacks;
-      stackInfo.oses = oses;
-      stackInfo.repos = repos;
-      this.getSupportedOSList(versionDefinition, stackInfo, params.dfd);
-    }, this);
+    // if data.items is empty, we show error modal end return to back step
+    if (data.items && data.items.length) {
+      data.items.sortProperty('VersionDefinition.stack_version').reverse().forEach(function (versionDefinition) {
+        // to display repos panel, should map all available operating systems including empty ones
+        var stackInfo = {};
+        stackInfo.isStacksExistInDb = isStacksExistInDb;
+        stackInfo.stacks = stacks;
+        stackInfo.oses = oses;
+        stackInfo.repos = repos;
+        this.getSupportedOSList(versionDefinition, stackInfo, params.dfd);
+      }, this);
+    } else {
+      App.showAlertPopup(Em.I18n.t('common.error'), Em.I18n.t('installer.step1.noVersionDefinitions'), function() {
+        App.router.send('back');
+      });
+    }
   },
 
   mergeChanges: function (repos, oses, stacks) {
@@ -681,7 +688,7 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
     var body = '';
     if(request && request.responseText) {
       try {
-        var json = $.parseJSON(request.responseText);
+        var json = JSON.parse(request.responseText);
         body = json.message;
       } catch (err) {}
     }
@@ -706,6 +713,23 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
     });
   },
 
+  showStackErrorAndSkipStepIfNeeded: function (response) {
+    var stackName = response.Versions.stack_name;
+    var stackVersion = response.Versions.stack_version;
+    var header = Em.I18n.t('installer.step1.useLocalRepo.getSurpottedOs.stackError.title').format(stackName, stackVersion);
+    var body = response.Versions['stack-errors'].join('. ');
+    this.decrementProperty('loadStacksRequestsCounter');
+    App.showAlertPopup(header, body);
+    if (this.get('loadStacksRequestsCounter') === 0 && !App.Stack.find().toArray().length) {
+      var wizardStep0Controller = App.router.get('wizardStep0Controller');
+      wizardStep0Controller.set('hasNotStacksAvailable', true);
+      App.router.send('gotoStep' + 0);
+      var installationErrorHeader = Em.I18n.t('installer.step1.useLocalRepo.getSurpottedOs.noStacksError.title');
+      var installationErrorBody = Em.I18n.t('installer.step1.useLocalRepo.getSurpottedOs.noStacksError.body');
+      App.showAlertPopup(installationErrorHeader, installationErrorBody);
+    }
+  },
+
   /**
    * onSuccess callback for getSupportedOSList.
    */
@@ -718,19 +742,38 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
       existedOS.isSelected = true;
       existedMap[existedOS.OperatingSystems.os_type] = existedOS;
     });
+    if (response.Versions && response.Versions['stack-errors'] && response.Versions['stack-errors'].length) {
+      this.showStackErrorAndSkipStepIfNeeded(response);
+      return;
+    }
     response.operating_systems.forEach(function(supportedOS) {
       if(!existedMap[supportedOS.OperatingSystems.os_type]) {
         supportedOS.isSelected = false;
         existedOS.push(supportedOS);
       } else {
-        existedMap[supportedOS.OperatingSystems.os_type].repositories.forEach(function (repo) {
-          supportedOS.repositories.forEach(function (supportedRepo) {
-            if (supportedRepo.Repositories.repo_id == repo.Repositories.repo_id) {
-              repo.Repositories.components = supportedRepo.Repositories.components;
-              repo.Repositories.distribution = supportedRepo.Repositories.distribution;
-            }
+        if (stack_default) { // only overwrite if it is stack default, otherwise use url from /version_definition
+          existedMap[supportedOS.OperatingSystems.os_type].repositories.forEach(function (repo) {
+            supportedOS.repositories.forEach(function (supportedRepo) {
+              if (supportedRepo.Repositories.repo_id == repo.Repositories.repo_id) {
+                repo.Repositories.base_url = supportedRepo.Repositories.base_url;
+                repo.Repositories.default_base_url = supportedRepo.Repositories.default_base_url;
+                repo.Repositories.latest_base_url = supportedRepo.Repositories.latest_base_url;
+                repo.Repositories.components = supportedRepo.Repositories.components;
+                repo.Repositories.distribution = supportedRepo.Repositories.distribution;
+              }
+            });
           });
-        });
+        }
+        else{
+          existedMap[supportedOS.OperatingSystems.os_type].repositories.forEach(function (repo) {
+            supportedOS.repositories.forEach(function (supportedRepo) {
+              if (supportedRepo.Repositories.repo_id == repo.Repositories.repo_id) {
+                repo.Repositories.components = supportedRepo.Repositories.components;
+                repo.Repositories.distribution = supportedRepo.Repositories.distribution;
+              }
+            });
+          });
+        }
       }
     });
 
@@ -766,7 +809,7 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
     var body = "";
     if(request && request.responseText){
       try {
-        var json = $.parseJSON(request.responseText);
+        var json = JSON.parse(request.responseText);
         body = json.message;
       } catch (err) {}
     }
@@ -865,6 +908,7 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
               this.set('content.isCheckInProgress', true);
               App.ajax.send({
                 name: 'wizard.advanced_repositories.valid_url',
+                dataType:'text',
                 sender: this,
                 data: {
                   stackName: stackName,
@@ -922,7 +966,10 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
       var repo = os.get('repositories').findProperty('repoId', params.repoId);
       if (repo) {
         var title = Ember.Handlebars.Utils.escapeExpression(request.status + ":" + request.statusText);
-        var content =  Ember.Handlebars.Utils.escapeExpression($.parseJSON(request.responseText) ? $.parseJSON(request.responseText).message : "");
+        var content = "";
+        try {
+          content = JSON.parse(request.responseText);
+        } catch (error) {}
         repo.setProperties({
           validation: 'INVALID',
           errorTitle: title,
@@ -1032,7 +1079,7 @@ App.InstallerController = App.WizardController.extend(App.Persist, {
           this.loadCurrentHostGroups();
           this.loadRecommendationsConfigs();
           this.loadComponentsFromConfigs();
-          this.loadConfigThemes().then(function() {
+          this.loadConfigThemes().done(function() {
             self.loadServiceConfigProperties();
             dfd.resolve();
           });
