@@ -142,6 +142,28 @@ App.MainAdminHighAvailabilityController = App.WizardController.extend({
     return true;
   },
 
+  /**
+   * enable router Based Federation
+   * @return {Boolean}
+   */
+  enableRouterFederation: function () {
+    //Prerequisite Checks
+    var message = [];
+    if (!App.HostComponent.find().filterProperty('componentName', 'ZOOKEEPER_SERVER').everyProperty('workStatus', 'STARTED')) {
+      message.push(Em.I18n.t('admin.nameNodeFederation.wizard.required.zookeepers'));
+    }
+
+    if (!App.HostComponent.find().filterProperty('componentName', 'JOURNALNODE').everyProperty('workStatus', 'STARTED')) {
+      message.push(Em.I18n.t('admin.nameNodeFederation.wizard.required.journalnodes'));
+    }
+    if (message.length > 0) {
+      this.showErrorPopup(message);
+      return false;
+    }
+    App.router.transitionTo('main.services.enableRouterFederation');
+    return true;
+  },
+
   /**
    * open Manage JournalNode Wizard if there are two started NameNodes with defined active/standby state
    * @returns {boolean}
