@@ -359,7 +359,7 @@ App.KerberosWizardStep4Controller = App.WizardStep7Controller.extend(App.AddSecu
   loadRecommendationsError: function(req, ajaxOpts, error, opt) {
     var resp;
     try {
-      resp = $.parseJSON(req.responseText);
+      resp = JSON.parse(req.responseText);
     } catch (e) { }
     return App.ModalPopup.show({
       header: Em.I18n.t('common.error'),
