@@ -773,6 +773,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     return App.ajax.send({
       name: 'admin.upgrade.abort',
       sender: this,
+      dataType:'text',
       data: {
         upgradeId: this.get('upgradeId'),
         isDowngrade: this.get('isDowngrade')
@@ -811,6 +812,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     return App.ajax.send({
       name: 'admin.upgrade.suspend',
       sender: this,
+      dataType:'text',
       data: {
         upgradeId: this.get('upgradeId'),
         isDowngrade: this.get('isDowngrade')
@@ -828,7 +830,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     var body = Em.I18n.t('admin.stackUpgrade.state.paused.fail.body');
     if (data && data.responseText) {
       try {
-        var json = $.parseJSON(data.responseText);
+        var json = JSON.parse(data.responseText);
         body = body + ' ' + json.message;
       } catch (err) {}
     }
@@ -844,7 +846,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     var body = Em.I18n.t('admin.stackDowngrade.state.paused.fail.body');
     if(data && data.responseText){
       try {
-        var json = $.parseJSON(data.responseText);
+        var json = JSON.parse(data.responseText);
         body = body + ' ' + json.message;
       } catch (err) {}
     }
@@ -896,7 +898,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
    */
   showPreparingUpgradeIndicator: function () {
     return App.ModalPopup.show({
-      header: '',
+      header: Em.I18n.t('admin.stackUpgrade.dialog.prepareUpgrade.header'),
       showFooter: false,
       showCloseButton: false,
       bodyClass: Em.View.extend({
@@ -910,12 +912,6 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
         barWidth: 'width: 100%;',
         progressBarClass: 'progress log_popup',
 
-        /**
-         * Popup-message
-         * @type {string}
-         */
-        message: Em.I18n.t('admin.stackUpgrade.dialog.prepareUpgrade.header'),
-
         /**
          * Hide popup when upgrade wizard is open
          * @method autoHide
@@ -938,7 +934,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     var body = "";
     if (data && data.responseText) {
       try {
-        var json = $.parseJSON(data.responseText);
+        var json = JSON.parse(data.responseText);
         body = json.message;
       } catch (err) {}
     }
@@ -1037,12 +1033,14 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
       var configsMergeCheckData = Em.get(configsMergeWarning, 'UpgradeChecks.failed_detail');
       if (configsMergeCheckData && Em.isArray(configsMergeCheckData)) {
         configs = configsMergeCheckData.reduce(function (allConfigs, item) {
-          var isDeprecated = Em.isNone(item.new_stack_value),
-            willBeRemoved = Em.isNone(item.result_value);
+          const isDeprecated = Em.isNone(item.new_stack_value),
+                willBeRemoved = Em.isNone(item.result_value),
+                configInfo = App.configsCollection.getConfigByName(item.property, item.type) || {};
 
           return allConfigs.concat({
             type: item.type,
             name: item.property,
+            serviceName: configInfo.serviceName,
             wasModified: (!isDeprecated && !willBeRemoved && Em.compare(item.current, item.result_value) === 0),
             currentValue: item.current,
             recommendedValue: isDeprecated ? Em.I18n.t('popup.clusterCheck.Upgrade.configsMerge.deprecated') : item.new_stack_value,
@@ -1091,7 +1089,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
       this.set('isUpgradeTypesLoaded', true);
     }
 
-    return App.ModalPopup.show({
+    const modal = App.ModalPopup.show({
       encodeBody: false,
       primary: function() {
         if ( preUpgradeShow ) return false;
@@ -1160,6 +1158,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
           self.runPreUpgradeCheckOnly({
             id: version.get('id'),
             label: version.get('displayName'),
+            id: version.get('id'),
             type: event.context.get('type')
           });
         },
@@ -1196,8 +1195,12 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
               self.runPreUpgradeCheckOnly.call(self, {
                 id: version.get('id'),
                 label: version.get('displayName'),
+                id: version.get('id'),
                 type: event.context.get('type')
               });
+            },
+            closeParent: function() {
+              modal.onClose();
             }
           }, configs);
         },
@@ -1257,6 +1260,8 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
         }
       }
     });
+
+    return modal;
   },
 
   /**
@@ -1763,7 +1768,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
 
         App.ajax.send({
           name: 'admin.stack_versions.edit.repo',
-          sender: this,
+          sender: self,
           data: {
             stackName: App.get('currentStackName'),
             stackVersion: stackVersionNumber,
@@ -1827,6 +1832,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     return App.ajax.send({
       name: 'admin.stack_versions.validate.repo',
       sender: this,
+      dataType:'text',
       data: {
         repo: repo,
         repoName: repo.get('repoName'),
@@ -1875,7 +1881,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     var body = "";
     if (data && data.responseText) {
       try {
-        var json = $.parseJSON(data.responseText);
+        var json = JSON.parse(data.responseText);
         body = json.message;
       } catch (err) {}
     }
@@ -2050,6 +2056,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     return App.ajax.send({
       name: 'admin.upgrade.upgradeItem.setState',
       sender: this,
+      dataType:'text',
       data: {
         upgradeId: item.get('request_id'),
         itemId: item.get('stage_id'),
@@ -2300,6 +2307,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
 
     output += '<table style="text-align: left;"><thead><tr>' +
         '<th>' + Em.I18n.t('popup.clusterCheck.Upgrade.configsMerge.configType') + '</th>' +
+        '<th>' + Em.I18n.t('popup.clusterCheck.Upgrade.configsMerge.serviceName') + '</th>' +
         '<th>' + Em.I18n.t('popup.clusterCheck.Upgrade.configsMerge.propertyName') + '</th>' +
         '<th>' + Em.I18n.t('popup.clusterCheck.Upgrade.configsMerge.currentValue') + '</th>' +
         '<th>' + Em.I18n.t('popup.clusterCheck.Upgrade.configsMerge.recommendedValue') + '</th>' +
@@ -2309,6 +2317,7 @@ App.MainAdminStackAndUpgradeController = Em.Controller.extend(App.LocalStorage,
     configs.context.forEach(function (config) {
       output += '<tr>' +
           '<td>' + config.type + '</td>' +
+          '<td>' + App.format.role(config.serviceName) + '</td>' +
           '<td>' + config.name + '</td>' +
           '<td>' + config.currentValue + '</td>' +
           '<td>' + config.recommendedValue + '</td>' +
