@@ -193,7 +193,7 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
     this.set('serviceToInstall', null);
     this.set('content.services', stackServices);
     var self = this;
-    this.loadServiceVersionFromVersionDefinitions().complete(function () {
+    this.loadServiceVersionFromVersionDefinitions().then(function () {
       var serviceVersionsMap = self.get('serviceVersionsMap');
       stackServices.forEach(function (stackService) {
         var serviceName = stackService.get('serviceName');
@@ -286,8 +286,11 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
    */
   skipConfigStep: function () {
     var skipConfigStep = true;
-    var selectedServices = this.get('content.services').filterProperty('isSelected', true).filterProperty('isInstalled', false).mapProperty('serviceName');
-    selectedServices.map(function (serviceName) {
+    this.get('content.services')
+      .filterProperty('isSelected', true)
+      .filterProperty('isInstalled', false)
+      .mapProperty('serviceName')
+      .map(function (serviceName) {
       skipConfigStep = skipConfigStep && this.isServiceNotConfigurable(serviceName);
     }, this);
     return skipConfigStep;
@@ -367,9 +370,12 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
    */
   saveClients: function () {
     var clients = [];
-    var serviceComponents = App.StackServiceComponent.find();
-    this.get('content.services').filterProperty('isSelected').filterProperty('isInstalled',false).forEach(function (_service) {
-      var serviceClients = serviceComponents.filterProperty('serviceName', _service.get('serviceName')).filterProperty('isClient');
+    var clientComponents = App.StackServiceComponent.find().filterProperty('isClient');
+    this.get('content.services')
+    .filterProperty('isSelected')
+    .filterProperty('isInstalled', false)
+    .forEach(function (_service) {
+      var serviceClients = clientComponents.filterProperty('serviceName', _service.get('serviceName'));
       serviceClients.forEach(function (client) {
         clients.push({
           component_name: client.get('componentName'),
@@ -439,10 +445,9 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
    * @method installServices
    */
   installServices: function (callback) {
-    var self = this;
     this.set('content.cluster.oldRequestsId', []);
-    this.installAdditionalClients().done(function () {
-      self.installSelectedServices(callback);
+    this.installAdditionalClients().done(() => {
+      this.installSelectedServices(callback);
     });
   },
 
@@ -452,11 +457,10 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
    * @method installSelectedServices
    */
   installSelectedServices: function (callback) {
-    var name = 'common.services.update';
-    var selectedServices = this.get('content.services').filterProperty('isInstalled', false).filterProperty('isSelected', true).mapProperty('serviceName');
+    var selectedServices = this.get('content.services').filterProperty('isInstalled', false).filterProperty('isSelected').mapProperty('serviceName');
     var dependentServices = this.getServicesBySelectedSlaves();
     var data = this.generateDataForInstallServices(selectedServices.concat(dependentServices));
-    this.installServicesRequest(name, data, callback.bind(this));
+    this.installServicesRequest('common.services.update', data, callback.bind(this));
   },
 
   installServicesRequest: function (name, data, callback) {
@@ -475,11 +479,11 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
    * @returns {Array}
    */
   getServicesBySelectedSlaves: function () {
-    var result = [];
+    const result = [];
     this.get('content.slaveComponentHosts').forEach(function (slaveComponent) {
       if (slaveComponent.hosts.someProperty('isInstalled', false)) {
-        var stackComponent = App.StackServiceComponent.find().findProperty('componentName', slaveComponent.componentName);
-        if (stackComponent) {
+        const stackComponent = App.StackServiceComponent.find(slaveComponent.componentName);
+        if (stackComponent.get('isLoaded')) {
           result.push(stackComponent.get('serviceName'));
         }
       }
@@ -496,14 +500,13 @@ App.AddServiceController = App.WizardController.extend(App.AddSecurityConfigs, {
     var dfd = $.Deferred();
     var count = 0;
     if (this.get('content.additionalClients.length') > 0) {
-      this.get('content.additionalClients').forEach(function (c) {
+      this.get('content.additionalClients').forEach((c) => {
         if (c.hostNames.length > 0) {
-          var queryStr = 'HostRoles/component_name='+ c.componentName + '&HostRoles/host_name.in(' + c.hostNames.join() + ')';
           this.get('installClietsQueue').addRequest({
             name: 'common.host_component.update',
             sender: this,
             data: {
-              query: queryStr,
+              query: 'HostRoles/component_name='+ c.componentName + '&HostRoles/host_name.in(' + c.hostNames.join() + ')',
               context: 'Install ' + App.format.role(c.componentName, false),
               HostRoles: {
                 state: 'INSTALLED'
