@@ -117,6 +117,15 @@ App.ReassignMasterWizardStep3Controller = Em.Controller.extend({
         }
       }
     },
+    {
+      componentName: 'TIMELINE_READER',
+      configs: {
+        'yarn-site': {
+          'yarn.timeline-service.reader.webapp.address': '<replace-value>:8198',
+          'yarn.timeline-service.reader.webapp.https.address': '<replace-value>:8199'
+        }
+      }
+    },
     {
       componentName: 'OOZIE_SERVER',
       configs: {
@@ -317,7 +326,9 @@ App.ReassignMasterWizardStep3Controller = Em.Controller.extend({
     var urlParams = [];
 
     this.get('wizardController.serviceToConfigSiteMap')[componentName].forEach(function(site){
-      urlParams.push('(type=' + site + '&tag=' + data.Clusters.desired_configs[site].tag + ')');
+      if (data.Clusters.desired_configs[site]) {
+        urlParams.push('(type=' + site + '&tag=' + data.Clusters.desired_configs[site].tag + ')');
+      }
     });
 
     // specific cases for certain components
@@ -360,13 +371,14 @@ App.ReassignMasterWizardStep3Controller = Em.Controller.extend({
           this.get('propertiesToChange')[type].forEach(function (property) {
             var propertyName = property.name,
               stackProperty = App.configsCollection.getConfigByName(propertyName, type) || {},
+              displayName = self.getDisplayName(stackProperty.displayName, propertyName, type, serviceName),
               displayedProperty = App.ServiceConfigProperty.create({
                 name: propertyName,
-                displayName: propertyName,
                 fileName: type
               }, stackProperty, {
                 value: configs[type][propertyName],
                 category: serviceName,
+                displayName,
                 isEditable: Boolean(stackProperty.isEditable !== false && !property.isSecure)
               });
             displayedConfigs.push(displayedProperty);
@@ -381,6 +393,23 @@ App.ReassignMasterWizardStep3Controller = Em.Controller.extend({
     });
   },
 
+  getDisplayName: function (stackDisplayName, propertyName, type, serviceName) {
+    let displayName = stackDisplayName || propertyName;
+    const keys = Em.keys(this.get('propertiesToChange'));
+    for (let i = 0; i < keys.length; i++) {
+      const fileName = keys[i],
+          service = App.config.get('serviceByConfigTypeMap')[fileName];
+      if (fileName !== type && service && service.get('serviceName') === serviceName) {
+        const configs = this.get('propertiesToChange')[fileName];
+        if (configs.someProperty('name', propertyName)) {
+          displayName = `${type}/${propertyName}`;
+          break;
+        }
+      }
+    }
+    return displayName;
+  },
+
   onLoadConfigs: function (data) {
     // Find hawq-site.xml location
     var hawqSiteIndex = -1;
@@ -482,7 +511,7 @@ App.ReassignMasterWizardStep3Controller = Em.Controller.extend({
       if (additionalConfigs.hasOwnProperty(site)) {
         for (var property in additionalConfigs[site]) {
           if (additionalConfigs[site].hasOwnProperty(property)) {
-            if (App.get('isHaEnabled') && componentName === 'NAMENODE' && (property === 'fs.defaultFS' || property === 'dfs.namenode.rpc-address')) continue;
+            if (App.get('isHaEnabled') && componentName === 'NAMENODE' && (['fs.defaultFS', 'dfs.namenode.rpc-address', 'dfs.namenode.http-address', 'dfs.namenode.https-address'].contains(property))) continue;
 
             configs[site][property] = additionalConfigs[site][property].replace('<replace-value>', replaceValue);
             if (!this.get('propertiesToChange').hasOwnProperty(site)) {
@@ -543,8 +572,22 @@ App.ReassignMasterWizardStep3Controller = Em.Controller.extend({
   _getNnInitializerSettings: function (configs) {
     var ret = {};
     if (App.get('isHaEnabled')) {
-      ret.namespaceId = configs['hdfs-site']['dfs.nameservices'];
-      ret.suffix = (configs['hdfs-site']['dfs.namenode.http-address.' + ret.namespaceId + '.nn1'].indexOf(this.get('content.reassignHosts.source')) != -1) ? 'nn1' : 'nn2';
+      const configsObject = configs['hdfs-site'],
+        nameSpaces = configsObject['dfs.nameservices'].split(','),
+        nameSpacesCount = nameSpaces.length,
+        propertyNames = Object.keys(configsObject);
+      for (let i = 0; i < nameSpacesCount; i++) {
+        const nameSpace = nameSpaces[i],
+          propertyNameStart = `dfs.namenode.http-address.${nameSpace}.`,
+          httpAddressPropertiesNames = propertyNames.filter(propertyName => propertyName.startsWith(propertyNameStart)),
+          matchingPropertyName = httpAddressPropertiesNames.find(propertyName => configsObject[propertyName].startsWith(this.get('content.reassignHosts.source')));
+        if (matchingPropertyName) {
+          const nameNodeSuffixMatch = matchingPropertyName.match(new RegExp(`${propertyNameStart}(\\w+)`));
+          ret.namespaceId = nameSpace;
+          ret.suffix = nameNodeSuffixMatch && nameNodeSuffixMatch[1];
+          break;
+        }
+      }
     }
     return ret;
   },
