@@ -250,7 +250,16 @@ App.WizardStep6Controller = Em.Controller.extend(App.HostComponentValidationMixi
     this.get('hosts').forEach(function (host) {
       host.checkboxes.filterProperty('isInstalled', false).forEach(function (checkbox) {
         if (checkbox.component === component) {
-          Em.set(checkbox, 'checked', checked);
+          if (!checkbox.isDisabled) {
+            var newCheckValue = checked;
+            Em.set(checkbox, 'checked', newCheckValue);
+            Em.run.next(() => {
+              var input = document.getElementById(checkbox.uId);
+              if (input && input.checked !== newCheckValue) {
+                input.checked = newCheckValue;
+              }
+            });
+          }
         }
       });
     });
@@ -302,9 +311,11 @@ App.WizardStep6Controller = Em.Controller.extend(App.HostComponentValidationMixi
     else if (this.get('isAddServiceWizard')) services = installedServices.concat(selectedServices);
 
     var headers = Em.A([]);
+    let doHideOzoneDataNodes = !!services.findProperty('serviceName', 'HDFS');
     services.forEach(function (stackService) {
       stackService.get('serviceComponents').forEach(function (serviceComponent) {
-        if (serviceComponent.get('isShownOnInstallerSlaveClientPage')) {
+        let hideComponent = serviceComponent.get('componentName') === 'OZONE_DATANODE' ? doHideOzoneDataNodes : false;
+        if (serviceComponent.get('isShownOnInstallerSlaveClientPage') && !hideComponent) {
           headers.pushObject(Em.Object.create({
             name: serviceComponent.get('componentName'),
             label: App.format.role(serviceComponent.get('componentName'), false),
@@ -339,6 +350,7 @@ App.WizardStep6Controller = Em.Controller.extend(App.HostComponentValidationMixi
     }
   },
 
+
   /**
    * Returns list of new hosts
    *
