@@ -29,18 +29,15 @@ require('mappers/repository_version_mapper');
 require('mappers/quicklinks_mapper');
 require('mappers/hosts_mapper');
 require('mappers/cluster_mapper');
-require('mappers/racks_mapper');
 require('mappers/users_mapper');
 require('mappers/service_mapper');
 require('mappers/service_metrics_mapper');
-require('mappers/target_cluster_mapper');
 require('mappers/components_state_mapper');
 require('mappers/alert_definitions_mapper');
 require('mappers/alert_definition_summary_mapper');
 require('mappers/alert_instances_mapper');
 require('mappers/alert_groups_mapper');
 require('mappers/alert_notification_mapper');
-require('mappers/root_service_mapper');
 require('mappers/widget_mapper');
 require('mappers/widget_layout_mapper');
 require('mappers/stack_upgrade_history_mapper');
