@@ -143,17 +143,26 @@ App.HostComponent = DS.Model.extend({
     return !App.get('components.nonHDP').contains(this.get('componentName'));
   }.property('componentName', 'App.components.nonHDP'),
 
+  /**
+   * @type {number}
+   */
+  warningCount: 0,
+  /**
+   * @type {number}
+   */
+  criticalCount: 0,
+
   /**
    * Does component have Critical Alerts
    * @type {boolean}
    */
-  hasCriticalAlerts: false,
+  hasCriticalAlerts: Em.computed.gte('criticalCount', 0),
 
   /**
    * Number of the Critical and Warning alerts for current component
    * @type {number}
    */
-  alertsCount: 0,
+  alertsCount: Em.computed.sumProperties('warningCount', 'criticalCount'),
 
   statusClass: function () {
     return this.get('isActive') ? this.get('workStatus') : 'icon-medkit';
@@ -347,6 +356,16 @@ App.HostComponentActionMap = {
         hasSubmenu: hasMultipleMasterComponentGroups,
         submenuOptions: hasMultipleMasterComponentGroups ? this.getMastersSubmenu(ctx, 'restartCertainHostComponents') : []
       },
+      //Ongoing feature. Will later replace RESTART_ALL
+      RESTART_SERVICE: {
+        action: 'restartServiceAllComponents',
+        context: ctx.get('serviceName'),
+        label: Em.I18n.t('restart.service.rest.context').format(ctx.get('displayName')),
+        cssClass: 'glyphicon glyphicon-time',
+        disabled: false,
+        hasSubmenu: true,
+        submenuOptions: ctx.get('controller.restartOptions')
+      },
       RESTART_NAMENODES: {
         action: '',
         label: Em.I18n.t('rollingrestart.dialog.title').format(pluralize(App.format.role('NAMENODE', false))),
@@ -554,7 +573,13 @@ App.HostComponentActionMap = {
         action: 'openNameNodeFederationWizard',
         label: Em.I18n.t('admin.nameNodeFederation.button.enable'),
         cssClass: 'icon icon-sitemap',
-        disabled: !App.get('isHaEnabled')
+        disabled: !App.get('isHaEnabled') || App.get('allHostNames.length') < 4
+      },
+      TOGGLE_RBF_FEDERATION: {
+        action: 'openRouterFederationWizard',
+        label: Em.I18n.t('admin.routerFederation.button.enable'),
+        cssClass: 'icon icon-sitemap',
+        disabled: !App.get('hasNameNodeFederation')
       },
       UPDATE_REPLICATION: {
         action: 'updateHBaseReplication',
