@@ -284,15 +284,15 @@ App.Router = Em.Router.extend({
     var dfd = $.Deferred();
     var self = this;
     var auth = App.db.getAuthenticated();
-    this.getClusterDataRequest().complete(function (xhr) {
-      if (xhr.state() === 'resolved') {
+    this.getClusterDataRequest().always(function (xhr, textStatus, jqXHRorErrorThrown) {
+      if (xhr && textStatus == 'success') {
         // if server knows the user and user authenticated by UI
         if (auth) {
           dfd.resolve(self.get('loggedIn'));
           // if server knows the user but UI don't, check the response header
           // and try to authorize
-        } else if (xhr.getResponseHeader('User')) {
-          var user = xhr.getResponseHeader('User');
+        } else if (jqXHRorErrorThrown.getResponseHeader('User')) {
+          var user = jqXHRorErrorThrown.getResponseHeader('User');
           App.ajax.send({
             name: 'router.afterLogin',
             sender: self,
@@ -421,6 +421,7 @@ App.Router = Em.Router.extend({
     App.ajax.send({
       name: 'router.login',
       sender: this,
+      dataType:'text',
       data: {
         auth: "Basic " + hash,
         usr: usr,
@@ -665,7 +666,7 @@ App.Router = Em.Router.extend({
         }),
         sortedMappedVersions = mappedVersions.sort(),
         latestVersion = sortedMappedVersions[sortedMappedVersions.length-1].replace(/[^\d.-]/g, '');
-      window.location.replace(App.appURLRoot +  'views/ADMIN_VIEW/' + latestVersion + '/INSTANCE/#/');
+      App.replaceWindowLocation(App.appURLRoot +  'views/ADMIN_VIEW/' + latestVersion + '/INSTANCE/#/')
     }
   },
 
