@@ -37,7 +37,7 @@ module.exports = Em.Route.extend(App.RouterRedirections, {
         var applicationController = App.router.get('applicationController');
         App.router.get('experimentalController').loadSupports().complete(function () {
           applicationController.startKeepAlivePoller();
-          clusterController.loadAmbariProperties().complete(function () {
+          clusterController.loadAmbariProperties().then(function () {
             App.router.get('mainViewsController').loadAmbariViews();
             clusterController.loadClusterName(false).done(function () {
               $('#main').removeClass('install-wizard-content');
@@ -59,7 +59,7 @@ module.exports = Em.Route.extend(App.RouterRedirections, {
                 }
                 else {
                   Em.run.next(function () {
-                    App.clusterStatus.updateFromServer().complete(function () {
+                    App.clusterStatus.updateFromServer().then(function () {
                       var currentClusterStatus = App.clusterStatus.get('value');
                       if (router.get('currentState.parentState.name') !== 'views' && router.get('currentState.parentState.name') !== 'view'
                           && currentClusterStatus && self.get('installerStatuses').contains(currentClusterStatus.clusterState)) {
@@ -893,6 +893,8 @@ module.exports = Em.Route.extend(App.RouterRedirections, {
 
     enableNameNodeFederation: require('routes/namenode_federation_routes'),
 
+    enableRouterFederation : require('routes/dfsrouter_federation_routes'),
+
     addHawqStandby: require('routes/add_hawq_standby_routes'),
 
     removeHawqStandby: require('routes/remove_hawq_standby_routes'),
