@@ -27,4 +27,13 @@ require("templates/main/service/widgets/create/step2_number");
 require("templates/main/service/widgets/create/step2_template");
 require("templates/main/service/widgets/create/step2_graph");
 require('templates/common/configs/widgets/controls');
+require('templates/common/configs/widgets/controls/create_override');
+require('templates/common/configs/widgets/controls/remove_override');
+require('templates/common/configs/widgets/controls/final');
+require('templates/common/configs/widgets/controls/set_recommended');
+require('templates/common/configs/widgets/controls/undo');
+require('templates/common/configs/widgets/controls/edit');
 require('templates/common/configs/widgets/config_label');
+require('templates/common/configs/configs_comparison_row');
+require('templates/common/configs/configs_comparison_cell');
+require('templates/wizard/installer_cancel_button');
