@@ -254,6 +254,7 @@ App.HostPopup = Em.Object.create({
       return App.ajax.send({
         name: 'background_operations.abort_request',
         sender: self,
+        dataType:'text',
         data: {
           requestId: serviceInfo.get('id'),
           requestName: requestName,
@@ -316,7 +317,8 @@ App.HostPopup = Em.Object.create({
       serviceName: serviceName,
       dataSourceController: controller,
       isBackgroundOperations: isBackgroundOperations,
-      inputData: controller.get("services")
+      inputData: controller.get("services"),
+      servicesInfo: []
     });
 
     if (isBackgroundOperations) {
