@@ -23,6 +23,7 @@ require('views/application');
 require('views/common/breadcrumbs_view');
 require('views/common/clock_view');
 require('views/common/checkbox_view');
+require('views/common/alert_badge');
 require('views/common/log_search_ui_link_view');
 require('views/common/log_file_search_view');
 require('views/common/log_tail_view');
@@ -119,6 +120,7 @@ require('views/common/helpers/pluralize_view');
 require('views/common/helpers/status_icon_view');
 require('views/common/chosen_plugin');
 require('views/common/export_metrics_menu_view');
+require('views/common/service_restart_view');
 require('views/login');
 require('views/main');
 require('views/main/menu');
@@ -222,6 +224,11 @@ require('views/main/admin/federation/step1_view');
 require('views/main/admin/federation/step2_view');
 require('views/main/admin/federation/step3_view');
 require('views/main/admin/federation/step4_view');
+require('views/main/admin/federation/routerBasedFederation/wizard_view');
+require('views/main/admin/federation/routerBasedFederation/step1_view');
+require('views/main/admin/federation/routerBasedFederation/step2_view');
+require('views/main/admin/federation/routerBasedFederation/step3_view');
+require('views/main/admin/federation/routerBasedFederation/step4_view');
 require('views/main/admin/serviceAccounts_view');
 require('views/main/admin/stack_upgrade/upgrade_wizard_view');
 require('views/main/admin/stack_upgrade/upgrade_version_box_view');
@@ -234,6 +241,7 @@ require('views/main/admin/stack_upgrade/services_view');
 require('views/main/admin/stack_upgrade/versions_view');
 require('views/main/admin/stack_upgrade/menu_view');
 require('views/main/admin/stack_upgrade/failed_hosts_modal_view');
+require('views/main/admin/stack_upgrade/custom_cluster_checks/custom_cluster_checks_view');
 require('views/main/admin/stack_and_upgrade_view');
 
 require('views/main/admin/kerberos');
