@@ -18,6 +18,7 @@
 var App = require('app');
 var string_utils = require('utils/string_utils');
 var dateUtils = require('utils/date/date');
+var chartUtils = require('utils/chart_utils');
 
 /**
  * @class
@@ -670,7 +671,7 @@ App.ChartLinearTimeView = Ember.View.extend(App.ExportMetricsMixin, {
    */
   dataPreProcess: function (data) {
     var self = this;
-    var palette = new Rickshaw.Color.Palette({scheme: 'munin'});
+    var palette = new Rickshaw.Color.Palette({scheme: chartUtils.getColorSchemeForChart(data.length)});
     // Format series for display
     var series_min_length = 100000000;
     data.forEach(function (series) {
