@@ -17,6 +17,7 @@
  */
 
 var App = require('app');
+var chartUtils = require('utils/chart_utils');
 
 App.GaugeWidgetView = Em.View.extend(App.WidgetMixin, {
   templateName: require('templates/common/widget/gauge_widget'),
@@ -87,7 +88,7 @@ App.GaugeWidgetView = Em.View.extend(App.WidgetMixin, {
     centerTextColor: Em.computed.alias('contentColor'),
 
     palette: new Rickshaw.Color.Palette({
-      scheme: ['#FFFFFF', '#D6DDDF'].reverse()
+      scheme: chartUtils.getColorSchemeForGaugeWidget()
     }),
 
     data: function () {
@@ -105,15 +106,15 @@ App.GaugeWidgetView = Em.View.extend(App.WidgetMixin, {
       var color_orange = App.healthStatusOrange;
       if ((isNaN(threshold1) && isNaN(threshold2)) || (isNaN(threshold1) && used <= threshold2) || (isNaN(threshold2) && used <= threshold1) || (!isNaN(threshold2) && (threshold1 > threshold2) && (used > threshold1)) || (!isNaN(threshold2) && (threshold1 < threshold2) && (used <= threshold1))) {
         this.set('palette', new Rickshaw.Color.Palette({
-          scheme: ['#DDDDDD', color_green].reverse()
+          scheme: chartUtils.getColorSchemeForGaugeWidget(color_green)
         }));
       } else if ((!isNaN(threshold2) && used.isInRange(threshold1, threshold2)) || (isNaN(threshold2) && used > threshold1)) {
         this.set('palette', new Rickshaw.Color.Palette({
-          scheme: ['#DDDDDD', color_orange].reverse()
+          scheme: chartUtils.getColorSchemeForGaugeWidget(color_orange)
         }));
       } else {
         this.set('palette', new Rickshaw.Color.Palette({
-          scheme: ['#DDDDDD', color_red].reverse()
+          scheme: chartUtils.getColorSchemeForGaugeWidget(color_red)
         }));
       }
       return App.widgetContentColor;
