@@ -26,13 +26,20 @@ App.LoginView = Em.View.extend({
     didInsertElement: function(){
       this._super();
       this.$().focus();
-    },
-    classNames: ['login-user-name']
+    }
   }),
   passTextField : Em.TextField.extend({
     insertNewline: function(){
       this.get("controller").submit();
     },
-    classNames: ['login-user-password']
+    didInsertElement: function(){
+      var self = this;
+      this._super();
+      this.$().attr('autocomplete', 'new-password');
+      // Hack to off autocomplete
+      this.$().on('focus', function () {
+        self.$().attr('type', 'password');
+      });
+    }
   })
-});
\ No newline at end of file
+});
