@@ -31,6 +31,6 @@ App.AddHawqStandbyWizardStep4View = App.HighAvailabilityProgressPageView.extend(
 
   submitButtonText: Em.I18n.t('common.complete'),
 
-  labelWidth: 'span5'
+  labelWidth: 'col-md-5'
 
 });
