@@ -169,8 +169,8 @@ App.MainDashboardWidgetsView = Em.View.extend(App.Persist, App.LocalStorage, App
     } else {
       this.addObserver('App.router.clusterController.isHDFSNameSpacesLoaded', this, 'setWidgetGroups');
     }
-    this.loadWidgetsSettings().complete(() => {
-      this.get('widgetGroupsDeferred').done(() => {
+    this.loadWidgetsSettings().then(() => {
+      this.get('widgetGroupsDeferred').then(() => {
         if (this.get('isDestroyed')) return;
         this.checkServicesChange();
         this.renderWidgets();
@@ -540,7 +540,7 @@ App.MainDashboardWidgetsView = Em.View.extend(App.Persist, App.LocalStorage, App
   },
 
   /**
-   * check if stack has upgraded from HDP 1.0 to 2.0 OR add/delete services.
+   * Check if any services with widgets were added or deleted.
    * Update the value on server if true.
    */
   checkServicesChange: function () {
@@ -561,6 +561,12 @@ App.MainDashboardWidgetsView = Em.View.extend(App.Persist, App.LocalStorage, App
           newValue[state].push(id);
         }
       });
+      userPreferences[state].forEach(id => {
+        if (!defaultPreferences.visible.contains(id) && !defaultPreferences.hidden.contains(id)) {
+          isChanged = true;
+          newValue[state] = newValue[state].without(id);
+        }
+      });
       Object.keys(defaultPreferences.groups).forEach(groupName => {
         const groupPreferences = defaultPreferences.groups[groupName],
           subGroupForAllItems = groupPreferences['*'],
