@@ -51,6 +51,11 @@ App.MainServiceInfoSummaryView = Em.View.extend({
    */
   clientObj: [],
   clientsLength: 0,
+  
+  /**
+   * @type {boolean}
+   */
+  hasComponents: Em.computed.or('mastersLength', 'slavesLength', 'clientsLength'),
 
   /**
    *  @property {String} templatePathPrefix - base path for custom templates
@@ -351,13 +356,10 @@ App.MainServiceInfoSummaryView = Em.View.extend({
   componentsCount: null,
   hostsCount: null,
 
-  alertsCount: Em.computed.alias('controller.content.alertsCount'),
-
-  hasNoAlerts: Em.computed.equal('alertsCount', 0),
-
-  hasCriticalAlerts: Em.computed.alias('controller.content.hasCriticalAlerts'),
-
-  hasNonCriticalAlertsOnly: Em.computed.and('!hasNoAlerts', '!hasCriticalAlerts'),
+  /**
+   * @type {boolean}
+   */
+  shouldShowNoneCount: true,
 
   /**
    * Define if service has alert definitions defined
