@@ -34,8 +34,6 @@ describe('App.KerberosWizardStep4Controller', function() {
     c = getController();
   });
 
-  App.TestAliases.testAsComputedEqual(getController(), 'isWithinAddService', 'wizardController.name', 'addServiceController');
-
   describe("#clearStep()", function () {
 
     beforeEach(function() {
@@ -213,85 +211,6 @@ describe('App.KerberosWizardStep4Controller', function() {
     });
   });
 
-  describe('#setStepConfigs', function() {
-    describe('Add Service Wizard', function() {
-
-      var properties = Em.A([
-        Em.Object.create({ name: 'realm', value: '', serviceName: 'Cluster' }),
-        Em.Object.create({ name: 'spnego_keytab', value: 'spnego_keytab_value', serviceName: 'Cluster', isEditable: true }),
-        Em.Object.create({ name: 'hdfs_keytab', value: '', serviceName: 'HDFS', observesValueFrom: 'spnego_keytab', isEditable: true }),
-        Em.Object.create({ name: 'falcon_keytab', value: 'falcon_keytab_value', serviceName: 'FALCON', isEditable: true }),
-        Em.Object.create({ name: 'mapreduce_keytab', value: 'mapreduce_keytab_value', serviceName: 'MAPREDUCE2', isEditable: true })
-      ]);
-
-      var res;
-      var controller;
-      before(function() {
-        sinon.stub(App.StackService, 'find').returns([
-          Em.Object.create({
-            serviceName: 'KERBEROS',
-            configCategories: [],
-            configTypeList: []
-          }),
-          Em.Object.create({
-            serviceName: 'HDFS',
-            configCategories: [],
-            configTypeList: []
-          }),
-          Em.Object.create({
-            serviceName: 'MAPREDUCE2',
-            configTypeList: []
-          })
-        ]);
-        sinon.stub(App.Service, 'find').returns([
-          Em.Object.create({
-            serviceName: 'HDFS'
-          }),
-          Em.Object.create({
-            serviceName: 'KERBEROS'
-          })
-        ]);
-        controller = App.KerberosWizardStep4Controller.create({
-          selectedServiceNames: ['FALCON', 'MAPREDUCE2'],
-          installedServiceNames: ['HDFS', 'KERBEROS'],
-          wizardController: Em.Object.create({
-            name: 'addServiceController',
-            getDBProperty: function() {
-              return Em.A([
-                Em.Object.create({ name: 'realm', value: 'realm_value' })
-              ]);
-            },
-            loadCachedStepConfigValues : function() {
-              return null;
-            }
-          })
-        });
-        sinon.stub(App.router, 'get').withArgs('mainAdminKerberosController.isManualKerberos').returns(false);
-        var stepConfigs = controller.setStepConfigs(properties);
-        res = stepConfigs[0].get('configs').concat(stepConfigs[1].get('configs'));
-      });
-
-      Em.A([
-        { name: 'spnego_keytab', e: false },
-        { name: 'falcon_keytab', e: true },
-        { name: 'hdfs_keytab', e: false },
-        { name: 'mapreduce_keytab', e: true }
-      ]).forEach(function(test) {
-        it('Add Service: property `{0}` should be {1} editable'.format(test.name, !!test.e ? '' : 'not '), function() {
-          expect(res.findProperty('name', test.name).get('isEditable')).to.eql(test.e);
-        });
-      });
-
-      after(function() {
-        controller.destroy();
-        controller = null;
-        App.StackService.find.restore();
-        App.Service.find.restore();
-        App.router.get.restore();
-      });
-    });
-  });
-
   describe("#createCategoryForServices()", function() {
     var controller = App.KerberosWizardStep4Controller.create({
       wizardController: {
@@ -336,66 +255,6 @@ describe('App.KerberosWizardStep4Controller', function() {
     });
   });
 
-  describe('#loadStep', function() {
-    var controller;
-    describe('skip "Configure Identities" step. ', function() {
-      beforeEach(function() {
-        controller = App.KerberosWizardStep4Controller.create({});
-        this.wizardController = App.AddServiceController.create({});
-        controller.set('wizardController', this.wizardController);
-        sinon.stub(controller, 'clearStep').returns(true);
-        sinon.stub(controller, 'getDescriptor').returns({ then: function() { return { always: function() {}}}});
-        sinon.stub(controller, 'setStepConfigs').returns(true);
-        sinon.stub(App.router, 'send').withArgs('next');
-      });
-
-      afterEach(function() {
-        controller.clearStep.restore();
-
-        controller.setStepConfigs.restore();
-        App.router.send.restore();
-      });
-
-      var tests = [
-        {
-          securityEnabled: true,
-          stepSkipped: false
-        },
-        {
-          securityEnabled: false,
-          stepSkipped: true
-        }
-      ];
-
-      tests.forEach(function(test) {
-        var message = 'Security {0} configure identities step should be {1}'.format(!!test.securityEnabled ? 'enabled' : 'disabled', !!test.stepSkipped ? 'skipped' : 'not skipped');
-        describe(message, function() {
-
-          beforeEach(function () {
-            sinon.stub(App, 'get').withArgs('isKerberosEnabled').returns(test.securityEnabled);
-            this.wizardController.checkSecurityStatus();
-            controller.loadStep();
-          });
-
-          afterEach(function () {
-            App.get.restore();
-          });
-
-          it('`send` is ' + (test.stepSkipped ? '' : 'not') + ' called with `next`', function () {
-            expect(App.router.send.calledWith('next')).to.be.eql(test.stepSkipped);
-          });
-
-        });
-      }, this);
-
-      it('step should not be disabled for Add Kerberos wizard', function() {
-        controller.set('wizardController', App.KerberosWizardController.create({}));
-        controller.loadStep();
-        expect(App.router.send.calledWith('next')).to.be.false;
-      });
-    });
-  });
-
   describe('#mergeDescriptorToConfigurations', function() {
     var genAppConfigProperty = function(name, fileName, value) {
       return App.ServiceConfigProperty.create({
@@ -598,35 +457,15 @@ describe('App.KerberosWizardStep4Controller', function() {
     };
 
     beforeEach(function() {
-      c.reopen({
-        isWithinAddService: true,
-        selectedServiceNames: []
-      });
-      sinon.stub(c, 'storeClusterDescriptorStatus');
       sinon.stub(c, 'loadClusterDescriptorConfigs').returns(mock);
       sinon.stub(mock, 'then');
     });
 
     afterEach(function() {
       c.loadClusterDescriptorConfigs.restore();
-      c.storeClusterDescriptorStatus.restore();
       mock.then.restore();
     });
 
-    it("App.ajax.send should be called", function() {
-      c.getDescriptor();
-      var args = testHelpers.findAjaxRequest('name', 'admin.kerberize.cluster_descriptor_artifact');
-      expect(args[0]).to.be.eql({
-        sender: c,
-        name: 'admin.kerberize.cluster_descriptor_artifact'
-      });
-    });
-
-    it("storeClusterDescriptorStatus should be called", function() {
-      c.getDescriptor();
-      expect(c.storeClusterDescriptorStatus.calledOnce).to.be.true;
-    });
-
     it("loadClusterDescriptorConfigs should be called", function() {
       c.getDescriptor();
       expect(c.loadClusterDescriptorConfigs.calledOnce).to.be.true;
@@ -637,11 +476,6 @@ describe('App.KerberosWizardStep4Controller', function() {
       expect(mock.then.calledOnce).to.be.true;
     });
 
-    it("then should be called, isWithinAddService is false", function() {
-      c.set('isWithinAddService', false);
-      c.getDescriptor();
-      expect(mock.then.calledOnce).to.be.true;
-    });
   });
 
   describe("#tweakConfigProperty()", function () {
