@@ -190,13 +190,16 @@ describe('App.WizardStep4Controller', function () {
         beforeEach(function () {
           controller.clear();
           Object.keys(testCase.condition).forEach(function (id) {
-            controller.pushObject(App.StackService.createRecord({
+            controller.pushObject(Em.Object.create({
               serviceName: id,
               isSelected: testCase.condition[id],
               canBeSelected: true,
               isInstalled: false,
               coSelectedServices: function() {
-                return App.StackService.coSelected[this.get('serviceName')] || [];
+                var coSelected = {
+                  'YARN': ['MAPREDUCE2']
+                };
+                return coSelected[this.get('serviceName')] || [];
               }.property('serviceName')
             }));
           });
