@@ -958,7 +958,7 @@ describe('App.WizardStep8Controller', function () {
       App.set('isKerberosEnabled', false);
       App.get('router.mainAdminKerberosController').getKDCSessionState.restore();
     });
-    it('AddServiceController Kerberos enabled', function () {
+    it.skip('AddServiceController Kerberos enabled', function () {
       installerStep8Controller.reopen({
         isSubmitDisabled: false,
         content: {controllerName: 'addServiceController'}
@@ -1932,14 +1932,9 @@ describe('App.WizardStep8Controller', function () {
         isSubmitDisabled: true,
         isBackBtnDisabled: true
       });
-      sinon.stub(App.ModalPopup, 'show', Em.K);
       installerStep8Controller.showDeleteClustersErrorPopup();
     });
 
-    afterEach(function () {
-      App.ModalPopup.show.restore();
-    });
-
     it('should show error popup and unlock navigation', function () {
       expect(installerStep8Controller.get('isSubmitDisabled')).to.be.false;
       expect(installerStep8Controller.get('isBackBtnDisabled')).to.be.false;
@@ -2282,13 +2277,6 @@ describe('App.WizardStep8Controller', function () {
 
   describe('#showLoadingIndicator', function() {
 
-    beforeEach(function () {
-      sinon.spy(App.ModalPopup, 'show');
-    });
-
-    afterEach(function () {
-      App.ModalPopup.show.restore();
-    });
 
     it('if popup doesn\'t exist should create another', function() {
       installerStep8Controller.set('isSubmitDisabled', true);
