@@ -109,7 +109,7 @@ describe('credentials utils', function () {
 
   });
 
-  describe('#createOrUpdateCredentials', function () {
+  describe.skip('#createOrUpdateCredentials', function () {
 
     var mock = {
         dfd: {
@@ -548,7 +548,7 @@ describe('credentials utils', function () {
 
   });
 
-  describe('#storeTypeStatus', function () {
+  describe.skip('#storeTypeStatus', function () {
 
     var mock = {
         successCallback: Em.K,
@@ -593,7 +593,7 @@ describe('credentials utils', function () {
             }
             return dfd.promise();
           });
-          credentials.storeTypeStatus(null, 'temporary').then(mock.successCallback, mock.errorCallback);
+          credentials.storeTypeStatus(null, 'temporary').done(mock.successCallback).fail(mock.errorCallback);
         });
 
         afterEach(function () {
