@@ -25,7 +25,9 @@ describe('Ember.computed macros', function () {
       someRandomTestingKey: function () {
         return this.get('someAnotherKey');
       }.property('someAnotherKey'),
-      someAnotherKey: ''
+      someAnotherKey: '',
+      appProp1: 1,
+      appProp2: 2
     });
   });
 
@@ -222,6 +224,44 @@ describe('Ember.computed macros', function () {
 
   });
 
+  describe('#ifThenElseByKeys', function () {
+
+    beforeEach(function () {
+      App.set('someAnotherKey', true);
+      this.obj = Em.Object.create({
+        prop1: true,
+        prop2: Em.computed.ifThenElseByKeys('prop1', 'prop4', 'prop5'),
+        prop3: Em.computed.ifThenElseByKeys('App.someRandomTestingKey', 'App.appProp1', 'App.appProp2'),
+        prop4: 1,
+        prop5: 2
+      });
+    });
+
+    it('`1` if `prop1` is true', function () {
+      expect(this.obj.get('prop2')).to.equal(1);
+    });
+
+    it('`0` if `prop1` is false', function () {
+      this.obj.set('prop1', false);
+      expect(this.obj.get('prop2')).to.equal(2);
+    });
+
+    it('prop2 dependent keys are valid', function () {
+      expect(Em.meta(this.obj).descs.prop2._dependentKeys).to.eql(['prop1', 'prop4', 'prop5']);
+    });
+
+    it('prop3 depends on App.* key', function () {
+      expect(this.obj.get('prop3')).to.equal(1);
+      App.set('someAnotherKey', false);
+      expect(this.obj.get('prop3')).to.equal(2);
+    });
+
+    it('prop3 dependent keys are valid', function () {
+      expect(Em.meta(this.obj).descs.prop3._dependentKeys).to.eql(['App.someRandomTestingKey', 'App.appProp1', 'App.appProp2']);
+    });
+
+  });
+
   describe('#and', function () {
 
     beforeEach(function () {
@@ -1195,6 +1235,42 @@ describe('Ember.computed macros', function () {
 
   });
 
+  describe('#existsInByKey', function () {
+
+    beforeEach(function () {
+      this.obj = Em.Object.create({
+        prop1: 'v1',
+        prop2: Em.computed.existsInByKey('prop1', 'prop3'),
+        prop3: ['v1', 'v2']
+      });
+    });
+
+    it('`true` if dependent value is in the array', function () {
+      expect(this.obj.get('prop2')).to.be.true;
+    });
+
+    it('`true` if dependent value is in the array (2)', function () {
+      this.obj.set('prop1', 'v2');
+      expect(this.obj.get('prop2')).to.be.true;
+    });
+
+    it('`false` if dependent value is not in the array', function () {
+      this.obj.set('prop1', 'v3');
+      expect(this.obj.get('prop2')).to.be.false;
+    });
+
+    it('`false` if dependent value is not in the array (2)', function () {
+      this.obj.set('prop1', 'v1');
+      this.obj.set('prop3', ['v2', 'v3']);
+      expect(this.obj.get('prop2')).to.be.false;
+    });
+
+    it('prop2 dependent keys are valid', function () {
+      expect(Em.meta(this.obj).descs.prop2._dependentKeys).to.eql(['prop1', 'prop3.[]']);
+    });
+
+  });
+
   describe('#percents', function () {
 
     beforeEach(function () {
@@ -1452,6 +1528,42 @@ describe('Ember.computed macros', function () {
 
   });
 
+  describe('#notExistsInByKey', function () {
+
+    beforeEach(function () {
+      this.obj = Em.Object.create({
+        prop1: 'v1',
+        prop2: Em.computed.notExistsInByKey('prop1', 'prop3'),
+        prop3: ['v1', 'v2']
+      });
+    });
+
+    it('`false` if dependent value is in the array', function () {
+      expect(this.obj.get('prop2')).to.be.false;
+    });
+
+    it('`false` if dependent value is in the array (2)', function () {
+      this.obj.set('prop1', 'v2');
+      expect(this.obj.get('prop2')).to.be.false;
+    });
+
+    it('`true` if dependent value is not in the array', function () {
+      this.obj.set('prop1', 'v3');
+      expect(this.obj.get('prop2')).to.be.true;
+    });
+
+    it('`true` if dependent value is not in the array (2)', function () {
+      this.obj.set('prop1', 'v1');
+      this.obj.set('prop3', ['v2', 'v3']);
+      expect(this.obj.get('prop2')).to.be.true;
+    });
+
+    it('prop2 dependent keys are valid', function () {
+      expect(Em.meta(this.obj).descs.prop2._dependentKeys).to.eql(['prop1', 'prop3.[]']);
+    });
+
+  });
+
   describe('#firstNotBlank', function () {
 
     beforeEach(function () {
