@@ -36,8 +36,7 @@ describe('App.HBaseAverageLoadView', function() {
       },
       e: {
         isNA: false,
-        content: '1',
-        hiddenInfo: 1
+        content: '1'
       }
     },
     {
@@ -46,8 +45,7 @@ describe('App.HBaseAverageLoadView', function() {
       },
       e: {
         isNA: false,
-        content: '10',
-        hiddenInfo: 10
+        content: '10'
       }
     },
     {
@@ -56,8 +54,7 @@ describe('App.HBaseAverageLoadView', function() {
       },
       e: {
         isNA: false,
-        content: '0',
-        hiddenInfo: 0
+        content: '0'
       }
     },
     {
@@ -66,8 +63,7 @@ describe('App.HBaseAverageLoadView', function() {
       },
       e: {
         isNA: true,
-        content: Em.I18n.t('services.service.summary.notAvailable'),
-        hiddenInfo: null
+        content: Em.I18n.t('services.service.summary.notAvailable')
       }
     }
   ];
@@ -75,9 +71,6 @@ describe('App.HBaseAverageLoadView', function() {
   tests.forEach(function(test) {
     describe('averageLoad - ' + test.model.averageLoad, function() {
       var hBaseAverageLoadView = App.HBaseAverageLoadView.create({model_type:null, model: test.model});
-      it('hiddenInfo', function() {
-        expect(hBaseAverageLoadView.get('hiddenInfo')).to.eql([Em.I18n.t('dashboard.services.hbase.averageLoadPerServer').format(test.e.hiddenInfo)]);
-      });
       it('content', function() {
         expect(hBaseAverageLoadView.get('content')).to.equal(test.e.content);
       });
