@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 """
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
@@ -521,7 +522,7 @@ if __name__ == '__main__':
   print 'The following prerequisites are required:'
   print '  * ONEFS management package must be installed'
   print '  * Ambari must be upgraded to >=v2.7.1'
-  print '  * Stack must be upgraded to HDP-3.0'
+  print '  * Stack must be upgraded to >=HDP-3.0'
   print '  * Is highly recommended to backup ambari database before you proceed.'
   conversion = Conversion(cluster, FsStorage())
   if not conversion.check_prerequisites():
