@@ -503,8 +503,9 @@ App.QueueController = Ember.ObjectController.extend({
 
     queue.set('name',name);
 
+    //new queue name has to be unique  
     foundWithName = this.store.all('queue').find(function (q) {
-      return q.get('path') === [queue.get('parentPath'),queue.get('name')].join('.');
+      return q.get('name') === queue.get('name') && q.get('path') != queue.get('path');
     });
 
     if (!Em.isEmpty(foundWithName) && queue.changedAttributes().hasOwnProperty('name')) {
